(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1150046,      20899]
NotebookOptionsPosition[   1143813,      20714]
NotebookOutlinePosition[   1144312,      20734]
CellTagsIndexPosition[   1144269,      20731]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "N-K-Modell \[Dash] Teil 1"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704872223864946`*^9, 3.670489147179757*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Dieser ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs f\[UDoubleDot]hrt in das ",
 StyleBox["N",
  FontSlant->"Italic"],
 "-",
 StyleBox["K",
  FontSlant->"Italic"],
 "-Modell nach Kauffman (1969) ein. Zuerst diskutieren wir das \
Originalbeispiel aus seiner Publikation, das auch in Abb. 5.34 und 5.35 \
dargestellt ist.\n\nDa die Sortierung der Input-Signale vorgegeben ist (bei ",
 StyleBox["K",
  FontSlant->"Italic"],
 " = 2 Inputs: 00, 01, 10, 11), kann die Boole\[CloseCurlyQuote]sche Funktion \
einfach als bin\[ADoubleDot]rer Vektor der L\[ADoubleDot]nge 4 vorgegeben \
werden."
}], "Text",
 CellChangeTimes->{{3.6771315446522655`*^9, 3.6771315536856813`*^9}, {
  3.677131594855153*^9, 3.6771316044179697`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"networkNodes", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<X\>\"", ",", " ", "\"\<Y\>\"", ",", " ", "\"\<Z\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.401338299061261*^9, 3.4013383225182323`*^9}, 
   3.401339735498317*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"updateSchemeX", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"updateSchemeY", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"updateSchemeZ", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.401338889245556*^9, 3.401338928869643*^9}, {
  3.4013394561041594`*^9, 3.4013394726537952`*^9}, {3.401339525639936*^9, 
  3.4013395286079273`*^9}}],

Cell[TextData[{
 "Mit einer Tabelle der Inputs, die sich \[UDoubleDot]ber den Befehl ",
 StyleBox["IntegerDigits",
  FontWeight->"Bold"],
 " elegant (und auf gr\[ODoubleDot]\[SZ]eres ",
 StyleBox["K",
  FontSlant->"Italic"],
 " verallgemeinerbar) erzeugen l\[ADoubleDot]sst, kann man nun diese Vektoren \
wieder als Update-Tabelle ausgeben."
}], "Text",
 CellChangeTimes->{{3.6771316842457113`*^9, 3.6771316967881336`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t0", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"IntegerDigits", "[", 
     RowBox[{"j", ",", "2", ",", "2"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.606115853615299*^9, 3.60611585588739*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677572791505074*^9}]
}, Open  ]],

Cell["In der allgemeinen Form lautet der Befehl:", "Text",
 CellChangeTimes->{{3.6771317321533957`*^9, 3.6771317420750127`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.60627201937824*^9, 3.606272021344695*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t0", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"IntegerDigits", "[", 
     RowBox[{"j", ",", "2", ",", "k"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "^", "k"}], " ", "-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.606115853615299*^9, 3.60611585588739*^9}, {
   3.606130268546578*^9, 3.606130312010041*^9}, 3.606272025177134*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677572791520674*^9}]
}, Open  ]],

Cell["Die Update-Tabelle erh\[ADoubleDot]lt man dann mit:", "Text",
 CellChangeTimes->{{3.677131759781044*^9, 3.6771317686730595`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", "t0", "]"}], ",", 
       RowBox[{"{", "updateSchemeX", "}"}]}], " ", "]"}], "]"}], ",", 
    RowBox[{"TableHeadings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Y(t)\>\"", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Z(t)\>\"", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<X(t+1)\>\"", ",", "Bold"}], "]"}]}], "}"}]}], "}"}]}], 
    ",", 
    RowBox[{"TableAlignments", "\[Rule]", "Center"}], ",", 
    RowBox[{"TableSpacing", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6061158605372353`*^9, 3.606115928455943*^9}, {
  3.6061159665132647`*^9, 3.606115982943221*^9}, {3.606121089646864*^9, 
  3.606121097436854*^9}, {3.606121198920765*^9, 3.606121203303232*^9}, {
  3.60612136161213*^9, 3.606121410896245*^9}, {3.606121496107723*^9, 
  3.6061215541527576`*^9}, {3.6061216506878*^9, 3.606121651033243*^9}, {
  3.606129391676453*^9, 3.606129430199728*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox[
       StyleBox["\<\"Y(t)\"\>",
        StripOnInput->False,
        FontWeight->Bold],
       HoldForm], 
      TagBox[
       StyleBox["\<\"Z(t)\"\>",
        StripOnInput->False,
        FontWeight->Bold],
       HoldForm], 
      TagBox[
       StyleBox["\<\"X(t+1)\"\>",
        StripOnInput->False,
        FontWeight->Bold],
       HoldForm]},
     {"0", "0", "0"},
     {"0", "1", "1"},
     {"1", "0", "0"},
     {"1", "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$, TableHeadings -> {None, {
       Style["Y(t)", Bold], 
       Style["Z(t)", Bold], 
       Style["X(t+1)", Bold]}}, TableAlignments -> Center, 
    TableSpacing -> {1, 1}]]]], "Output",
 CellChangeTimes->{3.677572791536274*^9}]
}, Open  ]],

Cell[TextData[{
 "Unser Ziel hier ist, einen Formalismus zu entwickeln, der sich sp\
\[ADoubleDot]ter auch f\[UDoubleDot]r gr\[ODoubleDot]\[SZ]ere Netzwerke und f\
\[UDoubleDot]r zuf\[ADoubleDot]llige Boole\[CloseCurlyQuote]sche Funktionen \
verwenden l\[ADoubleDot]sst. Daher erzeugen wir zuerst den Graphen. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " bietet die M\[ODoubleDot]glichkeit, \[UDoubleDot]ber den Befehl ",
 StyleBox["DegreeGraphDistribution",
  FontWeight->"Bold"],
 " Zufallsgraphen zu erzeugen, bei denen jeder Knoten einen vorgegebenen Grad \
erh\[ADoubleDot]lt. Der einzig m\[ODoubleDot]gliche Graph mit drei Knoten und \
Grad 2 entsteht \[UDoubleDot]ber:"
}], "Text",
 CellChangeTimes->{{3.677131813945339*^9, 3.6771318240073566`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g0", " ", "=", " ", 
  RowBox[{"RandomGraph", "[", 
   RowBox[{
    RowBox[{"DegreeGraphDistribution", "[", 
     RowBox[{"Table", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "3", "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6061297342104893`*^9, 3.6061297724575663`*^9}, {
  3.606129973970634*^9, 3.6061300141068068`*^9}, {3.6061301443589897`*^9, 
  3.606130146582831*^9}, {3.606133516875403*^9, 3.60613352810564*^9}, {
  3.606376132631373*^9, 3.606376135700238*^9}, {3.6238286541364307`*^9, 
  3.623828666829698*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 
      3}, {{{3, 2}, {3, 1}, {1, 3}, {1, 2}, {2, 1}, {2, 3}}, Null}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJw1VA0s3HcYvnJTPZSq2ZZ1Ldlqja1VS6PnY32l60ZWu5Sqj5lrs40udL42
s3ZhmOrqs9hpfUx81NqKQ5V+CHulNLX4OgzHMefucIfaWZUzl3bj/fknl8ub
vHl/z/s87/PYfh7pE2LA4XC++P+3/n/TK0B94e4cLr1Y/yZQTDWYcNY/OfLS
Srycz1e5bZQcLfxRKeiYl03h8nCuxmBGhr7NLVbjwSrUpQVpjLSjyHVzzxSM
KlD7+Msui92j6Jo1e9POZxK7XrVRFkePoLai36EoYwK5ukbPHXNS3D5h/m1Q
5BjqPsn5rSVNis9vDb8dKhjBavmhl2QnpLiTJ04VvTOEY+XfVaW/L0V7qkHF
auuqjX5oYP12NA84Apq39frGe2DF3vMgPCBneMwJLxh0EF4h7QOm6bTPAO0L
llLad23NMOPr7FkMqszOX+gdwJofjzkHuM7iAZNFcd3vEswvHo764U8Nzj9R
GivOdaLYVvWaVZAGG2pFXy1HP8LDq5qXw3rVaMGX9XnbINqvvmctcVSjZ2yM
46zoDg4tjoVVJM9g67VnQuurpXhYV9B5/OE0ciIc/vmr9SIIplMtDAKHcVq7
VuOUpoRSZ4VYfncQj2p8lYaTKuDv9Lt/bGkAH9yYihHun4YowRY937IfeeFy
UVLEDPTbPZ0c3SHBK6dF+2or1LAvOTjrjroTM64a7TrYpQFPs9dz52Mf45ut
Hyt8Z2ahOmBwu2HPQ2wKTRiKXZqDbsaH6S9O6QmmCgxgfGW4+KTrLynQmPFp
UdxdsKJVoDvju+xpZJajhxJXSX/gciuD4tKU+ArTyzTw3rtlTUrcyvSszw6J
zx1W4i6md0FNu73LpBJt2T3ksdqM+rFqs5/dE5fNe87uTW9I7x1l9yhieHjs
XrkM76fsnhPYPj3s3vV5tO+F5fK3/jWYgfhuffWcehhPXu5reyGdghOJovZb
PYP4xnwrV9CsAhsHM/6ZawPo9kAYlylWgh3aews9+jCi0j9MKFbAweokf6Om
buR9sD8joHkS5kvyO883duCQw9kcnkwOvMqTmeYpbZg4YiVf3SYH/qWJuEbv
ZuzwXo1plrRBYUqE8ar3BHiGP3kW3NsKeYF/h0RvmwRdkX2O395mqBUc+Kgl
RgFXimLyUvn3gHfW1YWnUoLOv+wbJ1k9LIfvLYz/bArObDH5fmVPDfy0xk/m
y6ZB3uu2aF9/A0ov6vwCTqtBy/vw0WBUOdzv9zi+MqMBCdXYwOpS6sdfWb8N
zcMkNk9K7+ESe+9nwoObeLSEF+sYXi/aBzf3aad9sYTtm0R8oD6V+BghvnDh
OvFlRnxiB+MzivhGC8a3O+mBlkyPPaQX8phep0hPdGZ6xpPeGMr0lpAfoIH5
4Rz5BXYzv3iRnyCV+UlFfoPLzG+J5EcwYH70JL/CbebXOvIz8JmfheR3GGd+
P0J5ADZhlAfjlBcgKaC8cKQ8gQ6WJ0cob6CU5c1tyiPQszwqpLyCQwuUV/WU
Z3CK5RlHv5F3kMLy7j8kjm8N
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         ArrowBox[BezierCurveBox[{
          1, {8.200629818601134*^-15, -0.2151802710442648}, 2}], 
          0.020399597244776385`], 
         ArrowBox[BezierCurveBox[{
          1, {-0.6796738226668952, 0.3924098644779064}, 3}], 
          0.020399597244776385`], 
         ArrowBox[BezierCurveBox[{
          2, {-3.13427212962242*^-15, -0.78481972895571}, 1}], 
          0.020399597244776385`], 
         ArrowBox[BezierCurveBox[{
          2, {0.18635158111754763`, 0.10759013552211703`}, 3}], 
          0.020399597244776385`], 
         ArrowBox[BezierCurveBox[{
          3, {-0.18635158111754363`, 0.10759013552215828`}, 1}], 
          0.020399597244776385`], 
         ArrowBox[BezierCurveBox[{
          3, {0.6796738226668931, 0.3924098644778326}, 2}], 
          0.020399597244776385`]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.020399597244776385`], DiskBox[2, 0.020399597244776385`],
          DiskBox[3, 0.020399597244776385`]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.6775727915830746`*^9}]
}, Open  ]],

Cell["\<\
Die Netzwerkarchitektur soll in der sp\[ADoubleDot]teren Update-Routine \
\[UDoubleDot]ber die Adjazenzmatrix ausgewertet werden.\
\>", "Text",
 CellChangeTimes->{{3.677131890121273*^9, 3.6771319052220993`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ad0", " ", "=", " ", 
   RowBox[{"AdjacencyMatrix", "[", "g0", "]"}]}], 
  StyleBox[";",
   FontColor->RGBColor[1, 0, 1]]}]], "Input",
 CellChangeTimes->{{3.606133554977393*^9, 3.606133560886222*^9}, 
   3.642039923573941*^9}],

Cell[TextData[{
 "Die folgende Routine f\[UDoubleDot]hrt das Update eines einzelnen Knotens \
durch. Die Argumente sind der Systemzustand ",
 StyleBox["sysState",
  FontWeight->"Bold"],
 ", die Knotennummer ",
 StyleBox["num",
  FontWeight->"Bold"],
 ", die Liste ",
 StyleBox["scheme",
  FontWeight->"Bold"],
 " der Boole\[CloseCurlyQuote]schen Regeln f\[UDoubleDot]r jeden Knoten, der \
Parameter ",
 StyleBox["K",
  FontSlant->"Italic"],
 " (hier als ",
 StyleBox["deg",
  FontWeight->"Bold"],
 " bezeichnet) und die Adjazenzmatrix ",
 StyleBox["mat",
  FontWeight->"Bold"],
 ". Im ersten Schritt, werden die Positionen der Einsen in der Zeile ",
 StyleBox["num",
  FontWeight->"Bold"],
 " der Adjazenzmatrix extrahiert. Da das Ausgabeobjekt der Adjazenzmatrix vom \
Typ ",
 StyleBox["SparseArray",
  FontWeight->"Bold"],
 " ist, muss vorher der Befehl ",
 StyleBox["Normal",
  FontWeight->"Bold"],
 " auf die Matrix angewendet werden. Aus den Elementen von ",
 StyleBox["sysState",
  FontWeight->"Bold"],
 " an diesen Positionen wird der Input des Knotens ",
 StyleBox["num",
  FontWeight->"Bold"],
 " rekonstruiert, um dann die entsprechende Komponente in der Boole\
\[CloseCurlyQuote]schen Regel des Knotens zu finden. Dieser Wert ist der \
Zustand des Knotens ",
 StyleBox["num",
  FontWeight->"Bold"],
 " im n\[ADoubleDot]chsten Zeitschritt."
}], "Text",
 CellChangeTimes->{{3.6771319614827986`*^9, 3.6771319738068204`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"updateGeneralTmp", "[", 
   RowBox[{
   "sysState_", ",", "num_", ",", "scheme_", ",", "deg_", ",", "mat_"}], 
   "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp0", ",", "tmp1", ",", "tmp2", ",", " ", "tmp3"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp0", " ", "=", " ", 
      RowBox[{"Position", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"mat", "[", 
          RowBox[{"[", "num", "]"}], "]"}], "]"}], ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp1", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"sysState", "[", 
          RowBox[{"[", "#", "]"}], "]"}], "&"}], ",", 
        RowBox[{"Flatten", "[", "tmp0", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp2", " ", "=", "  ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"j", ",", "2", ",", "deg"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", 
          RowBox[{
           RowBox[{"2", "^", "deg"}], " ", "-", "1"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tmp3", " ", "=", " ", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"tmp2", ",", "tmp1"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"scheme", "[", 
      RowBox[{"[", "tmp3", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.401338386146297*^9, 3.401338653410715*^9}, {
   3.401339533281372*^9, 3.4013397701826773`*^9}, {3.401339822836726*^9, 
   3.401339824219728*^9}, {3.6061307160471277`*^9, 3.606130724058123*^9}, {
   3.606130774595676*^9, 3.6061308259663353`*^9}, {3.606130901025762*^9, 
   3.606130914195921*^9}, {3.6061309596677856`*^9, 3.606131043621132*^9}, {
   3.6061312504287043`*^9, 3.606131337635042*^9}, {3.606131376263012*^9, 
   3.60613141795074*^9}, {3.60613167268804*^9, 3.606131699772957*^9}, {
   3.606133187797699*^9, 3.60613322136252*^9}, {3.6061332633057756`*^9, 
   3.606133393683731*^9}, 3.6061336573803473`*^9, {3.6061337287758408`*^9, 
   3.606133751176528*^9}}],

Cell["\<\
Aus dieser Routine l\[ADoubleDot]sst sich nun leicht eine Update-Routine f\
\[UDoubleDot]r das gesamte Netzwerk formulieren:\
\>", "Text",
 CellChangeTimes->{{3.6771320696329913`*^9, 3.6771320849864182`*^9}, {
  3.677132130310498*^9, 3.6771321492499313`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"updateGeneralFull", "[", 
   RowBox[{"state_", ",", "deg_", ",", "schemevec_", ",", "mat_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"updateGeneralTmp", "[", 
     RowBox[{"state", ",", "s", ",", 
      RowBox[{"schemevec", "[", 
       RowBox[{"[", "s", "]"}], "]"}], ",", "deg", ",", "mat"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", 
      RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40133977985104*^9, 3.401339900452424*^9}, {
  3.606130726307343*^9, 3.606130738094681*^9}, {3.606131430593993*^9, 
  3.606131521019794*^9}, {3.60613346604734*^9, 3.606133495989544*^9}}],

Cell["\<\
Als Letztes ben\[ODoubleDot]tigen wir einen Anfangszustand und eine etwas \
kompaktere Schreibweise der Boole\[CloseCurlyQuote]schen Update-Regeln:\
\>", "Text",
 CellChangeTimes->{{3.6771321113096647`*^9, 3.6771321206696815`*^9}, {
  3.677132167158763*^9, 3.6771321690619664`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"init", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.401339785049333*^9, 3.401339790506778*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"schemeX", "=", " ", 
   RowBox[{"{", 
    RowBox[{"updateSchemeX", ",", "updateSchemeY", ",", "updateSchemeZ"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.401338889245556*^9, 3.401338928869643*^9}, {
  3.4013394561041594`*^9, 3.4013394726537952`*^9}, {3.401339525639936*^9, 
  3.4013395286079273`*^9}, {3.6061315643221607`*^9, 3.60613158737481*^9}, {
  3.606272825050408*^9, 3.6062728340619307`*^9}}],

Cell["\<\
Auf dieser Grundlage k\[ODoubleDot]nnen wir nun einen ersten Zeitverlauf \
simulieren:\
\>", "Text",
 CellChangeTimes->{{3.6771321827899904`*^9, 3.6771322109822397`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NestList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"updateGeneralFull", "[", 
     RowBox[{"#", ",", "k", ",", "schemeX", ",", "ad0"}], "]"}], "&"}], ",", 
   "init", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.401339932323998*^9, 3.4013399421242723`*^9}, {
  3.606134032617045*^9, 3.60613403539783*^9}, {3.606134075473246*^9, 
  3.606134104329802*^9}, {3.606272282153646*^9, 3.6062722918402977`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775727916610746`*^9}]
}, Open  ]],

Cell["\<\
Nun wollen wir den Attraktorgraphen konstruieren. Vorbereitend erzeugen wir \
eine Tabelle aller Systemzust\[ADoubleDot]nde und eine Liste mit \
Knotennummern:\
\>", "Text",
 CellChangeTimes->{{3.6771322288920717`*^9, 3.6771322475527043`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"allStates", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"IntegerDigits", "[", 
      RowBox[{"j", ",", "2", ",", "3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "3"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"j", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "3"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Das entscheidende Konstruktionselement ist nun, auf jeden \
m\[ODoubleDot]glichen Systemzustand einen Update-Schritt anzuwenden:\
\>", "Text",
 CellChangeTimes->{{3.6771322682539406`*^9, 3.67713229613319*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"allStatesUpdated", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"updateGeneralFull", "[", 
       RowBox[{"#", ",", "2", ",", "schemeX", ",", "ad0"}], "]"}], "&"}], ",",
      " ", "allStates"}], "]"}]}], ";"}]], "Input"],

Cell[TextData[{
 "Danach k\[ODoubleDot]nnen die Knotennummern verwendet werden, um die Paare \
(Systemzustand, n\[ADoubleDot]chster Systemzustand) in ein Format zu bringen, \
das als Input f\[UDoubleDot]r den Befehl ",
 StyleBox["GraphPlot",
  FontWeight->"Bold"],
 " taugt:"
}], "Text",
 CellChangeTimes->{{3.677132363465908*^9, 3.6771323997077723`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"allStatesPairs", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"allStates", ",", "allStatesUpdated"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"allStates", "\[Rule]", "labels"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelPairs", " ", "=", " ", 
   RowBox[{"allStatesPairs", " ", "/.", " ", "labels2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"asp2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "3"}], "]"}], "&"}],
        ",", "allStates"}], "]"}], "\[Rule]", " ", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "3"}], "]"}], "&"}],
        ",", "allStatesUpdated"}], "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[TextData[{
 "Die in der Variablen ",
 StyleBox["asp2",
  FontWeight->"Bold"],
 " abgelegte Datenstruktur l\[ADoubleDot]sst sich nun direkt in einen Graphen \
\[UDoubleDot]bersetzen:"
}], "Text",
 CellChangeTimes->{{3.6771324281964226`*^9, 3.6771324543440685`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"asp2", ",", 
   RowBox[{"Method", "\[Rule]", "\"\<SpringEmbedding\>\""}], ",", " ", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
   RowBox[{"EdgeRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"#1", ",", "0.1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
   RowBox[{"VertexRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"White", ",", 
        RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
        RowBox[{"Disk", "[", 
         RowBox[{"#", ",", ".15"}], "]"}], ",", "Black", ",", 
        RowBox[{"Text", "[", 
         RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.401340485438327*^9, 3.4013405587342052`*^9}, {
   3.4013416432170897`*^9, 3.4013416439423428`*^9}, 3.6061078470297213`*^9, {
   3.606107886530925*^9, 3.606107913063192*^9}, {3.606107969718299*^9, 
   3.606107973329857*^9}, {3.6061080103089457`*^9, 3.606108018042417*^9}, {
   3.6420399675824537`*^9, 3.642039968840312*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[{{
     {GrayLevel[0], 
      ArrowBox[{{2.375658949807269, 1.682793212691676}, {1.555442202680025, 
       1.0248825712303349`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{1.555442202680025, 1.0248825712303349`}, {1.321856023284369, 
       0.}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{1.321856023284369, 0.}, {0.7815744616071384, 
       0.33850770868899405`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{2.382049184186591, 0.30594475319943804`}, {1.555442202680025,
        1.0248825712303349`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{0.7639694557237748, 1.7548600358383182`}, {1.555442202680025,
        1.0248825712303349`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{3.2169123420426837`, 2.2045543542221857`}, {
       2.375658949807269, 1.682793212691676}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{0.7815744616071384, 0.33850770868899405`}, {
       1.555442202680025, 1.0248825712303349`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{0., 2.3793115840927195`}, {0.7639694557237748, 
       1.7548600358383182`}}, 0.1]}}, {
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.375658949807269, 1.682793212691676}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"000\"\>", {2.375658949807269, 1.682793212691676}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.555442202680025, 1.0248825712303349`}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"001\"\>", {1.555442202680025, 1.0248825712303349`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.321856023284369, 0.}, 0.15], 
      {GrayLevel[0], InsetBox["\<\"101\"\>", {1.321856023284369, 0.}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.382049184186591, 0.30594475319943804`}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"010\"\>", {2.382049184186591, 0.30594475319943804`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.7639694557237748, 1.7548600358383182`}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"011\"\>", {0.7639694557237748, 1.7548600358383182`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.2169123420426837`, 2.2045543542221857`}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"100\"\>", {3.2169123420426837`, 2.2045543542221857`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.7815744616071384, 0.33850770868899405`}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"110\"\>", {0.7815744616071384, 0.33850770868899405`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0., 2.3793115840927195`}, 0.15], 
      {GrayLevel[0], InsetBox["\<\"111\"\>", {0., 2.3793115840927195`}]}}}},
   Annotation[#, 
    VertexCoordinateRules -> {{2.375658949807269, 1.682793212691676}, {
     1.555442202680025, 1.0248825712303349`}, {1.321856023284369, 0.}, {
     2.382049184186591, 0.30594475319943804`}, {0.7639694557237748, 
     1.7548600358383182`}, {3.2169123420426837`, 2.2045543542221857`}, {
     0.7815744616071384, 0.33850770868899405`}, {0., 2.3793115840927195`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.6775727917390747`*^9}]
}, Open  ]],

Cell[TextData[{
 "\[CapitalUDoubleDot]ber die Funktionen ",
 StyleBox["EdgeRenderingFunction",
  FontWeight->"Bold"],
 " und ",
 StyleBox["VertexRenderingFunction",
  FontWeight->"Bold"],
 " wurde dabei die Darstellung angepasst.\n\n"
}], "Text",
 CellChangeTimes->{{3.6771324834703197`*^9, 3.677132518353981*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: N-K-Modell \[Dash] Teil 2"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704872223864946`*^9, 3.670489147179757*^9, 
   3.670489325924272*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Im zweiten Teil dieses ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses wollen wir diese Methoden auf ein Boole\[CloseCurlyQuote]sches \
Zufallsnetz anwenden. Dazu ben\[ODoubleDot]tigen wir noch eine Routine, die \
eine Liste von ",
 StyleBox["N",
  FontSlant->"Italic"],
 " zuf\[ADoubleDot]llig ausgew\[ADoubleDot]hlten Boole\[CloseCurlyQuote]schen \
Funktionen (dargestellt als Liste von Vektoren der L\[ADoubleDot]nge ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "K"], TraditionalForm]]],
 ") erzeugt:"
}], "Text",
 CellChangeTimes->{{3.6771325436416254`*^9, 3.677132596548319*^9}, {
  3.677132627096574*^9, 3.6771326321831827`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateRandomUpdateSchemes", "[", 
   RowBox[{"deg_", ",", "num_"}], "]"}], ":=", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{"IntegerDigits", "[", 
     RowBox[{
      RowBox[{"RandomInteger", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"2", "^", 
           RowBox[{"(", 
            RowBox[{"2", "^", "deg"}], " ", ")"}]}], "-", "1"}]}], "}"}], 
       "]"}], ",", "2", ",", 
      RowBox[{"2", "^", "deg"}]}], "]"}], ",", 
    RowBox[{"{", "num", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6061297894052267`*^9, 3.60612980552717*^9}, {
  3.6061301567014647`*^9, 3.6061301705808477`*^9}, {3.6061306188956327`*^9, 
  3.606130642361621*^9}, {3.6061313878863707`*^9, 3.606131407635232*^9}}],

Cell[TextData[{
 "Der n\[ADoubleDot]chste Schritt ist die Erzeugung eines Zufallsnetzes sowie \
der zugeh\[ODoubleDot]rigen Adjazenzmatrix und der \
Boole\[CloseCurlyQuote]schen Funktionen. Wir w\[ADoubleDot]hlen ",
 StyleBox["K",
  FontSlant->"Italic"],
 " = 3 und ",
 StyleBox["N",
  FontSlant->"Italic"],
 " = 10."
}], "Text",
 CellChangeTimes->{{3.67713268185567*^9, 3.6771327185781345`*^9}}],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "488", "]"}]], "Input",
 CellChangeTimes->{{3.6061298659794083`*^9, 3.6061298721872253`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", " ", "=", " ", "10"}], ";"}]}], "Input",
 CellChangeTimes->{{3.606130132149866*^9, 3.606130140598631*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", " ", "=", " ", 
  RowBox[{"RandomGraph", "[", 
   RowBox[{
    RowBox[{"DegreeGraphDistribution", "[", 
     RowBox[{"Table", "[", 
      RowBox[{"k", ",", 
       RowBox[{"{", "n", "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6061297342104893`*^9, 3.6061297724575663`*^9}, {
  3.606129973970634*^9, 3.6061300141068068`*^9}, {3.6061301443589897`*^9, 
  3.606130146582831*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 
      10}, {{{6, 3}, {4, 6}, {2, 1}, {5, 9}, {10, 6}, {1, 7}, {8, 4}, {5, 
       10}, {2, 9}, {3, 2}, {7, 10}, {10, 3}, {9, 10}, {4, 1}, {6, 5}, {2, 
       4}, {5, 4}, {7, 5}, {1, 6}, {6, 2}, {4, 5}, {8, 7}, {1, 2}, {8, 9}, {3,
        7}, {7, 3}, {9, 1}, {9, 8}, {3, 8}, {10, 8}}, Null}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJw9VAk0FAoXHsQv/JbKNr+nLC2yPC2k0KeUtJDqJaS02LUiS+rltyUhS6G0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       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         ArrowBox[BezierCurveBox[{
          1, {0.22541721622094432`, 0.8360606943777129}, 2}], 
          0.0226361363816264], ArrowBox[{1, 6}, 0.0226361363816264], 
         ArrowBox[{1, 7}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          2, {0.022565730302903778`, 0.917617696407939}, 1}], 
          0.0226361363816264], ArrowBox[{2, 4}, 0.0226361363816264], 
         ArrowBox[{2, 9}, 0.0226361363816264], 
         ArrowBox[{3, 2}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          3, {1.3489845269093306`, 1.3143848351537077`}, 7}], 
          0.0226361363816264], ArrowBox[{3, 8}, 0.0226361363816264], 
         ArrowBox[{4, 1}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          4, {1.2469229088566764`, 1.04005755651289}, 5}], 
          0.0226361363816264], ArrowBox[{4, 6}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          5, {0.9364826983265409, 0.8261414964669128}, 4}], 
          0.0226361363816264], ArrowBox[{5, 9}, 0.0226361363816264], 
         ArrowBox[{5, 10}, 0.0226361363816264], 
         ArrowBox[{6, 2}, 0.0226361363816264], 
         ArrowBox[{6, 3}, 0.0226361363816264], 
         ArrowBox[{6, 5}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          7, {1.5116248523579106`, 1.1678616710437508`}, 3}], 
          0.0226361363816264], ArrowBox[{7, 5}, 0.0226361363816264], 
         ArrowBox[{7, 10}, 0.0226361363816264], 
         ArrowBox[{8, 4}, 0.0226361363816264], 
         ArrowBox[{8, 7}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          8, {1.6422207733855623`, 0.3105060894097072}, 9}], 
          0.0226361363816264], ArrowBox[{9, 1}, 0.0226361363816264], 
         ArrowBox[BezierCurveBox[{
          9, {1.3256895064476115`, 0.6519416991103885}, 8}], 
          0.0226361363816264], ArrowBox[{9, 10}, 0.0226361363816264], 
         ArrowBox[{10, 3}, 0.0226361363816264], 
         ArrowBox[{10, 6}, 0.0226361363816264], 
         ArrowBox[{10, 8}, 0.0226361363816264]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.0226361363816264], DiskBox[2, 0.0226361363816264], 
         DiskBox[3, 0.0226361363816264], DiskBox[4, 0.0226361363816264], 
         DiskBox[5, 0.0226361363816264], DiskBox[6, 0.0226361363816264], 
         DiskBox[7, 0.0226361363816264], DiskBox[8, 0.0226361363816264], 
         DiskBox[9, 0.0226361363816264], DiskBox[10, 0.0226361363816264]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.6775727918014746`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ad1", " ", "=", " ", 
   RowBox[{"AdjacencyMatrix", "[", "g1", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606133554977393*^9, 3.606133560886222*^9}, {
   3.606133971465383*^9, 3.6061339738639727`*^9}, 3.6239160199680753`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"schemeX2", " ", "=", " ", 
   RowBox[{"generateRandomUpdateSchemes", "[", 
    RowBox[{"k", ",", "n"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6061340385365334`*^9, 3.606134068098344*^9}, 
   3.606134278828722*^9, 3.606301794740088*^9}],

Cell[TextData[{
 "Die oben eingef\[UDoubleDot]hrten Schritte vom System zur Attraktorstruktur \
lassen sich ohne gr\[ODoubleDot]\[SZ]ere \[CapitalADoubleDot]nderungen nur \
durch Anpassen auf allgemeine Werte von ",
 StyleBox["N",
  FontSlant->"Italic"],
 " und ",
 StyleBox["K",
  FontSlant->"Italic"],
 " verwenden."
}], "Text",
 CellChangeTimes->{{3.6771327589520054`*^9, 3.6771327835084486`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"allStates", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"IntegerDigits", "[", 
      RowBox[{"j", ",", "2", ",", "n"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "n"}], " ", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"j", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "n"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allStatesUpdated", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"updateGeneralFull", "[", 
       RowBox[{"#", ",", "k", ",", "schemeX2", ",", "ad1"}], "]"}], "&"}], 
     ",", " ", "allStates"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allStatesPairs", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"allStates", ",", "allStatesUpdated"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"allStates", "\[Rule]", "labels"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelPairs", " ", "=", " ", 
   RowBox[{"allStatesPairs", " ", "/.", " ", "labels2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"asp2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "n"}], "]"}], "&"}],
        ",", "allStates"}], "]"}], "\[Rule]", " ", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "n"}], "]"}], "&"}],
        ",", "allStatesUpdated"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.401339966449061*^9, 3.4013399727019987`*^9}, {
   3.4013574668001537`*^9, 3.40135748923726*^9}, {3.401357577064673*^9, 
   3.4013576401596737`*^9}, 3.493430442683415*^9, 3.6061094791088047`*^9, {
   3.6061338624891977`*^9, 3.60613388278867*^9}, {3.606134141194728*^9, 
   3.606134174244998*^9}, {3.606134210450973*^9, 3.606134213386593*^9}, {
   3.606134325747615*^9, 3.606134351425618*^9}, {3.606134434623953*^9, 
   3.606134437893776*^9}, 3.6063017998139277`*^9, {3.606301872735292*^9, 
   3.606301875836204*^9}}],

Cell[TextData[{
 "Dies f\[UDoubleDot]hrt unmittelbar auf die (nun sehr viel gr\[ODoubleDot]\
\[SZ]ere) Attraktorstruktur",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{".", " "}], "34"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.677132829093729*^9, 3.677132887081031*^9}, {
   3.6771330144552546`*^9, 3.6771330361724925`*^9}, {3.6771330768739643`*^9, 
   3.67713308029037*^9}, 3.677133326731805*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1b", " ", "=", " ", 
  RowBox[{"Graph", "[", 
   RowBox[{"asp2", ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
    RowBox[{"VertexStyle", "\[Rule]", "LightGray"}], ",", 
    RowBox[{"VertexSize", "\[Rule]", "4"}], ",", 
    RowBox[{"VertexShapeFunction", "\[Rule]", "\"\<Circle\>\""}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"EdgeForm", "[", "Black", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.642040017223308*^9, 3.642040025512988*^9}, {
   3.6420411217232733`*^9, 3.6420411868915157`*^9}, {3.6420413089800386`*^9, 
   3.64204133042024*^9}, {3.6420414014917507`*^9, 3.6420414078341417`*^9}, {
   3.6420414821970367`*^9, 3.642041535664321*^9}, {3.6420415949355583`*^9, 
   3.64204159885194*^9}, {3.6420416291583843`*^9, 3.642041662294533*^9}, 
   3.670489417269433*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "0000000000", "1100101101", "0000000001", "1100100101", "0000000010", 
       "1000101101", "0000000011", "1000100101", "0000000100", "1110101111", 
       "0000000101", "1110100101", "0000000110", "1010101111", "0000000111", 
       "1010100101", "0000001000", "0110101001", "0000001001", "0110100001", 
       "0000001010", "0010101101", "0000001011", "0010100101", "0000001100", 
       "0110101011", "0000001101", "0000001110", "0010101111", "0000001111", 
       "0000010000", "0101101101", "0000010001", "0101100101", "0000010010", 
       "0001101101", "0000010011", "0001100101", "0000010100", "0111101110", 
       "0000010101", "0111100100", "0000010110", "0011101110", "0000010111", 
       "0011100100", "0000011000", "0111101001", "0000011001", "0111100001", 
       "0000011010", "0011101101", "0000011011", "0011100101", "0000011100", 
       "0111101010", "0000011101", "0111100000", "0000011110", "0000011111", 
       "0000100000", "1101111101", "0000100001", "1101110101", "0000100010", 
       "1001111101", "0000100011", "1001110101", "0000100100", "1111111111", 
       "0000100101", "1111110101", "0000100110", "1011111111", "0000100111", 
       "1011110101", "0000101000", "0111111001", "0000101001", "0111110001", 
       "0000101010", "0011111101", "0000101011", "0011110101", "0000101100", 
       "0111111011", "0000101101", "0000101110", "0011111111", "0000101111", 
       "0000110000", "0100111101", "0000110001", "0100110101", "0000110010", 
       "0000111101", "0000110011", "0000110101", "0000110100", "0110111110", 
       "0110110100", "0000110110", "0010111110", "0000110111", "0010110100", 
       "0000111000", "0110111001", "0000111001", "0110110001", "0000111010", 
       "0010111101", "0000111011", "0010110101", "0000111100", "0110111010", 
       "0110110000", "0000111110", "0000111111", "0001000000", "1000101001", 
       "0001000001", "1000000001", "0001000010", "1100001101", "0001000011", 
       "1100000101", "0001000100", "1010101011", "0001000101", "1010000001", 
       "0001000110", "1110001111", "0001000111", "1110000101", "0001001000", 
       "0010101001", "0001001001", "0010000001", "0001001010", "0110001001", 
       "0001001011", "0110000001", "0001001100", "0010101011", "0001001101", 
       "0001001110", "0110001011", "0001001111", "0001010000", "0001101001", 
       "0001010001", "0001010010", "0101001101", "0001010011", "0101000101", 
       "0001010100", "0011101010", "0001010101", "0011000000", "0001010110", 
       "0111001110", "0001010111", "0111000100", "0001011000", "0011101001", 
       "0001011001", "0011000001", "0001011010", "0111001001", "0001011011", 
       "0111000001", "0001011100", "0001011101", "0001011110", "0111001010", 
       "0001011111", "0111000000", "0001100000", "1001111001", "0001100001", 
       "1001010001", "0001100010", "1101011101", "0001100011", "1101010101", 
       "0001100100", "1011111011", "1011010001", "0001100110", "1111011111", 
       "0001100111", "1111010101", "0001101000", "0011111001", "0011010001", 
       "0001101010", "0111011001", "0001101011", "0111010001", "0001101100", 
       "0011111011", "0001101110", "0111011011", "0001101111", "0001110000", 
       "0001110001", "0001110010", "0100011101", "0001110011", "0100010101", 
       "0001110100", "0010111010", "0001110101", "0010010000", "0001110110", 
       "0110011110", "0001110111", "0110010100", "0001111000", "0010111001", 
       "0001111001", "0010010001", "0001111010", "0110011001", "0001111011", 
       "0110010001", "0001111100", "0001111101", "0001111110", "0110011010", 
       "0001111111", "0110010000", "0010000000", "0010000010", "0010000011", 
       "0010000100", "1110100110", "0010000101", "1110100100", "0010000110", 
       "1010100110", "0010000111", "1010100100", "0010001000", "0010001001", 
       "0010001010", "0010001011", "0010001100", "0110100010", "0010001101", 
       "0110100000", "0010001110", "0010100110", "0010001111", "0010100100", 
       "0010010010", "0010010011", "0010010100", "0111100111", "0010010101", 
       "0111100101", "0010010110", "0011100111", "0010010111", "0010011000", 
       "0010011001", "0010011010", "0010011011", "0010011100", "0111100011", 
       "0010011101", "0010011110", "0010011111", "0010100000", "1101101101", 
       "0010100001", "1101100101", "0010100010", "1001101101", "0010100011", 
       "1001100101", "1111101110", "1111100100", "1011101110", "0010100111", 
       "1011100100", "0010101000", "0010101010", "0010101100", "0010101110", 
       "0010110000", "0100101101", "0010110001", "0100100101", "0010110010", 
       "0010110011", "0110101111", "0110100101", "0010110110", "0010110111", 
       "0010111000", "0010111011", "0010111100", "0010111111", "1000100001", 
       "0011000010", "0011000011", "0011000100", "1010100010", "0011000101", 
       "1010000000", "0011000110", "1110000110", "0011000111", "1110000100", 
       "0011001000", "0011001001", "0011001010", "0011001011", "0011001100", 
       "0011001101", "0011001110", "0110000010", "0011001111", "0110000000", 
       "0011010000", "0011010010", "0011010011", "0011010100", "0011100011", 
       "0011010101", "0011010110", "0111000111", "0011010111", "0111000101", 
       "0011011000", "0011100001", "0011011001", "0011011010", "0011011011", 
       "0011011100", "0011011101", "0011011110", "0111000011", "0011011111", 
       "0011100000", "1001101001", "1001000001", "0011100010", "1101001101", 
       "1101000101", "1011101010", "1011000000", "0011100110", "1111001110", 
       "1111000100", "0011101000", "0011101011", "0011101100", "0011101111", 
       "0011110000", "0011110001", "0011110010", "0100001101", "0011110011", 
       "0100000101", "0011110100", "0011110110", "0110001111", "0011110111", 
       "0110000101", "0011111000", "0011111010", "0011111100", "0011111110", 
       "0100000000", "0110111101", "0100000001", "0110110101", "0100000010", 
       "0100000011", "0100000100", "0110111111", "0100000110", "0100000111", 
       "0100001000", "1100111001", "0100001001", "1100110001", "0100001010", 
       "1000111101", "0100001011", "1000110101", "0100001100", "1110111011", 
       "1110110001", "0100001110", "1010111111", "0100001111", "1010110101", 
       "0100010000", "1111111101", "0100010001", "0100010010", "1011111101", 
       "0100010011", "0100010100", "1111111110", "1111110100", "0100010110", 
       "1011111110", "0100010111", "1011110100", "0100011000", "0101111001", 
       "0100011001", "0101110001", "0100011010", "0100011011", "0100011100", 
       "0111111010", "0111110000", "0100011110", "0100011111", "0100100000", 
       "0111101101", "0100100001", "0100100010", "0100100011", "0100100100", 
       "0111101111", "0100100110", "0100100111", "0100101000", "1101101001", 
       "0100101001", "1101100001", "0100101010", "0100101011", "0100101100", 
       "1111101011", "1111100001", "0100101110", "1011101111", "0100101111", 
       "1011100101", "0100110000", "1110101101", "0100110001", "0100110010", 
       "1010101101", "0100110011", "0100110100", "1110101110", "0100110110", 
       "1010101110", "0100110111", "0100111000", "0100111001", "0100111010", 
       "0100111011", "0100111100", "0110101010", "0100111110", "0100111111", 
       "0101000000", "0101000001", "0101000010", "0110011101", "0101000011", 
       "0110010101", "0101000100", "0101000110", "0110011111", "0101000111", 
       "0101001000", "1000111001", "0101001001", "1000010001", "0101001010", 
       "1100011001", "0101001011", "1100010001", "0101001100", "1010111011", 
       "1010010001", "0101001110", "1110011011", "0101001111", "1110010001", 
       "0101010000", "1011111001", "0101010001", "0101010010", "1111011101", 
       "0101010011", "0101010100", "1011111010", "0101010101", "1011010000", 
       "0101010110", "1111011110", "0101010111", "1111010100", "0101011000", 
       "0101011001", "0101011010", "0101011011", "0101011100", "0101011101", 
       "0101011110", "0111011010", "0101011111", "0111010000", "0101100000", 
       "0101100001", "0101100010", "0111001101", "0101100011", "0101100100", 
       "0101100110", "0111001111", "0101100111", "0101101000", "0101101001", 
       "0101101010", "1101001001", "0101101011", "1101000001", "0101101100", 
       "1011101011", "1011000001", "0101101110", "1111001011", "0101101111", 
       "1111000001", "0101110000", "1010101001", "0101110010", "1110001101", 
       "0101110011", "0101110100", "1010101010", "0101110101", "0101110110", 
       "1110001110", "0101110111", "0101111000", "0101111010", "0101111011", 
       "0101111100", "0101111101", "0101111110", "0110001010", "0101111111", 
       "0110000011", "0110000100", "0110110110", "0110000110", "0110000111", 
       "0110001000", "0110001100", "1110110010", "0110001101", "1110110000", 
       "0110001110", "1010110110", "1010110100", "0110010010", "0110010011", 
       "1111110111", "0110010110", "1011110111", "0110010111", "0110011000", 
       "0110011011", "0110011100", "0111110011", "0111111101", "0111110101", 
       "0110100011", "0110100100", "0111111110", "0111110100", "0110100110", 
       "0110100111", "0110101000", "1101111001", "1101110001", "0110101100", 
       "1111111010", "0110101101", "1111110000", "0110101110", "1110111101", 
       "1110110101", "0110110010", "1010111101", "0110110011", "1110111111", 
       "0110110111", "0110111000", "0110111011", "0110111100", "0111000010", 
       "0111000110", "0111001000", "1000110001", "0111001011", "0111001100", 
       "1010110010", "1010010000", "1110010010", "1110010000", "1011110001", 
       "0111010010", "0111010011", "0111010100", "1011110011", "0111010101", 
       "0111010110", "1111010111", "0111010111", "0111011000", "0111011100", 
       "0111011101", "0111011110", "0111011111", "0111100010", "0111100110", 
       "0111101000", "1101011001", "0111101011", "1101010001", "0111101100", 
       "1111011010", "1111010000", "1010111001", "0111110010", "1110011101", 
       "1110010101", "0111110110", "1110011111", "0111110111", "0111111000", 
       "0111111100", "0111111111", "1000000000", "1000000010", "1000000011", 
       "1000000100", "1000000101", "1110100111", "1000000110", "1000000111", 
       "1000001000", "1000001001", "1000001010", "1000001011", "1000001100", 
       "1000001101", "1000001110", "1000001111", "1000010000", "1000010010", 
       "1000010011", "1000010100", "1000010101", "1000010110", "1000010111", 
       "1000011000", "1000011001", "1000011010", "1000011011", "1000011100", 
       "1000011101", "1000011110", "1000011111", "1000100000", "1000100010", 
       "1000100011", "1000100100", "1000100110", "1000100111", "1000101000", 
       "1000101010", "1000101011", "1000101100", "1000101110", "1000101111", 
       "1000110000", "1000110010", "1000110011", "1000110100", "1000110110", 
       "1000110111", "1000111000", "1000111010", "1000111011", "1000111100", 
       "1000111110", "1000111111", "1001000000", "1001000010", "1001000011", 
       "1001000100", "1001000101", "1010000011", "1001000110", "1001000111", 
       "1110000111", "1001001000", "1001001001", "1001001010", "1001001011", 
       "1001001100", "1001001101", "1001001110", "1001001111", "1001010000", 
       "1001010010", "1001010011", "1001010100", "1001010101", "1001010110", 
       "1001010111", "1001011000", "1001011001", "1001011010", "1001011011", 
       "1001011100", "1001011101", "1001011110", "1001011111", "1001100000", 
       "1001100001", "1001100010", "1001100011", "1001100100", "1011010011", 
       "1001100110", "1001100111", "1001101000", "1001101010", "1001101011", 
       "1001101100", "1001101110", "1001101111", "1001110000", "1001110001", 
       "1001110010", "1001110011", "1001110100", "1001110110", "1001110111", 
       "1001111000", "1001111010", "1001111011", "1001111100", "1001111110", 
       "1001111111", "1010000010", "1010000100", "1010000101", "1010000110", 
       "1010000111", "1010001000", "1010001001", "1010001010", "1010001011", 
       "1010001100", "1010001101", "1010001110", "1010001111", "1010010010", 
       "1010010011", "1010010100", "1010010101", "1010010110", "1010010111", 
       "1010011000", "1010011001", "1010011010", "1010011011", "1010011100", 
       "1010011101", "1010011110", "1010011111", "1010100000", "1010100001", 
       "1010100011", "1111101100", "1111100110", "1010100111", "1010101000", 
       "1010101100", "1010110000", "1010110001", "1010110011", "1010110111", 
       "1010111000", "1010111010", "1010111100", "1010111110", "1011000010", 
       "1011000011", "1011000100", "1011000101", "1011000110", "1011000111", 
       "1011001000", "1011001001", "1011001010", "1011001011", "1011001100", 
       "1011001101", "1011001110", "1011001111", "1011010010", "1011010100", 
       "1011010101", "1011010110", "1011010111", "1011011000", "1011011001", 
       "1011011010", "1011011011", "1011011100", "1011011101", "1011011110", 
       "1011011111", "1011100000", "1011100001", "1011100010", "1011100011", 
       "1011101000", "1011100110", "1111001100", "1011100111", "1111000110", 
       "1011101001", "1011101100", "1011101101", "1011110000", "1011110010", 
       "1011110110", "1011111000", "1011111100", "1100000000", "1100000001", 
       "1100000010", "1100000011", "1100000100", "1100000110", "1100000111", 
       "1100001000", "1100001001", "1100001010", "1100111101", "1100001011", 
       "1100110101", "1100001100", "1110111001", "1110110011", "1100001110", 
       "1100001111", "1110110111", "1100010000", "1100010010", "1100010011", 
       "1100010100", "1111111100", "1100010101", "1111110110", "1100010110", 
       "1100010111", "1100011000", "1100011010", "1100011011", "1100011100", 
       "1100011101", "1100011110", "1100011111", "1100100000", "1100100001", 
       "1100100010", "1100100011", "1100100100", "1100100110", "1100100111", 
       "1100101000", "1100101001", "1100101010", "1100101011", "1100101100", 
       "1111101001", "1111100011", "1100101110", "1111101101", "1100101111", 
       "1111100111", "1100110000", "1111100101", "1100110010", "1100110011", 
       "1100110100", "1100110110", "1100110111", "1100111000", "1100111010", 
       "1100111011", "1100111100", "1100111110", "1100111111", "1101000000", 
       "1101000010", "1101000011", "1101000100", "1101000110", "1101000111", 
       "1101001000", "1101001010", "1101001011", "1101001100", "1101001110", 
       "1110011001", "1101001111", "1110010011", "1101010000", "1101010010", 
       "1101010011", "1101010100", "1101010110", "1111011100", "1101010111", 
       "1111010110", "1101011000", "1101011010", "1101011011", "1101011100", 
       "1101011110", "1101011111", "1101100000", "1101100010", "1101100011", 
       "1101100100", "1101100110", "1101100111", "1101101000", "1101101010", 
       "1101101011", "1101101100", "1101101110", "1111001001", "1101101111", 
       "1111000011", "1101110000", "1101110010", "1111001101", "1101110011", 
       "1111000101", "1101110100", "1101110110", "1101110111", "1101111000", 
       "1101111010", "1101111011", "1101111100", "1101111110", "1101111111", 
       "1110000000", "1110000001", "1110000010", "1110000011", "1110001000", 
       "1110001001", "1110001010", "1110001011", "1110001100", "1110110100", 
       "1110110110", "1110010100", "1110010110", "1110010111", "1110011000", 
       "1110011010", "1110011100", "1110011110", "1110100000", "1110100001", 
       "1110100010", "1110100011", "1110101000", "1110101001", "1110101010", 
       "1110101011", "1110101100", "1111111000", "1111110010", "1110111000", 
       "1110111010", "1110111100", "1110111110", "1111000000", "1111000010", 
       "1111000111", "1111001000", "1111001010", "1111001111", "1111010001", 
       "1111010010", "1111010011", "1111011000", "1111011001", "1111011011", 
       "1111100000", "1111100010", "1111101000", "1111101010", "1111101111", 
       "1111110001", "1111110011", "1111111001", 
       "1111111011"}, {CompressedData["
1:eJw1mQf819MXxn/3HFE2iUJRWUVWGRVKIRRSSSGaohAJWZWMNEiZFSGrsiUp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       "], Null}, {BaseStyle -> EdgeForm[
         GrayLevel[0]], VertexShapeFunction -> {"Circle"}, VertexSize -> {4}, 
       VertexStyle -> {
         GrayLevel[0.85]}}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJw8mHk0lG/Yx4U2FUqhTfZ9mc3sMy7MjHUQCqnIUpTUD23WsrXYSpYSoqyR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       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.5], Arrowheads[0.0064769819088310475`],
          EdgeForm[GrayLevel[0]], ArrowBox[{1, 2}, 0.17135878410227104`], 
         ArrowBox[{2, 897}, 0.17135878410227104`], 
         ArrowBox[{3, 4}, 0.17135878410227104`], 
         ArrowBox[{4, 259}, 0.17135878410227104`], 
         ArrowBox[{5, 6}, 0.17135878410227104`], 
         ArrowBox[{6, 578}, 0.17135878410227104`], 
         ArrowBox[{7, 8}, 0.17135878410227104`], 
         ArrowBox[{8, 571}, 0.17135878410227104`], 
         ArrowBox[{9, 10}, 0.17135878410227104`], 
         ArrowBox[{10, 874}, 0.17135878410227104`], 
         ArrowBox[{11, 12}, 0.17135878410227104`], 
         ArrowBox[{12, 642}, 0.17135878410227104`], 
         ArrowBox[{13, 14}, 0.17135878410227104`], 
         ArrowBox[{14, 630}, 0.17135878410227104`], 
         ArrowBox[{15, 16}, 0.17135878410227104`], 
         ArrowBox[{16, 793}, 0.17135878410227104`], 
         ArrowBox[{17, 18}, 0.17135878410227104`], 
         ArrowBox[{18, 589}, 0.17135878410227104`], 
         ArrowBox[{19, 20}, 0.17135878410227104`], 
         ArrowBox[{20, 580}, 0.17135878410227104`], 
         ArrowBox[{21, 22}, 0.17135878410227104`], 
         ArrowBox[{22, 58}, 0.17135878410227104`], 
         ArrowBox[{23, 24}, 0.17135878410227104`], 
         ArrowBox[{24, 283}, 0.17135878410227104`], 
         ArrowBox[{25, 26}, 0.17135878410227104`], 
         ArrowBox[{26, 68}, 0.17135878410227104`], 
         ArrowBox[{27, 20}, 0.17135878410227104`], 
         ArrowBox[{28, 29}, 0.17135878410227104`], 
         ArrowBox[{29, 46}, 0.17135878410227104`], 
         ArrowBox[{30, 24}, 0.17135878410227104`], 
         ArrowBox[{31, 32}, 0.17135878410227104`], 
         ArrowBox[{32, 532}, 0.17135878410227104`], 
         ArrowBox[{33, 34}, 0.17135878410227104`], 
         ArrowBox[{34, 167}, 0.17135878410227104`], 
         ArrowBox[{35, 36}, 0.17135878410227104`], 
         ArrowBox[{36, 195}, 0.17135878410227104`], 
         ArrowBox[{37, 38}, 0.17135878410227104`], 
         ArrowBox[{38, 188}, 0.17135878410227104`], 
         ArrowBox[{39, 40}, 0.17135878410227104`], 
         ArrowBox[{40, 636}, 0.17135878410227104`], 
         ArrowBox[{41, 42}, 0.17135878410227104`], 
         ArrowBox[{42, 373}, 0.17135878410227104`], 
         ArrowBox[{43, 44}, 0.17135878410227104`], 
         ArrowBox[{44, 175}, 0.17135878410227104`], 
         ArrowBox[{45, 46}, 0.17135878410227104`], 
         ArrowBox[{46, 352}, 0.17135878410227104`], 
         ArrowBox[{47, 48}, 0.17135878410227104`], 
         ArrowBox[{48, 181}, 0.17135878410227104`], 
         ArrowBox[{49, 50}, 0.17135878410227104`], 
         ArrowBox[{50, 195}, 0.17135878410227104`], 
         ArrowBox[{51, 52}, 0.17135878410227104`], 
         ArrowBox[{52, 159}, 0.17135878410227104`], 
         ArrowBox[{53, 54}, 0.17135878410227104`], 
         ArrowBox[{54, 353}, 0.17135878410227104`], 
         ArrowBox[{55, 56}, 0.17135878410227104`], 
         ArrowBox[{56, 632}, 0.17135878410227104`], 
         ArrowBox[{57, 58}, 0.17135878410227104`], 
         ArrowBox[{58, 194}, 0.17135878410227104`], 
         ArrowBox[{59, 44}, 0.17135878410227104`], 
         ArrowBox[{60, 46}, 0.17135878410227104`], 
         ArrowBox[{61, 62}, 0.17135878410227104`], 
         ArrowBox[{62, 306}, 0.17135878410227104`], 
         ArrowBox[{63, 64}, 0.17135878410227104`], 
         ArrowBox[{64, 805}, 0.17135878410227104`], 
         ArrowBox[{65, 66}, 0.17135878410227104`], 
         ArrowBox[{66, 327}, 0.17135878410227104`], 
         ArrowBox[{67, 68}, 0.17135878410227104`], 
         ArrowBox[{68, 327}, 0.17135878410227104`], 
         ArrowBox[{69, 70}, 0.17135878410227104`], 
         ArrowBox[{70, 617}, 0.17135878410227104`], 
         ArrowBox[{71, 72}, 0.17135878410227104`], 
         ArrowBox[{72, 740}, 0.17135878410227104`], 
         ArrowBox[{73, 74}, 0.17135878410227104`], 
         ArrowBox[{74, 344}, 0.17135878410227104`], 
         ArrowBox[{75, 76}, 0.17135878410227104`], 
         ArrowBox[{76, 307}, 0.17135878410227104`], 
         ArrowBox[{77, 78}, 0.17135878410227104`], 
         ArrowBox[{78, 33}, 0.17135878410227104`], 
         ArrowBox[{79, 80}, 0.17135878410227104`], 
         ArrowBox[{80, 486}, 0.17135878410227104`], 
         ArrowBox[{81, 82}, 0.17135878410227104`], 
         ArrowBox[{82, 138}, 0.17135878410227104`], 
         ArrowBox[{83, 84}, 0.17135878410227104`], 
         ArrowBox[{84, 138}, 0.17135878410227104`], 
         ArrowBox[{85, 86}, 0.17135878410227104`], 
         ArrowBox[{86, 403}, 0.17135878410227104`], 
         ArrowBox[{87, 80}, 0.17135878410227104`], 
         ArrowBox[{88, 89}, 0.17135878410227104`], 
         ArrowBox[{89, 142}, 0.17135878410227104`], 
         ArrowBox[{90, 84}, 0.17135878410227104`], 
         ArrowBox[{91, 92}, 0.17135878410227104`], 
         ArrowBox[{92, 251}, 0.17135878410227104`], 
         ArrowBox[{93, 94}, 0.17135878410227104`], 
         ArrowBox[{94, 239}, 0.17135878410227104`], 
         ArrowBox[{95, 96}, 0.17135878410227104`], 
         ArrowBox[{96, 116}, 0.17135878410227104`], 
         ArrowBox[{97, 98}, 0.17135878410227104`], 
         ArrowBox[{98, 101}, 0.17135878410227104`], 
         ArrowBox[{99, 100}, 0.17135878410227104`], 
         ArrowBox[{100, 304}, 0.17135878410227104`], 
         ArrowBox[{101, 600}, 0.17135878410227104`], 
         ArrowBox[{102, 103}, 0.17135878410227104`], 
         ArrowBox[{103, 29}, 0.17135878410227104`], 
         ArrowBox[{104, 105}, 0.17135878410227104`], 
         ArrowBox[{105, 297}, 0.17135878410227104`], 
         ArrowBox[{106, 107}, 0.17135878410227104`], 
         ArrowBox[{107, 449}, 0.17135878410227104`], 
         ArrowBox[{108, 109}, 0.17135878410227104`], 
         ArrowBox[{109, 596}, 0.17135878410227104`], 
         ArrowBox[{110, 111}, 0.17135878410227104`], 
         ArrowBox[{111, 20}, 0.17135878410227104`], 
         ArrowBox[{112, 113}, 0.17135878410227104`], 
         ArrowBox[{113, 298}, 0.17135878410227104`], 
         ArrowBox[{114, 115}, 0.17135878410227104`], 
         ArrowBox[{115, 96}, 0.17135878410227104`], 
         ArrowBox[{116, 595}, 0.17135878410227104`], 
         ArrowBox[{117, 103}, 0.17135878410227104`], 
         ArrowBox[{118, 105}, 0.17135878410227104`], 
         ArrowBox[{119, 120}, 0.17135878410227104`], 
         ArrowBox[{120, 80}, 0.17135878410227104`], 
         ArrowBox[{121, 122}, 0.17135878410227104`], 
         ArrowBox[{122, 4}, 0.17135878410227104`], 
         ArrowBox[{123, 124}, 0.17135878410227104`], 
         ArrowBox[{124, 864}, 0.17135878410227104`], 
         ArrowBox[{125, 126}, 0.17135878410227104`], 
         ArrowBox[{126, 601}, 0.17135878410227104`], 
         ArrowBox[{127, 128}, 0.17135878410227104`], 
         ArrowBox[{128, 261}, 0.17135878410227104`], 
         ArrowBox[{129, 130}, 0.17135878410227104`], 
         ArrowBox[{130, 4}, 0.17135878410227104`], 
         ArrowBox[{131, 132}, 0.17135878410227104`], 
         ArrowBox[{132, 981}, 0.17135878410227104`], 
         ArrowBox[{133, 134}, 0.17135878410227104`], 
         ArrowBox[{134, 558}, 0.17135878410227104`], 
         ArrowBox[{135, 136}, 0.17135878410227104`], 
         ArrowBox[{136, 50}, 0.17135878410227104`], 
         ArrowBox[{137, 138}, 0.17135878410227104`], 
         ArrowBox[{138, 4}, 0.17135878410227104`], 
         ArrowBox[{139, 140}, 0.17135878410227104`], 
         ArrowBox[{140, 389}, 0.17135878410227104`], 
         ArrowBox[{141, 142}, 0.17135878410227104`], 
         ArrowBox[{142, 379}, 0.17135878410227104`], 
         ArrowBox[{143, 144}, 0.17135878410227104`], 
         ArrowBox[{144, 54}, 0.17135878410227104`], 
         ArrowBox[{145, 138}, 0.17135878410227104`], 
         ArrowBox[{146, 147}, 0.17135878410227104`], 
         ArrowBox[{147, 393}, 0.17135878410227104`], 
         ArrowBox[{148, 142}, 0.17135878410227104`], 
         ArrowBox[{149, 150}, 0.17135878410227104`], 
         ArrowBox[{150, 195}, 0.17135878410227104`], 
         ArrowBox[{151, 121}, 0.17135878410227104`], 
         ArrowBox[{152, 153}, 0.17135878410227104`], 
         ArrowBox[{153, 486}, 0.17135878410227104`], 
         ArrowBox[{154, 155}, 0.17135878410227104`], 
         ArrowBox[{155, 222}, 0.17135878410227104`], 
         ArrowBox[{156, 157}, 0.17135878410227104`], 
         ArrowBox[{157, 169}, 0.17135878410227104`], 
         ArrowBox[{158, 159}, 0.17135878410227104`], 
         ArrowBox[{159, 305}, 0.17135878410227104`], 
         ArrowBox[{160, 161}, 0.17135878410227104`], 
         ArrowBox[{161, 613}, 0.17135878410227104`], 
         ArrowBox[{162, 163}, 0.17135878410227104`], 
         ArrowBox[{163, 295}, 0.17135878410227104`], 
         ArrowBox[{164, 165}, 0.17135878410227104`], 
         ArrowBox[{165, 167}, 0.17135878410227104`], 
         ArrowBox[{166, 167}, 0.17135878410227104`], 
         ArrowBox[{167, 122}, 0.17135878410227104`], 
         ArrowBox[{168, 169}, 0.17135878410227104`], 
         ArrowBox[{169, 479}, 0.17135878410227104`], 
         ArrowBox[{170, 171}, 0.17135878410227104`], 
         ArrowBox[{171, 222}, 0.17135878410227104`], 
         ArrowBox[{172, 157}, 0.17135878410227104`], 
         ArrowBox[{173, 159}, 0.17135878410227104`], 
         ArrowBox[{174, 175}, 0.17135878410227104`], 
         ArrowBox[{175, 483}, 0.17135878410227104`], 
         ArrowBox[{176, 177}, 0.17135878410227104`], 
         ArrowBox[{177, 293}, 0.17135878410227104`], 
         ArrowBox[{178, 179}, 0.17135878410227104`], 
         ArrowBox[{179, 195}, 0.17135878410227104`], 
         ArrowBox[{180, 181}, 0.17135878410227104`], 
         ArrowBox[{181, 121}, 0.17135878410227104`], 
         ArrowBox[{182, 183}, 0.17135878410227104`], 
         ArrowBox[{183, 327}, 0.17135878410227104`], 
         ArrowBox[{184, 185}, 0.17135878410227104`], 
         ArrowBox[{185, 819}, 0.17135878410227104`], 
         ArrowBox[{186, 187}, 0.17135878410227104`], 
         ArrowBox[{187, 171}, 0.17135878410227104`], 
         ArrowBox[{188, 121}, 0.17135878410227104`], 
         ArrowBox[{189, 190}, 0.17135878410227104`], 
         ArrowBox[{190, 617}, 0.17135878410227104`], 
         ArrowBox[{191, 192}, 0.17135878410227104`], 
         ArrowBox[{192, 740}, 0.17135878410227104`], 
         ArrowBox[{193, 194}, 0.17135878410227104`], 
         ArrowBox[{194, 138}, 0.17135878410227104`], 
         ArrowBox[{195, 121}, 0.17135878410227104`], 
         ArrowBox[{196, 197}, 0.17135878410227104`], 
         ArrowBox[{197, 151}, 0.17135878410227104`], 
         ArrowBox[{198, 199}, 0.17135878410227104`], 
         ArrowBox[{199, 188}, 0.17135878410227104`], 
         ArrowBox[{200, 201}, 0.17135878410227104`], 
         ArrowBox[{201, 142}, 0.17135878410227104`], 
         ArrowBox[{202, 203}, 0.17135878410227104`], 
         ArrowBox[{203, 493}, 0.17135878410227104`], 
         ArrowBox[{204, 199}, 0.17135878410227104`], 
         ArrowBox[{205, 108}, 0.17135878410227104`], 
         ArrowBox[{206, 33}, 0.17135878410227104`], 
         ArrowBox[{207, 208}, 0.17135878410227104`], 
         ArrowBox[{208, 422}, 0.17135878410227104`], 
         ArrowBox[{209, 210}, 0.17135878410227104`], 
         ArrowBox[{210, 409}, 0.17135878410227104`], 
         ArrowBox[{211, 212}, 0.17135878410227104`], 
         ArrowBox[{212, 22}, 0.17135878410227104`], 
         ArrowBox[{213, 214}, 0.17135878410227104`], 
         ArrowBox[{214, 34}, 0.17135878410227104`], 
         ArrowBox[{215, 216}, 0.17135878410227104`], 
         ArrowBox[{216, 370}, 0.17135878410227104`], 
         ArrowBox[{217, 218}, 0.17135878410227104`], 
         ArrowBox[{218, 571}, 0.17135878410227104`], 
         ArrowBox[{219, 220}, 0.17135878410227104`], 
         ArrowBox[{220, 20}, 0.17135878410227104`], 
         ArrowBox[{221, 222}, 0.17135878410227104`], 
         ArrowBox[{222, 34}, 0.17135878410227104`], 
         ArrowBox[{223, 224}, 0.17135878410227104`], 
         ArrowBox[{224, 417}, 0.17135878410227104`], 
         ArrowBox[{225, 226}, 0.17135878410227104`], 
         ArrowBox[{226, 72}, 0.17135878410227104`], 
         ArrowBox[{227, 212}, 0.17135878410227104`], 
         ArrowBox[{228, 214}, 0.17135878410227104`], 
         ArrowBox[{229, 230}, 0.17135878410227104`], 
         ArrowBox[{230, 213}, 0.17135878410227104`], 
         ArrowBox[{231, 232}, 0.17135878410227104`], 
         ArrowBox[{232, 72}, 0.17135878410227104`], 
         ArrowBox[{233, 4}, 0.17135878410227104`], 
         ArrowBox[{234, 8}, 0.17135878410227104`], 
         ArrowBox[{235, 8}, 0.17135878410227104`], 
         ArrowBox[{236, 237}, 0.17135878410227104`], 
         ArrowBox[{237, 646}, 0.17135878410227104`], 
         ArrowBox[{238, 239}, 0.17135878410227104`], 
         ArrowBox[{239, 646}, 0.17135878410227104`], 
         ArrowBox[{240, 241}, 0.17135878410227104`], 
         ArrowBox[{241, 792}, 0.17135878410227104`], 
         ArrowBox[{242, 243}, 0.17135878410227104`], 
         ArrowBox[{243, 792}, 0.17135878410227104`], 
         ArrowBox[{244, 20}, 0.17135878410227104`], 
         ArrowBox[{245, 20}, 0.17135878410227104`], 
         ArrowBox[{246, 24}, 0.17135878410227104`], 
         ArrowBox[{247, 24}, 0.17135878410227104`], 
         ArrowBox[{248, 249}, 0.17135878410227104`], 
         ArrowBox[{249, 82}, 0.17135878410227104`], 
         ArrowBox[{250, 251}, 0.17135878410227104`], 
         ArrowBox[{251, 579}, 0.17135878410227104`], 
         ArrowBox[{252, 253}, 0.17135878410227104`], 
         ArrowBox[{253, 284}, 0.17135878410227104`], 
         ArrowBox[{254, 255}, 0.17135878410227104`], 
         ArrowBox[{255, 282}, 0.17135878410227104`], 
         ArrowBox[{256, 38}, 0.17135878410227104`], 
         ArrowBox[{257, 38}, 0.17135878410227104`], 
         ArrowBox[{258, 259}, 0.17135878410227104`], 
         ArrowBox[{259, 618}, 0.17135878410227104`], 
         ArrowBox[{260, 261}, 0.17135878410227104`], 
         ArrowBox[{261, 326}, 0.17135878410227104`], 
         ArrowBox[{262, 263}, 0.17135878410227104`], 
         ArrowBox[{263, 356}, 0.17135878410227104`], 
         ArrowBox[{264, 54}, 0.17135878410227104`], 
         ArrowBox[{265, 50}, 0.17135878410227104`], 
         ArrowBox[{266, 50}, 0.17135878410227104`], 
         ArrowBox[{267, 54}, 0.17135878410227104`], 
         ArrowBox[{268, 54}, 0.17135878410227104`], 
         ArrowBox[{269, 270}, 0.17135878410227104`], 
         ArrowBox[{270, 620}, 0.17135878410227104`], 
         ArrowBox[{271, 50}, 0.17135878410227104`], 
         ArrowBox[{272, 263}, 0.17135878410227104`], 
         ArrowBox[{273, 54}, 0.17135878410227104`], 
         ArrowBox[{274, 275}, 0.17135878410227104`], 
         ArrowBox[{275, 806}, 0.17135878410227104`], 
         ArrowBox[{276, 277}, 0.17135878410227104`], 
         ArrowBox[{277, 307}, 0.17135878410227104`], 
         ArrowBox[{278, 279}, 0.17135878410227104`], 
         ArrowBox[{279, 328}, 0.17135878410227104`], 
         ArrowBox[{280, 281}, 0.17135878410227104`], 
         ArrowBox[{281, 740}, 0.17135878410227104`], 
         ArrowBox[{282, 1013}, 0.17135878410227104`], 
         ArrowBox[{283, 372}, 0.17135878410227104`], 
         ArrowBox[{284, 607}, 0.17135878410227104`], 
         ArrowBox[{285, 286}, 0.17135878410227104`], 
         ArrowBox[{286, 836}, 0.17135878410227104`], 
         ArrowBox[{287, 48}, 0.17135878410227104`], 
         ArrowBox[{288, 52}, 0.17135878410227104`], 
         ArrowBox[{289, 56}, 0.17135878410227104`], 
         ArrowBox[{290, 44}, 0.17135878410227104`], 
         ArrowBox[{291, 292}, 0.17135878410227104`], 
         ArrowBox[{292, 442}, 0.17135878410227104`], 
         ArrowBox[{293, 294}, 0.17135878410227104`], 
         ArrowBox[{294, 261}, 0.17135878410227104`], 
         ArrowBox[{295, 87}, 0.17135878410227104`], 
         ArrowBox[{296, 71}, 0.17135878410227104`], 
         ArrowBox[{297, 413}, 0.17135878410227104`], 
         ArrowBox[{298, 584}, 0.17135878410227104`], 
         ArrowBox[{299, 29}, 0.17135878410227104`], 
         ArrowBox[{300, 24}, 0.17135878410227104`], 
         ArrowBox[{301, 18}, 0.17135878410227104`], 
         ArrowBox[{302, 24}, 0.17135878410227104`], 
         ArrowBox[{303, 26}, 0.17135878410227104`], 
         ArrowBox[{304, 24}, 0.17135878410227104`], 
         ArrowBox[{305, 64}, 0.17135878410227104`], 
         ArrowBox[{306, 126}, 0.17135878410227104`], 
         ArrowBox[{307, 126}, 0.17135878410227104`], 
         ArrowBox[{308, 309}, 0.17135878410227104`], 
         ArrowBox[{309, 275}, 0.17135878410227104`], 
         ArrowBox[{310, 311}, 0.17135878410227104`], 
         ArrowBox[{311, 4}, 0.17135878410227104`], 
         ArrowBox[{312, 313}, 0.17135878410227104`], 
         ArrowBox[{313, 101}, 0.17135878410227104`], 
         ArrowBox[{314, 315}, 0.17135878410227104`], 
         ArrowBox[{315, 101}, 0.17135878410227104`], 
         ArrowBox[{316, 276}, 0.17135878410227104`], 
         ArrowBox[{317, 138}, 0.17135878410227104`], 
         ArrowBox[{318, 142}, 0.17135878410227104`], 
         ArrowBox[{319, 142}, 0.17135878410227104`], 
         ArrowBox[{320, 278}, 0.17135878410227104`], 
         ArrowBox[{321, 233}, 0.17135878410227104`], 
         ArrowBox[{322, 323}, 0.17135878410227104`], 
         ArrowBox[{323, 113}, 0.17135878410227104`], 
         ArrowBox[{324, 325}, 0.17135878410227104`], 
         ArrowBox[{325, 379}, 0.17135878410227104`], 
         ArrowBox[{326, 180}, 0.17135878410227104`], 
         ArrowBox[{327, 155}, 0.17135878410227104`], 
         ArrowBox[{328, 155}, 0.17135878410227104`], 
         ArrowBox[{329, 330}, 0.17135878410227104`], 
         ArrowBox[{330, 351}, 0.17135878410227104`], 
         ArrowBox[{331, 167}, 0.17135878410227104`], 
         ArrowBox[{332, 333}, 0.17135878410227104`], 
         ArrowBox[{333, 218}, 0.17135878410227104`], 
         ArrowBox[{334, 335}, 0.17135878410227104`], 
         ArrowBox[{335, 214}, 0.17135878410227104`], 
         ArrowBox[{336, 337}, 0.17135878410227104`], 
         ArrowBox[{337, 348}, 0.17135878410227104`], 
         ArrowBox[{338, 167}, 0.17135878410227104`], 
         ArrowBox[{339, 171}, 0.17135878410227104`], 
         ArrowBox[{340, 171}, 0.17135878410227104`], 
         ArrowBox[{341, 330}, 0.17135878410227104`], 
         ArrowBox[{342, 167}, 0.17135878410227104`], 
         ArrowBox[{343, 344}, 0.17135878410227104`], 
         ArrowBox[{344, 471}, 0.17135878410227104`], 
         ArrowBox[{345, 171}, 0.17135878410227104`], 
         ArrowBox[{346, 347}, 0.17135878410227104`], 
         ArrowBox[{347, 195}, 0.17135878410227104`], 
         ArrowBox[{348, 122}, 0.17135878410227104`], 
         ArrowBox[{349, 350}, 0.17135878410227104`], 
         ArrowBox[{350, 776}, 0.17135878410227104`], 
         ArrowBox[{351, 257}, 0.17135878410227104`], 
         ArrowBox[{352, 169}, 0.17135878410227104`], 
         ArrowBox[{353, 305}, 0.17135878410227104`], 
         ArrowBox[{354, 355}, 0.17135878410227104`], 
         ArrowBox[{355, 614}, 0.17135878410227104`], 
         ArrowBox[{356, 291}, 0.17135878410227104`], 
         ArrowBox[{357, 165}, 0.17135878410227104`], 
         ArrowBox[{358, 171}, 0.17135878410227104`], 
         ArrowBox[{359, 157}, 0.17135878410227104`], 
         ArrowBox[{360, 177}, 0.17135878410227104`], 
         ArrowBox[{361, 79}, 0.17135878410227104`], 
         ArrowBox[{362, 3}, 0.17135878410227104`], 
         ArrowBox[{363, 364}, 0.17135878410227104`], 
         ArrowBox[{364, 396}, 0.17135878410227104`], 
         ArrowBox[{365, 366}, 0.17135878410227104`], 
         ArrowBox[{366, 379}, 0.17135878410227104`], 
         ArrowBox[{367, 144}, 0.17135878410227104`], 
         ArrowBox[{368, 369}, 0.17135878410227104`], 
         ArrowBox[{369, 568}, 0.17135878410227104`], 
         ArrowBox[{370, 371}, 0.17135878410227104`], 
         ArrowBox[{371, 101}, 0.17135878410227104`], 
         ArrowBox[{372, 136}, 0.17135878410227104`], 
         ArrowBox[{373, 140}, 0.17135878410227104`], 
         ArrowBox[{374, 144}, 0.17135878410227104`], 
         ArrowBox[{375, 147}, 0.17135878410227104`], 
         ArrowBox[{376, 377}, 0.17135878410227104`], 
         ArrowBox[{377, 109}, 0.17135878410227104`], 
         ArrowBox[{378, 379}, 0.17135878410227104`], 
         ArrowBox[{379, 596}, 0.17135878410227104`], 
         ArrowBox[{380, 111}, 0.17135878410227104`], 
         ArrowBox[{381, 113}, 0.17135878410227104`], 
         ArrowBox[{382, 383}, 0.17135878410227104`], 
         ArrowBox[{383, 113}, 0.17135878410227104`], 
         ArrowBox[{384, 304}, 0.17135878410227104`], 
         ArrowBox[{385, 113}, 0.17135878410227104`], 
         ArrowBox[{386, 387}, 0.17135878410227104`], 
         ArrowBox[{387, 516}, 0.17135878410227104`], 
         ArrowBox[{388, 389}, 0.17135878410227104`], 
         ArrowBox[{389, 903}, 0.17135878410227104`], 
         ArrowBox[{390, 391}, 0.17135878410227104`], 
         ArrowBox[{391, 639}, 0.17135878410227104`], 
         ArrowBox[{392, 393}, 0.17135878410227104`], 
         ArrowBox[{393, 642}, 0.17135878410227104`], 
         ArrowBox[{394, 395}, 0.17135878410227104`], 
         ArrowBox[{395, 544}, 0.17135878410227104`], 
         ArrowBox[{396, 72}, 0.17135878410227104`], 
         ArrowBox[{397, 398}, 0.17135878410227104`], 
         ArrowBox[{398, 259}, 0.17135878410227104`], 
         ArrowBox[{399, 400}, 0.17135878410227104`], 
         ArrowBox[{400, 259}, 0.17135878410227104`], 
         ArrowBox[{401, 402}, 0.17135878410227104`], 
         ArrowBox[{402, 328}, 0.17135878410227104`], 
         ArrowBox[{403, 72}, 0.17135878410227104`], 
         ArrowBox[{404, 405}, 0.17135878410227104`], 
         ArrowBox[{405, 307}, 0.17135878410227104`], 
         ArrowBox[{406, 76}, 0.17135878410227104`], 
         ArrowBox[{407, 408}, 0.17135878410227104`], 
         ArrowBox[{408, 197}, 0.17135878410227104`], 
         ArrowBox[{409, 492}, 0.17135878410227104`], 
         ArrowBox[{410, 411}, 0.17135878410227104`], 
         ArrowBox[{411, 169}, 0.17135878410227104`], 
         ArrowBox[{412, 413}, 0.17135878410227104`], 
         ArrowBox[{413, 165}, 0.17135878410227104`], 
         ArrowBox[{414, 415}, 0.17135878410227104`], 
         ArrowBox[{415, 3}, 0.17135878410227104`], 
         ArrowBox[{416, 417}, 0.17135878410227104`], 
         ArrowBox[{417, 130}, 0.17135878410227104`], 
         ArrowBox[{418, 228}, 0.17135878410227104`], 
         ArrowBox[{419, 213}, 0.17135878410227104`], 
         ArrowBox[{420, 421}, 0.17135878410227104`], 
         ArrowBox[{421, 416}, 0.17135878410227104`], 
         ArrowBox[{422, 638}, 0.17135878410227104`], 
         ArrowBox[{423, 375}, 0.17135878410227104`], 
         ArrowBox[{424, 367}, 0.17135878410227104`], 
         ArrowBox[{425, 426}, 0.17135878410227104`], 
         ArrowBox[{426, 500}, 0.17135878410227104`], 
         ArrowBox[{427, 261}, 0.17135878410227104`], 
         ArrowBox[{428, 52}, 0.17135878410227104`], 
         ArrowBox[{429, 54}, 0.17135878410227104`], 
         ArrowBox[{430, 431}, 0.17135878410227104`], 
         ArrowBox[{431, 637}, 0.17135878410227104`], 
         ArrowBox[{432, 360}, 0.17135878410227104`], 
         ArrowBox[{433, 54}, 0.17135878410227104`], 
         ArrowBox[{434, 435}, 0.17135878410227104`], 
         ArrowBox[{435, 348}, 0.17135878410227104`], 
         ArrowBox[{436, 437}, 0.17135878410227104`], 
         ArrowBox[{437, 167}, 0.17135878410227104`], 
         ArrowBox[{438, 279}, 0.17135878410227104`], 
         ArrowBox[{439, 281}, 0.17135878410227104`], 
         ArrowBox[{440, 441}, 0.17135878410227104`], 
         ArrowBox[{441, 634}, 0.17135878410227104`], 
         ArrowBox[{442, 195}, 0.17135878410227104`], 
         ArrowBox[{443, 444}, 0.17135878410227104`], 
         ArrowBox[{444, 605}, 0.17135878410227104`], 
         ArrowBox[{445, 446}, 0.17135878410227104`], 
         ArrowBox[{446, 805}, 0.17135878410227104`], 
         ArrowBox[{447, 448}, 0.17135878410227104`], 
         ArrowBox[{448, 999}, 0.17135878410227104`], 
         ArrowBox[{449, 12}, 0.17135878410227104`], 
         ArrowBox[{450, 451}, 0.17135878410227104`], 
         ArrowBox[{451, 629}, 0.17135878410227104`], 
         ArrowBox[{452, 16}, 0.17135878410227104`], 
         ArrowBox[{453, 454}, 0.17135878410227104`], 
         ArrowBox[{454, 872}, 0.17135878410227104`], 
         ArrowBox[{455, 456}, 0.17135878410227104`], 
         ArrowBox[{456, 635}, 0.17135878410227104`], 
         ArrowBox[{457, 243}, 0.17135878410227104`], 
         ArrowBox[{458, 436}, 0.17135878410227104`], 
         ArrowBox[{459, 427}, 0.17135878410227104`], 
         ArrowBox[{460, 87}, 0.17135878410227104`], 
         ArrowBox[{461, 71}, 0.17135878410227104`], 
         ArrowBox[{462, 463}, 0.17135878410227104`], 
         ArrowBox[{463, 66}, 0.17135878410227104`], 
         ArrowBox[{464, 290}, 0.17135878410227104`], 
         ArrowBox[{465, 255}, 0.17135878410227104`], 
         ArrowBox[{466, 220}, 0.17135878410227104`], 
         ArrowBox[{467, 222}, 0.17135878410227104`], 
         ArrowBox[{468, 469}, 0.17135878410227104`], 
         ArrowBox[{469, 80}, 0.17135878410227104`], 
         ArrowBox[{470, 471}, 0.17135878410227104`], 
         ArrowBox[{471, 72}, 0.17135878410227104`], 
         ArrowBox[{472, 302}, 0.17135878410227104`], 
         ArrowBox[{473, 474}, 0.17135878410227104`], 
         ArrowBox[{474, 84}, 0.17135878410227104`], 
         ArrowBox[{475, 471}, 0.17135878410227104`], 
         ArrowBox[{476, 477}, 0.17135878410227104`], 
         ArrowBox[{477, 80}, 0.17135878410227104`], 
         ArrowBox[{478, 479}, 0.17135878410227104`], 
         ArrowBox[{479, 34}, 0.17135878410227104`], 
         ArrowBox[{480, 481}, 0.17135878410227104`], 
         ArrowBox[{481, 417}, 0.17135878410227104`], 
         ArrowBox[{482, 483}, 0.17135878410227104`], 
         ArrowBox[{483, 72}, 0.17135878410227104`], 
         ArrowBox[{484, 485}, 0.17135878410227104`], 
         ArrowBox[{485, 261}, 0.17135878410227104`], 
         ArrowBox[{486, 34}, 0.17135878410227104`], 
         ArrowBox[{487, 488}, 0.17135878410227104`], 
         ArrowBox[{488, 544}, 0.17135878410227104`], 
         ArrowBox[{489, 490}, 0.17135878410227104`], 
         ArrowBox[{490, 72}, 0.17135878410227104`], 
         ArrowBox[{491, 492}, 0.17135878410227104`], 
         ArrowBox[{492, 167}, 0.17135878410227104`], 
         ArrowBox[{493, 188}, 0.17135878410227104`], 
         ArrowBox[{494, 495}, 0.17135878410227104`], 
         ArrowBox[{495, 328}, 0.17135878410227104`], 
         ArrowBox[{496, 192}, 0.17135878410227104`], 
         ArrowBox[{497, 498}, 0.17135878410227104`], 
         ArrowBox[{498, 169}, 0.17135878410227104`], 
         ArrowBox[{499, 500}, 0.17135878410227104`], 
         ArrowBox[{500, 180}, 0.17135878410227104`], 
         ArrowBox[{501, 502}, 0.17135878410227104`], 
         ArrowBox[{502, 199}, 0.17135878410227104`], 
         ArrowBox[{503, 504}, 0.17135878410227104`], 
         ArrowBox[{504, 615}, 0.17135878410227104`], 
         ArrowBox[{505, 221}, 0.17135878410227104`], 
         ArrowBox[{506, 151}, 0.17135878410227104`], 
         ArrowBox[{507, 506}, 0.17135878410227104`], 
         ArrowBox[{508, 493}, 0.17135878410227104`], 
         ArrowBox[{509, 373}, 0.17135878410227104`], 
         ArrowBox[{510, 326}, 0.17135878410227104`], 
         ArrowBox[{511, 512}, 0.17135878410227104`], 
         ArrowBox[{512, 493}, 0.17135878410227104`], 
         ArrowBox[{513, 514}, 0.17135878410227104`], 
         ArrowBox[{514, 615}, 0.17135878410227104`], 
         ArrowBox[{515, 165}, 0.17135878410227104`], 
         ArrowBox[{516, 167}, 0.17135878410227104`], 
         ArrowBox[{517, 518}, 0.17135878410227104`], 
         ArrowBox[{518, 612}, 0.17135878410227104`], 
         ArrowBox[{519, 335}, 0.17135878410227104`], 
         ArrowBox[{520, 358}, 0.17135878410227104`], 
         ArrowBox[{521, 522}, 0.17135878410227104`], 
         ArrowBox[{522, 614}, 0.17135878410227104`], 
         ArrowBox[{523, 335}, 0.17135878410227104`], 
         ArrowBox[{524, 347}, 0.17135878410227104`], 
         ArrowBox[{525, 348}, 0.17135878410227104`], 
         ArrowBox[{526, 527}, 0.17135878410227104`], 
         ArrowBox[{527, 479}, 0.17135878410227104`], 
         ArrowBox[{528, 529}, 0.17135878410227104`], 
         ArrowBox[{529, 222}, 0.17135878410227104`], 
         ArrowBox[{530, 531}, 0.17135878410227104`], 
         ArrowBox[{531, 171}, 0.17135878410227104`], 
         ArrowBox[{532, 122}, 0.17135878410227104`], 
         ArrowBox[{533, 534}, 0.17135878410227104`], 
         ArrowBox[{534, 483}, 0.17135878410227104`], 
         ArrowBox[{535, 536}, 0.17135878410227104`], 
         ArrowBox[{536, 222}, 0.17135878410227104`], 
         ArrowBox[{537, 538}, 0.17135878410227104`], 
         ArrowBox[{538, 50}, 0.17135878410227104`], 
         ArrowBox[{539, 540}, 0.17135878410227104`], 
         ArrowBox[{540, 563}, 0.17135878410227104`], 
         ArrowBox[{541, 134}, 0.17135878410227104`], 
         ArrowBox[{542, 543}, 0.17135878410227104`], 
         ArrowBox[{543, 426}, 0.17135878410227104`], 
         ArrowBox[{544, 311}, 0.17135878410227104`], 
         ArrowBox[{545, 546}, 0.17135878410227104`], 
         ArrowBox[{546, 980}, 0.17135878410227104`], 
         ArrowBox[{547, 315}, 0.17135878410227104`], 
         ArrowBox[{548, 79}, 0.17135878410227104`], 
         ArrowBox[{549, 388}, 0.17135878410227104`], 
         ArrowBox[{550, 378}, 0.17135878410227104`], 
         ArrowBox[{551, 288}, 0.17135878410227104`], 
         ArrowBox[{552, 233}, 0.17135878410227104`], 
         ArrowBox[{553, 554}, 0.17135878410227104`], 
         ArrowBox[{554, 393}, 0.17135878410227104`], 
         ArrowBox[{555, 325}, 0.17135878410227104`], 
         ArrowBox[{556, 113}, 0.17135878410227104`], 
         ArrowBox[{557, 558}, 0.17135878410227104`], 
         ArrowBox[{558, 398}, 0.17135878410227104`], 
         ArrowBox[{559, 299}, 0.17135878410227104`], 
         ArrowBox[{560, 105}, 0.17135878410227104`], 
         ArrowBox[{561, 389}, 0.17135878410227104`], 
         ArrowBox[{562, 563}, 0.17135878410227104`], 
         ArrowBox[{563, 402}, 0.17135878410227104`], 
         ArrowBox[{564, 565}, 0.17135878410227104`], 
         ArrowBox[{565, 402}, 0.17135878410227104`], 
         ArrowBox[{566, 567}, 0.17135878410227104`], 
         ArrowBox[{567, 426}, 0.17135878410227104`], 
         ArrowBox[{568, 426}, 0.17135878410227104`], 
         ArrowBox[{569, 76}, 0.17135878410227104`], 
         ArrowBox[{570, 76}, 0.17135878410227104`], 
         ArrowBox[{571, 622}, 0.17135878410227104`], 
         ArrowBox[{572, 573}, 0.17135878410227104`], 
         ArrowBox[{573, 333}, 0.17135878410227104`], 
         ArrowBox[{574, 76}, 0.17135878410227104`], 
         ArrowBox[{575, 417}, 0.17135878410227104`], 
         ArrowBox[{576, 213}, 0.17135878410227104`], 
         ArrowBox[{577, 578}, 0.17135878410227104`], 
         ArrowBox[{578, 641}, 0.17135878410227104`], 
         ArrowBox[{579, 222}, 0.17135878410227104`], 
         ArrowBox[{580, 486}, 0.17135878410227104`], 
         ArrowBox[{581, 84}, 0.17135878410227104`], 
         ArrowBox[{582, 583}, 0.17135878410227104`], 
         ArrowBox[{583, 576}, 0.17135878410227104`], 
         ArrowBox[{584, 485}, 0.17135878410227104`], 
         ArrowBox[{585, 375}, 0.17135878410227104`], 
         ArrowBox[{586, 367}, 0.17135878410227104`], 
         ArrowBox[{587, 588}, 0.17135878410227104`], 
         ArrowBox[{588, 121}, 0.17135878410227104`], 
         ArrowBox[{589, 532}, 0.17135878410227104`], 
         ArrowBox[{590, 591}, 0.17135878410227104`], 
         ArrowBox[{591, 506}, 0.17135878410227104`], 
         ArrowBox[{592, 593}, 0.17135878410227104`], 
         ArrowBox[{593, 492}, 0.17135878410227104`], 
         ArrowBox[{594, 411}, 0.17135878410227104`], 
         ArrowBox[{595, 578}, 0.17135878410227104`], 
         ArrowBox[{596, 571}, 0.17135878410227104`], 
         ArrowBox[{597, 598}, 0.17135878410227104`], 
         ArrowBox[{598, 270}, 0.17135878410227104`], 
         ArrowBox[{599, 400}, 0.17135878410227104`], 
         ArrowBox[{600, 644}, 0.17135878410227104`], 
         ArrowBox[{601, 400}, 0.17135878410227104`], 
         ArrowBox[{602, 459}, 0.17135878410227104`], 
         ArrowBox[{603, 98}, 0.17135878410227104`], 
         ArrowBox[{604, 603}, 0.17135878410227104`], 
         ArrowBox[{605, 471}, 0.17135878410227104`], 
         ArrowBox[{606, 572}, 0.17135878410227104`], 
         ArrowBox[{607, 608}, 0.17135878410227104`], 
         ArrowBox[{608, 544}, 0.17135878410227104`], 
         ArrowBox[{609, 483}, 0.17135878410227104`], 
         ArrowBox[{610, 611}, 0.17135878410227104`], 
         ArrowBox[{611, 32}, 0.17135878410227104`], 
         ArrowBox[{612, 34}, 0.17135878410227104`], 
         ArrowBox[{613, 72}, 0.17135878410227104`], 
         ArrowBox[{614, 72}, 0.17135878410227104`], 
         ArrowBox[{615, 121}, 0.17135878410227104`], 
         ArrowBox[{616, 192}, 0.17135878410227104`], 
         ArrowBox[{617, 192}, 0.17135878410227104`], 
         ArrowBox[{618, 619}, 0.17135878410227104`], 
         ArrowBox[{619, 155}, 0.17135878410227104`], 
         ArrowBox[{620, 188}, 0.17135878410227104`], 
         ArrowBox[{621, 622}, 0.17135878410227104`], 
         ArrowBox[BezierCurveBox[{622, 1028, 1031, 1033, 1039, 1041, 1044, 
          622},
          SplineDegree->7], 0.17135878410227104`], 
         ArrowBox[{623, 192}, 0.17135878410227104`], 
         ArrowBox[{624, 206}, 0.17135878410227104`], 
         ArrowBox[{625, 365}, 0.17135878410227104`], 
         ArrowBox[{626, 195}, 0.17135878410227104`], 
         ArrowBox[{627, 617}, 0.17135878410227104`], 
         ArrowBox[{628, 199}, 0.17135878410227104`], 
         ArrowBox[{629, 626}, 0.17135878410227104`], 
         ArrowBox[{630, 627}, 0.17135878410227104`], 
         ArrowBox[{631, 179}, 0.17135878410227104`], 
         ArrowBox[{632, 151}, 0.17135878410227104`], 
         ArrowBox[{633, 634}, 0.17135878410227104`], 
         ArrowBox[{634, 188}, 0.17135878410227104`], 
         ArrowBox[{635, 498}, 0.17135878410227104`], 
         ArrowBox[{636, 493}, 0.17135878410227104`], 
         ArrowBox[{637, 615}, 0.17135878410227104`], 
         ArrowBox[{638, 50}, 0.17135878410227104`], 
         ArrowBox[{639, 640}, 0.17135878410227104`], 
         ArrowBox[{640, 578}, 0.17135878410227104`], 
         ArrowBox[{641, 571}, 0.17135878410227104`], 
         ArrowBox[{642, 643}, 0.17135878410227104`], 
         ArrowBox[{643, 644}, 0.17135878410227104`], 
         ArrowBox[{644, 641}, 0.17135878410227104`], 
         ArrowBox[{645, 108}, 0.17135878410227104`], 
         ArrowBox[{646, 302}, 0.17135878410227104`], 
         ArrowBox[{647, 226}, 0.17135878410227104`], 
         ArrowBox[{648, 2}, 0.17135878410227104`], 
         ArrowBox[{649, 2}, 0.17135878410227104`], 
         ArrowBox[{650, 4}, 0.17135878410227104`], 
         ArrowBox[{651, 448}, 0.17135878410227104`], 
         ArrowBox[{652, 653}, 0.17135878410227104`], 
         ArrowBox[{653, 642}, 0.17135878410227104`], 
         ArrowBox[{654, 448}, 0.17135878410227104`], 
         ArrowBox[{655, 653}, 0.17135878410227104`], 
         ArrowBox[{656, 18}, 0.17135878410227104`], 
         ArrowBox[{657, 20}, 0.17135878410227104`], 
         ArrowBox[{658, 592}, 0.17135878410227104`], 
         ArrowBox[{659, 298}, 0.17135878410227104`], 
         ArrowBox[{660, 18}, 0.17135878410227104`], 
         ArrowBox[{661, 581}, 0.17135878410227104`], 
         ArrowBox[{662, 592}, 0.17135878410227104`], 
         ArrowBox[{663, 586}, 0.17135878410227104`], 
         ArrowBox[{664, 32}, 0.17135878410227104`], 
         ArrowBox[{665, 32}, 0.17135878410227104`], 
         ArrowBox[{666, 34}, 0.17135878410227104`], 
         ArrowBox[{667, 635}, 0.17135878410227104`], 
         ArrowBox[{668, 630}, 0.17135878410227104`], 
         ArrowBox[{669, 635}, 0.17135878410227104`], 
         ArrowBox[{670, 630}, 0.17135878410227104`], 
         ArrowBox[{671, 48}, 0.17135878410227104`], 
         ArrowBox[{672, 50}, 0.17135878410227104`], 
         ArrowBox[{673, 426}, 0.17135878410227104`], 
         ArrowBox[{674, 261}, 0.17135878410227104`], 
         ArrowBox[{675, 631}, 0.17135878410227104`], 
         ArrowBox[{676, 629}, 0.17135878410227104`], 
         ArrowBox[{677, 635}, 0.17135878410227104`], 
         ArrowBox[{678, 630}, 0.17135878410227104`], 
         ArrowBox[{679, 62}, 0.17135878410227104`], 
         ArrowBox[{680, 62}, 0.17135878410227104`], 
         ArrowBox[{681, 64}, 0.17135878410227104`], 
         ArrowBox[{682, 402}, 0.17135878410227104`], 
         ArrowBox[{683, 402}, 0.17135878410227104`], 
         ArrowBox[{684, 571}, 0.17135878410227104`], 
         ArrowBox[{685, 78}, 0.17135878410227104`], 
         ArrowBox[{686, 579}, 0.17135878410227104`], 
         ArrowBox[{687, 580}, 0.17135878410227104`], 
         ArrowBox[{688, 78}, 0.17135878410227104`], 
         ArrowBox[{689, 579}, 0.17135878410227104`], 
         ArrowBox[{690, 644}, 0.17135878410227104`], 
         ArrowBox[{691, 552}, 0.17135878410227104`], 
         ArrowBox[{692, 552}, 0.17135878410227104`], 
         ArrowBox[{693, 544}, 0.17135878410227104`], 
         ArrowBox[{694, 646}, 0.17135878410227104`], 
         ArrowBox[{695, 646}, 0.17135878410227104`], 
         ArrowBox[{696, 642}, 0.17135878410227104`], 
         ArrowBox[{697, 78}, 0.17135878410227104`], 
         ArrowBox[{698, 579}, 0.17135878410227104`], 
         ArrowBox[{699, 580}, 0.17135878410227104`], 
         ArrowBox[{700, 645}, 0.17135878410227104`], 
         ArrowBox[{701, 646}, 0.17135878410227104`], 
         ArrowBox[{702, 642}, 0.17135878410227104`], 
         ArrowBox[{703, 120}, 0.17135878410227104`], 
         ArrowBox[{704, 124}, 0.17135878410227104`], 
         ArrowBox[{705, 126}, 0.17135878410227104`], 
         ArrowBox[{706, 538}, 0.17135878410227104`], 
         ArrowBox[{707, 708}, 0.17135878410227104`], 
         ArrowBox[{708, 4}, 0.17135878410227104`], 
         ArrowBox[{709, 540}, 0.17135878410227104`], 
         ArrowBox[{710, 711}, 0.17135878410227104`], 
         ArrowBox[{711, 558}, 0.17135878410227104`], 
         ArrowBox[{712, 136}, 0.17135878410227104`], 
         ArrowBox[{713, 138}, 0.17135878410227104`], 
         ArrowBox[{714, 140}, 0.17135878410227104`], 
         ArrowBox[{715, 142}, 0.17135878410227104`], 
         ArrowBox[{716, 136}, 0.17135878410227104`], 
         ArrowBox[{717, 235}, 0.17135878410227104`], 
         ArrowBox[{718, 140}, 0.17135878410227104`], 
         ArrowBox[{719, 556}, 0.17135878410227104`], 
         ArrowBox[{720, 150}, 0.17135878410227104`], 
         ArrowBox[{721, 153}, 0.17135878410227104`], 
         ArrowBox[{722, 155}, 0.17135878410227104`], 
         ArrowBox[{723, 357}, 0.17135878410227104`], 
         ArrowBox[{724, 306}, 0.17135878410227104`], 
         ArrowBox[{725, 610}, 0.17135878410227104`], 
         ArrowBox[{726, 606}, 0.17135878410227104`], 
         ArrowBox[{727, 165}, 0.17135878410227104`], 
         ArrowBox[{728, 167}, 0.17135878410227104`], 
         ArrowBox[{729, 169}, 0.17135878410227104`], 
         ArrowBox[{730, 171}, 0.17135878410227104`], 
         ArrowBox[{731, 357}, 0.17135878410227104`], 
         ArrowBox[{732, 306}, 0.17135878410227104`], 
         ArrowBox[{733, 607}, 0.17135878410227104`], 
         ArrowBox[{734, 605}, 0.17135878410227104`], 
         ArrowBox[{735, 179}, 0.17135878410227104`], 
         ArrowBox[{736, 181}, 0.17135878410227104`], 
         ArrowBox[{737, 183}, 0.17135878410227104`], 
         ArrowBox[{738, 185}, 0.17135878410227104`], 
         ArrowBox[{739, 492}, 0.17135878410227104`], 
         ArrowBox[{740, 155}, 0.17135878410227104`], 
         ArrowBox[{741, 495}, 0.17135878410227104`], 
         ArrowBox[{742, 622}, 0.17135878410227104`], 
         ArrowBox[{743, 194}, 0.17135878410227104`], 
         ArrowBox[{744, 197}, 0.17135878410227104`], 
         ArrowBox[{745, 199}, 0.17135878410227104`], 
         ArrowBox[{746, 194}, 0.17135878410227104`], 
         ArrowBox[{747, 197}, 0.17135878410227104`], 
         ArrowBox[{748, 617}, 0.17135878410227104`], 
         ArrowBox[{749, 221}, 0.17135878410227104`], 
         ArrowBox[{750, 151}, 0.17135878410227104`], 
         ArrowBox[{751, 510}, 0.17135878410227104`], 
         ArrowBox[{752, 499}, 0.17135878410227104`], 
         ArrowBox[{753, 372}, 0.17135878410227104`], 
         ArrowBox[{754, 625}, 0.17135878410227104`], 
         ArrowBox[{755, 621}, 0.17135878410227104`], 
         ArrowBox[{756, 194}, 0.17135878410227104`], 
         ArrowBox[{757, 197}, 0.17135878410227104`], 
         ArrowBox[{758, 199}, 0.17135878410227104`], 
         ArrowBox[{759, 372}, 0.17135878410227104`], 
         ArrowBox[{760, 624}, 0.17135878410227104`], 
         ArrowBox[{761, 616}, 0.17135878410227104`], 
         ArrowBox[{762, 4}, 0.17135878410227104`], 
         ArrowBox[{763, 239}, 0.17135878410227104`], 
         ArrowBox[{764, 237}, 0.17135878410227104`], 
         ArrowBox[{765, 239}, 0.17135878410227104`], 
         ArrowBox[{766, 237}, 0.17135878410227104`], 
         ArrowBox[{767, 20}, 0.17135878410227104`], 
         ArrowBox[{768, 20}, 0.17135878410227104`], 
         ArrowBox[{769, 298}, 0.17135878410227104`], 
         ArrowBox[{770, 298}, 0.17135878410227104`], 
         ArrowBox[{771, 251}, 0.17135878410227104`], 
         ArrowBox[{772, 249}, 0.17135878410227104`], 
         ArrowBox[{773, 582}, 0.17135878410227104`], 
         ArrowBox[{774, 585}, 0.17135878410227104`], 
         ArrowBox[{775, 34}, 0.17135878410227104`], 
         ArrowBox[{776, 34}, 0.17135878410227104`], 
         ArrowBox[{777, 261}, 0.17135878410227104`], 
         ArrowBox[{778, 259}, 0.17135878410227104`], 
         ArrowBox[{779, 261}, 0.17135878410227104`], 
         ArrowBox[{780, 259}, 0.17135878410227104`], 
         ArrowBox[{781, 50}, 0.17135878410227104`], 
         ArrowBox[{782, 50}, 0.17135878410227104`], 
         ArrowBox[{783, 261}, 0.17135878410227104`], 
         ArrowBox[{784, 261}, 0.17135878410227104`], 
         ArrowBox[{785, 50}, 0.17135878410227104`], 
         ArrowBox[{786, 270}, 0.17135878410227104`], 
         ArrowBox[{787, 261}, 0.17135878410227104`], 
         ArrowBox[{788, 259}, 0.17135878410227104`], 
         ArrowBox[{789, 275}, 0.17135878410227104`], 
         ArrowBox[{790, 277}, 0.17135878410227104`], 
         ArrowBox[{791, 277}, 0.17135878410227104`], 
         ArrowBox[{792, 847}, 0.17135878410227104`], 
         ArrowBox[{793, 625}, 0.17135878410227104`], 
         ArrowBox[{794, 793}, 0.17135878410227104`], 
         ArrowBox[{795, 48}, 0.17135878410227104`], 
         ArrowBox[{796, 631}, 0.17135878410227104`], 
         ArrowBox[{797, 32}, 0.17135878410227104`], 
         ArrowBox[{798, 34}, 0.17135878410227104`], 
         ArrowBox[{799, 34}, 0.17135878410227104`], 
         ArrowBox[{800, 259}, 0.17135878410227104`], 
         ArrowBox[{801, 48}, 0.17135878410227104`], 
         ArrowBox[{802, 426}, 0.17135878410227104`], 
         ArrowBox[{803, 48}, 0.17135878410227104`], 
         ArrowBox[{804, 426}, 0.17135878410227104`], 
         ArrowBox[{805, 126}, 0.17135878410227104`], 
         ArrowBox[{806, 126}, 0.17135878410227104`], 
         ArrowBox[{807, 789}, 0.17135878410227104`], 
         ArrowBox[{808, 762}, 0.17135878410227104`], 
         ArrowBox[{809, 315}, 0.17135878410227104`], 
         ArrowBox[{810, 313}, 0.17135878410227104`], 
         ArrowBox[{811, 276}, 0.17135878410227104`], 
         ArrowBox[{812, 138}, 0.17135878410227104`], 
         ArrowBox[{813, 142}, 0.17135878410227104`], 
         ArrowBox[{814, 142}, 0.17135878410227104`], 
         ArrowBox[{815, 274}, 0.17135878410227104`], 
         ArrowBox[{816, 234}, 0.17135878410227104`], 
         ArrowBox[{817, 325}, 0.17135878410227104`], 
         ArrowBox[{818, 323}, 0.17135878410227104`], 
         ArrowBox[{819, 155}, 0.17135878410227104`], 
         ArrowBox[{820, 337}, 0.17135878410227104`], 
         ArrowBox[{821, 307}, 0.17135878410227104`], 
         ArrowBox[{822, 335}, 0.17135878410227104`], 
         ArrowBox[{823, 333}, 0.17135878410227104`], 
         ArrowBox[{824, 337}, 0.17135878410227104`], 
         ArrowBox[{825, 167}, 0.17135878410227104`], 
         ArrowBox[{826, 171}, 0.17135878410227104`], 
         ArrowBox[{827, 171}, 0.17135878410227104`], 
         ArrowBox[{828, 337}, 0.17135878410227104`], 
         ArrowBox[{829, 307}, 0.17135878410227104`], 
         ArrowBox[{830, 171}, 0.17135878410227104`], 
         ArrowBox[{831, 344}, 0.17135878410227104`], 
         ArrowBox[{832, 347}, 0.17135878410227104`], 
         ArrowBox[{833, 348}, 0.17135878410227104`], 
         ArrowBox[{834, 350}, 0.17135878410227104`], 
         ArrowBox[{835, 351}, 0.17135878410227104`], 
         ArrowBox[{836, 165}, 0.17135878410227104`], 
         ArrowBox[{837, 838}, 0.17135878410227104`], 
         ArrowBox[{838, 797}, 0.17135878410227104`], 
         ArrowBox[{839, 840}, 0.17135878410227104`], 
         ArrowBox[{840, 218}, 0.17135878410227104`], 
         ArrowBox[{841, 167}, 0.17135878410227104`], 
         ArrowBox[{842, 357}, 0.17135878410227104`], 
         ArrowBox[{843, 306}, 0.17135878410227104`], 
         ArrowBox[{844, 150}, 0.17135878410227104`], 
         ArrowBox[{845, 153}, 0.17135878410227104`], 
         ArrowBox[{846, 518}, 0.17135878410227104`], 
         ArrowBox[{847, 165}, 0.17135878410227104`], 
         ArrowBox[{848, 165}, 0.17135878410227104`], 
         ArrowBox[{849, 377}, 0.17135878410227104`], 
         ArrowBox[{850, 379}, 0.17135878410227104`], 
         ArrowBox[{851, 377}, 0.17135878410227104`], 
         ArrowBox[{852, 379}, 0.17135878410227104`], 
         ArrowBox[{853, 377}, 0.17135878410227104`], 
         ArrowBox[{854, 377}, 0.17135878410227104`], 
         ArrowBox[{855, 601}, 0.17135878410227104`], 
         ArrowBox[{856, 387}, 0.17135878410227104`], 
         ArrowBox[{857, 389}, 0.17135878410227104`], 
         ArrowBox[{858, 859}, 0.17135878410227104`], 
         ArrowBox[{859, 629}, 0.17135878410227104`], 
         ArrowBox[{860, 861}, 0.17135878410227104`], 
         ArrowBox[{861, 793}, 0.17135878410227104`], 
         ArrowBox[{862, 863}, 0.17135878410227104`], 
         ArrowBox[{863, 417}, 0.17135878410227104`], 
         ArrowBox[{864, 72}, 0.17135878410227104`], 
         ArrowBox[{865, 595}, 0.17135878410227104`], 
         ArrowBox[{866, 867}, 0.17135878410227104`], 
         ArrowBox[{867, 571}, 0.17135878410227104`], 
         ArrowBox[{868, 402}, 0.17135878410227104`], 
         ArrowBox[{869, 402}, 0.17135878410227104`], 
         ArrowBox[{870, 72}, 0.17135878410227104`], 
         ArrowBox[{871, 872}, 0.17135878410227104`], 
         ArrowBox[{872, 194}, 0.17135878410227104`], 
         ArrowBox[{873, 874}, 0.17135878410227104`], 
         ArrowBox[{874, 495}, 0.17135878410227104`], 
         ArrowBox[{875, 872}, 0.17135878410227104`], 
         ArrowBox[{876, 874}, 0.17135878410227104`], 
         ArrowBox[{877, 415}, 0.17135878410227104`], 
         ArrowBox[{878, 552}, 0.17135878410227104`], 
         ArrowBox[{879, 544}, 0.17135878410227104`], 
         ArrowBox[{880, 645}, 0.17135878410227104`], 
         ArrowBox[{881, 639}, 0.17135878410227104`], 
         ArrowBox[{882, 646}, 0.17135878410227104`], 
         ArrowBox[{883, 642}, 0.17135878410227104`], 
         ArrowBox[{884, 426}, 0.17135878410227104`], 
         ArrowBox[{885, 261}, 0.17135878410227104`], 
         ArrowBox[{886, 426}, 0.17135878410227104`], 
         ArrowBox[{887, 261}, 0.17135878410227104`], 
         ArrowBox[{888, 426}, 0.17135878410227104`], 
         ArrowBox[{889, 426}, 0.17135878410227104`], 
         ArrowBox[{890, 259}, 0.17135878410227104`], 
         ArrowBox[{891, 435}, 0.17135878410227104`], 
         ArrowBox[{892, 437}, 0.17135878410227104`], 
         ArrowBox[{893, 275}, 0.17135878410227104`], 
         ArrowBox[{894, 277}, 0.17135878410227104`], 
         ArrowBox[{895, 896}, 0.17135878410227104`], 
         ArrowBox[{896, 181}, 0.17135878410227104`], 
         ArrowBox[{897, 620}, 0.17135878410227104`], 
         ArrowBox[{898, 899}, 0.17135878410227104`], 
         ArrowBox[{899, 819}, 0.17135878410227104`], 
         ArrowBox[{900, 901}, 0.17135878410227104`], 
         ArrowBox[{901, 621}, 0.17135878410227104`], 
         ArrowBox[{902, 899}, 0.17135878410227104`], 
         ArrowBox[{903, 327}, 0.17135878410227104`], 
         ArrowBox[{904, 899}, 0.17135878410227104`], 
         ArrowBox[{905, 903}, 0.17135878410227104`], 
         ArrowBox[{906, 792}, 0.17135878410227104`], 
         ArrowBox[{907, 792}, 0.17135878410227104`], 
         ArrowBox[{908, 793}, 0.17135878410227104`], 
         ArrowBox[{909, 525}, 0.17135878410227104`], 
         ArrowBox[{910, 32}, 0.17135878410227104`], 
         ArrowBox[{911, 34}, 0.17135878410227104`], 
         ArrowBox[{912, 631}, 0.17135878410227104`], 
         ArrowBox[{913, 635}, 0.17135878410227104`], 
         ArrowBox[{914, 630}, 0.17135878410227104`], 
         ArrowBox[{915, 220}, 0.17135878410227104`], 
         ArrowBox[{916, 469}, 0.17135878410227104`], 
         ArrowBox[{917, 471}, 0.17135878410227104`], 
         ArrowBox[{918, 220}, 0.17135878410227104`], 
         ArrowBox[{919, 469}, 0.17135878410227104`], 
         ArrowBox[{920, 574}, 0.17135878410227104`], 
         ArrowBox[{921, 477}, 0.17135878410227104`], 
         ArrowBox[{922, 481}, 0.17135878410227104`], 
         ArrowBox[{923, 483}, 0.17135878410227104`], 
         ArrowBox[{924, 638}, 0.17135878410227104`], 
         ArrowBox[{925, 926}, 0.17135878410227104`], 
         ArrowBox[{926, 417}, 0.17135878410227104`], 
         ArrowBox[{927, 928}, 0.17135878410227104`], 
         ArrowBox[{928, 72}, 0.17135878410227104`], 
         ArrowBox[{929, 492}, 0.17135878410227104`], 
         ArrowBox[{930, 495}, 0.17135878410227104`], 
         ArrowBox[{931, 192}, 0.17135878410227104`], 
         ArrowBox[{932, 847}, 0.17135878410227104`], 
         ArrowBox[{933, 934}, 0.17135878410227104`], 
         ArrowBox[{934, 362}, 0.17135878410227104`], 
         ArrowBox[{935, 936}, 0.17135878410227104`], 
         ArrowBox[{936, 192}, 0.17135878410227104`], 
         ArrowBox[{937, 221}, 0.17135878410227104`], 
         ArrowBox[{938, 506}, 0.17135878410227104`], 
         ArrowBox[{939, 493}, 0.17135878410227104`], 
         ArrowBox[{940, 372}, 0.17135878410227104`], 
         ArrowBox[{941, 624}, 0.17135878410227104`], 
         ArrowBox[{942, 616}, 0.17135878410227104`], 
         ArrowBox[{943, 165}, 0.17135878410227104`], 
         ArrowBox[{944, 518}, 0.17135878410227104`], 
         ArrowBox[{945, 335}, 0.17135878410227104`], 
         ArrowBox[{946, 165}, 0.17135878410227104`], 
         ArrowBox[{947, 518}, 0.17135878410227104`], 
         ArrowBox[{948, 333}, 0.17135878410227104`], 
         ArrowBox[{949, 347}, 0.17135878410227104`], 
         ArrowBox[{950, 527}, 0.17135878410227104`], 
         ArrowBox[{951, 529}, 0.17135878410227104`], 
         ArrowBox[{952, 841}, 0.17135878410227104`], 
         ArrowBox[{953, 954}, 0.17135878410227104`], 
         ArrowBox[{954, 479}, 0.17135878410227104`], 
         ArrowBox[{955, 956}, 0.17135878410227104`], 
         ArrowBox[{956, 471}, 0.17135878410227104`], 
         ArrowBox[{957, 841}, 0.17135878410227104`], 
         ArrowBox[{958, 959}, 0.17135878410227104`], 
         ArrowBox[{959, 775}, 0.17135878410227104`], 
         ArrowBox[{960, 961}, 0.17135878410227104`], 
         ArrowBox[{961, 256}, 0.17135878410227104`], 
         ArrowBox[{962, 836}, 0.17135878410227104`], 
         ArrowBox[{963, 838}, 0.17135878410227104`], 
         ArrowBox[{964, 840}, 0.17135878410227104`], 
         ArrowBox[{965, 150}, 0.17135878410227104`], 
         ArrowBox[{966, 478}, 0.17135878410227104`], 
         ArrowBox[{967, 467}, 0.17135878410227104`], 
         ArrowBox[{968, 357}, 0.17135878410227104`], 
         ArrowBox[{969, 607}, 0.17135878410227104`], 
         ArrowBox[{970, 605}, 0.17135878410227104`], 
         ArrowBox[{971, 379}, 0.17135878410227104`], 
         ArrowBox[{972, 379}, 0.17135878410227104`], 
         ArrowBox[{973, 379}, 0.17135878410227104`], 
         ArrowBox[{974, 379}, 0.17135878410227104`], 
         ArrowBox[{975, 389}, 0.17135878410227104`], 
         ArrowBox[{976, 389}, 0.17135878410227104`], 
         ArrowBox[{977, 861}, 0.17135878410227104`], 
         ArrowBox[{978, 861}, 0.17135878410227104`], 
         ArrowBox[{979, 565}, 0.17135878410227104`], 
         ArrowBox[{980, 402}, 0.17135878410227104`], 
         ArrowBox[{981, 402}, 0.17135878410227104`], 
         ArrowBox[{982, 72}, 0.17135878410227104`], 
         ArrowBox[{983, 72}, 0.17135878410227104`], 
         ArrowBox[{984, 571}, 0.17135878410227104`], 
         ArrowBox[{985, 417}, 0.17135878410227104`], 
         ArrowBox[{986, 544}, 0.17135878410227104`], 
         ArrowBox[{987, 80}, 0.17135878410227104`], 
         ArrowBox[{988, 580}, 0.17135878410227104`], 
         ArrowBox[{989, 579}, 0.17135878410227104`], 
         ArrowBox[{990, 580}, 0.17135878410227104`], 
         ArrowBox[{991, 579}, 0.17135878410227104`], 
         ArrowBox[{992, 580}, 0.17135878410227104`], 
         ArrowBox[{993, 588}, 0.17135878410227104`], 
         ArrowBox[{994, 589}, 0.17135878410227104`], 
         ArrowBox[{995, 62}, 0.17135878410227104`], 
         ArrowBox[{996, 64}, 0.17135878410227104`], 
         ArrowBox[{997, 998}, 0.17135878410227104`], 
         ArrowBox[{998, 221}, 0.17135878410227104`], 
         ArrowBox[{999, 495}, 0.17135878410227104`], 
         ArrowBox[{1000, 415}, 0.17135878410227104`], 
         ArrowBox[{1001, 552}, 0.17135878410227104`], 
         ArrowBox[{1002, 78}, 0.17135878410227104`], 
         ArrowBox[{1003, 579}, 0.17135878410227104`], 
         ArrowBox[{1004, 293}, 0.17135878410227104`], 
         ArrowBox[{1005, 471}, 0.17135878410227104`], 
         ArrowBox[{1006, 572}, 0.17135878410227104`], 
         ArrowBox[{1007, 608}, 0.17135878410227104`], 
         ArrowBox[{1008, 483}, 0.17135878410227104`], 
         ArrowBox[{1009, 613}, 0.17135878410227104`], 
         ArrowBox[{1010, 188}, 0.17135878410227104`], 
         ArrowBox[{1011, 192}, 0.17135878410227104`], 
         ArrowBox[{1012, 192}, 0.17135878410227104`], 
         ArrowBox[{1013, 206}, 0.17135878410227104`], 
         ArrowBox[{1014, 151}, 0.17135878410227104`], 
         ArrowBox[{1015, 493}, 0.17135878410227104`], 
         ArrowBox[{1016, 194}, 0.17135878410227104`], 
         ArrowBox[{1017, 626}, 0.17135878410227104`], 
         ArrowBox[{1018, 179}, 0.17135878410227104`], 
         ArrowBox[{1019, 632}, 0.17135878410227104`], 
         ArrowBox[{1020, 1011}, 0.17135878410227104`], 
         ArrowBox[{1021, 188}, 0.17135878410227104`], 
         ArrowBox[{1022, 192}, 0.17135878410227104`], 
         ArrowBox[{1023, 151}, 0.17135878410227104`], 
         ArrowBox[{1024, 493}, 0.17135878410227104`]}, 
        {GrayLevel[0.85], EdgeForm[GrayLevel[0]], 
         DiskBox[1, 0.17135878410227104`], DiskBox[2, 0.17135878410227104`], 
         DiskBox[3, 0.17135878410227104`], DiskBox[4, 0.17135878410227104`], 
         DiskBox[5, 0.17135878410227104`], DiskBox[6, 0.17135878410227104`], 
         DiskBox[7, 0.17135878410227104`], DiskBox[8, 0.17135878410227104`], 
         DiskBox[9, 0.17135878410227104`], DiskBox[10, 0.17135878410227104`], 
         DiskBox[11, 0.17135878410227104`], DiskBox[12, 0.17135878410227104`],
          DiskBox[13, 0.17135878410227104`], 
         DiskBox[14, 0.17135878410227104`], DiskBox[15, 0.17135878410227104`],
          DiskBox[16, 0.17135878410227104`], 
         DiskBox[17, 0.17135878410227104`], DiskBox[18, 0.17135878410227104`],
          DiskBox[19, 0.17135878410227104`], 
         DiskBox[20, 0.17135878410227104`], DiskBox[21, 0.17135878410227104`],
          DiskBox[22, 0.17135878410227104`], 
         DiskBox[23, 0.17135878410227104`], DiskBox[24, 0.17135878410227104`],
          DiskBox[25, 0.17135878410227104`], 
         DiskBox[26, 0.17135878410227104`], DiskBox[27, 0.17135878410227104`],
          DiskBox[28, 0.17135878410227104`], 
         DiskBox[29, 0.17135878410227104`], DiskBox[30, 0.17135878410227104`],
          DiskBox[31, 0.17135878410227104`], 
         DiskBox[32, 0.17135878410227104`], DiskBox[33, 0.17135878410227104`],
          DiskBox[34, 0.17135878410227104`], 
         DiskBox[35, 0.17135878410227104`], DiskBox[36, 0.17135878410227104`],
          DiskBox[37, 0.17135878410227104`], 
         DiskBox[38, 0.17135878410227104`], DiskBox[39, 0.17135878410227104`],
          DiskBox[40, 0.17135878410227104`], 
         DiskBox[41, 0.17135878410227104`], DiskBox[42, 0.17135878410227104`],
          DiskBox[43, 0.17135878410227104`], 
         DiskBox[44, 0.17135878410227104`], DiskBox[45, 0.17135878410227104`],
          DiskBox[46, 0.17135878410227104`], 
         DiskBox[47, 0.17135878410227104`], DiskBox[48, 0.17135878410227104`],
          DiskBox[49, 0.17135878410227104`], 
         DiskBox[50, 0.17135878410227104`], DiskBox[51, 0.17135878410227104`],
          DiskBox[52, 0.17135878410227104`], 
         DiskBox[53, 0.17135878410227104`], DiskBox[54, 0.17135878410227104`],
          DiskBox[55, 0.17135878410227104`], 
         DiskBox[56, 0.17135878410227104`], DiskBox[57, 0.17135878410227104`],
          DiskBox[58, 0.17135878410227104`], 
         DiskBox[59, 0.17135878410227104`], DiskBox[60, 0.17135878410227104`],
          DiskBox[61, 0.17135878410227104`], 
         DiskBox[62, 0.17135878410227104`], DiskBox[63, 0.17135878410227104`],
          DiskBox[64, 0.17135878410227104`], 
         DiskBox[65, 0.17135878410227104`], DiskBox[66, 0.17135878410227104`],
          DiskBox[67, 0.17135878410227104`], 
         DiskBox[68, 0.17135878410227104`], DiskBox[69, 0.17135878410227104`],
          DiskBox[70, 0.17135878410227104`], 
         DiskBox[71, 0.17135878410227104`], DiskBox[72, 0.17135878410227104`],
          DiskBox[73, 0.17135878410227104`], 
         DiskBox[74, 0.17135878410227104`], DiskBox[75, 0.17135878410227104`],
          DiskBox[76, 0.17135878410227104`], 
         DiskBox[77, 0.17135878410227104`], DiskBox[78, 0.17135878410227104`],
          DiskBox[79, 0.17135878410227104`], 
         DiskBox[80, 0.17135878410227104`], DiskBox[81, 0.17135878410227104`],
          DiskBox[82, 0.17135878410227104`], 
         DiskBox[83, 0.17135878410227104`], DiskBox[84, 0.17135878410227104`],
          DiskBox[85, 0.17135878410227104`], 
         DiskBox[86, 0.17135878410227104`], DiskBox[87, 0.17135878410227104`],
          DiskBox[88, 0.17135878410227104`], 
         DiskBox[89, 0.17135878410227104`], DiskBox[90, 0.17135878410227104`],
          DiskBox[91, 0.17135878410227104`], 
         DiskBox[92, 0.17135878410227104`], DiskBox[93, 0.17135878410227104`],
          DiskBox[94, 0.17135878410227104`], 
         DiskBox[95, 0.17135878410227104`], DiskBox[96, 0.17135878410227104`],
          DiskBox[97, 0.17135878410227104`], 
         DiskBox[98, 0.17135878410227104`], DiskBox[99, 0.17135878410227104`],
          DiskBox[100, 0.17135878410227104`], 
         DiskBox[101, 0.17135878410227104`], 
         DiskBox[102, 0.17135878410227104`], 
         DiskBox[103, 0.17135878410227104`], 
         DiskBox[104, 0.17135878410227104`], 
         DiskBox[105, 0.17135878410227104`], 
         DiskBox[106, 0.17135878410227104`], 
         DiskBox[107, 0.17135878410227104`], 
         DiskBox[108, 0.17135878410227104`], 
         DiskBox[109, 0.17135878410227104`], 
         DiskBox[110, 0.17135878410227104`], 
         DiskBox[111, 0.17135878410227104`], 
         DiskBox[112, 0.17135878410227104`], 
         DiskBox[113, 0.17135878410227104`], 
         DiskBox[114, 0.17135878410227104`], 
         DiskBox[115, 0.17135878410227104`], 
         DiskBox[116, 0.17135878410227104`], 
         DiskBox[117, 0.17135878410227104`], 
         DiskBox[118, 0.17135878410227104`], 
         DiskBox[119, 0.17135878410227104`], 
         DiskBox[120, 0.17135878410227104`], 
         DiskBox[121, 0.17135878410227104`], 
         DiskBox[122, 0.17135878410227104`], 
         DiskBox[123, 0.17135878410227104`], 
         DiskBox[124, 0.17135878410227104`], 
         DiskBox[125, 0.17135878410227104`], 
         DiskBox[126, 0.17135878410227104`], 
         DiskBox[127, 0.17135878410227104`], 
         DiskBox[128, 0.17135878410227104`], 
         DiskBox[129, 0.17135878410227104`], 
         DiskBox[130, 0.17135878410227104`], 
         DiskBox[131, 0.17135878410227104`], 
         DiskBox[132, 0.17135878410227104`], 
         DiskBox[133, 0.17135878410227104`], 
         DiskBox[134, 0.17135878410227104`], 
         DiskBox[135, 0.17135878410227104`], 
         DiskBox[136, 0.17135878410227104`], 
         DiskBox[137, 0.17135878410227104`], 
         DiskBox[138, 0.17135878410227104`], 
         DiskBox[139, 0.17135878410227104`], 
         DiskBox[140, 0.17135878410227104`], 
         DiskBox[141, 0.17135878410227104`], 
         DiskBox[142, 0.17135878410227104`], 
         DiskBox[143, 0.17135878410227104`], 
         DiskBox[144, 0.17135878410227104`], 
         DiskBox[145, 0.17135878410227104`], 
         DiskBox[146, 0.17135878410227104`], 
         DiskBox[147, 0.17135878410227104`], 
         DiskBox[148, 0.17135878410227104`], 
         DiskBox[149, 0.17135878410227104`], 
         DiskBox[150, 0.17135878410227104`], 
         DiskBox[151, 0.17135878410227104`], 
         DiskBox[152, 0.17135878410227104`], 
         DiskBox[153, 0.17135878410227104`], 
         DiskBox[154, 0.17135878410227104`], 
         DiskBox[155, 0.17135878410227104`], 
         DiskBox[156, 0.17135878410227104`], 
         DiskBox[157, 0.17135878410227104`], 
         DiskBox[158, 0.17135878410227104`], 
         DiskBox[159, 0.17135878410227104`], 
         DiskBox[160, 0.17135878410227104`], 
         DiskBox[161, 0.17135878410227104`], 
         DiskBox[162, 0.17135878410227104`], 
         DiskBox[163, 0.17135878410227104`], 
         DiskBox[164, 0.17135878410227104`], 
         DiskBox[165, 0.17135878410227104`], 
         DiskBox[166, 0.17135878410227104`], 
         DiskBox[167, 0.17135878410227104`], 
         DiskBox[168, 0.17135878410227104`], 
         DiskBox[169, 0.17135878410227104`], 
         DiskBox[170, 0.17135878410227104`], 
         DiskBox[171, 0.17135878410227104`], 
         DiskBox[172, 0.17135878410227104`], 
         DiskBox[173, 0.17135878410227104`], 
         DiskBox[174, 0.17135878410227104`], 
         DiskBox[175, 0.17135878410227104`], 
         DiskBox[176, 0.17135878410227104`], 
         DiskBox[177, 0.17135878410227104`], 
         DiskBox[178, 0.17135878410227104`], 
         DiskBox[179, 0.17135878410227104`], 
         DiskBox[180, 0.17135878410227104`], 
         DiskBox[181, 0.17135878410227104`], 
         DiskBox[182, 0.17135878410227104`], 
         DiskBox[183, 0.17135878410227104`], 
         DiskBox[184, 0.17135878410227104`], 
         DiskBox[185, 0.17135878410227104`], 
         DiskBox[186, 0.17135878410227104`], 
         DiskBox[187, 0.17135878410227104`], 
         DiskBox[188, 0.17135878410227104`], 
         DiskBox[189, 0.17135878410227104`], 
         DiskBox[190, 0.17135878410227104`], 
         DiskBox[191, 0.17135878410227104`], 
         DiskBox[192, 0.17135878410227104`], 
         DiskBox[193, 0.17135878410227104`], 
         DiskBox[194, 0.17135878410227104`], 
         DiskBox[195, 0.17135878410227104`], 
         DiskBox[196, 0.17135878410227104`], 
         DiskBox[197, 0.17135878410227104`], 
         DiskBox[198, 0.17135878410227104`], 
         DiskBox[199, 0.17135878410227104`], 
         DiskBox[200, 0.17135878410227104`], 
         DiskBox[201, 0.17135878410227104`], 
         DiskBox[202, 0.17135878410227104`], 
         DiskBox[203, 0.17135878410227104`], 
         DiskBox[204, 0.17135878410227104`], 
         DiskBox[205, 0.17135878410227104`], 
         DiskBox[206, 0.17135878410227104`], 
         DiskBox[207, 0.17135878410227104`], 
         DiskBox[208, 0.17135878410227104`], 
         DiskBox[209, 0.17135878410227104`], 
         DiskBox[210, 0.17135878410227104`], 
         DiskBox[211, 0.17135878410227104`], 
         DiskBox[212, 0.17135878410227104`], 
         DiskBox[213, 0.17135878410227104`], 
         DiskBox[214, 0.17135878410227104`], 
         DiskBox[215, 0.17135878410227104`], 
         DiskBox[216, 0.17135878410227104`], 
         DiskBox[217, 0.17135878410227104`], 
         DiskBox[218, 0.17135878410227104`], 
         DiskBox[219, 0.17135878410227104`], 
         DiskBox[220, 0.17135878410227104`], 
         DiskBox[221, 0.17135878410227104`], 
         DiskBox[222, 0.17135878410227104`], 
         DiskBox[223, 0.17135878410227104`], 
         DiskBox[224, 0.17135878410227104`], 
         DiskBox[225, 0.17135878410227104`], 
         DiskBox[226, 0.17135878410227104`], 
         DiskBox[227, 0.17135878410227104`], 
         DiskBox[228, 0.17135878410227104`], 
         DiskBox[229, 0.17135878410227104`], 
         DiskBox[230, 0.17135878410227104`], 
         DiskBox[231, 0.17135878410227104`], 
         DiskBox[232, 0.17135878410227104`], 
         DiskBox[233, 0.17135878410227104`], 
         DiskBox[234, 0.17135878410227104`], 
         DiskBox[235, 0.17135878410227104`], 
         DiskBox[236, 0.17135878410227104`], 
         DiskBox[237, 0.17135878410227104`], 
         DiskBox[238, 0.17135878410227104`], 
         DiskBox[239, 0.17135878410227104`], 
         DiskBox[240, 0.17135878410227104`], 
         DiskBox[241, 0.17135878410227104`], 
         DiskBox[242, 0.17135878410227104`], 
         DiskBox[243, 0.17135878410227104`], 
         DiskBox[244, 0.17135878410227104`], 
         DiskBox[245, 0.17135878410227104`], 
         DiskBox[246, 0.17135878410227104`], 
         DiskBox[247, 0.17135878410227104`], 
         DiskBox[248, 0.17135878410227104`], 
         DiskBox[249, 0.17135878410227104`], 
         DiskBox[250, 0.17135878410227104`], 
         DiskBox[251, 0.17135878410227104`], 
         DiskBox[252, 0.17135878410227104`], 
         DiskBox[253, 0.17135878410227104`], 
         DiskBox[254, 0.17135878410227104`], 
         DiskBox[255, 0.17135878410227104`], 
         DiskBox[256, 0.17135878410227104`], 
         DiskBox[257, 0.17135878410227104`], 
         DiskBox[258, 0.17135878410227104`], 
         DiskBox[259, 0.17135878410227104`], 
         DiskBox[260, 0.17135878410227104`], 
         DiskBox[261, 0.17135878410227104`], 
         DiskBox[262, 0.17135878410227104`], 
         DiskBox[263, 0.17135878410227104`], 
         DiskBox[264, 0.17135878410227104`], 
         DiskBox[265, 0.17135878410227104`], 
         DiskBox[266, 0.17135878410227104`], 
         DiskBox[267, 0.17135878410227104`], 
         DiskBox[268, 0.17135878410227104`], 
         DiskBox[269, 0.17135878410227104`], 
         DiskBox[270, 0.17135878410227104`], 
         DiskBox[271, 0.17135878410227104`], 
         DiskBox[272, 0.17135878410227104`], 
         DiskBox[273, 0.17135878410227104`], 
         DiskBox[274, 0.17135878410227104`], 
         DiskBox[275, 0.17135878410227104`], 
         DiskBox[276, 0.17135878410227104`], 
         DiskBox[277, 0.17135878410227104`], 
         DiskBox[278, 0.17135878410227104`], 
         DiskBox[279, 0.17135878410227104`], 
         DiskBox[280, 0.17135878410227104`], 
         DiskBox[281, 0.17135878410227104`], 
         DiskBox[282, 0.17135878410227104`], 
         DiskBox[283, 0.17135878410227104`], 
         DiskBox[284, 0.17135878410227104`], 
         DiskBox[285, 0.17135878410227104`], 
         DiskBox[286, 0.17135878410227104`], 
         DiskBox[287, 0.17135878410227104`], 
         DiskBox[288, 0.17135878410227104`], 
         DiskBox[289, 0.17135878410227104`], 
         DiskBox[290, 0.17135878410227104`], 
         DiskBox[291, 0.17135878410227104`], 
         DiskBox[292, 0.17135878410227104`], 
         DiskBox[293, 0.17135878410227104`], 
         DiskBox[294, 0.17135878410227104`], 
         DiskBox[295, 0.17135878410227104`], 
         DiskBox[296, 0.17135878410227104`], 
         DiskBox[297, 0.17135878410227104`], 
         DiskBox[298, 0.17135878410227104`], 
         DiskBox[299, 0.17135878410227104`], 
         DiskBox[300, 0.17135878410227104`], 
         DiskBox[301, 0.17135878410227104`], 
         DiskBox[302, 0.17135878410227104`], 
         DiskBox[303, 0.17135878410227104`], 
         DiskBox[304, 0.17135878410227104`], 
         DiskBox[305, 0.17135878410227104`], 
         DiskBox[306, 0.17135878410227104`], 
         DiskBox[307, 0.17135878410227104`], 
         DiskBox[308, 0.17135878410227104`], 
         DiskBox[309, 0.17135878410227104`], 
         DiskBox[310, 0.17135878410227104`], 
         DiskBox[311, 0.17135878410227104`], 
         DiskBox[312, 0.17135878410227104`], 
         DiskBox[313, 0.17135878410227104`], 
         DiskBox[314, 0.17135878410227104`], 
         DiskBox[315, 0.17135878410227104`], 
         DiskBox[316, 0.17135878410227104`], 
         DiskBox[317, 0.17135878410227104`], 
         DiskBox[318, 0.17135878410227104`], 
         DiskBox[319, 0.17135878410227104`], 
         DiskBox[320, 0.17135878410227104`], 
         DiskBox[321, 0.17135878410227104`], 
         DiskBox[322, 0.17135878410227104`], 
         DiskBox[323, 0.17135878410227104`], 
         DiskBox[324, 0.17135878410227104`], 
         DiskBox[325, 0.17135878410227104`], 
         DiskBox[326, 0.17135878410227104`], 
         DiskBox[327, 0.17135878410227104`], 
         DiskBox[328, 0.17135878410227104`], 
         DiskBox[329, 0.17135878410227104`], 
         DiskBox[330, 0.17135878410227104`], 
         DiskBox[331, 0.17135878410227104`], 
         DiskBox[332, 0.17135878410227104`], 
         DiskBox[333, 0.17135878410227104`], 
         DiskBox[334, 0.17135878410227104`], 
         DiskBox[335, 0.17135878410227104`], 
         DiskBox[336, 0.17135878410227104`], 
         DiskBox[337, 0.17135878410227104`], 
         DiskBox[338, 0.17135878410227104`], 
         DiskBox[339, 0.17135878410227104`], 
         DiskBox[340, 0.17135878410227104`], 
         DiskBox[341, 0.17135878410227104`], 
         DiskBox[342, 0.17135878410227104`], 
         DiskBox[343, 0.17135878410227104`], 
         DiskBox[344, 0.17135878410227104`], 
         DiskBox[345, 0.17135878410227104`], 
         DiskBox[346, 0.17135878410227104`], 
         DiskBox[347, 0.17135878410227104`], 
         DiskBox[348, 0.17135878410227104`], 
         DiskBox[349, 0.17135878410227104`], 
         DiskBox[350, 0.17135878410227104`], 
         DiskBox[351, 0.17135878410227104`], 
         DiskBox[352, 0.17135878410227104`], 
         DiskBox[353, 0.17135878410227104`], 
         DiskBox[354, 0.17135878410227104`], 
         DiskBox[355, 0.17135878410227104`], 
         DiskBox[356, 0.17135878410227104`], 
         DiskBox[357, 0.17135878410227104`], 
         DiskBox[358, 0.17135878410227104`], 
         DiskBox[359, 0.17135878410227104`], 
         DiskBox[360, 0.17135878410227104`], 
         DiskBox[361, 0.17135878410227104`], 
         DiskBox[362, 0.17135878410227104`], 
         DiskBox[363, 0.17135878410227104`], 
         DiskBox[364, 0.17135878410227104`], 
         DiskBox[365, 0.17135878410227104`], 
         DiskBox[366, 0.17135878410227104`], 
         DiskBox[367, 0.17135878410227104`], 
         DiskBox[368, 0.17135878410227104`], 
         DiskBox[369, 0.17135878410227104`], 
         DiskBox[370, 0.17135878410227104`], 
         DiskBox[371, 0.17135878410227104`], 
         DiskBox[372, 0.17135878410227104`], 
         DiskBox[373, 0.17135878410227104`], 
         DiskBox[374, 0.17135878410227104`], 
         DiskBox[375, 0.17135878410227104`], 
         DiskBox[376, 0.17135878410227104`], 
         DiskBox[377, 0.17135878410227104`], 
         DiskBox[378, 0.17135878410227104`], 
         DiskBox[379, 0.17135878410227104`], 
         DiskBox[380, 0.17135878410227104`], 
         DiskBox[381, 0.17135878410227104`], 
         DiskBox[382, 0.17135878410227104`], 
         DiskBox[383, 0.17135878410227104`], 
         DiskBox[384, 0.17135878410227104`], 
         DiskBox[385, 0.17135878410227104`], 
         DiskBox[386, 0.17135878410227104`], 
         DiskBox[387, 0.17135878410227104`], 
         DiskBox[388, 0.17135878410227104`], 
         DiskBox[389, 0.17135878410227104`], 
         DiskBox[390, 0.17135878410227104`], 
         DiskBox[391, 0.17135878410227104`], 
         DiskBox[392, 0.17135878410227104`], 
         DiskBox[393, 0.17135878410227104`], 
         DiskBox[394, 0.17135878410227104`], 
         DiskBox[395, 0.17135878410227104`], 
         DiskBox[396, 0.17135878410227104`], 
         DiskBox[397, 0.17135878410227104`], 
         DiskBox[398, 0.17135878410227104`], 
         DiskBox[399, 0.17135878410227104`], 
         DiskBox[400, 0.17135878410227104`], 
         DiskBox[401, 0.17135878410227104`], 
         DiskBox[402, 0.17135878410227104`], 
         DiskBox[403, 0.17135878410227104`], 
         DiskBox[404, 0.17135878410227104`], 
         DiskBox[405, 0.17135878410227104`], 
         DiskBox[406, 0.17135878410227104`], 
         DiskBox[407, 0.17135878410227104`], 
         DiskBox[408, 0.17135878410227104`], 
         DiskBox[409, 0.17135878410227104`], 
         DiskBox[410, 0.17135878410227104`], 
         DiskBox[411, 0.17135878410227104`], 
         DiskBox[412, 0.17135878410227104`], 
         DiskBox[413, 0.17135878410227104`], 
         DiskBox[414, 0.17135878410227104`], 
         DiskBox[415, 0.17135878410227104`], 
         DiskBox[416, 0.17135878410227104`], 
         DiskBox[417, 0.17135878410227104`], 
         DiskBox[418, 0.17135878410227104`], 
         DiskBox[419, 0.17135878410227104`], 
         DiskBox[420, 0.17135878410227104`], 
         DiskBox[421, 0.17135878410227104`], 
         DiskBox[422, 0.17135878410227104`], 
         DiskBox[423, 0.17135878410227104`], 
         DiskBox[424, 0.17135878410227104`], 
         DiskBox[425, 0.17135878410227104`], 
         DiskBox[426, 0.17135878410227104`], 
         DiskBox[427, 0.17135878410227104`], 
         DiskBox[428, 0.17135878410227104`], 
         DiskBox[429, 0.17135878410227104`], 
         DiskBox[430, 0.17135878410227104`], 
         DiskBox[431, 0.17135878410227104`], 
         DiskBox[432, 0.17135878410227104`], 
         DiskBox[433, 0.17135878410227104`], 
         DiskBox[434, 0.17135878410227104`], 
         DiskBox[435, 0.17135878410227104`], 
         DiskBox[436, 0.17135878410227104`], 
         DiskBox[437, 0.17135878410227104`], 
         DiskBox[438, 0.17135878410227104`], 
         DiskBox[439, 0.17135878410227104`], 
         DiskBox[440, 0.17135878410227104`], 
         DiskBox[441, 0.17135878410227104`], 
         DiskBox[442, 0.17135878410227104`], 
         DiskBox[443, 0.17135878410227104`], 
         DiskBox[444, 0.17135878410227104`], 
         DiskBox[445, 0.17135878410227104`], 
         DiskBox[446, 0.17135878410227104`], 
         DiskBox[447, 0.17135878410227104`], 
         DiskBox[448, 0.17135878410227104`], 
         DiskBox[449, 0.17135878410227104`], 
         DiskBox[450, 0.17135878410227104`], 
         DiskBox[451, 0.17135878410227104`], 
         DiskBox[452, 0.17135878410227104`], 
         DiskBox[453, 0.17135878410227104`], 
         DiskBox[454, 0.17135878410227104`], 
         DiskBox[455, 0.17135878410227104`], 
         DiskBox[456, 0.17135878410227104`], 
         DiskBox[457, 0.17135878410227104`], 
         DiskBox[458, 0.17135878410227104`], 
         DiskBox[459, 0.17135878410227104`], 
         DiskBox[460, 0.17135878410227104`], 
         DiskBox[461, 0.17135878410227104`], 
         DiskBox[462, 0.17135878410227104`], 
         DiskBox[463, 0.17135878410227104`], 
         DiskBox[464, 0.17135878410227104`], 
         DiskBox[465, 0.17135878410227104`], 
         DiskBox[466, 0.17135878410227104`], 
         DiskBox[467, 0.17135878410227104`], 
         DiskBox[468, 0.17135878410227104`], 
         DiskBox[469, 0.17135878410227104`], 
         DiskBox[470, 0.17135878410227104`], 
         DiskBox[471, 0.17135878410227104`], 
         DiskBox[472, 0.17135878410227104`], 
         DiskBox[473, 0.17135878410227104`], 
         DiskBox[474, 0.17135878410227104`], 
         DiskBox[475, 0.17135878410227104`], 
         DiskBox[476, 0.17135878410227104`], 
         DiskBox[477, 0.17135878410227104`], 
         DiskBox[478, 0.17135878410227104`], 
         DiskBox[479, 0.17135878410227104`], 
         DiskBox[480, 0.17135878410227104`], 
         DiskBox[481, 0.17135878410227104`], 
         DiskBox[482, 0.17135878410227104`], 
         DiskBox[483, 0.17135878410227104`], 
         DiskBox[484, 0.17135878410227104`], 
         DiskBox[485, 0.17135878410227104`], 
         DiskBox[486, 0.17135878410227104`], 
         DiskBox[487, 0.17135878410227104`], 
         DiskBox[488, 0.17135878410227104`], 
         DiskBox[489, 0.17135878410227104`], 
         DiskBox[490, 0.17135878410227104`], 
         DiskBox[491, 0.17135878410227104`], 
         DiskBox[492, 0.17135878410227104`], 
         DiskBox[493, 0.17135878410227104`], 
         DiskBox[494, 0.17135878410227104`], 
         DiskBox[495, 0.17135878410227104`], 
         DiskBox[496, 0.17135878410227104`], 
         DiskBox[497, 0.17135878410227104`], 
         DiskBox[498, 0.17135878410227104`], 
         DiskBox[499, 0.17135878410227104`], 
         DiskBox[500, 0.17135878410227104`], 
         DiskBox[501, 0.17135878410227104`], 
         DiskBox[502, 0.17135878410227104`], 
         DiskBox[503, 0.17135878410227104`], 
         DiskBox[504, 0.17135878410227104`], 
         DiskBox[505, 0.17135878410227104`], 
         DiskBox[506, 0.17135878410227104`], 
         DiskBox[507, 0.17135878410227104`], 
         DiskBox[508, 0.17135878410227104`], 
         DiskBox[509, 0.17135878410227104`], 
         DiskBox[510, 0.17135878410227104`], 
         DiskBox[511, 0.17135878410227104`], 
         DiskBox[512, 0.17135878410227104`], 
         DiskBox[513, 0.17135878410227104`], 
         DiskBox[514, 0.17135878410227104`], 
         DiskBox[515, 0.17135878410227104`], 
         DiskBox[516, 0.17135878410227104`], 
         DiskBox[517, 0.17135878410227104`], 
         DiskBox[518, 0.17135878410227104`], 
         DiskBox[519, 0.17135878410227104`], 
         DiskBox[520, 0.17135878410227104`], 
         DiskBox[521, 0.17135878410227104`], 
         DiskBox[522, 0.17135878410227104`], 
         DiskBox[523, 0.17135878410227104`], 
         DiskBox[524, 0.17135878410227104`], 
         DiskBox[525, 0.17135878410227104`], 
         DiskBox[526, 0.17135878410227104`], 
         DiskBox[527, 0.17135878410227104`], 
         DiskBox[528, 0.17135878410227104`], 
         DiskBox[529, 0.17135878410227104`], 
         DiskBox[530, 0.17135878410227104`], 
         DiskBox[531, 0.17135878410227104`], 
         DiskBox[532, 0.17135878410227104`], 
         DiskBox[533, 0.17135878410227104`], 
         DiskBox[534, 0.17135878410227104`], 
         DiskBox[535, 0.17135878410227104`], 
         DiskBox[536, 0.17135878410227104`], 
         DiskBox[537, 0.17135878410227104`], 
         DiskBox[538, 0.17135878410227104`], 
         DiskBox[539, 0.17135878410227104`], 
         DiskBox[540, 0.17135878410227104`], 
         DiskBox[541, 0.17135878410227104`], 
         DiskBox[542, 0.17135878410227104`], 
         DiskBox[543, 0.17135878410227104`], 
         DiskBox[544, 0.17135878410227104`], 
         DiskBox[545, 0.17135878410227104`], 
         DiskBox[546, 0.17135878410227104`], 
         DiskBox[547, 0.17135878410227104`], 
         DiskBox[548, 0.17135878410227104`], 
         DiskBox[549, 0.17135878410227104`], 
         DiskBox[550, 0.17135878410227104`], 
         DiskBox[551, 0.17135878410227104`], 
         DiskBox[552, 0.17135878410227104`], 
         DiskBox[553, 0.17135878410227104`], 
         DiskBox[554, 0.17135878410227104`], 
         DiskBox[555, 0.17135878410227104`], 
         DiskBox[556, 0.17135878410227104`], 
         DiskBox[557, 0.17135878410227104`], 
         DiskBox[558, 0.17135878410227104`], 
         DiskBox[559, 0.17135878410227104`], 
         DiskBox[560, 0.17135878410227104`], 
         DiskBox[561, 0.17135878410227104`], 
         DiskBox[562, 0.17135878410227104`], 
         DiskBox[563, 0.17135878410227104`], 
         DiskBox[564, 0.17135878410227104`], 
         DiskBox[565, 0.17135878410227104`], 
         DiskBox[566, 0.17135878410227104`], 
         DiskBox[567, 0.17135878410227104`], 
         DiskBox[568, 0.17135878410227104`], 
         DiskBox[569, 0.17135878410227104`], 
         DiskBox[570, 0.17135878410227104`], 
         DiskBox[571, 0.17135878410227104`], 
         DiskBox[572, 0.17135878410227104`], 
         DiskBox[573, 0.17135878410227104`], 
         DiskBox[574, 0.17135878410227104`], 
         DiskBox[575, 0.17135878410227104`], 
         DiskBox[576, 0.17135878410227104`], 
         DiskBox[577, 0.17135878410227104`], 
         DiskBox[578, 0.17135878410227104`], 
         DiskBox[579, 0.17135878410227104`], 
         DiskBox[580, 0.17135878410227104`], 
         DiskBox[581, 0.17135878410227104`], 
         DiskBox[582, 0.17135878410227104`], 
         DiskBox[583, 0.17135878410227104`], 
         DiskBox[584, 0.17135878410227104`], 
         DiskBox[585, 0.17135878410227104`], 
         DiskBox[586, 0.17135878410227104`], 
         DiskBox[587, 0.17135878410227104`], 
         DiskBox[588, 0.17135878410227104`], 
         DiskBox[589, 0.17135878410227104`], 
         DiskBox[590, 0.17135878410227104`], 
         DiskBox[591, 0.17135878410227104`], 
         DiskBox[592, 0.17135878410227104`], 
         DiskBox[593, 0.17135878410227104`], 
         DiskBox[594, 0.17135878410227104`], 
         DiskBox[595, 0.17135878410227104`], 
         DiskBox[596, 0.17135878410227104`], 
         DiskBox[597, 0.17135878410227104`], 
         DiskBox[598, 0.17135878410227104`], 
         DiskBox[599, 0.17135878410227104`], 
         DiskBox[600, 0.17135878410227104`], 
         DiskBox[601, 0.17135878410227104`], 
         DiskBox[602, 0.17135878410227104`], 
         DiskBox[603, 0.17135878410227104`], 
         DiskBox[604, 0.17135878410227104`], 
         DiskBox[605, 0.17135878410227104`], 
         DiskBox[606, 0.17135878410227104`], 
         DiskBox[607, 0.17135878410227104`], 
         DiskBox[608, 0.17135878410227104`], 
         DiskBox[609, 0.17135878410227104`], 
         DiskBox[610, 0.17135878410227104`], 
         DiskBox[611, 0.17135878410227104`], 
         DiskBox[612, 0.17135878410227104`], 
         DiskBox[613, 0.17135878410227104`], 
         DiskBox[614, 0.17135878410227104`], 
         DiskBox[615, 0.17135878410227104`], 
         DiskBox[616, 0.17135878410227104`], 
         DiskBox[617, 0.17135878410227104`], 
         DiskBox[618, 0.17135878410227104`], 
         DiskBox[619, 0.17135878410227104`], 
         DiskBox[620, 0.17135878410227104`], 
         DiskBox[621, 0.17135878410227104`], 
         DiskBox[622, 0.17135878410227104`], 
         DiskBox[623, 0.17135878410227104`], 
         DiskBox[624, 0.17135878410227104`], 
         DiskBox[625, 0.17135878410227104`], 
         DiskBox[626, 0.17135878410227104`], 
         DiskBox[627, 0.17135878410227104`], 
         DiskBox[628, 0.17135878410227104`], 
         DiskBox[629, 0.17135878410227104`], 
         DiskBox[630, 0.17135878410227104`], 
         DiskBox[631, 0.17135878410227104`], 
         DiskBox[632, 0.17135878410227104`], 
         DiskBox[633, 0.17135878410227104`], 
         DiskBox[634, 0.17135878410227104`], 
         DiskBox[635, 0.17135878410227104`], 
         DiskBox[636, 0.17135878410227104`], 
         DiskBox[637, 0.17135878410227104`], 
         DiskBox[638, 0.17135878410227104`], 
         DiskBox[639, 0.17135878410227104`], 
         DiskBox[640, 0.17135878410227104`], 
         DiskBox[641, 0.17135878410227104`], 
         DiskBox[642, 0.17135878410227104`], 
         DiskBox[643, 0.17135878410227104`], 
         DiskBox[644, 0.17135878410227104`], 
         DiskBox[645, 0.17135878410227104`], 
         DiskBox[646, 0.17135878410227104`], 
         DiskBox[647, 0.17135878410227104`], 
         DiskBox[648, 0.17135878410227104`], 
         DiskBox[649, 0.17135878410227104`], 
         DiskBox[650, 0.17135878410227104`], 
         DiskBox[651, 0.17135878410227104`], 
         DiskBox[652, 0.17135878410227104`], 
         DiskBox[653, 0.17135878410227104`], 
         DiskBox[654, 0.17135878410227104`], 
         DiskBox[655, 0.17135878410227104`], 
         DiskBox[656, 0.17135878410227104`], 
         DiskBox[657, 0.17135878410227104`], 
         DiskBox[658, 0.17135878410227104`], 
         DiskBox[659, 0.17135878410227104`], 
         DiskBox[660, 0.17135878410227104`], 
         DiskBox[661, 0.17135878410227104`], 
         DiskBox[662, 0.17135878410227104`], 
         DiskBox[663, 0.17135878410227104`], 
         DiskBox[664, 0.17135878410227104`], 
         DiskBox[665, 0.17135878410227104`], 
         DiskBox[666, 0.17135878410227104`], 
         DiskBox[667, 0.17135878410227104`], 
         DiskBox[668, 0.17135878410227104`], 
         DiskBox[669, 0.17135878410227104`], 
         DiskBox[670, 0.17135878410227104`], 
         DiskBox[671, 0.17135878410227104`], 
         DiskBox[672, 0.17135878410227104`], 
         DiskBox[673, 0.17135878410227104`], 
         DiskBox[674, 0.17135878410227104`], 
         DiskBox[675, 0.17135878410227104`], 
         DiskBox[676, 0.17135878410227104`], 
         DiskBox[677, 0.17135878410227104`], 
         DiskBox[678, 0.17135878410227104`], 
         DiskBox[679, 0.17135878410227104`], 
         DiskBox[680, 0.17135878410227104`], 
         DiskBox[681, 0.17135878410227104`], 
         DiskBox[682, 0.17135878410227104`], 
         DiskBox[683, 0.17135878410227104`], 
         DiskBox[684, 0.17135878410227104`], 
         DiskBox[685, 0.17135878410227104`], 
         DiskBox[686, 0.17135878410227104`], 
         DiskBox[687, 0.17135878410227104`], 
         DiskBox[688, 0.17135878410227104`], 
         DiskBox[689, 0.17135878410227104`], 
         DiskBox[690, 0.17135878410227104`], 
         DiskBox[691, 0.17135878410227104`], 
         DiskBox[692, 0.17135878410227104`], 
         DiskBox[693, 0.17135878410227104`], 
         DiskBox[694, 0.17135878410227104`], 
         DiskBox[695, 0.17135878410227104`], 
         DiskBox[696, 0.17135878410227104`], 
         DiskBox[697, 0.17135878410227104`], 
         DiskBox[698, 0.17135878410227104`], 
         DiskBox[699, 0.17135878410227104`], 
         DiskBox[700, 0.17135878410227104`], 
         DiskBox[701, 0.17135878410227104`], 
         DiskBox[702, 0.17135878410227104`], 
         DiskBox[703, 0.17135878410227104`], 
         DiskBox[704, 0.17135878410227104`], 
         DiskBox[705, 0.17135878410227104`], 
         DiskBox[706, 0.17135878410227104`], 
         DiskBox[707, 0.17135878410227104`], 
         DiskBox[708, 0.17135878410227104`], 
         DiskBox[709, 0.17135878410227104`], 
         DiskBox[710, 0.17135878410227104`], 
         DiskBox[711, 0.17135878410227104`], 
         DiskBox[712, 0.17135878410227104`], 
         DiskBox[713, 0.17135878410227104`], 
         DiskBox[714, 0.17135878410227104`], 
         DiskBox[715, 0.17135878410227104`], 
         DiskBox[716, 0.17135878410227104`], 
         DiskBox[717, 0.17135878410227104`], 
         DiskBox[718, 0.17135878410227104`], 
         DiskBox[719, 0.17135878410227104`], 
         DiskBox[720, 0.17135878410227104`], 
         DiskBox[721, 0.17135878410227104`], 
         DiskBox[722, 0.17135878410227104`], 
         DiskBox[723, 0.17135878410227104`], 
         DiskBox[724, 0.17135878410227104`], 
         DiskBox[725, 0.17135878410227104`], 
         DiskBox[726, 0.17135878410227104`], 
         DiskBox[727, 0.17135878410227104`], 
         DiskBox[728, 0.17135878410227104`], 
         DiskBox[729, 0.17135878410227104`], 
         DiskBox[730, 0.17135878410227104`], 
         DiskBox[731, 0.17135878410227104`], 
         DiskBox[732, 0.17135878410227104`], 
         DiskBox[733, 0.17135878410227104`], 
         DiskBox[734, 0.17135878410227104`], 
         DiskBox[735, 0.17135878410227104`], 
         DiskBox[736, 0.17135878410227104`], 
         DiskBox[737, 0.17135878410227104`], 
         DiskBox[738, 0.17135878410227104`], 
         DiskBox[739, 0.17135878410227104`], 
         DiskBox[740, 0.17135878410227104`], 
         DiskBox[741, 0.17135878410227104`], 
         DiskBox[742, 0.17135878410227104`], 
         DiskBox[743, 0.17135878410227104`], 
         DiskBox[744, 0.17135878410227104`], 
         DiskBox[745, 0.17135878410227104`], 
         DiskBox[746, 0.17135878410227104`], 
         DiskBox[747, 0.17135878410227104`], 
         DiskBox[748, 0.17135878410227104`], 
         DiskBox[749, 0.17135878410227104`], 
         DiskBox[750, 0.17135878410227104`], 
         DiskBox[751, 0.17135878410227104`], 
         DiskBox[752, 0.17135878410227104`], 
         DiskBox[753, 0.17135878410227104`], 
         DiskBox[754, 0.17135878410227104`], 
         DiskBox[755, 0.17135878410227104`], 
         DiskBox[756, 0.17135878410227104`], 
         DiskBox[757, 0.17135878410227104`], 
         DiskBox[758, 0.17135878410227104`], 
         DiskBox[759, 0.17135878410227104`], 
         DiskBox[760, 0.17135878410227104`], 
         DiskBox[761, 0.17135878410227104`], 
         DiskBox[762, 0.17135878410227104`], 
         DiskBox[763, 0.17135878410227104`], 
         DiskBox[764, 0.17135878410227104`], 
         DiskBox[765, 0.17135878410227104`], 
         DiskBox[766, 0.17135878410227104`], 
         DiskBox[767, 0.17135878410227104`], 
         DiskBox[768, 0.17135878410227104`], 
         DiskBox[769, 0.17135878410227104`], 
         DiskBox[770, 0.17135878410227104`], 
         DiskBox[771, 0.17135878410227104`], 
         DiskBox[772, 0.17135878410227104`], 
         DiskBox[773, 0.17135878410227104`], 
         DiskBox[774, 0.17135878410227104`], 
         DiskBox[775, 0.17135878410227104`], 
         DiskBox[776, 0.17135878410227104`], 
         DiskBox[777, 0.17135878410227104`], 
         DiskBox[778, 0.17135878410227104`], 
         DiskBox[779, 0.17135878410227104`], 
         DiskBox[780, 0.17135878410227104`], 
         DiskBox[781, 0.17135878410227104`], 
         DiskBox[782, 0.17135878410227104`], 
         DiskBox[783, 0.17135878410227104`], 
         DiskBox[784, 0.17135878410227104`], 
         DiskBox[785, 0.17135878410227104`], 
         DiskBox[786, 0.17135878410227104`], 
         DiskBox[787, 0.17135878410227104`], 
         DiskBox[788, 0.17135878410227104`], 
         DiskBox[789, 0.17135878410227104`], 
         DiskBox[790, 0.17135878410227104`], 
         DiskBox[791, 0.17135878410227104`], 
         DiskBox[792, 0.17135878410227104`], 
         DiskBox[793, 0.17135878410227104`], 
         DiskBox[794, 0.17135878410227104`], 
         DiskBox[795, 0.17135878410227104`], 
         DiskBox[796, 0.17135878410227104`], 
         DiskBox[797, 0.17135878410227104`], 
         DiskBox[798, 0.17135878410227104`], 
         DiskBox[799, 0.17135878410227104`], 
         DiskBox[800, 0.17135878410227104`], 
         DiskBox[801, 0.17135878410227104`], 
         DiskBox[802, 0.17135878410227104`], 
         DiskBox[803, 0.17135878410227104`], 
         DiskBox[804, 0.17135878410227104`], 
         DiskBox[805, 0.17135878410227104`], 
         DiskBox[806, 0.17135878410227104`], 
         DiskBox[807, 0.17135878410227104`], 
         DiskBox[808, 0.17135878410227104`], 
         DiskBox[809, 0.17135878410227104`], 
         DiskBox[810, 0.17135878410227104`], 
         DiskBox[811, 0.17135878410227104`], 
         DiskBox[812, 0.17135878410227104`], 
         DiskBox[813, 0.17135878410227104`], 
         DiskBox[814, 0.17135878410227104`], 
         DiskBox[815, 0.17135878410227104`], 
         DiskBox[816, 0.17135878410227104`], 
         DiskBox[817, 0.17135878410227104`], 
         DiskBox[818, 0.17135878410227104`], 
         DiskBox[819, 0.17135878410227104`], 
         DiskBox[820, 0.17135878410227104`], 
         DiskBox[821, 0.17135878410227104`], 
         DiskBox[822, 0.17135878410227104`], 
         DiskBox[823, 0.17135878410227104`], 
         DiskBox[824, 0.17135878410227104`], 
         DiskBox[825, 0.17135878410227104`], 
         DiskBox[826, 0.17135878410227104`], 
         DiskBox[827, 0.17135878410227104`], 
         DiskBox[828, 0.17135878410227104`], 
         DiskBox[829, 0.17135878410227104`], 
         DiskBox[830, 0.17135878410227104`], 
         DiskBox[831, 0.17135878410227104`], 
         DiskBox[832, 0.17135878410227104`], 
         DiskBox[833, 0.17135878410227104`], 
         DiskBox[834, 0.17135878410227104`], 
         DiskBox[835, 0.17135878410227104`], 
         DiskBox[836, 0.17135878410227104`], 
         DiskBox[837, 0.17135878410227104`], 
         DiskBox[838, 0.17135878410227104`], 
         DiskBox[839, 0.17135878410227104`], 
         DiskBox[840, 0.17135878410227104`], 
         DiskBox[841, 0.17135878410227104`], 
         DiskBox[842, 0.17135878410227104`], 
         DiskBox[843, 0.17135878410227104`], 
         DiskBox[844, 0.17135878410227104`], 
         DiskBox[845, 0.17135878410227104`], 
         DiskBox[846, 0.17135878410227104`], 
         DiskBox[847, 0.17135878410227104`], 
         DiskBox[848, 0.17135878410227104`], 
         DiskBox[849, 0.17135878410227104`], 
         DiskBox[850, 0.17135878410227104`], 
         DiskBox[851, 0.17135878410227104`], 
         DiskBox[852, 0.17135878410227104`], 
         DiskBox[853, 0.17135878410227104`], 
         DiskBox[854, 0.17135878410227104`], 
         DiskBox[855, 0.17135878410227104`], 
         DiskBox[856, 0.17135878410227104`], 
         DiskBox[857, 0.17135878410227104`], 
         DiskBox[858, 0.17135878410227104`], 
         DiskBox[859, 0.17135878410227104`], 
         DiskBox[860, 0.17135878410227104`], 
         DiskBox[861, 0.17135878410227104`], 
         DiskBox[862, 0.17135878410227104`], 
         DiskBox[863, 0.17135878410227104`], 
         DiskBox[864, 0.17135878410227104`], 
         DiskBox[865, 0.17135878410227104`], 
         DiskBox[866, 0.17135878410227104`], 
         DiskBox[867, 0.17135878410227104`], 
         DiskBox[868, 0.17135878410227104`], 
         DiskBox[869, 0.17135878410227104`], 
         DiskBox[870, 0.17135878410227104`], 
         DiskBox[871, 0.17135878410227104`], 
         DiskBox[872, 0.17135878410227104`], 
         DiskBox[873, 0.17135878410227104`], 
         DiskBox[874, 0.17135878410227104`], 
         DiskBox[875, 0.17135878410227104`], 
         DiskBox[876, 0.17135878410227104`], 
         DiskBox[877, 0.17135878410227104`], 
         DiskBox[878, 0.17135878410227104`], 
         DiskBox[879, 0.17135878410227104`], 
         DiskBox[880, 0.17135878410227104`], 
         DiskBox[881, 0.17135878410227104`], 
         DiskBox[882, 0.17135878410227104`], 
         DiskBox[883, 0.17135878410227104`], 
         DiskBox[884, 0.17135878410227104`], 
         DiskBox[885, 0.17135878410227104`], 
         DiskBox[886, 0.17135878410227104`], 
         DiskBox[887, 0.17135878410227104`], 
         DiskBox[888, 0.17135878410227104`], 
         DiskBox[889, 0.17135878410227104`], 
         DiskBox[890, 0.17135878410227104`], 
         DiskBox[891, 0.17135878410227104`], 
         DiskBox[892, 0.17135878410227104`], 
         DiskBox[893, 0.17135878410227104`], 
         DiskBox[894, 0.17135878410227104`], 
         DiskBox[895, 0.17135878410227104`], 
         DiskBox[896, 0.17135878410227104`], 
         DiskBox[897, 0.17135878410227104`], 
         DiskBox[898, 0.17135878410227104`], 
         DiskBox[899, 0.17135878410227104`], 
         DiskBox[900, 0.17135878410227104`], 
         DiskBox[901, 0.17135878410227104`], 
         DiskBox[902, 0.17135878410227104`], 
         DiskBox[903, 0.17135878410227104`], 
         DiskBox[904, 0.17135878410227104`], 
         DiskBox[905, 0.17135878410227104`], 
         DiskBox[906, 0.17135878410227104`], 
         DiskBox[907, 0.17135878410227104`], 
         DiskBox[908, 0.17135878410227104`], 
         DiskBox[909, 0.17135878410227104`], 
         DiskBox[910, 0.17135878410227104`], 
         DiskBox[911, 0.17135878410227104`], 
         DiskBox[912, 0.17135878410227104`], 
         DiskBox[913, 0.17135878410227104`], 
         DiskBox[914, 0.17135878410227104`], 
         DiskBox[915, 0.17135878410227104`], 
         DiskBox[916, 0.17135878410227104`], 
         DiskBox[917, 0.17135878410227104`], 
         DiskBox[918, 0.17135878410227104`], 
         DiskBox[919, 0.17135878410227104`], 
         DiskBox[920, 0.17135878410227104`], 
         DiskBox[921, 0.17135878410227104`], 
         DiskBox[922, 0.17135878410227104`], 
         DiskBox[923, 0.17135878410227104`], 
         DiskBox[924, 0.17135878410227104`], 
         DiskBox[925, 0.17135878410227104`], 
         DiskBox[926, 0.17135878410227104`], 
         DiskBox[927, 0.17135878410227104`], 
         DiskBox[928, 0.17135878410227104`], 
         DiskBox[929, 0.17135878410227104`], 
         DiskBox[930, 0.17135878410227104`], 
         DiskBox[931, 0.17135878410227104`], 
         DiskBox[932, 0.17135878410227104`], 
         DiskBox[933, 0.17135878410227104`], 
         DiskBox[934, 0.17135878410227104`], 
         DiskBox[935, 0.17135878410227104`], 
         DiskBox[936, 0.17135878410227104`], 
         DiskBox[937, 0.17135878410227104`], 
         DiskBox[938, 0.17135878410227104`], 
         DiskBox[939, 0.17135878410227104`], 
         DiskBox[940, 0.17135878410227104`], 
         DiskBox[941, 0.17135878410227104`], 
         DiskBox[942, 0.17135878410227104`], 
         DiskBox[943, 0.17135878410227104`], 
         DiskBox[944, 0.17135878410227104`], 
         DiskBox[945, 0.17135878410227104`], 
         DiskBox[946, 0.17135878410227104`], 
         DiskBox[947, 0.17135878410227104`], 
         DiskBox[948, 0.17135878410227104`], 
         DiskBox[949, 0.17135878410227104`], 
         DiskBox[950, 0.17135878410227104`], 
         DiskBox[951, 0.17135878410227104`], 
         DiskBox[952, 0.17135878410227104`], 
         DiskBox[953, 0.17135878410227104`], 
         DiskBox[954, 0.17135878410227104`], 
         DiskBox[955, 0.17135878410227104`], 
         DiskBox[956, 0.17135878410227104`], 
         DiskBox[957, 0.17135878410227104`], 
         DiskBox[958, 0.17135878410227104`], 
         DiskBox[959, 0.17135878410227104`], 
         DiskBox[960, 0.17135878410227104`], 
         DiskBox[961, 0.17135878410227104`], 
         DiskBox[962, 0.17135878410227104`], 
         DiskBox[963, 0.17135878410227104`], 
         DiskBox[964, 0.17135878410227104`], 
         DiskBox[965, 0.17135878410227104`], 
         DiskBox[966, 0.17135878410227104`], 
         DiskBox[967, 0.17135878410227104`], 
         DiskBox[968, 0.17135878410227104`], 
         DiskBox[969, 0.17135878410227104`], 
         DiskBox[970, 0.17135878410227104`], 
         DiskBox[971, 0.17135878410227104`], 
         DiskBox[972, 0.17135878410227104`], 
         DiskBox[973, 0.17135878410227104`], 
         DiskBox[974, 0.17135878410227104`], 
         DiskBox[975, 0.17135878410227104`], 
         DiskBox[976, 0.17135878410227104`], 
         DiskBox[977, 0.17135878410227104`], 
         DiskBox[978, 0.17135878410227104`], 
         DiskBox[979, 0.17135878410227104`], 
         DiskBox[980, 0.17135878410227104`], 
         DiskBox[981, 0.17135878410227104`], 
         DiskBox[982, 0.17135878410227104`], 
         DiskBox[983, 0.17135878410227104`], 
         DiskBox[984, 0.17135878410227104`], 
         DiskBox[985, 0.17135878410227104`], 
         DiskBox[986, 0.17135878410227104`], 
         DiskBox[987, 0.17135878410227104`], 
         DiskBox[988, 0.17135878410227104`], 
         DiskBox[989, 0.17135878410227104`], 
         DiskBox[990, 0.17135878410227104`], 
         DiskBox[991, 0.17135878410227104`], 
         DiskBox[992, 0.17135878410227104`], 
         DiskBox[993, 0.17135878410227104`], 
         DiskBox[994, 0.17135878410227104`], 
         DiskBox[995, 0.17135878410227104`], 
         DiskBox[996, 0.17135878410227104`], 
         DiskBox[997, 0.17135878410227104`], 
         DiskBox[998, 0.17135878410227104`], 
         DiskBox[999, 0.17135878410227104`], 
         DiskBox[1000, 0.17135878410227104`], 
         DiskBox[1001, 0.17135878410227104`], 
         DiskBox[1002, 0.17135878410227104`], 
         DiskBox[1003, 0.17135878410227104`], 
         DiskBox[1004, 0.17135878410227104`], 
         DiskBox[1005, 0.17135878410227104`], 
         DiskBox[1006, 0.17135878410227104`], 
         DiskBox[1007, 0.17135878410227104`], 
         DiskBox[1008, 0.17135878410227104`], 
         DiskBox[1009, 0.17135878410227104`], 
         DiskBox[1010, 0.17135878410227104`], 
         DiskBox[1011, 0.17135878410227104`], 
         DiskBox[1012, 0.17135878410227104`], 
         DiskBox[1013, 0.17135878410227104`], 
         DiskBox[1014, 0.17135878410227104`], 
         DiskBox[1015, 0.17135878410227104`], 
         DiskBox[1016, 0.17135878410227104`], 
         DiskBox[1017, 0.17135878410227104`], 
         DiskBox[1018, 0.17135878410227104`], 
         DiskBox[1019, 0.17135878410227104`], 
         DiskBox[1020, 0.17135878410227104`], 
         DiskBox[1021, 0.17135878410227104`], 
         DiskBox[1022, 0.17135878410227104`], 
         DiskBox[1023, 0.17135878410227104`], 
         DiskBox[1024, 0.17135878410227104`]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaseStyle->{
    EdgeForm[
     GrayLevel[0]]},
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.6775727935330777`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: N-K-Modell \[Dash] Teil 3"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704872223864946`*^9, 3.670489147179757*^9, 
   3.6704894516538935`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Der dritte Teil dieses ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses ist dem biologischen Fallbeispiel aus Li et al. (2004) gewidmet, \
der Boole\[CloseCurlyQuote]schen Modellierung des Zellzyklus-Netzwerks der \
Hefe. Als Erstes \[UDoubleDot]bernehmen wir die Knotennamen und die \
aktivierenden und inhibierenden Verbindungen aus der Publikation. Dabei ist \
zu beachten, dass dort f\[UDoubleDot]r alle Knoten ohne inhibierenden Input \
auch noch eine Selbstinhibition eingef\[UDoubleDot]gt wurde."
}], "Text",
 CellChangeTimes->{{3.6771333409382315`*^9, 3.67713335126645*^9}, 
   3.677397222133749*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"yeastNodes", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Cell Size\>\"", ",", "\"\<Cln3\>\"", ",", "\"\<SBF\>\"", ",", 
     "\"\<MBF\>\"", ",", "\"\<Cln1,2\>\"", ",", "\"\<Clb5,6\>\"", ",", 
     "\"\<Sic1\>\"", ",", "\"\<Cdh1\>\"", ",", "\"\<Clb1,2\>\"", ",", 
     "\"\<Cdc20&Cdc14\>\"", ",", "\"\<Mcm1/SFF\>\"", ",", "\"\<Swi5\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606364698605196*^9, 3.606364707640025*^9}, {
  3.642041859490613*^9, 3.6420418651643457`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"activatorList", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"12", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "9"}], "}"}]}], "}"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", 
     RowBox[{"(", " ", 
      RowBox[{"n1", "\[Rule]", "n2"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.6063652474712257`*^9, {3.606365320574788*^9, 3.606365361945854*^9}, {
   3.606365419340746*^9, 3.6063654277804537`*^9}, 3.623829462598259*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"inhibitorList", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "12"}], "}"}]}], "}"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", 
     RowBox[{"(", " ", 
      RowBox[{"n1", "\[Rule]", "n2"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606365482649658*^9, 3.606365484307419*^9}, 
   3.623829468585726*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"selfinhibitorList", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"12", ",", "12"}], "}"}]}], "}"}], "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", 
     RowBox[{"(", " ", 
      RowBox[{"n1", "\[Rule]", "n2"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606365536005472*^9, 3.606365537319467*^9}, 
   3.623829473549621*^9}],

Cell["\<\
Mit diesen Zutaten lassen sich nun der Graph und die verallgemeinerte \
Adjazenzmatrix (in der aktivierende und inhibierende Verbindungen gem\
\[ADoubleDot]\[SZ] ihres Vorzeichens charakterisiert sind) erzeugen. Es \
erweist sich als g\[UDoubleDot]nstig, die Knotennummern bei der Erzeugung der \
Teilgraphen explizit mit anzugeben. Das erleichtert die Erzeugung der \
Adjazenzmatrix.\
\>", "Text",
 CellChangeTimes->{{3.677397281491853*^9, 3.677397296093479*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g1", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"j", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "yeastNodes", "]"}]}], "}"}]}], "]"}], ",", 
     "activatorList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606365372032674*^9, 3.6063653897340107`*^9}, {
  3.606365446106963*^9, 3.606365472654825*^9}, {3.6063656606211643`*^9, 
  3.606365660911701*^9}, {3.606365719562911*^9, 3.606365740488948*^9}, {
  3.606367203641593*^9, 3.606367204567387*^9}, {3.6063672388936977`*^9, 
  3.6063672427646*^9}, {3.606367379944706*^9, 3.606367380294763*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g2", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"j", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "yeastNodes", "]"}]}], "}"}]}], "]"}], ",", 
     "inhibitorList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606365372032674*^9, 3.6063653897340107`*^9}, {
  3.606365446106963*^9, 3.606365511250392*^9}, {3.606365663229233*^9, 
  3.606365663487557*^9}, {3.6063657489810743`*^9, 3.60636574928937*^9}, {
  3.6063672636530037`*^9, 3.606367266238162*^9}, {3.606367370019825*^9, 
  3.6063673702925367`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g3", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"j", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "yeastNodes", "]"}]}], "}"}]}], "]"}], ",", 
     "selfinhibitorList"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606365372032674*^9, 3.6063653897340107`*^9}, {
  3.606365446106963*^9, 3.606365545625505*^9}, {3.6063656662210484`*^9, 
  3.606365666495393*^9}, {3.606365757090893*^9, 3.606365757363866*^9}, {
  3.606367276874838*^9, 3.606367278167595*^9}, {3.606367372721525*^9, 
  3.6063673730796747`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yeastGraph", " ", "=", " ", 
  RowBox[{"GraphUnion", "[", 
   RowBox[{"g1", ",", "g2", ",", "g3", ",", 
    RowBox[{"GraphLayout", "\[Rule]", "\"\<CircularEmbedding\>\""}], ",", 
    RowBox[{"EdgeStyle", "\[Rule]", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "g1", "]"}], "->", 
         RowBox[{"Table", "[", 
          RowBox[{"Green", ",", 
           RowBox[{"{", 
            RowBox[{"Length", "[", "activatorList", "]"}], "}"}]}], "]"}]}], 
        "]"}], ",", 
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "g2", "]"}], "->", 
         RowBox[{"Table", "[", 
          RowBox[{"Red", ",", 
           RowBox[{"{", 
            RowBox[{"Length", "[", "inhibitorList", "]"}], "}"}]}], "]"}]}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"EdgeList", "[", "g3", "]"}], "->", 
         RowBox[{"Table", "[", 
          RowBox[{"Yellow", ",", 
           RowBox[{"{", 
            RowBox[{"Length", "[", "selfinhibitorList", "]"}], "}"}]}], 
          "]"}]}], "]"}]}], "]"}]}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"j", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "yeastNodes", "]"}]}], "}"}]}], "]"}], 
       "\[Rule]", "yeastNodes"}], "]"}]}], ",", 
    RowBox[{"VertexSize", "\[Rule]", "0.2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6063655511530323`*^9, 3.6063656067569237`*^9}, {
   3.606365792550686*^9, 3.606365927148398*^9}, 3.6063663198303947`*^9, {
   3.606366792314122*^9, 3.606366895298234*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
      12}, {{{1, 2}, {2, 2}, {2, 3}, {2, 4}, {3, 5}, {4, 6}, {5, 5}, {5, 7}, {
       5, 8}, {6, 7}, {6, 8}, {6, 9}, {6, 11}, {7, 6}, {7, 9}, {8, 9}, {9, 
       3}, {9, 4}, {9, 7}, {9, 8}, {9, 10}, {9, 11}, {9, 12}, {10, 6}, {10, 
       7}, {10, 8}, {10, 9}, {10, 10}, {10, 12}, {11, 9}, {11, 10}, {11, 
       11}, {11, 12}, {12, 7}, {12, 12}}, Null}, {
      EdgeStyle -> {
        DirectedEdge[6, 7] -> RGBColor[1, 0, 0], DirectedEdge[2, 3] -> 
         RGBColor[0, 1, 0], DirectedEdge[10, 8] -> RGBColor[0, 1, 0], 
         DirectedEdge[10, 12] -> RGBColor[0, 1, 0], DirectedEdge[2, 4] -> 
         RGBColor[0, 1, 0], DirectedEdge[5, 8] -> RGBColor[1, 0, 0], 
         DirectedEdge[7, 6] -> RGBColor[1, 0, 0], DirectedEdge[7, 9] -> 
         RGBColor[1, 0, 0], DirectedEdge[1, 2] -> RGBColor[0, 1, 0], 
         DirectedEdge[9, 3] -> RGBColor[1, 0, 0], DirectedEdge[11, 11] -> 
         RGBColor[1, 1, 0], DirectedEdge[9, 8] -> RGBColor[1, 0, 0], 
         DirectedEdge[12, 12] -> RGBColor[1, 1, 0], DirectedEdge[9, 7] -> 
         RGBColor[1, 0, 0], DirectedEdge[8, 9] -> RGBColor[1, 0, 0], 
         DirectedEdge[10, 9] -> RGBColor[1, 0, 0], DirectedEdge[10, 10] -> 
         RGBColor[1, 1, 0], DirectedEdge[9, 12] -> RGBColor[1, 0, 0], 
         DirectedEdge[11, 10] -> RGBColor[0, 1, 0], DirectedEdge[5, 7] -> 
         RGBColor[1, 0, 0], DirectedEdge[6, 8] -> RGBColor[1, 0, 0], 
         DirectedEdge[10, 6] -> RGBColor[1, 0, 0], DirectedEdge[9, 4] -> 
         RGBColor[1, 0, 0], DirectedEdge[11, 9] -> RGBColor[0, 1, 0], 
         DirectedEdge[6, 9] -> RGBColor[0, 1, 0], DirectedEdge[3, 5] -> 
         RGBColor[0, 1, 0], DirectedEdge[9, 10] -> RGBColor[0, 1, 0], 
         DirectedEdge[6, 11] -> RGBColor[0, 1, 0], DirectedEdge[11, 12] -> 
         RGBColor[0, 1, 0], DirectedEdge[2, 2] -> RGBColor[1, 1, 0], 
         DirectedEdge[9, 11] -> RGBColor[0, 1, 0], DirectedEdge[12, 7] -> 
         RGBColor[0, 1, 0], DirectedEdge[5, 5] -> RGBColor[1, 1, 0], 
         DirectedEdge[4, 6] -> RGBColor[0, 1, 0], DirectedEdge[10, 7] -> 
         RGBColor[0, 1, 0]}, GraphLayout -> "CircularEmbedding", 
       VertexLabels -> {
        9 -> "Clb1,2", 5 -> "Cln1,2", 6 -> "Clb5,6", 4 -> "MBF", 12 -> "Swi5",
          8 -> "Cdh1", 7 -> "Sic1", 1 -> "Cell Size", 10 -> "Cdc20&Cdc14", 2 -> 
         "Cln3", 3 -> "SBF", 11 -> "Mcm1/SFF"}, VertexSize -> {0.2}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{-0.5000000000000007, 
          0.866025403784439}, {-0.866025403784439, 0.5000000000000008}}, 
          0.05176380902050407]}, 
        {RGBColor[1, 1, 0], 
         ArrowBox[BezierCurveBox[{{-0.866025403784439, 
          0.5000000000000008}, {-1.083557010621769, 
          0.35894799774638736`}, {-1.304551581346427, 
          0.42728040377216436`}, {-1.3905216288603222`, 
          0.5582931516734785}, {-1.1787568665382724`, 
          0.9250804792680167}, {-1.0223114748791802`, 
          0.9161346081070856}, {-0.8526365899968152, 
          0.7589138987739836}, {-0.866025403784439, 0.5000000000000008}},
          SplineDegree->7], 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{-0.866025403784439, 0.5000000000000008}, {-1., 
          1.0106430996148606`*^-15}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{-0.866025403784439, 
          0.5000000000000008}, {-0.8660254037844383, -0.49999999999999933`}}, 
          0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{-1., 
          1.0106430996148606`*^-15}, {-0.4999999999999995, \
-0.8660254037844379}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{-0.8660254037844383, -0.49999999999999933`}, {
          3.8285686989269494`*^-16, -1.}}, 0.05176380902050407]}, 
        {RGBColor[1, 1, 0], 
         ArrowBox[
          BezierCurveBox[{{-0.4999999999999995, -0.8660254037844379}, \
{-0.3605173146934567, -1.0643445859736471`}, {-0.41885272356877734`, \
-1.295423410091496}, {-0.5510258603581584, -1.3884102683442539`}, \
{-0.9268856330822139, -1.1714075273844686`}, {-0.9124432200119135, \
-1.01044880410061}, {-0.7414907924868802, -0.8443894460155059}, \
{-0.4999999999999995, -0.8660254037844379}},
          SplineDegree->7], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{-0.4999999999999995, -0.8660254037844379}, {
          0.5000000000000006, -0.866025403784439}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{-0.4999999999999995, -0.8660254037844379}, {
          0.8660254037844389, -0.5000000000000012}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{3.8285686989269494`*^-16, -1.}, {
          0.2279691172947537, -0.8507923283006567}, {
          0.5000000000000006, -0.866025403784439}}], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{3.8285686989269494`*^-16, -1.}, {
          0.8660254037844389, -0.5000000000000012}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{3.8285686989269494`*^-16, -1.}, {
          1., -1.133107779529596*^-15}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{3.8285686989269494`*^-16, -1.}, {0.4999999999999996, 
          0.8660254037844379}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{0.5000000000000006, -0.866025403784439}, {
          0.27203088270524556`, -1.0152330754835446`}, {
          3.8285686989269494`*^-16, -1.}}], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{0.5000000000000006, -0.866025403784439}, {
          0.6075901355221257, -0.3507923283006426}, {
          1., -1.133107779529596*^-15}}], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{0.8660254037844389, -0.5000000000000012}, {
          0.8507923283006614, -0.2279691172946049}, {
          1., -1.133107779529596*^-15}}], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{1., -1.133107779529596*^-15}, {-1., 
          1.0106430996148606`*^-15}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{
          1., -1.133107779529596*^-15}, {-0.8660254037844383, \
-0.49999999999999933`}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
          0.8924098644778727, -0.5152330754837324}, {
          0.5000000000000006, -0.866025403784439}}], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
          1.0152330754837788`, -0.2720308827053317}, {
          0.8660254037844389, -0.5000000000000012}}], 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
          0.850792328300661, 0.2279691172947333}, {0.8660254037844384, 
          0.4999999999999992}}], 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
          0.6075901355221264, 0.35079232830065743`}, {0.4999999999999996, 
          0.8660254037844379}}], 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{1., -1.133107779529596*^-15}, {1.8369701987210297`*^-16, 
          1.}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[{{0.8660254037844384, 0.4999999999999992}, {
          3.8285686989269494`*^-16, -1.}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{0.8660254037844384, 0.4999999999999992}, {
          0.5000000000000006, -0.866025403784439}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{0.8660254037844384, 0.4999999999999992}, {
          0.8660254037844389, -0.5000000000000012}}, 0.05176380902050407]}, 
        {RGBColor[1, 0, 0], 
         ArrowBox[BezierCurveBox[{{0.8660254037844384, 0.4999999999999992}, {
          1.0152330754837788`, 0.2720308827052114}, {
          1., -1.133107779529596*^-15}}], 0.05176380902050407]}, 
        {RGBColor[1, 1, 0], 
         ArrowBox[BezierCurveBox[{{0.8660254037844384, 0.4999999999999992}, {
          0.8526365899968146, 0.7589138987739822}, {1.0223114748791795`, 
          0.9161346081070842}, {1.1787568665382717`, 0.9250804792680154}, {
          1.3905216288603215`, 0.5582931516734773}, {1.3045515813464261`, 
          0.4272804037721629}, {1.0835570106217682`, 0.35894799774638597`}, {
          0.8660254037844384, 0.4999999999999992}},
          SplineDegree->7], 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{0.8660254037844384, 0.4999999999999992}, {
          1.8369701987210297`*^-16, 1.}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[BezierCurveBox[{{0.4999999999999996, 0.8660254037844379}, {
          0.8924098644778725, 0.5152330754838258}, {
          1., -1.133107779529596*^-15}}], 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{0.4999999999999996, 0.8660254037844379}, {
          0.8660254037844384, 0.4999999999999992}}, 0.05176380902050407]}, 
        {RGBColor[1, 1, 0], 
         ArrowBox[BezierCurveBox[{{0.4999999999999996, 0.8660254037844379}, {
          0.3589479977463864, 1.0835570106217678`}, {0.4272804037721636, 
          1.3045515813464257`}, {0.5582931516734778, 1.3905216288603208`}, {
          0.9250804792680158, 1.1787568665382708`}, {0.9161346081070847, 
          1.0223114748791788`}, {0.7589138987739827, 0.8526365899968139}, {
          0.4999999999999996, 0.8660254037844379}},
          SplineDegree->7], 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{0.4999999999999996, 0.8660254037844379}, {
          1.8369701987210297`*^-16, 1.}}, 0.05176380902050407]}, 
        {RGBColor[0, 1, 0], 
         ArrowBox[{{1.8369701987210297`*^-16, 1.}, {
          0.5000000000000006, -0.866025403784439}}, 0.05176380902050407]}, 
        {RGBColor[1, 1, 0], 
         ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
          1.}, {-0.22766239534445862`, 
          0.9165988533019837}, {-0.43576908464762254`, 
          1.0327541319233835`}, {-0.4913785674874095, 
          1.1844903481499467`}, {-0.18449034814994572`, 
          1.49137856748741}, {-0.03275413192338256, 1.4357690846476228`}, {
          0.08340114669801688, 1.2276623953444588`}, {
          1.8369701987210297`*^-16, 1.}},
          SplineDegree->7], 0.05176380902050407]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{-0.5000000000000007, 0.866025403784439}, 
          0.05176380902050407], 
         InsetBox["\<\"Cell Size\"\>", 
          Offset[{2, 2}, {-0.4482361909794966, 0.9177892128049431}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-0.866025403784439, 0.5000000000000008}, 
          0.05176380902050407], 
         InsetBox["\<\"Cln3\"\>", 
          Offset[{2, 2}, {-0.814261594763935, 0.5517638090205048}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-1., 1.0106430996148606`*^-15}, 0.05176380902050407], 
         InsetBox["\<\"SBF\"\>", 
          Offset[{2, 2}, {-0.948236190979496, 0.051763809020505085`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-0.8660254037844383, -0.49999999999999933`}, 
          0.05176380902050407], 
         InsetBox["\<\"MBF\"\>", 
          Offset[{2, 2}, {-0.8142615947639342, -0.44823619097949524`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-0.4999999999999995, -0.8660254037844379}, 
          0.05176380902050407], 
         InsetBox["\<\"Cln1,2\"\>", 
          Offset[{2, 2}, {-0.4482361909794954, -0.8142615947639339}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8285686989269494`*^-16, -1.}, 0.05176380902050407], 
         InsetBox["\<\"Clb5,6\"\>", 
          Offset[{2, 2}, {0.05176380902050445, -0.948236190979496}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.5000000000000006, -0.866025403784439}, 
          0.05176380902050407], 
         InsetBox["\<\"Sic1\"\>", 
          Offset[{2, 2}, {0.5517638090205046, -0.814261594763935}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8660254037844389, -0.5000000000000012}, 
          0.05176380902050407], 
         InsetBox["\<\"Cdh1\"\>", 
          Offset[{2, 2}, {0.917789212804943, -0.44823619097949713`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1., -1.133107779529596*^-15}, 0.05176380902050407], 
         InsetBox["\<\"Clb1,2\"\>", Offset[{2, 2}, 
          {1.0517638090205041`, 0.05176380902050294}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8660254037844384, 0.4999999999999992}, 
          0.05176380902050407], 
         InsetBox["\<\"Cdc20&Cdc14\"\>", 
          Offset[{2, 2}, {0.9177892128049424, 0.5517638090205033}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.4999999999999996, 0.8660254037844379}, 
          0.05176380902050407], 
         InsetBox["\<\"Mcm1/SFF\"\>", 
          Offset[{2, 2}, {0.5517638090205037, 0.917789212804942}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.8369701987210297`*^-16, 1.}, 0.05176380902050407], 
         InsetBox["\<\"Swi5\"\>", 
          Offset[{2, 2}, {0.05176380902050425, 1.0517638090205041`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.6775727936890783`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Option ",
 StyleBox["EdgeStyle",
  FontWeight->"Bold"],
 " erfordert f\[UDoubleDot]r eine Angabe von verbindungsspezifischen Farben \
eine etwas sperrige Formatierung: Verbindung \[Rule] Farbe. Dies wird hier \
\[UDoubleDot]ber die ",
 StyleBox["Thread",
  FontWeight->"Bold"],
 "-Befehle erreicht. Der so dargestellte Graph entspricht Abb. 1B in Li et \
al. (2004). Nun folgt die Erzeugung der verallgemeinerten Adjazenzmatrix:"
}], "Text",
 CellChangeTimes->{{3.677397329667738*^9, 3.677397412301083*^9}, {
  3.6774853641797533`*^9, 3.6774853874237947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m1", "=", 
   RowBox[{"AdjacencyMatrix", "[", "g1", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m2", "=", 
   RowBox[{"AdjacencyMatrix", "[", "g2", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m3", "=", 
   RowBox[{"AdjacencyMatrix", "[", "g3", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yeastAd", " ", "=", " ", 
   RowBox[{"m1", " ", "-", " ", "m2", " ", "-", "m3"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Normal", "[", "yeastAd", "]"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.606366467231882*^9, 3.606366557597411*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "1", "1", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", "0", "1", "0"},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "1", "1", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "1", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "1"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", 
      RowBox[{"-", "1"}], "1"},
     {"0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677572793751478*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Mehrheitsabfrage von aktivierenden und inhibierenden Inputs, die den \
Kern der Update-Funktion darstellt, l\[ADoubleDot]sst sich in sehr einfacher \
Form\[UDoubleDot]ber eine ",
 StyleBox["Which",
  FontWeight->"Bold"],
 "-Abfrage implementieren:"
}], "Text",
 CellChangeTimes->{{3.677397733593648*^9, 3.677397752439481*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"updateFun", "[", 
   RowBox[{"mat_", ",", "vec_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp1", ",", " ", "tmp2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", " ", "=", " ", 
      RowBox[{"Length", "[", "vec", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp2", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "tmp1", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmp2", "[", 
         RowBox[{"[", "j", "]"}], "]"}], "=", " ", 
        RowBox[{"Which", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mat", ".", "vec"}], ")"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ">", "0"}], ",", "1", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mat", ".", "vec"}], ")"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], "<", "0"}], ",", "0", ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mat", ".", "vec"}], ")"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", " ", 
          RowBox[{"vec", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "tmp1"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "tmp2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.606367110962105*^9}],

Cell["\<\
Als Anfangszustand w\[ADoubleDot]hlen wir den ersten Systemzustand aus Tab. 2 \
in Li et al. (2004).\
\>", "Text",
 CellChangeTimes->{{3.6773978681634846`*^9, 3.677397883079111*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"initYeast", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1",
      ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.6063670603249283`*^9, {3.6063742291415377`*^9, 3.6063742297572603`*^9}, {
   3.606379579804121*^9, 3.6063795806280003`*^9}, 3.6420438112415657`*^9}],

Cell["\<\
Mit diesen Zuweisungen k\[ODoubleDot]nnen wir nun unser erstes numerisches \
Experiment zum Hefezellzyklus durchf\[UDoubleDot]hren. Die Simulation von 15 \
Zeitschritten reproduziert Tab. 2 aus Li et al. (2004):\
\>", "Text",
 CellChangeTimes->{{3.6773979194115744`*^9, 3.6773979336231995`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"res1", " ", "=", " ", 
   RowBox[{"NestList", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"updateFun", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"Normal", "[", "yeastAd", "]"}], "]"}], ",", "#"}], "]"}], 
      "&"}], ",", "initYeast", ",", "15"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606367124672913*^9, 3.6063671427785063`*^9}, 
   3.606379585344203*^9, 3.623829557301244*^9}],

Cell[TextData[{
 "Eine einfache grafische Darstellung erfolgt mit ",
 StyleBox["ArrayPlot",
  FontWeight->"Bold"],
 " und ist in Abb. 5.57 dargestellt."
}], "Text",
 CellChangeTimes->{{3.6773979956957083`*^9, 3.677398004026123*^9}, {
  3.6773980487534018`*^9, 3.677398051077806*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"res1", ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Zeit\>\"", ",", "15"}], "]"}], ",", "None"}], "}"}]}], 
   ",", 
   RowBox[{"FrameTicks", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "None", ",", "None", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"j", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "12"}], "}"}]}], "]"}], ",", 
         RowBox[{"Thread", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"yeastNodes", ",", "9"}], "]"}], "]"}]}], "}"}], "]"}]}], 
     "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.6063674267177267`*^9, {3.606374401670384*^9, 3.606374570676478*^9}, {
   3.60637460122978*^9, 3.606374640016391*^9}, {3.6063746851480017`*^9, 
   3.606374746655108*^9}, {3.606379831398797*^9, 3.606379916479253*^9}, {
   3.623829635568355*^9, 3.623829639806776*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[
  RasterBox[{{1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 0, 0, 1,
    1, 1, 1}, {1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 0, 0, 
   1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 0}, {1, 1, 1, 1, 1, 1, 0, 0,
    1, 0, 1, 0}, {1, 1, 1, 1, 1, 1, 0, 1, 1, 0, 0, 0}, {1, 1, 1, 1, 1, 1, 0, 
   1, 0, 0, 0, 0}, {1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0}, {1, 1, 1, 1, 0, 0, 1,
    1, 0, 0, 0, 1}, {1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 0, 1}, {1, 1, 0, 0, 0, 0, 
   1, 1, 1, 1, 1, 1}, {1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 0, 0, 0, 1,
    0, 0, 1, 1, 1, 1}, {1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1}, {1, 0, 1, 1, 1, 
   1, 0, 0, 1, 1, 1, 1}}, {{0, 0}, {12, 16}}, {0, 1}],
  AspectRatio->0.3,
  Frame->Automatic,
  FrameLabel->{None, 
    FormBox[
     StyleBox["\"Zeit\"", 15, StripOnInput -> False], TraditionalForm]},
  FrameTicks->{{{{11.5, 
       FormBox["5", TraditionalForm]}, {6.5, 
       FormBox["10", TraditionalForm]}, {1.5, 
       FormBox["15", TraditionalForm]}}, None}, {None, {{0.5, 
       FormBox[
        StyleBox["\"Cell Size\"", 9, StripOnInput -> False], 
        TraditionalForm]}, {1.5, 
       FormBox[
        StyleBox["\"Cln3\"", 9, StripOnInput -> False], TraditionalForm]}, {
      2.5, 
       FormBox[
        StyleBox["\"SBF\"", 9, StripOnInput -> False], TraditionalForm]}, {
      3.5, 
       FormBox[
        StyleBox["\"MBF\"", 9, StripOnInput -> False], TraditionalForm]}, {
      4.5, 
       FormBox[
        StyleBox["\"Cln1,2\"", 9, StripOnInput -> False], TraditionalForm]}, {
      5.5, 
       FormBox[
        StyleBox["\"Clb5,6\"", 9, StripOnInput -> False], TraditionalForm]}, {
      6.5, 
       FormBox[
        StyleBox["\"Sic1\"", 9, StripOnInput -> False], TraditionalForm]}, {
      7.5, 
       FormBox[
        StyleBox["\"Cdh1\"", 9, StripOnInput -> False], TraditionalForm]}, {
      8.5, 
       FormBox[
        StyleBox["\"Clb1,2\"", 9, StripOnInput -> False], TraditionalForm]}, {
      9.5, 
       FormBox[
        StyleBox["\"Cdc20&Cdc14\"", 9, StripOnInput -> False], 
        TraditionalForm]}, {10.5, 
       FormBox[
        StyleBox["\"Mcm1/SFF\"", 9, StripOnInput -> False], 
        TraditionalForm]}, {11.5, 
       FormBox[
        StyleBox["\"Swi5\"", 9, StripOnInput -> False], TraditionalForm]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->800,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Output",
 CellChangeTimes->{3.6775727938606787`*^9}]
}, Open  ]],

Cell[TextData[{
 "Nun kommen wir zur Analyse der Attraktorstruktur. Der erste Knoten im \
Netzwerk, ",
 StyleBox["Cell Size",
  FontSlant->"Italic"],
 ", ist ein Checkpoint, der nur als Schalter dient, um die station\
\[ADoubleDot]re G1-Phase bei geeigneter Zellgr\[ODoubleDot]\[SZ]e in das \
genetische Programm des Zellzyklus zu \[UDoubleDot]berf\[UDoubleDot]hren. Um \
die Attraktorstruktur des eigentlichen Netzwerks zu analysieren, setzen wir \
diesen Zustand auf Null, indem wir nur bin\[ADoubleDot]re Zahlen der L\
\[ADoubleDot]nge 11 erzeugen und um eine Null an der linken Seite erweitern. \
Ansonsten kopieren wir pr\[ADoubleDot]zise das Vorgehen von den \
vorangegangenen Attraktoranalysen. Dies entspricht der schon diskutierten ",
 StyleBox["Befehlsabfolge.",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.6773980679102354`*^9, 3.6773980899072742`*^9}, {
  3.6773981224645314`*^9, 3.677398144959771*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"allStates", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"IntegerDigits", "[", 
      RowBox[{"j", ",", "2", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "11"}], "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"labels", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"j", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "11"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"allStatesUpdated", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"updateFun", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"Normal", "[", "yeastAd", "]"}], "]"}], ",", "#"}], "]"}], 
      "&"}], ",", " ", "allStates"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"allStatesPairs", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"allStates", ",", "allStatesUpdated"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"labels2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"allStates", "\[Rule]", "labels"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"labelPairs", " ", "=", " ", 
   RowBox[{"allStatesPairs", " ", "/.", " ", "labels2"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"asp2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "12"}], "]"}], 
        "&"}], ",", "allStates"}], "]"}], "\[Rule]", " ", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "12"}], "]"}], 
        "&"}], ",", "allStatesUpdated"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.606367542384912*^9, {3.60636757261093*^9, 3.606367586994026*^9}, 
   3.6063685894579153`*^9, 3.606374905705571*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Man erh\[ADoubleDot]lt dann die Attraktorgraphen wieder durch einfache \
Darstellung der Liste ",
 StyleBox["asp2",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.677398148266977*^9, 3.6773981578765936`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gYeast", " ", "=", " ", 
  RowBox[{"Graph", "[", 
   RowBox[{"asp2", ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
    RowBox[{"VertexStyle", "\[Rule]", "LightGray"}], ",", 
    RowBox[{"VertexSize", "\[Rule]", "8"}], ",", 
    RowBox[{"VertexShapeFunction", "\[Rule]", "\"\<Circle\>\""}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"EdgeForm", "[", "Black", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.642043990359921*^9, 3.642043992990925*^9}, 
   3.670489631524011*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "000000000000", "000000000001", "000000100000", "000000000010", 
       "000000001101", "000000000011", "000000101101", "000000000100", 
       "000000110001", "000000000101", "000000000110", "000000110101", 
       "000000000111", "000000001000", "000000001110", "000000001001", 
       "000000001010", "000000001011", "000000001100", "000000100110", 
       "000000001111", "000000101111", "000000010000", "000000010001", 
       "000000110000", "000000010010", "000000010101", "000000010011", 
       "000000010100", "000000010110", "000000010111", "000000011000", 
       "000000011001", "000000011010", "000000011011", "000000011100", 
       "000000011101", "000000110110", "000000011110", "000000011111", 
       "000000110111", "000000100001", "000000100010", "000000100101", 
       "000000100011", "000000100100", "000000100111", "000000101000", 
       "000000101001", "000000101010", "000000101011", "000000101110", 
       "000000101100", "000000110010", "000000110011", "000000110100", 
       "000000111000", "000000111001", "000000111010", "000000111011", 
       "000000111100", "000000111101", "000000111110", "000000111111", 
       "000001000000", "000001001010", "000001000001", "000001000010", 
       "000001001111", "000001000011", "000001000100", "000001000101", 
       "000001000110", "000001000111", "000001001000", "000001001110", 
       "000001001001", "000001001011", "000001001100", "000001001101", 
       "000001010000", "000001010001", "000001010010", "000001010011", 
       "000001010100", "000001010101", "000001010110", "000001010111", 
       "000001011000", "000001011001", "000001011010", "000001011011", 
       "000001011100", "000001011101", "000001011110", "000001011111", 
       "000001100000", "000001100001", "000001100010", "000001100011", 
       "000001100100", "000001100101", "000001100110", "000001100111", 
       "000001101000", "000001101001", "000001101010", "000001101011", 
       "000001101100", "000001101101", "000001101110", "000001101111", 
       "000001110000", "000001110001", "000001110010", "000001110011", 
       "000001110100", "000001110101", "000001110110", "000001110111", 
       "000001111000", "000001111001", "000001111010", "000001111011", 
       "000001111100", "000001111101", "000001111110", "000001111111", 
       "000010000000", "000010000001", "000010000010", "000010000011", 
       "000010000100", "000010000101", "000010000110", "000010000111", 
       "000010001000", "000010001001", "000010001010", "000010001011", 
       "000010001100", "000010001101", "000010001110", "000010001111", 
       "000010010000", "000010010001", "000010010010", "000010010011", 
       "000010010100", "000010010101", "000010010110", "000010010111", 
       "000010011000", "000010011001", "000010011010", "000010011011", 
       "000010011100", "000010011101", "000010011110", "000010011111", 
       "000010100000", "000010100001", "000010100010", "000010100011", 
       "000010100100", "000010100101", "000010100110", "000010100111", 
       "000010101000", "000010101001", "000010101010", "000010101011", 
       "000010101100", "000010101101", "000010101110", "000010101111", 
       "000010110000", "000010110001", "000010110010", "000010110011", 
       "000010110100", "000010110101", "000010110110", "000010110111", 
       "000010111000", "000010111001", "000010111010", "000010111011", 
       "000010111100", "000010111101", "000010111110", "000010111111", 
       "000011000000", "000011000001", "000011000010", "000011000011", 
       "000011000100", "000011000101", "000011000110", "000011000111", 
       "000011001000", "000011001001", "000011001010", "000011001011", 
       "000011001100", "000011001101", "000011001110", "000011001111", 
       "000011010000", "000011010001", "000011010010", "000011010011", 
       "000011010100", "000011010101", "000011010110", "000011010111", 
       "000011011000", "000011011001", "000011011010", "000011011011", 
       "000011011100", "000011011101", "000011011110", "000011011111", 
       "000011100000", "000011100001", "000011100010", "000011100011", 
       "000011100100", "000011100101", "000011100110", "000011100111", 
       "000011101000", "000011101001", "000011101010", "000011101011", 
       "000011101100", "000011101101", "000011101110", "000011101111", 
       "000011110000", "000011110001", "000011110010", "000011110011", 
       "000011110100", "000011110101", "000011110110", "000011110111", 
       "000011111000", "000011111001", "000011111010", "000011111011", 
       "000011111100", "000011111101", "000011111110", "000011111111", 
       "000100000000", "000101000000", "000100000001", "000101100000", 
       "000100000010", "000101001101", "000100000011", "000101101101", 
       "000100000100", "000100110001", "000100000101", "000100000110", 
       "000100110101", "000100000111", "000100001000", "000100001001", 
       "000100001010", "000100001011", "000100001100", "000100001101", 
       "000100001110", "000100001111", "000100010000", "000101010000", 
       "000100010001", "000101110000", "000100010010", "000101010101", 
       "000100010011", "000101110101", "000100010100", "000100010101", 
       "000100010110", "000100010111", "000100011000", "000100011001", 
       "000100011010", "000100011011", "000100011100", "000100011101", 
       "000100011110", "000100011111", "000100100000", "000100100001", 
       "000100100010", "000100100101", "000100100011", "000100100100", 
       "000100100110", "000100100111", "000100101000", "000100101001", 
       "000100101010", "000100101011", "000100101100", "000100101101", 
       "000100101110", "000100101111", "000100110000", "000100110010", 
       "000100110011", "000100110100", "000100110110", "000100110111", 
       "000100111000", "000100111001", "000100111010", "000100111011", 
       "000100111100", "000100111101", "000100111110", "000100111111", 
       "000101001010", "000101000001", "000101000010", "000101001111", 
       "000101000011", "000101000100", "000101000101", "000101100011", 
       "000101000110", "000101000111", "000101101111", "000101001000", 
       "000101001001", "000101001011", "000101001100", "000101001110", 
       "000101010001", "000101010010", "000101010011", "000101010100", 
       "000101110011", "000101010110", "000101010111", "000101110111", 
       "000101011000", "000101011001", "000101011010", "000101011011", 
       "000101011100", "000101011101", "000101011110", "000101011111", 
       "000101100001", "000101100010", "000101100100", "000101100101", 
       "000101100110", "000101100111", "000101101000", "000101101001", 
       "000101101010", "000101101011", "000101101100", "000101101110", 
       "000101110001", "000101110010", "000101110100", "000101110110", 
       "000101111000", "000101111001", "000101111010", "000101111011", 
       "000101111100", "000101111101", "000101111110", "000101111111", 
       "000110000000", "000110000001", "000110000010", "000110000011", 
       "000110000100", "000110000101", "000110000110", "000110000111", 
       "000110001000", "000110001001", "000110001010", "000110001011", 
       "000110001100", "000110001101", "000110001110", "000110001111", 
       "000110010000", "000110010001", "000110010010", "000110010011", 
       "000110010100", "000110010101", "000110010110", "000110010111", 
       "000110011000", "000110011001", "000110011010", "000110011011", 
       "000110011100", "000110011101", "000110011110", "000110011111", 
       "000110100000", "000110100001", "000110100010", "000110100011", 
       "000110100100", "000110100101", "000110100110", "000110100111", 
       "000110101000", "000110101001", "000110101010", "000110101011", 
       "000110101100", "000110101101", "000110101110", "000110101111", 
       "000110110000", "000110110001", "000110110010", "000110110011", 
       "000110110100", "000110110101", "000110110110", "000110110111", 
       "000110111000", "000110111001", "000110111010", "000110111011", 
       "000110111100", "000110111101", "000110111110", "000110111111", 
       "000111000000", "000111000001", "000111000010", "000111000011", 
       "000111000100", "000111000101", "000111000110", "000111000111", 
       "000111001000", "000111001001", "000111001010", "000111001011", 
       "000111001100", "000111001101", "000111001110", "000111001111", 
       "000111010000", "000111010001", "000111010010", "000111010011", 
       "000111010100", "000111010101", "000111010110", "000111010111", 
       "000111011000", "000111011001", "000111011010", "000111011011", 
       "000111011100", "000111011101", "000111011110", "000111011111", 
       "000111100000", "000111100001", "000111100010", "000111100011", 
       "000111100100", "000111100101", "000111100110", "000111100111", 
       "000111101000", "000111101001", "000111101010", "000111101011", 
       "000111101100", "000111101101", "000111101110", "000111101111", 
       "000111110000", "000111110001", "000111110010", "000111110011", 
       "000111110100", "000111110101", "000111110110", "000111110111", 
       "000111111000", "000111111001", "000111111010", "000111111011", 
       "000111111100", "000111111101", "000111111110", "000111111111", 
       "001000000000", "001010000000", "001000000001", "001010100000", 
       "001000000010", "001010001101", "001000000011", "001010101101", 
       "001000000100", "001010110001", "001000000101", "001000000110", 
       "001010110101", "001000000111", "001000001000", "001000001001", 
       "001000001010", "001000001011", "001000001100", "001000001101", 
       "001000001110", "001000001111", "001000010000", "001010010000", 
       "001000010001", "001010110000", "001000010010", "001010010101", 
       "001000010011", "001000010100", "001000010101", "001000010110", 
       "001000010111", "001000011000", "001000011001", "001000011010", 
       "001000011011", "001000011100", "001000011101", "001000011110", 
       "001000011111", "001000100000", "001000100001", "001000100010", 
       "001010100101", "001000100011", "001000100100", "001000100101", 
       "001000100110", "001000100111", "001000101000", "001000101001", 
       "001000101010", "001000101011", "001000101100", "001000101101", 
       "001000101110", "001000101111", "001000110000", "001000110001", 
       "001000110010", "001000110011", "001000110100", "001000110101", 
       "001000110110", "001000110111", "001000111000", "001000111001", 
       "001000111010", "001000111011", "001000111100", "001000111101", 
       "001000111110", "001000111111", "001001000000", "001011001010", 
       "001001000001", "001001000010", "001011001111", "001001000011", 
       "001001000100", "001010000011", "001001000101", "001010100011", 
       "001001000110", "001010001111", "001001000111", "001010101111", 
       "001001001000", "001001001001", "001001001010", "001001001011", 
       "001001001100", "001001001101", "001001001110", "001001001111", 
       "001001010000", "001011000010", "001001010001", "001001010010", 
       "001001010011", "001001010100", "001010010011", "001001010101", 
       "001010110011", "001001010110", "001010010111", "001001010111", 
       "001010110111", "001001011000", "001001011001", "001001011010", 
       "001001011011", "001001011100", "001001011101", "001001011110", 
       "001001011111", "001001100000", "001010000010", "001001100001", 
       "001010100010", "001001100010", "001001100011", "001001100100", 
       "001001100101", "001001100110", "001010100111", "001001100111", 
       "001001101000", "001001101001", "001001101010", "001001101011", 
       "001001101100", "001001101101", "001001101110", "001001101111", 
       "001001110000", "001001110001", "001001110010", "001010000111", 
       "001001110011", "001001110100", "001001110101", "001001110110", 
       "001001110111", "001001111000", "001001111001", "001001111010", 
       "001001111011", "001001111100", "001001111101", "001001111110", 
       "001001111111", "001010000001", "001010000100", "001010000101", 
       "001010100001", "001010000110", "001010001000", "001010001001", 
       "001010001010", "001010001011", "001010001100", "001010001110", 
       "001010010001", "001010010010", "001010010100", "001010010110", 
       "001010011000", "001010011001", "001010011010", "001010011011", 
       "001010011100", "001010011101", "001010011110", "001010011111", 
       "001010100100", "001010100110", "001010101000", "001010101001", 
       "001010101010", "001010101011", "001010101100", "001010101110", 
       "001010110010", "001010110100", "001010110110", "001010111000", 
       "001010111001", "001010111010", "001010111011", "001010111100", 
       "001010111101", "001010111110", "001010111111", "001011000000", 
       "001011000001", "001011000011", "001011000100", "001011000101", 
       "001011000110", "001011000111", "001011001000", "001011001001", 
       "001011001011", "001011001100", "001011001101", "001011001110", 
       "001011010000", "001011010001", "001011010010", "001011010011", 
       "001011010100", "001011010101", "001011010110", "001011010111", 
       "001011011000", "001011011001", "001011011010", "001011011011", 
       "001011011100", "001011011101", "001011011110", "001011011111", 
       "001011100000", "001011100001", "001011100010", "001011100011", 
       "001011100100", "001011100101", "001011100110", "001011100111", 
       "001011101000", "001011101001", "001011101010", "001011101011", 
       "001011101100", "001011101101", "001011101110", "001011101111", 
       "001011110000", "001011110001", "001011110010", "001011110011", 
       "001011110100", "001011110101", "001011110110", "001011110111", 
       "001011111000", "001011111001", "001011111010", "001011111011", 
       "001011111100", "001011111101", "001011111110", "001011111111", 
       "001100000000", "001111000000", "001100000001", "001111100000", 
       "001100000010", "001111001101", "001100000011", "001111101101", 
       "001100000100", "001110110001", "001100000101", "001100000110", 
       "001110110101", "001100000111", "001100001000", "001100001001", 
       "001100001010", "001100001011", "001100001100", "001100001101", 
       "001100001110", "001100001111", "001100010000", "001111010000", 
       "001100010001", "001111110000", "001100010010", "001111010101", 
       "001100010011", "001111110101", "001100010100", "001100010101", 
       "001100010110", "001100010111", "001100011000", "001100011001", 
       "001100011010", "001100011011", "001100011100", "001100011101", 
       "001100011110", "001100011111", "001100100000", "001110100000", 
       "001100100001", "001100100010", "001110100101", "001100100011", 
       "001100100100", "001100100101", "001100100110", "001100100111", 
       "001100101000", "001100101001", "001100101010", "001100101011", 
       "001100101100", "001100101101", "001100101110", "001100101111", 
       "001100110000", "001110110000", "001100110001", "001100110010", 
       "001100110011", "001100110100", "001100110101", "001100110110", 
       "001100110111", "001100111000", "001100111001", "001100111010", 
       "001100111011", "001100111100", "001100111101", "001100111110", 
       "001100111111", "001101000000", "001111001010", "001101000001", 
       "001101000010", "001111001111", "001101000011", "001101000100", 
       "001111000011", "001101000101", "001111100011", "001101000110", 
       "001101000111", "001111101111", "001101001000", "001101001001", 
       "001101001010", "001101001011", "001101001100", "001101001101", 
       "001101001110", "001101001111", "001101010000", "001111000010", 
       "001101010001", "001101010010", "001101010011", "001101010100", 
       "001111010011", "001101010101", "001111110011", "001101010110", 
       "001111010111", "001101010111", "001111110111", "001101011000", 
       "001101011001", "001101011010", "001101011011", "001101011100", 
       "001101011101", "001101011110", "001101011111", "001101100000", 
       "001101100001", "001111100010", "001101100010", "001101100011", 
       "001101100100", "001110100011", "001101100101", "001101100110", 
       "001110100111", "001101100111", "001101101000", "001101101001", 
       "001101101010", "001101101011", "001101101100", "001101101101", 
       "001101101110", "001101101111", "001101110000", "001101110001", 
       "001101110010", "001111000111", "001101110011", "001111100111", 
       "001101110100", "001110110011", "001101110101", "001101110110", 
       "001110110111", "001101110111", "001101111000", "001101111001", 
       "001101111010", "001101111011", "001101111100", "001101111101", 
       "001101111110", "001101111111", "001110000000", "001110000001", 
       "001110000010", "001110000011", "001110000100", "001110000101", 
       "001110100001", "001110000110", "001110000111", "001110001000", 
       "001110001001", "001110001010", "001110001011", "001110001100", 
       "001110001101", "001110001110", "001110001111", "001110010000", 
       "001110010001", "001110010010", "001111000101", "001110010011", 
       "001110010100", "001110010101", "001110010110", "001110010111", 
       "001110011000", "001110011001", "001110011010", "001110011011", 
       "001110011100", "001110011101", "001110011110", "001110011111", 
       "001110100010", "001110100100", "001110100110", "001110101000", 
       "001110101001", "001110101010", "001110101011", "001110101100", 
       "001110101101", "001110101110", "001110101111", "001110110010", 
       "001110110100", "001110110110", "001110111000", "001110111001", 
       "001110111010", "001110111011", "001110111100", "001110111101", 
       "001110111110", "001110111111", "001111000001", "001111000100", 
       "001111000110", "001111001000", "001111001001", "001111001011", 
       "001111001100", "001111001110", "001111010001", "001111010010", 
       "001111010100", "001111010110", "001111011000", "001111011001", 
       "001111011010", "001111011011", "001111011100", "001111011101", 
       "001111011110", "001111011111", "001111100001", "001111100100", 
       "001111100101", "001111100110", "001111101000", "001111101001", 
       "001111101010", "001111101011", "001111101100", "001111101110", 
       "001111110001", "001111110010", "001111110100", "001111110110", 
       "001111111000", "001111111001", "001111111010", "001111111011", 
       "001111111100", "001111111101", "001111111110", "001111111111", 
       "010000000000", "010000000001", "010000000010", "010000000011", 
       "010000000100", "010000000101", "010000000110", "010000000111", 
       "010000001000", "010000001001", "010000001010", "010000001011", 
       "010000001100", "010000001101", "010000001110", "010000001111", 
       "010000010000", "010000010001", "010000010010", "010000010011", 
       "010000010100", "010000010101", "010000010110", "010000010111", 
       "010000011000", "010000011001", "010000011010", "010000011011", 
       "010000011100", "010000011101", "010000011110", "010000011111", 
       "010000100000", "010000100001", "010000100010", "010000100011", 
       "010000100100", "010000100101", "010000100110", "010000100111", 
       "010000101000", "010000101001", "010000101010", "010000101011", 
       "010000101100", "010000101101", "010000101110", "010000101111", 
       "010000110000", "010000110001", "010000110010", "010000110011", 
       "010000110100", "010000110101", "010000110110", "010000110111", 
       "010000111000", "010000111001", "010000111010", "010000111011", 
       "010000111100", "010000111101", "010000111110", "010000111111", 
       "010001000000", "010001000001", "010001000010", "010001000011", 
       "010001000100", "010001000101", "010001000110", "010001000111", 
       "010001001000", "010001001001", "010001001010", "010001001011", 
       "010001001100", "010001001101", "010001001110", "010001001111", 
       "010001010000", "010001010001", "010001010010", "010001010011", 
       "010001010100", "010001010101", "010001010110", "010001010111", 
       "010001011000", "010001011001", "010001011010", "010001011011", 
       "010001011100", "010001011101", "010001011110", "010001011111", 
       "010001100000", "010001100001", "010001100010", "010001100011", 
       "010001100100", "010001100101", "010001100110", "010001100111", 
       "010001101000", "010001101001", "010001101010", "010001101011", 
       "010001101100", "010001101101", "010001101110", "010001101111", 
       "010001110000", "010001110001", "010001110010", "010001110011", 
       "010001110100", "010001110101", "010001110110", "010001110111", 
       "010001111000", "010001111001", "010001111010", "010001111011", 
       "010001111100", "010001111101", "010001111110", "010001111111", 
       "010010000000", "010010000001", "010010000010", "010010000011", 
       "010010000100", "010010000101", "010010000110", "010010000111", 
       "010010001000", "010010001001", "010010001010", "010010001011", 
       "010010001100", "010010001101", "010010001110", "010010001111", 
       "010010010000", "010010010001", "010010010010", "010010010011", 
       "010010010100", "010010010101", "010010010110", "010010010111", 
       "010010011000", "010010011001", "010010011010", "010010011011", 
       "010010011100", "010010011101", "010010011110", "010010011111", 
       "010010100000", "010010100001", "010010100010", "010010100011", 
       "010010100100", "010010100101", "010010100110", "010010100111", 
       "010010101000", "010010101001", "010010101010", "010010101011", 
       "010010101100", "010010101101", "010010101110", "010010101111", 
       "010010110000", "010010110001", "010010110010", "010010110011", 
       "010010110100", "010010110101", "010010110110", "010010110111", 
       "010010111000", "010010111001", "010010111010", "010010111011", 
       "010010111100", "010010111101", "010010111110", "010010111111", 
       "010011000000", "010011000001", "010011000010", "010011000011", 
       "010011000100", "010011000101", "010011000110", "010011000111", 
       "010011001000", "010011001001", "010011001010", "010011001011", 
       "010011001100", "010011001101", "010011001110", "010011001111", 
       "010011010000", "010011010001", "010011010010", "010011010011", 
       "010011010100", "010011010101", "010011010110", "010011010111", 
       "010011011000", "010011011001", "010011011010", "010011011011", 
       "010011011100", "010011011101", "010011011110", "010011011111", 
       "010011100000", "010011100001", "010011100010", "010011100011", 
       "010011100100", "010011100101", "010011100110", "010011100111", 
       "010011101000", "010011101001", "010011101010", "010011101011", 
       "010011101100", "010011101101", "010011101110", "010011101111", 
       "010011110000", "010011110001", "010011110010", "010011110011", 
       "010011110100", "010011110101", "010011110110", "010011110111", 
       "010011111000", "010011111001", "010011111010", "010011111011", 
       "010011111100", "010011111101", "010011111110", "010011111111", 
       "010100000000", "010100000001", "010100000010", "010100000011", 
       "010100000100", "010100000101", "010100000110", "010100000111", 
       "010100001000", "010100001001", "010100001010", "010100001011", 
       "010100001100", "010100001101", "010100001110", "010100001111", 
       "010100010000", "010100010001", "010100010010", "010100010011", 
       "010100010100", "010100010101", "010100010110", "010100010111", 
       "010100011000", "010100011001", "010100011010", "010100011011", 
       "010100011100", "010100011101", "010100011110", "010100011111", 
       "010100100000", "010100100001", "010100100010", "010100100011", 
       "010100100100", "010100100101", "010100100110", "010100100111", 
       "010100101000", "010100101001", "010100101010", "010100101011", 
       "010100101100", "010100101101", "010100101110", "010100101111", 
       "010100110000", "010100110001", "010100110010", "010100110011", 
       "010100110100", "010100110101", "010100110110", "010100110111", 
       "010100111000", "010100111001", "010100111010", "010100111011", 
       "010100111100", "010100111101", "010100111110", "010100111111", 
       "010101000000", "010101000001", "010101000010", "010101000011", 
       "010101000100", "010101000101", "010101000110", "010101000111", 
       "010101001000", "010101001001", "010101001010", "010101001011", 
       "010101001100", "010101001101", "010101001110", "010101001111", 
       "010101010000", "010101010001", "010101010010", "010101010011", 
       "010101010100", "010101010101", "010101010110", "010101010111", 
       "010101011000", "010101011001", "010101011010", "010101011011", 
       "010101011100", "010101011101", "010101011110", "010101011111", 
       "010101100000", "010101100001", "010101100010", "010101100011", 
       "010101100100", "010101100101", "010101100110", "010101100111", 
       "010101101000", "010101101001", "010101101010", "010101101011", 
       "010101101100", "010101101101", "010101101110", "010101101111", 
       "010101110000", "010101110001", "010101110010", "010101110011", 
       "010101110100", "010101110101", "010101110110", "010101110111", 
       "010101111000", "010101111001", "010101111010", "010101111011", 
       "010101111100", "010101111101", "010101111110", "010101111111", 
       "010110000000", "010110000001", "010110000010", "010110000011", 
       "010110000100", "010110000101", "010110000110", "010110000111", 
       "010110001000", "010110001001", "010110001010", "010110001011", 
       "010110001100", "010110001101", "010110001110", "010110001111", 
       "010110010000", "010110010001", "010110010010", "010110010011", 
       "010110010100", "010110010101", "010110010110", "010110010111", 
       "010110011000", "010110011001", "010110011010", "010110011011", 
       "010110011100", "010110011101", "010110011110", "010110011111", 
       "010110100000", "010110100001", "010110100010", "010110100011", 
       "010110100100", "010110100101", "010110100110", "010110100111", 
       "010110101000", "010110101001", "010110101010", "010110101011", 
       "010110101100", "010110101101", "010110101110", "010110101111", 
       "010110110000", "010110110001", "010110110010", "010110110011", 
       "010110110100", "010110110101", "010110110110", "010110110111", 
       "010110111000", "010110111001", "010110111010", "010110111011", 
       "010110111100", "010110111101", "010110111110", "010110111111", 
       "010111000000", "010111000001", "010111000010", "010111000011", 
       "010111000100", "010111000101", "010111000110", "010111000111", 
       "010111001000", "010111001001", "010111001010", "010111001011", 
       "010111001100", "010111001101", "010111001110", "010111001111", 
       "010111010000", "010111010001", "010111010010", "010111010011", 
       "010111010100", "010111010101", "010111010110", "010111010111", 
       "010111011000", "010111011001", "010111011010", "010111011011", 
       "010111011100", "010111011101", "010111011110", "010111011111", 
       "010111100000", "010111100001", "010111100010", "010111100011", 
       "010111100100", "010111100101", "010111100110", "010111100111", 
       "010111101000", "010111101001", "010111101010", "010111101011", 
       "010111101100", "010111101101", "010111101110", "010111101111", 
       "010111110000", "010111110001", "010111110010", "010111110011", 
       "010111110100", "010111110101", "010111110110", "010111110111", 
       "010111111000", "010111111001", "010111111010", "010111111011", 
       "010111111100", "010111111101", "010111111110", "010111111111", 
       "011000000000", "011000000001", "011000000010", "011000000011", 
       "011000000100", "011000000101", "011000000110", "011000000111", 
       "011000001000", "011000001001", "011000001010", "011000001011", 
       "011000001100", "011000001101", "011000001110", "011000001111", 
       "011000010000", "011000010001", "011000010010", "011000010011", 
       "011000010100", "011000010101", "011000010110", "011000010111", 
       "011000011000", "011000011001", "011000011010", "011000011011", 
       "011000011100", "011000011101", "011000011110", "011000011111", 
       "011000100000", "011000100001", "011000100010", "011000100011", 
       "011000100100", "011000100101", "011000100110", "011000100111", 
       "011000101000", "011000101001", "011000101010", "011000101011", 
       "011000101100", "011000101101", "011000101110", "011000101111", 
       "011000110000", "011000110001", "011000110010", "011000110011", 
       "011000110100", "011000110101", "011000110110", "011000110111", 
       "011000111000", "011000111001", "011000111010", "011000111011", 
       "011000111100", "011000111101", "011000111110", "011000111111", 
       "011001000000", "011001000001", "011001000010", "011001000011", 
       "011001000100", "011001000101", "011001000110", "011001000111", 
       "011001001000", "011001001001", "011001001010", "011001001011", 
       "011001001100", "011001001101", "011001001110", "011001001111", 
       "011001010000", "011001010001", "011001010010", "011001010011", 
       "011001010100", "011001010101", "011001010110", "011001010111", 
       "011001011000", "011001011001", "011001011010", "011001011011", 
       "011001011100", "011001011101", "011001011110", "011001011111", 
       "011001100000", "011001100001", "011001100010", "011001100011", 
       "011001100100", "011001100101", "011001100110", "011001100111", 
       "011001101000", "011001101001", "011001101010", "011001101011", 
       "011001101100", "011001101101", "011001101110", "011001101111", 
       "011001110000", "011001110001", "011001110010", "011001110011", 
       "011001110100", "011001110101", "011001110110", "011001110111", 
       "011001111000", "011001111001", "011001111010", "011001111011", 
       "011001111100", "011001111101", "011001111110", "011001111111", 
       "011010000000", "011010000001", "011010000010", "011010000011", 
       "011010000100", "011010000101", "011010000110", "011010000111", 
       "011010001000", "011010001001", "011010001010", "011010001011", 
       "011010001100", "011010001101", "011010001110", "011010001111", 
       "011010010000", "011010010001", "011010010010", "011010010011", 
       "011010010100", "011010010101", "011010010110", "011010010111", 
       "011010011000", "011010011001", "011010011010", "011010011011", 
       "011010011100", "011010011101", "011010011110", "011010011111", 
       "011010100000", "011010100001", "011010100010", "011010100011", 
       "011010100100", "011010100101", "011010100110", "011010100111", 
       "011010101000", "011010101001", "011010101010", "011010101011", 
       "011010101100", "011010101101", "011010101110", "011010101111", 
       "011010110000", "011010110001", "011010110010", "011010110011", 
       "011010110100", "011010110101", "011010110110", "011010110111", 
       "011010111000", "011010111001", "011010111010", "011010111011", 
       "011010111100", "011010111101", "011010111110", "011010111111", 
       "011011000000", "011011000001", "011011000010", "011011000011", 
       "011011000100", "011011000101", "011011000110", "011011000111", 
       "011011001000", "011011001001", "011011001010", "011011001011", 
       "011011001100", "011011001101", "011011001110", "011011001111", 
       "011011010000", "011011010001", "011011010010", "011011010011", 
       "011011010100", "011011010101", "011011010110", "011011010111", 
       "011011011000", "011011011001", "011011011010", "011011011011", 
       "011011011100", "011011011101", "011011011110", "011011011111", 
       "011011100000", "011011100001", "011011100010", "011011100011", 
       "011011100100", "011011100101", "011011100110", "011011100111", 
       "011011101000", "011011101001", "011011101010", "011011101011", 
       "011011101100", "011011101101", "011011101110", "011011101111", 
       "011011110000", "011011110001", "011011110010", "011011110011", 
       "011011110100", "011011110101", "011011110110", "011011110111", 
       "011011111000", "011011111001", "011011111010", "011011111011", 
       "011011111100", "011011111101", "011011111110", "011011111111", 
       "011100000000", "011100000001", "011100000010", "011100000011", 
       "011100000100", "011100000101", "011100000110", "011100000111", 
       "011100001000", "011100001001", "011100001010", "011100001011", 
       "011100001100", "011100001101", "011100001110", "011100001111", 
       "011100010000", "011100010001", "011100010010", "011100010011", 
       "011100010100", "011100010101", "011100010110", "011100010111", 
       "011100011000", "011100011001", "011100011010", "011100011011", 
       "011100011100", "011100011101", "011100011110", "011100011111", 
       "011100100000", "011100100001", "011100100010", "011100100011", 
       "011100100100", "011100100101", "011100100110", "011100100111", 
       "011100101000", "011100101001", "011100101010", "011100101011", 
       "011100101100", "011100101101", "011100101110", "011100101111", 
       "011100110000", "011100110001", "011100110010", "011100110011", 
       "011100110100", "011100110101", "011100110110", "011100110111", 
       "011100111000", "011100111001", "011100111010", "011100111011", 
       "011100111100", "011100111101", "011100111110", "011100111111", 
       "011101000000", "011101000001", "011101000010", "011101000011", 
       "011101000100", "011101000101", "011101000110", "011101000111", 
       "011101001000", "011101001001", "011101001010", "011101001011", 
       "011101001100", "011101001101", "011101001110", "011101001111", 
       "011101010000", "011101010001", "011101010010", "011101010011", 
       "011101010100", "011101010101", "011101010110", "011101010111", 
       "011101011000", "011101011001", "011101011010", "011101011011", 
       "011101011100", "011101011101", "011101011110", "011101011111", 
       "011101100000", "011101100001", "011101100010", "011101100011", 
       "011101100100", "011101100101", "011101100110", "011101100111", 
       "011101101000", "011101101001", "011101101010", "011101101011", 
       "011101101100", "011101101101", "011101101110", "011101101111", 
       "011101110000", "011101110001", "011101110010", "011101110011", 
       "011101110100", "011101110101", "011101110110", "011101110111", 
       "011101111000", "011101111001", "011101111010", "011101111011", 
       "011101111100", "011101111101", "011101111110", "011101111111", 
       "011110000000", "011110000001", "011110000010", "011110000011", 
       "011110000100", "011110000101", "011110000110", "011110000111", 
       "011110001000", "011110001001", "011110001010", "011110001011", 
       "011110001100", "011110001101", "011110001110", "011110001111", 
       "011110010000", "011110010001", "011110010010", "011110010011", 
       "011110010100", "011110010101", "011110010110", "011110010111", 
       "011110011000", "011110011001", "011110011010", "011110011011", 
       "011110011100", "011110011101", "011110011110", "011110011111", 
       "011110100000", "011110100001", "011110100010", "011110100011", 
       "011110100100", "011110100101", "011110100110", "011110100111", 
       "011110101000", "011110101001", "011110101010", "011110101011", 
       "011110101100", "011110101101", "011110101110", "011110101111", 
       "011110110000", "011110110001", "011110110010", "011110110011", 
       "011110110100", "011110110101", "011110110110", "011110110111", 
       "011110111000", "011110111001", "011110111010", "011110111011", 
       "011110111100", "011110111101", "011110111110", "011110111111", 
       "011111000000", "011111000001", "011111000010", "011111000011", 
       "011111000100", "011111000101", "011111000110", "011111000111", 
       "011111001000", "011111001001", "011111001010", "011111001011", 
       "011111001100", "011111001101", "011111001110", "011111001111", 
       "011111010000", "011111010001", "011111010010", "011111010011", 
       "011111010100", "011111010101", "011111010110", "011111010111", 
       "011111011000", "011111011001", "011111011010", "011111011011", 
       "011111011100", "011111011101", "011111011110", "011111011111", 
       "011111100000", "011111100001", "011111100010", "011111100011", 
       "011111100100", "011111100101", "011111100110", "011111100111", 
       "011111101000", "011111101001", "011111101010", "011111101011", 
       "011111101100", "011111101101", "011111101110", "011111101111", 
       "011111110000", "011111110001", "011111110010", "011111110011", 
       "011111110100", "011111110101", "011111110110", "011111110111", 
       "011111111000", "011111111001", "011111111010", "011111111011", 
       "011111111100", "011111111101", "011111111110", 
       "011111111111"}, {CompressedData["
1:eJwt2wN4HVsXxvEz5wzS1E7TNnVq23ba1LbTNk1t27Zt27Zt2zbvmrv+3/Os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       "], Null}, {BaseStyle -> EdgeForm[
         GrayLevel[0]], VertexShapeFunction -> {"Circle"}, VertexSize -> {8}, 
       VertexStyle -> {
         GrayLevel[0.85]}}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJw8eXk0lO/7v0qSXfadMWbGvo19mcs2M5akoiSlbCFZoiwpkt6JFNJGKktR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       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.5], Arrowheads[0.005481096590095407], 
         EdgeForm[GrayLevel[0]], 
         ArrowBox[BezierCurveBox[{1, 2052, 2055, 2057, 2063, 2065, 2068, 1},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{2, 3}, 0.13026950515838204`], 
         ArrowBox[BezierCurveBox[{3, 2075, 2078, 2080, 2086, 2088, 2091, 3},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{4, 5}, 0.13026950515838204`], 
         ArrowBox[{5, 20}, 0.13026950515838204`], 
         ArrowBox[{6, 7}, 0.13026950515838204`], 
         ArrowBox[{7, 20}, 0.13026950515838204`], 
         ArrowBox[{8, 9}, 0.13026950515838204`], 
         ArrowBox[{9, 25}, 0.13026950515838204`], 
         ArrowBox[{10, 9}, 0.13026950515838204`], 
         ArrowBox[{11, 12}, 0.13026950515838204`], 
         ArrowBox[{12, 9}, 0.13026950515838204`], 
         ArrowBox[{13, 12}, 0.13026950515838204`], 
         ArrowBox[{14, 15}, 0.13026950515838204`], 
         ArrowBox[{15, 21}, 0.13026950515838204`], 
         ArrowBox[{16, 15}, 0.13026950515838204`], 
         ArrowBox[{17, 15}, 0.13026950515838204`], 
         ArrowBox[{18, 15}, 0.13026950515838204`], 
         ArrowBox[{19, 11}, 0.13026950515838204`], 
         ArrowBox[{20, 12}, 0.13026950515838204`], 
         ArrowBox[{21, 22}, 0.13026950515838204`], 
         ArrowBox[{22, 47}, 0.13026950515838204`], 
         ArrowBox[BezierCurveBox[{23, 2098, 2101, 2103, 2109, 2111, 2114, 23},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{24, 25}, 0.13026950515838204`], 
         ArrowBox[BezierCurveBox[{25, 2121, 2124, 2126, 2132, 2134, 2137, 25},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{26, 27}, 0.13026950515838204`], 
         ArrowBox[{27, 9}, 0.13026950515838204`], 
         ArrowBox[{28, 12}, 0.13026950515838204`], 
         ArrowBox[{29, 9}, 0.13026950515838204`], 
         ArrowBox[{30, 12}, 0.13026950515838204`], 
         ArrowBox[{31, 12}, 0.13026950515838204`], 
         ArrowBox[{32, 11}, 0.13026950515838204`], 
         ArrowBox[{33, 11}, 0.13026950515838204`], 
         ArrowBox[{34, 15}, 0.13026950515838204`], 
         ArrowBox[{35, 15}, 0.13026950515838204`], 
         ArrowBox[{36, 30}, 0.13026950515838204`], 
         ArrowBox[{37, 38}, 0.13026950515838204`], 
         ArrowBox[{38, 12}, 0.13026950515838204`], 
         ArrowBox[{39, 31}, 0.13026950515838204`], 
         ArrowBox[{40, 41}, 0.13026950515838204`], 
         ArrowBox[{41, 12}, 0.13026950515838204`], 
         ArrowBox[{42, 3}, 0.13026950515838204`], 
         ArrowBox[{43, 44}, 0.13026950515838204`], 
         ArrowBox[{44, 9}, 0.13026950515838204`], 
         ArrowBox[{45, 44}, 0.13026950515838204`], 
         ArrowBox[{46, 9}, 0.13026950515838204`], 
         ArrowBox[{47, 12}, 0.13026950515838204`], 
         ArrowBox[{48, 11}, 0.13026950515838204`], 
         ArrowBox[{49, 20}, 0.13026950515838204`], 
         ArrowBox[{50, 15}, 0.13026950515838204`], 
         ArrowBox[{51, 52}, 0.13026950515838204`], 
         ArrowBox[{52, 47}, 0.13026950515838204`], 
         ArrowBox[{53, 20}, 0.13026950515838204`], 
         ArrowBox[{54, 12}, 0.13026950515838204`], 
         ArrowBox[{55, 12}, 0.13026950515838204`], 
         ArrowBox[{56, 9}, 0.13026950515838204`], 
         ArrowBox[{57, 11}, 0.13026950515838204`], 
         ArrowBox[{58, 20}, 0.13026950515838204`], 
         ArrowBox[{59, 11}, 0.13026950515838204`], 
         ArrowBox[{60, 20}, 0.13026950515838204`], 
         ArrowBox[{61, 38}, 0.13026950515838204`], 
         ArrowBox[{62, 38}, 0.13026950515838204`], 
         ArrowBox[{63, 41}, 0.13026950515838204`], 
         ArrowBox[{64, 41}, 0.13026950515838204`], 
         ArrowBox[{65, 66}, 0.13026950515838204`], 
         ArrowBox[{66, 76}, 0.13026950515838204`], 
         ArrowBox[{67, 66}, 0.13026950515838204`], 
         ArrowBox[{68, 69}, 0.13026950515838204`], 
         ArrowBox[{69, 21}, 0.13026950515838204`], 
         ArrowBox[{70, 69}, 0.13026950515838204`], 
         ArrowBox[{71, 6}, 0.13026950515838204`], 
         ArrowBox[{72, 45}, 0.13026950515838204`], 
         ArrowBox[{73, 21}, 0.13026950515838204`], 
         ArrowBox[{74, 22}, 0.13026950515838204`], 
         ArrowBox[{75, 76}, 0.13026950515838204`], 
         ArrowBox[{76, 21}, 0.13026950515838204`], 
         ArrowBox[{77, 76}, 0.13026950515838204`], 
         ArrowBox[{78, 76}, 0.13026950515838204`], 
         ArrowBox[{79, 15}, 0.13026950515838204`], 
         ArrowBox[{80, 15}, 0.13026950515838204`], 
         ArrowBox[{81, 68}, 0.13026950515838204`], 
         ArrowBox[{82, 68}, 0.13026950515838204`], 
         ArrowBox[{83, 69}, 0.13026950515838204`], 
         ArrowBox[{84, 69}, 0.13026950515838204`], 
         ArrowBox[{85, 28}, 0.13026950515838204`], 
         ArrowBox[{86, 55}, 0.13026950515838204`], 
         ArrowBox[{87, 31}, 0.13026950515838204`], 
         ArrowBox[{88, 41}, 0.13026950515838204`], 
         ArrowBox[{89, 76}, 0.13026950515838204`], 
         ArrowBox[{90, 76}, 0.13026950515838204`], 
         ArrowBox[{91, 76}, 0.13026950515838204`], 
         ArrowBox[{92, 76}, 0.13026950515838204`], 
         ArrowBox[{93, 11}, 0.13026950515838204`], 
         ArrowBox[{94, 11}, 0.13026950515838204`], 
         ArrowBox[{95, 21}, 0.13026950515838204`], 
         ArrowBox[{96, 21}, 0.13026950515838204`], 
         ArrowBox[{97, 4}, 0.13026950515838204`], 
         ArrowBox[{98, 43}, 0.13026950515838204`], 
         ArrowBox[{99, 21}, 0.13026950515838204`], 
         ArrowBox[{100, 22}, 0.13026950515838204`], 
         ArrowBox[{101, 45}, 0.13026950515838204`], 
         ArrowBox[{102, 45}, 0.13026950515838204`], 
         ArrowBox[{103, 47}, 0.13026950515838204`], 
         ArrowBox[{104, 47}, 0.13026950515838204`], 
         ArrowBox[{105, 15}, 0.13026950515838204`], 
         ArrowBox[{106, 15}, 0.13026950515838204`], 
         ArrowBox[{107, 15}, 0.13026950515838204`], 
         ArrowBox[{108, 15}, 0.13026950515838204`], 
         ArrowBox[{109, 11}, 0.13026950515838204`], 
         ArrowBox[{110, 20}, 0.13026950515838204`], 
         ArrowBox[{111, 21}, 0.13026950515838204`], 
         ArrowBox[{112, 22}, 0.13026950515838204`], 
         ArrowBox[{113, 4}, 0.13026950515838204`], 
         ArrowBox[{114, 43}, 0.13026950515838204`], 
         ArrowBox[{115, 13}, 0.13026950515838204`], 
         ArrowBox[{116, 47}, 0.13026950515838204`], 
         ArrowBox[{117, 55}, 0.13026950515838204`], 
         ArrowBox[{118, 55}, 0.13026950515838204`], 
         ArrowBox[{119, 41}, 0.13026950515838204`], 
         ArrowBox[{120, 41}, 0.13026950515838204`], 
         ArrowBox[{121, 11}, 0.13026950515838204`], 
         ArrowBox[{122, 11}, 0.13026950515838204`], 
         ArrowBox[{123, 15}, 0.13026950515838204`], 
         ArrowBox[{124, 15}, 0.13026950515838204`], 
         ArrowBox[{125, 11}, 0.13026950515838204`], 
         ArrowBox[{126, 20}, 0.13026950515838204`], 
         ArrowBox[{127, 13}, 0.13026950515838204`], 
         ArrowBox[{128, 47}, 0.13026950515838204`], 
         ArrowBox[{129, 1}, 0.13026950515838204`], 
         ArrowBox[{130, 1}, 0.13026950515838204`], 
         ArrowBox[{131, 5}, 0.13026950515838204`], 
         ArrowBox[{132, 5}, 0.13026950515838204`], 
         ArrowBox[{133, 2}, 0.13026950515838204`], 
         ArrowBox[{134, 42}, 0.13026950515838204`], 
         ArrowBox[{135, 10}, 0.13026950515838204`], 
         ArrowBox[{136, 44}, 0.13026950515838204`], 
         ArrowBox[{137, 15}, 0.13026950515838204`], 
         ArrowBox[{138, 15}, 0.13026950515838204`], 
         ArrowBox[{139, 15}, 0.13026950515838204`], 
         ArrowBox[{140, 15}, 0.13026950515838204`], 
         ArrowBox[{141, 11}, 0.13026950515838204`], 
         ArrowBox[{142, 11}, 0.13026950515838204`], 
         ArrowBox[{143, 21}, 0.13026950515838204`], 
         ArrowBox[{144, 21}, 0.13026950515838204`], 
         ArrowBox[{145, 1}, 0.13026950515838204`], 
         ArrowBox[{146, 1}, 0.13026950515838204`], 
         ArrowBox[{147, 10}, 0.13026950515838204`], 
         ArrowBox[{148, 10}, 0.13026950515838204`], 
         ArrowBox[{149, 24}, 0.13026950515838204`], 
         ArrowBox[{150, 9}, 0.13026950515838204`], 
         ArrowBox[{151, 27}, 0.13026950515838204`], 
         ArrowBox[{152, 12}, 0.13026950515838204`], 
         ArrowBox[{153, 11}, 0.13026950515838204`], 
         ArrowBox[{154, 11}, 0.13026950515838204`], 
         ArrowBox[{155, 15}, 0.13026950515838204`], 
         ArrowBox[{156, 15}, 0.13026950515838204`], 
         ArrowBox[{157, 11}, 0.13026950515838204`], 
         ArrowBox[{158, 11}, 0.13026950515838204`], 
         ArrowBox[{159, 13}, 0.13026950515838204`], 
         ArrowBox[{160, 13}, 0.13026950515838204`], 
         ArrowBox[{161, 1}, 0.13026950515838204`], 
         ArrowBox[{162, 3}, 0.13026950515838204`], 
         ArrowBox[{163, 10}, 0.13026950515838204`], 
         ArrowBox[{164, 44}, 0.13026950515838204`], 
         ArrowBox[{165, 42}, 0.13026950515838204`], 
         ArrowBox[{166, 42}, 0.13026950515838204`], 
         ArrowBox[{167, 44}, 0.13026950515838204`], 
         ArrowBox[{168, 44}, 0.13026950515838204`], 
         ArrowBox[{169, 11}, 0.13026950515838204`], 
         ArrowBox[{170, 11}, 0.13026950515838204`], 
         ArrowBox[{171, 15}, 0.13026950515838204`], 
         ArrowBox[{172, 15}, 0.13026950515838204`], 
         ArrowBox[{173, 11}, 0.13026950515838204`], 
         ArrowBox[{174, 20}, 0.13026950515838204`], 
         ArrowBox[{175, 13}, 0.13026950515838204`], 
         ArrowBox[{176, 47}, 0.13026950515838204`], 
         ArrowBox[{177, 1}, 0.13026950515838204`], 
         ArrowBox[{178, 3}, 0.13026950515838204`], 
         ArrowBox[{179, 10}, 0.13026950515838204`], 
         ArrowBox[{180, 44}, 0.13026950515838204`], 
         ArrowBox[{181, 9}, 0.13026950515838204`], 
         ArrowBox[{182, 9}, 0.13026950515838204`], 
         ArrowBox[{183, 12}, 0.13026950515838204`], 
         ArrowBox[{184, 12}, 0.13026950515838204`], 
         ArrowBox[{185, 11}, 0.13026950515838204`], 
         ArrowBox[{186, 11}, 0.13026950515838204`], 
         ArrowBox[{187, 11}, 0.13026950515838204`], 
         ArrowBox[{188, 11}, 0.13026950515838204`], 
         ArrowBox[{189, 11}, 0.13026950515838204`], 
         ArrowBox[{190, 20}, 0.13026950515838204`], 
         ArrowBox[{191, 13}, 0.13026950515838204`], 
         ArrowBox[{192, 47}, 0.13026950515838204`], 
         ArrowBox[{193, 66}, 0.13026950515838204`], 
         ArrowBox[{194, 66}, 0.13026950515838204`], 
         ArrowBox[{195, 69}, 0.13026950515838204`], 
         ArrowBox[{196, 69}, 0.13026950515838204`], 
         ArrowBox[{197, 6}, 0.13026950515838204`], 
         ArrowBox[{198, 6}, 0.13026950515838204`], 
         ArrowBox[{199, 21}, 0.13026950515838204`], 
         ArrowBox[{200, 21}, 0.13026950515838204`], 
         ArrowBox[{201, 76}, 0.13026950515838204`], 
         ArrowBox[{202, 76}, 0.13026950515838204`], 
         ArrowBox[{203, 76}, 0.13026950515838204`], 
         ArrowBox[{204, 76}, 0.13026950515838204`], 
         ArrowBox[{205, 15}, 0.13026950515838204`], 
         ArrowBox[{206, 15}, 0.13026950515838204`], 
         ArrowBox[{207, 21}, 0.13026950515838204`], 
         ArrowBox[{208, 21}, 0.13026950515838204`], 
         ArrowBox[{209, 68}, 0.13026950515838204`], 
         ArrowBox[{210, 68}, 0.13026950515838204`], 
         ArrowBox[{211, 69}, 0.13026950515838204`], 
         ArrowBox[{212, 69}, 0.13026950515838204`], 
         ArrowBox[{213, 6}, 0.13026950515838204`], 
         ArrowBox[{214, 6}, 0.13026950515838204`], 
         ArrowBox[{215, 13}, 0.13026950515838204`], 
         ArrowBox[{216, 13}, 0.13026950515838204`], 
         ArrowBox[{217, 76}, 0.13026950515838204`], 
         ArrowBox[{218, 76}, 0.13026950515838204`], 
         ArrowBox[{219, 76}, 0.13026950515838204`], 
         ArrowBox[{220, 76}, 0.13026950515838204`], 
         ArrowBox[{221, 11}, 0.13026950515838204`], 
         ArrowBox[{222, 11}, 0.13026950515838204`], 
         ArrowBox[{223, 21}, 0.13026950515838204`], 
         ArrowBox[{224, 21}, 0.13026950515838204`], 
         ArrowBox[{225, 4}, 0.13026950515838204`], 
         ArrowBox[{226, 4}, 0.13026950515838204`], 
         ArrowBox[{227, 21}, 0.13026950515838204`], 
         ArrowBox[{228, 21}, 0.13026950515838204`], 
         ArrowBox[{229, 6}, 0.13026950515838204`], 
         ArrowBox[{230, 45}, 0.13026950515838204`], 
         ArrowBox[{231, 13}, 0.13026950515838204`], 
         ArrowBox[{232, 47}, 0.13026950515838204`], 
         ArrowBox[{233, 15}, 0.13026950515838204`], 
         ArrowBox[{234, 15}, 0.13026950515838204`], 
         ArrowBox[{235, 15}, 0.13026950515838204`], 
         ArrowBox[{236, 15}, 0.13026950515838204`], 
         ArrowBox[{237, 11}, 0.13026950515838204`], 
         ArrowBox[{238, 11}, 0.13026950515838204`], 
         ArrowBox[{239, 21}, 0.13026950515838204`], 
         ArrowBox[{240, 21}, 0.13026950515838204`], 
         ArrowBox[{241, 4}, 0.13026950515838204`], 
         ArrowBox[{242, 4}, 0.13026950515838204`], 
         ArrowBox[{243, 13}, 0.13026950515838204`], 
         ArrowBox[{244, 13}, 0.13026950515838204`], 
         ArrowBox[{245, 6}, 0.13026950515838204`], 
         ArrowBox[{246, 45}, 0.13026950515838204`], 
         ArrowBox[{247, 13}, 0.13026950515838204`], 
         ArrowBox[{248, 47}, 0.13026950515838204`], 
         ArrowBox[{249, 11}, 0.13026950515838204`], 
         ArrowBox[{250, 11}, 0.13026950515838204`], 
         ArrowBox[{251, 15}, 0.13026950515838204`], 
         ArrowBox[{252, 15}, 0.13026950515838204`], 
         ArrowBox[{253, 11}, 0.13026950515838204`], 
         ArrowBox[{254, 11}, 0.13026950515838204`], 
         ArrowBox[{255, 13}, 0.13026950515838204`], 
         ArrowBox[{256, 13}, 0.13026950515838204`], 
         ArrowBox[{257, 258}, 0.13026950515838204`], 
         ArrowBox[{258, 329}, 0.13026950515838204`], 
         ArrowBox[{259, 260}, 0.13026950515838204`], 
         ArrowBox[{260, 331}, 0.13026950515838204`], 
         ArrowBox[{261, 262}, 0.13026950515838204`], 
         ArrowBox[{262, 76}, 0.13026950515838204`], 
         ArrowBox[{263, 264}, 0.13026950515838204`], 
         ArrowBox[{264, 20}, 0.13026950515838204`], 
         ArrowBox[{265, 266}, 0.13026950515838204`], 
         ArrowBox[{266, 315}, 0.13026950515838204`], 
         ArrowBox[{267, 266}, 0.13026950515838204`], 
         ArrowBox[{268, 269}, 0.13026950515838204`], 
         ArrowBox[{269, 266}, 0.13026950515838204`], 
         ArrowBox[{270, 269}, 0.13026950515838204`], 
         ArrowBox[{271, 76}, 0.13026950515838204`], 
         ArrowBox[{272, 76}, 0.13026950515838204`], 
         ArrowBox[{273, 76}, 0.13026950515838204`], 
         ArrowBox[{274, 76}, 0.13026950515838204`], 
         ArrowBox[{275, 11}, 0.13026950515838204`], 
         ArrowBox[{276, 20}, 0.13026950515838204`], 
         ArrowBox[{277, 21}, 0.13026950515838204`], 
         ArrowBox[{278, 22}, 0.13026950515838204`], 
         ArrowBox[{279, 280}, 0.13026950515838204`], 
         ArrowBox[{280, 331}, 0.13026950515838204`], 
         ArrowBox[{281, 282}, 0.13026950515838204`], 
         ArrowBox[{282, 331}, 0.13026950515838204`], 
         ArrowBox[{283, 284}, 0.13026950515838204`], 
         ArrowBox[{284, 349}, 0.13026950515838204`], 
         ArrowBox[{285, 286}, 0.13026950515838204`], 
         ArrowBox[{286, 317}, 0.13026950515838204`], 
         ArrowBox[{287, 266}, 0.13026950515838204`], 
         ArrowBox[{288, 266}, 0.13026950515838204`], 
         ArrowBox[{289, 269}, 0.13026950515838204`], 
         ArrowBox[{290, 269}, 0.13026950515838204`], 
         ArrowBox[{291, 73}, 0.13026950515838204`], 
         ArrowBox[{292, 73}, 0.13026950515838204`], 
         ArrowBox[{293, 76}, 0.13026950515838204`], 
         ArrowBox[{294, 76}, 0.13026950515838204`], 
         ArrowBox[{295, 30}, 0.13026950515838204`], 
         ArrowBox[{296, 38}, 0.13026950515838204`], 
         ArrowBox[{297, 31}, 0.13026950515838204`], 
         ArrowBox[{298, 41}, 0.13026950515838204`], 
         ArrowBox[BezierCurveBox[{299, 2144, 2147, 2149, 2155, 2157, 2160, 
          299},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{300, 299}, 0.13026950515838204`], 
         ArrowBox[{301, 302}, 0.13026950515838204`], 
         ArrowBox[{302, 266}, 0.13026950515838204`], 
         ArrowBox[{303, 302}, 0.13026950515838204`], 
         ArrowBox[{304, 266}, 0.13026950515838204`], 
         ArrowBox[{305, 269}, 0.13026950515838204`], 
         ArrowBox[{306, 269}, 0.13026950515838204`], 
         ArrowBox[{307, 11}, 0.13026950515838204`], 
         ArrowBox[{308, 20}, 0.13026950515838204`], 
         ArrowBox[{309, 15}, 0.13026950515838204`], 
         ArrowBox[{310, 52}, 0.13026950515838204`], 
         ArrowBox[{311, 20}, 0.13026950515838204`], 
         ArrowBox[{312, 20}, 0.13026950515838204`], 
         ArrowBox[{313, 47}, 0.13026950515838204`], 
         ArrowBox[{314, 47}, 0.13026950515838204`], 
         ArrowBox[BezierCurveBox[{315, 2167, 2170, 2172, 2178, 2180, 2183, 
          315},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{316, 269}, 0.13026950515838204`], 
         ArrowBox[{317, 269}, 0.13026950515838204`], 
         ArrowBox[{318, 266}, 0.13026950515838204`], 
         ArrowBox[{319, 269}, 0.13026950515838204`], 
         ArrowBox[{320, 269}, 0.13026950515838204`], 
         ArrowBox[{321, 11}, 0.13026950515838204`], 
         ArrowBox[{322, 20}, 0.13026950515838204`], 
         ArrowBox[{323, 11}, 0.13026950515838204`], 
         ArrowBox[{324, 20}, 0.13026950515838204`], 
         ArrowBox[{325, 38}, 0.13026950515838204`], 
         ArrowBox[{326, 38}, 0.13026950515838204`], 
         ArrowBox[{327, 41}, 0.13026950515838204`], 
         ArrowBox[{328, 41}, 0.13026950515838204`], 
         ArrowBox[{329, 76}, 0.13026950515838204`], 
         ArrowBox[{330, 329}, 0.13026950515838204`], 
         ArrowBox[{331, 332}, 0.13026950515838204`], 
         ArrowBox[{332, 69}, 0.13026950515838204`], 
         ArrowBox[{333, 332}, 0.13026950515838204`], 
         ArrowBox[{334, 333}, 0.13026950515838204`], 
         ArrowBox[{335, 336}, 0.13026950515838204`], 
         ArrowBox[{336, 339}, 0.13026950515838204`], 
         ArrowBox[{337, 332}, 0.13026950515838204`], 
         ArrowBox[{338, 339}, 0.13026950515838204`], 
         ArrowBox[{339, 22}, 0.13026950515838204`], 
         ArrowBox[{340, 76}, 0.13026950515838204`], 
         ArrowBox[{341, 76}, 0.13026950515838204`], 
         ArrowBox[{342, 76}, 0.13026950515838204`], 
         ArrowBox[{343, 76}, 0.13026950515838204`], 
         ArrowBox[{344, 69}, 0.13026950515838204`], 
         ArrowBox[{345, 331}, 0.13026950515838204`], 
         ArrowBox[{346, 332}, 0.13026950515838204`], 
         ArrowBox[{347, 332}, 0.13026950515838204`], 
         ArrowBox[{348, 347}, 0.13026950515838204`], 
         ArrowBox[{349, 366}, 0.13026950515838204`], 
         ArrowBox[{350, 351}, 0.13026950515838204`], 
         ArrowBox[{351, 352}, 0.13026950515838204`], 
         ArrowBox[{352, 320}, 0.13026950515838204`], 
         ArrowBox[{353, 76}, 0.13026950515838204`], 
         ArrowBox[{354, 76}, 0.13026950515838204`], 
         ArrowBox[{355, 76}, 0.13026950515838204`], 
         ArrowBox[{356, 76}, 0.13026950515838204`], 
         ArrowBox[{357, 73}, 0.13026950515838204`], 
         ArrowBox[{358, 73}, 0.13026950515838204`], 
         ArrowBox[{359, 69}, 0.13026950515838204`], 
         ArrowBox[{360, 69}, 0.13026950515838204`], 
         ArrowBox[{361, 362}, 0.13026950515838204`], 
         ArrowBox[{362, 332}, 0.13026950515838204`], 
         ArrowBox[{363, 303}, 0.13026950515838204`], 
         ArrowBox[{364, 303}, 0.13026950515838204`], 
         ArrowBox[{365, 306}, 0.13026950515838204`], 
         ArrowBox[{366, 306}, 0.13026950515838204`], 
         ArrowBox[{367, 76}, 0.13026950515838204`], 
         ArrowBox[{368, 76}, 0.13026950515838204`], 
         ArrowBox[{369, 76}, 0.13026950515838204`], 
         ArrowBox[{370, 76}, 0.13026950515838204`], 
         ArrowBox[{371, 11}, 0.13026950515838204`], 
         ArrowBox[{372, 21}, 0.13026950515838204`], 
         ArrowBox[{373, 362}, 0.13026950515838204`], 
         ArrowBox[{374, 338}, 0.13026950515838204`], 
         ArrowBox[{375, 317}, 0.13026950515838204`], 
         ArrowBox[{376, 320}, 0.13026950515838204`], 
         ArrowBox[{377, 73}, 0.13026950515838204`], 
         ArrowBox[{378, 73}, 0.13026950515838204`], 
         ArrowBox[{379, 76}, 0.13026950515838204`], 
         ArrowBox[{380, 76}, 0.13026950515838204`], 
         ArrowBox[{381, 11}, 0.13026950515838204`], 
         ArrowBox[{382, 20}, 0.13026950515838204`], 
         ArrowBox[{383, 13}, 0.13026950515838204`], 
         ArrowBox[{384, 47}, 0.13026950515838204`], 
         ArrowBox[{385, 258}, 0.13026950515838204`], 
         ArrowBox[{386, 258}, 0.13026950515838204`], 
         ArrowBox[{387, 262}, 0.13026950515838204`], 
         ArrowBox[{388, 262}, 0.13026950515838204`], 
         ArrowBox[{389, 259}, 0.13026950515838204`], 
         ArrowBox[{390, 300}, 0.13026950515838204`], 
         ArrowBox[{391, 267}, 0.13026950515838204`], 
         ArrowBox[{392, 302}, 0.13026950515838204`], 
         ArrowBox[{393, 76}, 0.13026950515838204`], 
         ArrowBox[{394, 76}, 0.13026950515838204`], 
         ArrowBox[{395, 76}, 0.13026950515838204`], 
         ArrowBox[{396, 76}, 0.13026950515838204`], 
         ArrowBox[{397, 11}, 0.13026950515838204`], 
         ArrowBox[{398, 11}, 0.13026950515838204`], 
         ArrowBox[{399, 21}, 0.13026950515838204`], 
         ArrowBox[{400, 21}, 0.13026950515838204`], 
         ArrowBox[{401, 258}, 0.13026950515838204`], 
         ArrowBox[{402, 258}, 0.13026950515838204`], 
         ArrowBox[{403, 335}, 0.13026950515838204`], 
         ArrowBox[{404, 335}, 0.13026950515838204`], 
         ArrowBox[{405, 281}, 0.13026950515838204`], 
         ArrowBox[{406, 266}, 0.13026950515838204`], 
         ArrowBox[{407, 288}, 0.13026950515838204`], 
         ArrowBox[{408, 269}, 0.13026950515838204`], 
         ArrowBox[{409, 73}, 0.13026950515838204`], 
         ArrowBox[{410, 73}, 0.13026950515838204`], 
         ArrowBox[{411, 76}, 0.13026950515838204`], 
         ArrowBox[{412, 76}, 0.13026950515838204`], 
         ArrowBox[{413, 11}, 0.13026950515838204`], 
         ArrowBox[{414, 11}, 0.13026950515838204`], 
         ArrowBox[{415, 13}, 0.13026950515838204`], 
         ArrowBox[{416, 13}, 0.13026950515838204`], 
         ArrowBox[{417, 257}, 0.13026950515838204`], 
         ArrowBox[{418, 299}, 0.13026950515838204`], 
         ArrowBox[{419, 267}, 0.13026950515838204`], 
         ArrowBox[{420, 302}, 0.13026950515838204`], 
         ArrowBox[{421, 300}, 0.13026950515838204`], 
         ArrowBox[{422, 300}, 0.13026950515838204`], 
         ArrowBox[{423, 302}, 0.13026950515838204`], 
         ArrowBox[{424, 302}, 0.13026950515838204`], 
         ArrowBox[{425, 11}, 0.13026950515838204`], 
         ArrowBox[{426, 11}, 0.13026950515838204`], 
         ArrowBox[{427, 15}, 0.13026950515838204`], 
         ArrowBox[{428, 15}, 0.13026950515838204`], 
         ArrowBox[{429, 11}, 0.13026950515838204`], 
         ArrowBox[{430, 20}, 0.13026950515838204`], 
         ArrowBox[{431, 13}, 0.13026950515838204`], 
         ArrowBox[{432, 47}, 0.13026950515838204`], 
         ArrowBox[{433, 257}, 0.13026950515838204`], 
         ArrowBox[{434, 299}, 0.13026950515838204`], 
         ArrowBox[{435, 267}, 0.13026950515838204`], 
         ArrowBox[{436, 302}, 0.13026950515838204`], 
         ArrowBox[{437, 266}, 0.13026950515838204`], 
         ArrowBox[{438, 266}, 0.13026950515838204`], 
         ArrowBox[{439, 269}, 0.13026950515838204`], 
         ArrowBox[{440, 269}, 0.13026950515838204`], 
         ArrowBox[{441, 11}, 0.13026950515838204`], 
         ArrowBox[{442, 11}, 0.13026950515838204`], 
         ArrowBox[{443, 11}, 0.13026950515838204`], 
         ArrowBox[{444, 11}, 0.13026950515838204`], 
         ArrowBox[{445, 11}, 0.13026950515838204`], 
         ArrowBox[{446, 20}, 0.13026950515838204`], 
         ArrowBox[{447, 13}, 0.13026950515838204`], 
         ArrowBox[{448, 47}, 0.13026950515838204`], 
         ArrowBox[{449, 329}, 0.13026950515838204`], 
         ArrowBox[{450, 329}, 0.13026950515838204`], 
         ArrowBox[{451, 332}, 0.13026950515838204`], 
         ArrowBox[{452, 332}, 0.13026950515838204`], 
         ArrowBox[{453, 333}, 0.13026950515838204`], 
         ArrowBox[{454, 333}, 0.13026950515838204`], 
         ArrowBox[{455, 332}, 0.13026950515838204`], 
         ArrowBox[{456, 332}, 0.13026950515838204`], 
         ArrowBox[{457, 76}, 0.13026950515838204`], 
         ArrowBox[{458, 76}, 0.13026950515838204`], 
         ArrowBox[{459, 76}, 0.13026950515838204`], 
         ArrowBox[{460, 76}, 0.13026950515838204`], 
         ArrowBox[{461, 76}, 0.13026950515838204`], 
         ArrowBox[{462, 76}, 0.13026950515838204`], 
         ArrowBox[{463, 69}, 0.13026950515838204`], 
         ArrowBox[{464, 69}, 0.13026950515838204`], 
         ArrowBox[{465, 331}, 0.13026950515838204`], 
         ArrowBox[{466, 331}, 0.13026950515838204`], 
         ArrowBox[{467, 332}, 0.13026950515838204`], 
         ArrowBox[{468, 332}, 0.13026950515838204`], 
         ArrowBox[{469, 333}, 0.13026950515838204`], 
         ArrowBox[{470, 333}, 0.13026950515838204`], 
         ArrowBox[{471, 338}, 0.13026950515838204`], 
         ArrowBox[{472, 338}, 0.13026950515838204`], 
         ArrowBox[{473, 76}, 0.13026950515838204`], 
         ArrowBox[{474, 76}, 0.13026950515838204`], 
         ArrowBox[{475, 76}, 0.13026950515838204`], 
         ArrowBox[{476, 76}, 0.13026950515838204`], 
         ArrowBox[{477, 73}, 0.13026950515838204`], 
         ArrowBox[{478, 73}, 0.13026950515838204`], 
         ArrowBox[{479, 69}, 0.13026950515838204`], 
         ArrowBox[{480, 69}, 0.13026950515838204`], 
         ArrowBox[{481, 331}, 0.13026950515838204`], 
         ArrowBox[{482, 331}, 0.13026950515838204`], 
         ArrowBox[{483, 332}, 0.13026950515838204`], 
         ArrowBox[{484, 332}, 0.13026950515838204`], 
         ArrowBox[{485, 263}, 0.13026950515838204`], 
         ArrowBox[{486, 303}, 0.13026950515838204`], 
         ArrowBox[{487, 270}, 0.13026950515838204`], 
         ArrowBox[{488, 306}, 0.13026950515838204`], 
         ArrowBox[{489, 76}, 0.13026950515838204`], 
         ArrowBox[{490, 76}, 0.13026950515838204`], 
         ArrowBox[{491, 76}, 0.13026950515838204`], 
         ArrowBox[{492, 76}, 0.13026950515838204`], 
         ArrowBox[{493, 11}, 0.13026950515838204`], 
         ArrowBox[{494, 11}, 0.13026950515838204`], 
         ArrowBox[{495, 21}, 0.13026950515838204`], 
         ArrowBox[{496, 21}, 0.13026950515838204`], 
         ArrowBox[{497, 331}, 0.13026950515838204`], 
         ArrowBox[{498, 331}, 0.13026950515838204`], 
         ArrowBox[{499, 338}, 0.13026950515838204`], 
         ArrowBox[{500, 338}, 0.13026950515838204`], 
         ArrowBox[{501, 263}, 0.13026950515838204`], 
         ArrowBox[{502, 303}, 0.13026950515838204`], 
         ArrowBox[{503, 270}, 0.13026950515838204`], 
         ArrowBox[{504, 306}, 0.13026950515838204`], 
         ArrowBox[{505, 73}, 0.13026950515838204`], 
         ArrowBox[{506, 73}, 0.13026950515838204`], 
         ArrowBox[{507, 76}, 0.13026950515838204`], 
         ArrowBox[{508, 76}, 0.13026950515838204`], 
         ArrowBox[{509, 11}, 0.13026950515838204`], 
         ArrowBox[{510, 11}, 0.13026950515838204`], 
         ArrowBox[{511, 13}, 0.13026950515838204`], 
         ArrowBox[{512, 13}, 0.13026950515838204`], 
         ArrowBox[{513, 514}, 0.13026950515838204`], 
         ArrowBox[BezierCurveBox[{514, 2190, 2193, 2195, 2201, 2203, 2206, 
          514},
          SplineDegree->7], 0.13026950515838204`], 
         ArrowBox[{515, 516}, 0.13026950515838204`], 
         ArrowBox[{516, 514}, 0.13026950515838204`], 
         ArrowBox[{517, 518}, 0.13026950515838204`], 
         ArrowBox[{518, 135}, 0.13026950515838204`], 
         ArrowBox[{519, 520}, 0.13026950515838204`], 
         ArrowBox[{520, 167}, 0.13026950515838204`], 
         ArrowBox[{521, 522}, 0.13026950515838204`], 
         ArrowBox[{522, 516}, 0.13026950515838204`], 
         ArrowBox[{523, 522}, 0.13026950515838204`], 
         ArrowBox[{524, 525}, 0.13026950515838204`], 
         ArrowBox[{525, 522}, 0.13026950515838204`], 
         ArrowBox[{526, 525}, 0.13026950515838204`], 
         ArrowBox[{527, 143}, 0.13026950515838204`], 
         ArrowBox[{528, 143}, 0.13026950515838204`], 
         ArrowBox[{529, 143}, 0.13026950515838204`], 
         ArrowBox[{530, 143}, 0.13026950515838204`], 
         ArrowBox[{531, 135}, 0.13026950515838204`], 
         ArrowBox[{532, 167}, 0.13026950515838204`], 
         ArrowBox[{533, 144}, 0.13026950515838204`], 
         ArrowBox[{534, 176}, 0.13026950515838204`], 
         ArrowBox[{535, 536}, 0.13026950515838204`], 
         ArrowBox[{536, 514}, 0.13026950515838204`], 
         ArrowBox[{537, 538}, 0.13026950515838204`], 
         ArrowBox[{538, 514}, 0.13026950515838204`], 
         ArrowBox[{539, 540}, 0.13026950515838204`], 
         ArrowBox[{540, 522}, 0.13026950515838204`], 
         ArrowBox[{541, 525}, 0.13026950515838204`], 
         ArrowBox[{542, 522}, 0.13026950515838204`], 
         ArrowBox[{543, 522}, 0.13026950515838204`], 
         ArrowBox[{544, 525}, 0.13026950515838204`], 
         ArrowBox[{545, 525}, 0.13026950515838204`], 
         ArrowBox[{546, 135}, 0.13026950515838204`], 
         ArrowBox[{547, 135}, 0.13026950515838204`], 
         ArrowBox[{548, 143}, 0.13026950515838204`], 
         ArrowBox[{549, 143}, 0.13026950515838204`], 
         ArrowBox[{550, 151}, 0.13026950515838204`], 
         ArrowBox[{551, 183}, 0.13026950515838204`], 
         ArrowBox[{552, 152}, 0.13026950515838204`], 
         ArrowBox[{553, 184}, 0.13026950515838204`], 
         ArrowBox[{554, 516}, 0.13026950515838204`], 
         ArrowBox[{555, 516}, 0.13026950515838204`], 
         ArrowBox[{556, 557}, 0.13026950515838204`], 
         ArrowBox[{557, 669}, 0.13026950515838204`], 
         ArrowBox[{558, 557}, 0.13026950515838204`], 
         ArrowBox[{559, 522}, 0.13026950515838204`], 
         ArrowBox[{560, 522}, 0.13026950515838204`], 
         ArrowBox[{561, 525}, 0.13026950515838204`], 
         ArrowBox[{562, 525}, 0.13026950515838204`], 
         ArrowBox[{563, 135}, 0.13026950515838204`], 
         ArrowBox[{564, 167}, 0.13026950515838204`], 
         ArrowBox[{565, 143}, 0.13026950515838204`], 
         ArrowBox[{566, 175}, 0.13026950515838204`], 
         ArrowBox[{567, 167}, 0.13026950515838204`], 
         ArrowBox[{568, 167}, 0.13026950515838204`], 
         ArrowBox[{569, 168}, 0.13026950515838204`], 
         ArrowBox[{570, 168}, 0.13026950515838204`], 
         ArrowBox[{571, 538}, 0.13026950515838204`], 
         ArrowBox[{572, 538}, 0.13026950515838204`], 
         ArrowBox[{573, 525}, 0.13026950515838204`], 
         ArrowBox[{574, 525}, 0.13026950515838204`], 
         ArrowBox[{575, 522}, 0.13026950515838204`], 
         ArrowBox[{576, 522}, 0.13026950515838204`], 
         ArrowBox[{577, 525}, 0.13026950515838204`], 
         ArrowBox[{578, 525}, 0.13026950515838204`], 
         ArrowBox[{579, 135}, 0.13026950515838204`], 
         ArrowBox[{580, 167}, 0.13026950515838204`], 
         ArrowBox[{581, 135}, 0.13026950515838204`], 
         ArrowBox[{582, 167}, 0.13026950515838204`], 
         ArrowBox[{583, 183}, 0.13026950515838204`], 
         ArrowBox[{584, 183}, 0.13026950515838204`], 
         ArrowBox[{585, 184}, 0.13026950515838204`], 
         ArrowBox[{586, 184}, 0.13026950515838204`], 
         ArrowBox[{587, 588}, 0.13026950515838204`], 
         ArrowBox[{588, 207}, 0.13026950515838204`], 
         ArrowBox[{589, 588}, 0.13026950515838204`], 
         ArrowBox[{590, 591}, 0.13026950515838204`], 
         ArrowBox[{591, 144}, 0.13026950515838204`], 
         ArrowBox[{592, 591}, 0.13026950515838204`], 
         ArrowBox[{593, 594}, 0.13026950515838204`], 
         ArrowBox[{594, 518}, 0.13026950515838204`], 
         ArrowBox[{595, 596}, 0.13026950515838204`], 
         ArrowBox[{596, 557}, 0.13026950515838204`], 
         ArrowBox[{597, 598}, 0.13026950515838204`], 
         ArrowBox[{598, 144}, 0.13026950515838204`], 
         ArrowBox[{599, 600}, 0.13026950515838204`], 
         ArrowBox[{600, 168}, 0.13026950515838204`], 
         ArrowBox[{601, 207}, 0.13026950515838204`], 
         ArrowBox[{602, 207}, 0.13026950515838204`], 
         ArrowBox[{603, 207}, 0.13026950515838204`], 
         ArrowBox[{604, 207}, 0.13026950515838204`], 
         ArrowBox[{605, 143}, 0.13026950515838204`], 
         ArrowBox[{606, 143}, 0.13026950515838204`], 
         ArrowBox[{607, 144}, 0.13026950515838204`], 
         ArrowBox[{608, 144}, 0.13026950515838204`], 
         ArrowBox[{609, 610}, 0.13026950515838204`], 
         ArrowBox[{610, 591}, 0.13026950515838204`], 
         ArrowBox[{611, 610}, 0.13026950515838204`], 
         ArrowBox[{612, 591}, 0.13026950515838204`], 
         ArrowBox[{613, 591}, 0.13026950515838204`], 
         ArrowBox[{614, 615}, 0.13026950515838204`], 
         ArrowBox[{615, 668}, 0.13026950515838204`], 
         ArrowBox[{616, 617}, 0.13026950515838204`], 
         ArrowBox[{617, 557}, 0.13026950515838204`], 
         ArrowBox[{618, 619}, 0.13026950515838204`], 
         ArrowBox[{619, 525}, 0.13026950515838204`], 
         ArrowBox[{620, 621}, 0.13026950515838204`], 
         ArrowBox[{621, 525}, 0.13026950515838204`], 
         ArrowBox[{622, 207}, 0.13026950515838204`], 
         ArrowBox[{623, 207}, 0.13026950515838204`], 
         ArrowBox[{624, 207}, 0.13026950515838204`], 
         ArrowBox[{625, 207}, 0.13026950515838204`], 
         ArrowBox[{626, 135}, 0.13026950515838204`], 
         ArrowBox[{627, 135}, 0.13026950515838204`], 
         ArrowBox[{628, 144}, 0.13026950515838204`], 
         ArrowBox[{629, 144}, 0.13026950515838204`], 
         ArrowBox[{630, 631}, 0.13026950515838204`], 
         ArrowBox[{631, 518}, 0.13026950515838204`], 
         ArrowBox[{632, 633}, 0.13026950515838204`], 
         ArrowBox[{633, 668}, 0.13026950515838204`], 
         ArrowBox[{634, 598}, 0.13026950515838204`], 
         ArrowBox[{635, 600}, 0.13026950515838204`], 
         ArrowBox[{636, 596}, 0.13026950515838204`], 
         ArrowBox[{637, 596}, 0.13026950515838204`], 
         ArrowBox[{638, 639}, 0.13026950515838204`], 
         ArrowBox[{639, 557}, 0.13026950515838204`], 
         ArrowBox[{640, 639}, 0.13026950515838204`], 
         ArrowBox[{641, 143}, 0.13026950515838204`], 
         ArrowBox[{642, 143}, 0.13026950515838204`], 
         ArrowBox[{643, 143}, 0.13026950515838204`], 
         ArrowBox[{644, 143}, 0.13026950515838204`], 
         ArrowBox[{645, 135}, 0.13026950515838204`], 
         ArrowBox[{646, 167}, 0.13026950515838204`], 
         ArrowBox[{647, 144}, 0.13026950515838204`], 
         ArrowBox[{648, 176}, 0.13026950515838204`], 
         ArrowBox[{649, 631}, 0.13026950515838204`], 
         ArrowBox[{650, 633}, 0.13026950515838204`], 
         ArrowBox[{651, 652}, 0.13026950515838204`], 
         ArrowBox[{652, 557}, 0.13026950515838204`], 
         ArrowBox[{653, 639}, 0.13026950515838204`], 
         ArrowBox[{654, 617}, 0.13026950515838204`], 
         ArrowBox[{655, 617}, 0.13026950515838204`], 
         ArrowBox[{656, 621}, 0.13026950515838204`], 
         ArrowBox[{657, 621}, 0.13026950515838204`], 
         ArrowBox[{658, 135}, 0.13026950515838204`], 
         ArrowBox[{659, 135}, 0.13026950515838204`], 
         ArrowBox[{660, 143}, 0.13026950515838204`], 
         ArrowBox[{661, 143}, 0.13026950515838204`], 
         ArrowBox[{662, 135}, 0.13026950515838204`], 
         ArrowBox[{663, 167}, 0.13026950515838204`], 
         ArrowBox[{664, 136}, 0.13026950515838204`], 
         ArrowBox[{665, 168}, 0.13026950515838204`], 
         ArrowBox[{666, 514}, 0.13026950515838204`], 
         ArrowBox[{667, 666}, 0.13026950515838204`], 
         ArrowBox[{668, 669}, 0.13026950515838204`], 
         ArrowBox[{669, 516}, 0.13026950515838204`], 
         ArrowBox[{670, 668}, 0.13026950515838204`], 
         ArrowBox[{671, 143}, 0.13026950515838204`], 
         ArrowBox[{672, 143}, 0.13026950515838204`], 
         ArrowBox[{673, 143}, 0.13026950515838204`], 
         ArrowBox[{674, 143}, 0.13026950515838204`], 
         ArrowBox[{675, 135}, 0.13026950515838204`], 
         ArrowBox[{676, 144}, 0.13026950515838204`], 
         ArrowBox[{677, 514}, 0.13026950515838204`], 
         ArrowBox[{678, 668}, 0.13026950515838204`], 
         ArrowBox[{679, 677}, 0.13026950515838204`], 
         ArrowBox[{680, 540}, 0.13026950515838204`], 
         ArrowBox[{681, 135}, 0.13026950515838204`], 
         ArrowBox[{682, 135}, 0.13026950515838204`], 
         ArrowBox[{683, 143}, 0.13026950515838204`], 
         ArrowBox[{684, 143}, 0.13026950515838204`], 
         ArrowBox[{685, 135}, 0.13026950515838204`], 
         ArrowBox[{686, 135}, 0.13026950515838204`], 
         ArrowBox[{687, 136}, 0.13026950515838204`], 
         ArrowBox[{688, 136}, 0.13026950515838204`], 
         ArrowBox[{689, 669}, 0.13026950515838204`], 
         ArrowBox[{690, 557}, 0.13026950515838204`], 
         ArrowBox[{691, 135}, 0.13026950515838204`], 
         ArrowBox[{692, 135}, 0.13026950515838204`], 
         ArrowBox[{693, 143}, 0.13026950515838204`], 
         ArrowBox[{694, 143}, 0.13026950515838204`], 
         ArrowBox[{695, 135}, 0.13026950515838204`], 
         ArrowBox[{696, 136}, 0.13026950515838204`], 
         ArrowBox[{697, 668}, 0.13026950515838204`], 
         ArrowBox[{698, 522}, 0.13026950515838204`], 
         ArrowBox[{699, 525}, 0.13026950515838204`], 
         ArrowBox[{700, 135}, 0.13026950515838204`], 
         ArrowBox[{701, 135}, 0.13026950515838204`], 
         ArrowBox[{702, 135}, 0.13026950515838204`], 
         ArrowBox[{703, 135}, 0.13026950515838204`], 
         ArrowBox[{704, 135}, 0.13026950515838204`], 
         ArrowBox[{705, 167}, 0.13026950515838204`], 
         ArrowBox[{706, 136}, 0.13026950515838204`], 
         ArrowBox[{707, 168}, 0.13026950515838204`], 
         ArrowBox[{708, 588}, 0.13026950515838204`], 
         ArrowBox[{709, 588}, 0.13026950515838204`], 
         ArrowBox[{710, 591}, 0.13026950515838204`], 
         ArrowBox[{711, 594}, 0.13026950515838204`], 
         ArrowBox[{712, 594}, 0.13026950515838204`], 
         ArrowBox[{713, 598}, 0.13026950515838204`], 
         ArrowBox[{714, 598}, 0.13026950515838204`], 
         ArrowBox[{715, 207}, 0.13026950515838204`], 
         ArrowBox[{716, 207}, 0.13026950515838204`], 
         ArrowBox[{717, 207}, 0.13026950515838204`], 
         ArrowBox[{718, 143}, 0.13026950515838204`], 
         ArrowBox[{719, 143}, 0.13026950515838204`], 
         ArrowBox[{720, 144}, 0.13026950515838204`], 
         ArrowBox[{721, 610}, 0.13026950515838204`], 
         ArrowBox[{722, 610}, 0.13026950515838204`], 
         ArrowBox[{723, 591}, 0.13026950515838204`], 
         ArrowBox[{724, 591}, 0.13026950515838204`], 
         ArrowBox[{725, 594}, 0.13026950515838204`], 
         ArrowBox[{726, 594}, 0.13026950515838204`], 
         ArrowBox[{727, 652}, 0.13026950515838204`], 
         ArrowBox[{728, 652}, 0.13026950515838204`], 
         ArrowBox[{729, 207}, 0.13026950515838204`], 
         ArrowBox[{730, 207}, 0.13026950515838204`], 
         ArrowBox[{731, 207}, 0.13026950515838204`], 
         ArrowBox[{732, 207}, 0.13026950515838204`], 
         ArrowBox[{733, 135}, 0.13026950515838204`], 
         ArrowBox[{734, 135}, 0.13026950515838204`], 
         ArrowBox[{735, 144}, 0.13026950515838204`], 
         ArrowBox[{736, 144}, 0.13026950515838204`], 
         ArrowBox[{737, 631}, 0.13026950515838204`], 
         ArrowBox[{738, 631}, 0.13026950515838204`], 
         ArrowBox[{739, 598}, 0.13026950515838204`], 
         ArrowBox[{740, 598}, 0.13026950515838204`], 
         ArrowBox[{741, 594}, 0.13026950515838204`], 
         ArrowBox[{742, 596}, 0.13026950515838204`], 
         ArrowBox[{743, 652}, 0.13026950515838204`], 
         ArrowBox[{744, 639}, 0.13026950515838204`], 
         ArrowBox[{745, 143}, 0.13026950515838204`], 
         ArrowBox[{746, 143}, 0.13026950515838204`], 
         ArrowBox[{747, 143}, 0.13026950515838204`], 
         ArrowBox[{748, 143}, 0.13026950515838204`], 
         ArrowBox[{749, 135}, 0.13026950515838204`], 
         ArrowBox[{750, 135}, 0.13026950515838204`], 
         ArrowBox[{751, 144}, 0.13026950515838204`], 
         ArrowBox[{752, 144}, 0.13026950515838204`], 
         ArrowBox[{753, 631}, 0.13026950515838204`], 
         ArrowBox[{754, 631}, 0.13026950515838204`], 
         ArrowBox[{755, 652}, 0.13026950515838204`], 
         ArrowBox[{756, 652}, 0.13026950515838204`], 
         ArrowBox[{757, 594}, 0.13026950515838204`], 
         ArrowBox[{758, 596}, 0.13026950515838204`], 
         ArrowBox[{759, 652}, 0.13026950515838204`], 
         ArrowBox[{760, 639}, 0.13026950515838204`], 
         ArrowBox[{761, 135}, 0.13026950515838204`], 
         ArrowBox[{762, 135}, 0.13026950515838204`], 
         ArrowBox[{763, 143}, 0.13026950515838204`], 
         ArrowBox[{764, 143}, 0.13026950515838204`], 
         ArrowBox[{765, 135}, 0.13026950515838204`], 
         ArrowBox[{766, 135}, 0.13026950515838204`], 
         ArrowBox[{767, 136}, 0.13026950515838204`], 
         ArrowBox[{768, 136}, 0.13026950515838204`], 
         ArrowBox[{769, 770}, 0.13026950515838204`], 
         ArrowBox[{770, 847}, 0.13026950515838204`], 
         ArrowBox[{771, 772}, 0.13026950515838204`], 
         ArrowBox[{772, 868}, 0.13026950515838204`], 
         ArrowBox[{773, 774}, 0.13026950515838204`], 
         ArrowBox[{774, 207}, 0.13026950515838204`], 
         ArrowBox[{775, 776}, 0.13026950515838204`], 
         ArrowBox[{776, 135}, 0.13026950515838204`], 
         ArrowBox[{777, 778}, 0.13026950515838204`], 
         ArrowBox[{778, 812}, 0.13026950515838204`], 
         ArrowBox[{779, 778}, 0.13026950515838204`], 
         ArrowBox[{780, 781}, 0.13026950515838204`], 
         ArrowBox[{781, 778}, 0.13026950515838204`], 
         ArrowBox[{782, 781}, 0.13026950515838204`], 
         ArrowBox[{783, 207}, 0.13026950515838204`], 
         ArrowBox[{784, 207}, 0.13026950515838204`], 
         ArrowBox[{785, 207}, 0.13026950515838204`], 
         ArrowBox[{786, 207}, 0.13026950515838204`], 
         ArrowBox[{787, 135}, 0.13026950515838204`], 
         ArrowBox[{788, 167}, 0.13026950515838204`], 
         ArrowBox[{789, 144}, 0.13026950515838204`], 
         ArrowBox[{790, 176}, 0.13026950515838204`], 
         ArrowBox[{791, 792}, 0.13026950515838204`], 
         ArrowBox[{792, 868}, 0.13026950515838204`], 
         ArrowBox[{793, 794}, 0.13026950515838204`], 
         ArrowBox[{794, 868}, 0.13026950515838204`], 
         ArrowBox[{795, 796}, 0.13026950515838204`], 
         ArrowBox[{796, 853}, 0.13026950515838204`], 
         ArrowBox[{797, 798}, 0.13026950515838204`], 
         ArrowBox[{798, 894}, 0.13026950515838204`], 
         ArrowBox[{799, 778}, 0.13026950515838204`], 
         ArrowBox[{800, 778}, 0.13026950515838204`], 
         ArrowBox[{801, 781}, 0.13026950515838204`], 
         ArrowBox[{802, 781}, 0.13026950515838204`], 
         ArrowBox[{803, 199}, 0.13026950515838204`], 
         ArrowBox[{804, 199}, 0.13026950515838204`], 
         ArrowBox[{805, 207}, 0.13026950515838204`], 
         ArrowBox[{806, 207}, 0.13026950515838204`], 
         ArrowBox[{807, 151}, 0.13026950515838204`], 
         ArrowBox[{808, 183}, 0.13026950515838204`], 
         ArrowBox[{809, 152}, 0.13026950515838204`], 
         ArrowBox[{810, 184}, 0.13026950515838204`], 
         ArrowBox[{811, 812}, 0.13026950515838204`], 
         ArrowBox[{812, 927}, 0.13026950515838204`], 
         ArrowBox[{813, 812}, 0.13026950515838204`], 
         ArrowBox[{814, 815}, 0.13026950515838204`], 
         ArrowBox[{815, 933}, 0.13026950515838204`], 
         ArrowBox[{816, 815}, 0.13026950515838204`], 
         ArrowBox[{817, 778}, 0.13026950515838204`], 
         ArrowBox[{818, 778}, 0.13026950515838204`], 
         ArrowBox[{819, 781}, 0.13026950515838204`], 
         ArrowBox[{820, 781}, 0.13026950515838204`], 
         ArrowBox[{821, 135}, 0.13026950515838204`], 
         ArrowBox[{822, 167}, 0.13026950515838204`], 
         ArrowBox[{823, 143}, 0.13026950515838204`], 
         ArrowBox[{824, 175}, 0.13026950515838204`], 
         ArrowBox[{825, 167}, 0.13026950515838204`], 
         ArrowBox[{826, 167}, 0.13026950515838204`], 
         ArrowBox[{827, 168}, 0.13026950515838204`], 
         ArrowBox[{828, 168}, 0.13026950515838204`], 
         ArrowBox[{829, 830}, 0.13026950515838204`], 
         ArrowBox[{830, 927}, 0.13026950515838204`], 
         ArrowBox[{831, 830}, 0.13026950515838204`], 
         ArrowBox[{832, 781}, 0.13026950515838204`], 
         ArrowBox[{833, 781}, 0.13026950515838204`], 
         ArrowBox[{834, 778}, 0.13026950515838204`], 
         ArrowBox[{835, 778}, 0.13026950515838204`], 
         ArrowBox[{836, 781}, 0.13026950515838204`], 
         ArrowBox[{837, 781}, 0.13026950515838204`], 
         ArrowBox[{838, 135}, 0.13026950515838204`], 
         ArrowBox[{839, 167}, 0.13026950515838204`], 
         ArrowBox[{840, 135}, 0.13026950515838204`], 
         ArrowBox[{841, 167}, 0.13026950515838204`], 
         ArrowBox[{842, 183}, 0.13026950515838204`], 
         ArrowBox[{843, 183}, 0.13026950515838204`], 
         ArrowBox[{844, 184}, 0.13026950515838204`], 
         ArrowBox[{845, 184}, 0.13026950515838204`], 
         ArrowBox[{846, 847}, 0.13026950515838204`], 
         ArrowBox[{847, 207}, 0.13026950515838204`], 
         ArrowBox[{848, 847}, 0.13026950515838204`], 
         ArrowBox[{849, 850}, 0.13026950515838204`], 
         ArrowBox[{850, 208}, 0.13026950515838204`], 
         ArrowBox[{851, 850}, 0.13026950515838204`], 
         ArrowBox[{852, 853}, 0.13026950515838204`], 
         ArrowBox[{853, 850}, 0.13026950515838204`], 
         ArrowBox[{854, 855}, 0.13026950515838204`], 
         ArrowBox[{855, 850}, 0.13026950515838204`], 
         ArrowBox[{856, 850}, 0.13026950515838204`], 
         ArrowBox[{857, 858}, 0.13026950515838204`], 
         ArrowBox[{858, 144}, 0.13026950515838204`], 
         ArrowBox[{859, 207}, 0.13026950515838204`], 
         ArrowBox[{860, 207}, 0.13026950515838204`], 
         ArrowBox[{861, 207}, 0.13026950515838204`], 
         ArrowBox[{862, 207}, 0.13026950515838204`], 
         ArrowBox[{863, 207}, 0.13026950515838204`], 
         ArrowBox[{864, 207}, 0.13026950515838204`], 
         ArrowBox[{865, 208}, 0.13026950515838204`], 
         ArrowBox[{866, 208}, 0.13026950515838204`], 
         ArrowBox[{867, 868}, 0.13026950515838204`], 
         ArrowBox[{868, 850}, 0.13026950515838204`], 
         ArrowBox[{869, 868}, 0.13026950515838204`], 
         ArrowBox[{870, 850}, 0.13026950515838204`], 
         ArrowBox[{871, 850}, 0.13026950515838204`], 
         ArrowBox[{872, 873}, 0.13026950515838204`], 
         ArrowBox[{873, 850}, 0.13026950515838204`], 
         ArrowBox[{874, 875}, 0.13026950515838204`], 
         ArrowBox[{875, 910}, 0.13026950515838204`], 
         ArrowBox[{876, 877}, 0.13026950515838204`], 
         ArrowBox[{877, 910}, 0.13026950515838204`], 
         ArrowBox[{878, 879}, 0.13026950515838204`], 
         ArrowBox[{879, 897}, 0.13026950515838204`], 
         ArrowBox[{880, 207}, 0.13026950515838204`], 
         ArrowBox[{881, 207}, 0.13026950515838204`], 
         ArrowBox[{882, 207}, 0.13026950515838204`], 
         ArrowBox[{883, 207}, 0.13026950515838204`], 
         ArrowBox[{884, 199}, 0.13026950515838204`], 
         ArrowBox[{885, 199}, 0.13026950515838204`], 
         ArrowBox[{886, 208}, 0.13026950515838204`], 
         ArrowBox[{887, 208}, 0.13026950515838204`], 
         ArrowBox[{888, 868}, 0.13026950515838204`], 
         ArrowBox[{889, 890}, 0.13026950515838204`], 
         ArrowBox[{890, 850}, 0.13026950515838204`], 
         ArrowBox[{891, 850}, 0.13026950515838204`], 
         ArrowBox[{892, 858}, 0.13026950515838204`], 
         ArrowBox[{893, 894}, 0.13026950515838204`], 
         ArrowBox[{894, 815}, 0.13026950515838204`], 
         ArrowBox[{895, 894}, 0.13026950515838204`], 
         ArrowBox[{896, 897}, 0.13026950515838204`], 
         ArrowBox[{897, 815}, 0.13026950515838204`], 
         ArrowBox[{898, 897}, 0.13026950515838204`], 
         ArrowBox[{899, 207}, 0.13026950515838204`], 
         ArrowBox[{900, 207}, 0.13026950515838204`], 
         ArrowBox[{901, 207}, 0.13026950515838204`], 
         ArrowBox[{902, 207}, 0.13026950515838204`], 
         ArrowBox[{903, 135}, 0.13026950515838204`], 
         ArrowBox[{904, 167}, 0.13026950515838204`], 
         ArrowBox[{905, 144}, 0.13026950515838204`], 
         ArrowBox[{906, 176}, 0.13026950515838204`], 
         ArrowBox[{907, 868}, 0.13026950515838204`], 
         ArrowBox[{908, 890}, 0.13026950515838204`], 
         ArrowBox[{909, 910}, 0.13026950515838204`], 
         ArrowBox[{910, 850}, 0.13026950515838204`], 
         ArrowBox[{911, 912}, 0.13026950515838204`], 
         ArrowBox[{912, 897}, 0.13026950515838204`], 
         ArrowBox[{913, 914}, 0.13026950515838204`], 
         ArrowBox[{914, 815}, 0.13026950515838204`], 
         ArrowBox[{915, 914}, 0.13026950515838204`], 
         ArrowBox[{916, 917}, 0.13026950515838204`], 
         ArrowBox[{917, 781}, 0.13026950515838204`], 
         ArrowBox[{918, 917}, 0.13026950515838204`], 
         ArrowBox[{919, 199}, 0.13026950515838204`], 
         ArrowBox[{920, 199}, 0.13026950515838204`], 
         ArrowBox[{921, 207}, 0.13026950515838204`], 
         ArrowBox[{922, 207}, 0.13026950515838204`], 
         ArrowBox[{923, 135}, 0.13026950515838204`], 
         ArrowBox[{924, 167}, 0.13026950515838204`], 
         ArrowBox[{925, 136}, 0.13026950515838204`], 
         ArrowBox[{926, 168}, 0.13026950515838204`], 
         ArrowBox[{927, 770}, 0.13026950515838204`], 
         ArrowBox[{928, 770}, 0.13026950515838204`], 
         ArrowBox[{929, 774}, 0.13026950515838204`], 
         ArrowBox[{930, 774}, 0.13026950515838204`], 
         ArrowBox[{931, 928}, 0.13026950515838204`], 
         ArrowBox[{932, 933}, 0.13026950515838204`], 
         ArrowBox[{933, 812}, 0.13026950515838204`], 
         ArrowBox[{934, 932}, 0.13026950515838204`], 
         ArrowBox[{935, 815}, 0.13026950515838204`], 
         ArrowBox[{936, 207}, 0.13026950515838204`], 
         ArrowBox[{937, 207}, 0.13026950515838204`], 
         ArrowBox[{938, 207}, 0.13026950515838204`], 
         ArrowBox[{939, 207}, 0.13026950515838204`], 
         ArrowBox[{940, 135}, 0.13026950515838204`], 
         ArrowBox[{941, 135}, 0.13026950515838204`], 
         ArrowBox[{942, 144}, 0.13026950515838204`], 
         ArrowBox[{943, 144}, 0.13026950515838204`], 
         ArrowBox[{944, 770}, 0.13026950515838204`], 
         ArrowBox[{945, 770}, 0.13026950515838204`], 
         ArrowBox[{946, 947}, 0.13026950515838204`], 
         ArrowBox[{947, 853}, 0.13026950515838204`], 
         ArrowBox[{948, 947}, 0.13026950515838204`], 
         ArrowBox[{949, 945}, 0.13026950515838204`], 
         ArrowBox[{950, 778}, 0.13026950515838204`], 
         ArrowBox[{951, 950}, 0.13026950515838204`], 
         ArrowBox[{952, 781}, 0.13026950515838204`], 
         ArrowBox[{953, 199}, 0.13026950515838204`], 
         ArrowBox[{954, 199}, 0.13026950515838204`], 
         ArrowBox[{955, 207}, 0.13026950515838204`], 
         ArrowBox[{956, 207}, 0.13026950515838204`], 
         ArrowBox[{957, 135}, 0.13026950515838204`], 
         ArrowBox[{958, 135}, 0.13026950515838204`], 
         ArrowBox[{959, 136}, 0.13026950515838204`], 
         ArrowBox[{960, 136}, 0.13026950515838204`], 
         ArrowBox[{961, 932}, 0.13026950515838204`], 
         ArrowBox[{962, 933}, 0.13026950515838204`], 
         ArrowBox[{963, 815}, 0.13026950515838204`], 
         ArrowBox[{964, 135}, 0.13026950515838204`], 
         ArrowBox[{965, 135}, 0.13026950515838204`], 
         ArrowBox[{966, 143}, 0.13026950515838204`], 
         ArrowBox[{967, 143}, 0.13026950515838204`], 
         ArrowBox[{968, 135}, 0.13026950515838204`], 
         ArrowBox[{969, 167}, 0.13026950515838204`], 
         ArrowBox[{970, 136}, 0.13026950515838204`], 
         ArrowBox[{971, 168}, 0.13026950515838204`], 
         ArrowBox[{972, 932}, 0.13026950515838204`], 
         ArrowBox[{973, 778}, 0.13026950515838204`], 
         ArrowBox[{974, 781}, 0.13026950515838204`], 
         ArrowBox[{975, 135}, 0.13026950515838204`], 
         ArrowBox[{976, 135}, 0.13026950515838204`], 
         ArrowBox[{977, 135}, 0.13026950515838204`], 
         ArrowBox[{978, 135}, 0.13026950515838204`], 
         ArrowBox[{979, 135}, 0.13026950515838204`], 
         ArrowBox[{980, 167}, 0.13026950515838204`], 
         ArrowBox[{981, 136}, 0.13026950515838204`], 
         ArrowBox[{982, 168}, 0.13026950515838204`], 
         ArrowBox[{983, 847}, 0.13026950515838204`], 
         ArrowBox[{984, 853}, 0.13026950515838204`], 
         ArrowBox[{985, 850}, 0.13026950515838204`], 
         ArrowBox[{986, 207}, 0.13026950515838204`], 
         ArrowBox[{987, 207}, 0.13026950515838204`], 
         ArrowBox[{988, 207}, 0.13026950515838204`], 
         ArrowBox[{989, 207}, 0.13026950515838204`], 
         ArrowBox[{990, 208}, 0.13026950515838204`], 
         ArrowBox[{991, 868}, 0.13026950515838204`], 
         ArrowBox[{992, 850}, 0.13026950515838204`], 
         ArrowBox[{993, 853}, 0.13026950515838204`], 
         ArrowBox[{994, 910}, 0.13026950515838204`], 
         ArrowBox[{995, 207}, 0.13026950515838204`], 
         ArrowBox[{996, 207}, 0.13026950515838204`], 
         ArrowBox[{997, 207}, 0.13026950515838204`], 
         ArrowBox[{998, 207}, 0.13026950515838204`], 
         ArrowBox[{999, 199}, 0.13026950515838204`], 
         ArrowBox[{1000, 199}, 0.13026950515838204`], 
         ArrowBox[{1001, 208}, 0.13026950515838204`], 
         ArrowBox[{1002, 208}, 0.13026950515838204`], 
         ArrowBox[{1003, 868}, 0.13026950515838204`], 
         ArrowBox[{1004, 930}, 0.13026950515838204`], 
         ArrowBox[{1005, 894}, 0.13026950515838204`], 
         ArrowBox[{1006, 935}, 0.13026950515838204`], 
         ArrowBox[{1007, 207}, 0.13026950515838204`], 
         ArrowBox[{1008, 207}, 0.13026950515838204`], 
         ArrowBox[{1009, 207}, 0.13026950515838204`], 
         ArrowBox[{1010, 207}, 0.13026950515838204`], 
         ArrowBox[{1011, 135}, 0.13026950515838204`], 
         ArrowBox[{1012, 144}, 0.13026950515838204`], 
         ArrowBox[{1013, 868}, 0.13026950515838204`], 
         ArrowBox[{1014, 910}, 0.13026950515838204`], 
         ArrowBox[{1015, 930}, 0.13026950515838204`], 
         ArrowBox[{1016, 935}, 0.13026950515838204`], 
         ArrowBox[{1017, 199}, 0.13026950515838204`], 
         ArrowBox[{1018, 199}, 0.13026950515838204`], 
         ArrowBox[{1019, 207}, 0.13026950515838204`], 
         ArrowBox[{1020, 207}, 0.13026950515838204`], 
         ArrowBox[{1021, 135}, 0.13026950515838204`], 
         ArrowBox[{1022, 135}, 0.13026950515838204`], 
         ArrowBox[{1023, 136}, 0.13026950515838204`], 
         ArrowBox[{1024, 136}, 0.13026950515838204`], 
         ArrowBox[{1025, 769}, 0.13026950515838204`], 
         ArrowBox[{1026, 811}, 0.13026950515838204`], 
         ArrowBox[{1027, 788}, 0.13026950515838204`], 
         ArrowBox[{1028, 826}, 0.13026950515838204`], 
         ArrowBox[{1029, 831}, 0.13026950515838204`], 
         ArrowBox[{1030, 831}, 0.13026950515838204`], 
         ArrowBox[{1031, 835}, 0.13026950515838204`], 
         ArrowBox[{1032, 835}, 0.13026950515838204`], 
         ArrowBox[{1033, 15}, 0.13026950515838204`], 
         ArrowBox[{1034, 15}, 0.13026950515838204`], 
         ArrowBox[{1035, 15}, 0.13026950515838204`], 
         ArrowBox[{1036, 15}, 0.13026950515838204`], 
         ArrowBox[{1037, 11}, 0.13026950515838204`], 
         ArrowBox[{1038, 20}, 0.13026950515838204`], 
         ArrowBox[{1039, 21}, 0.13026950515838204`], 
         ArrowBox[{1040, 22}, 0.13026950515838204`], 
         ArrowBox[{1041, 791}, 0.13026950515838204`], 
         ArrowBox[{1042, 829}, 0.13026950515838204`], 
         ArrowBox[{1043, 800}, 0.13026950515838204`], 
         ArrowBox[{1044, 835}, 0.13026950515838204`], 
         ArrowBox[{1045, 831}, 0.13026950515838204`], 
         ArrowBox[{1046, 831}, 0.13026950515838204`], 
         ArrowBox[{1047, 835}, 0.13026950515838204`], 
         ArrowBox[{1048, 835}, 0.13026950515838204`], 
         ArrowBox[{1049, 11}, 0.13026950515838204`], 
         ArrowBox[{1050, 11}, 0.13026950515838204`], 
         ArrowBox[{1051, 15}, 0.13026950515838204`], 
         ArrowBox[{1052, 15}, 0.13026950515838204`], 
         ArrowBox[{1053, 30}, 0.13026950515838204`], 
         ArrowBox[{1054, 38}, 0.13026950515838204`], 
         ArrowBox[{1055, 31}, 0.13026950515838204`], 
         ArrowBox[{1056, 41}, 0.13026950515838204`], 
         ArrowBox[{1057, 811}, 0.13026950515838204`], 
         ArrowBox[{1058, 811}, 0.13026950515838204`], 
         ArrowBox[{1059, 818}, 0.13026950515838204`], 
         ArrowBox[{1060, 818}, 0.13026950515838204`], 
         ArrowBox[{1061, 831}, 0.13026950515838204`], 
         ArrowBox[{1062, 831}, 0.13026950515838204`], 
         ArrowBox[{1063, 835}, 0.13026950515838204`], 
         ArrowBox[{1064, 835}, 0.13026950515838204`], 
         ArrowBox[{1065, 11}, 0.13026950515838204`], 
         ArrowBox[{1066, 20}, 0.13026950515838204`], 
         ArrowBox[{1067, 15}, 0.13026950515838204`], 
         ArrowBox[{1068, 52}, 0.13026950515838204`], 
         ArrowBox[{1069, 20}, 0.13026950515838204`], 
         ArrowBox[{1070, 20}, 0.13026950515838204`], 
         ArrowBox[{1071, 47}, 0.13026950515838204`], 
         ArrowBox[{1072, 47}, 0.13026950515838204`], 
         ArrowBox[{1073, 829}, 0.13026950515838204`], 
         ArrowBox[{1074, 829}, 0.13026950515838204`], 
         ArrowBox[{1075, 835}, 0.13026950515838204`], 
         ArrowBox[{1076, 835}, 0.13026950515838204`], 
         ArrowBox[{1077, 831}, 0.13026950515838204`], 
         ArrowBox[{1078, 831}, 0.13026950515838204`], 
         ArrowBox[{1079, 835}, 0.13026950515838204`], 
         ArrowBox[{1080, 835}, 0.13026950515838204`], 
         ArrowBox[{1081, 11}, 0.13026950515838204`], 
         ArrowBox[{1082, 20}, 0.13026950515838204`], 
         ArrowBox[{1083, 11}, 0.13026950515838204`], 
         ArrowBox[{1084, 20}, 0.13026950515838204`], 
         ArrowBox[{1085, 38}, 0.13026950515838204`], 
         ArrowBox[{1086, 38}, 0.13026950515838204`], 
         ArrowBox[{1087, 41}, 0.13026950515838204`], 
         ArrowBox[{1088, 41}, 0.13026950515838204`], 
         ArrowBox[{1089, 861}, 0.13026950515838204`], 
         ArrowBox[{1090, 861}, 0.13026950515838204`], 
         ArrowBox[{1091, 866}, 0.13026950515838204`], 
         ArrowBox[{1092, 866}, 0.13026950515838204`], 
         ArrowBox[{1093, 775}, 0.13026950515838204`], 
         ArrowBox[{1094, 816}, 0.13026950515838204`], 
         ArrowBox[{1095, 790}, 0.13026950515838204`], 
         ArrowBox[{1096, 828}, 0.13026950515838204`], 
         ArrowBox[{1097, 76}, 0.13026950515838204`], 
         ArrowBox[{1098, 76}, 0.13026950515838204`], 
         ArrowBox[{1099, 76}, 0.13026950515838204`], 
         ArrowBox[{1100, 76}, 0.13026950515838204`], 
         ArrowBox[{1101, 15}, 0.13026950515838204`], 
         ArrowBox[{1102, 15}, 0.13026950515838204`], 
         ArrowBox[{1103, 21}, 0.13026950515838204`], 
         ArrowBox[{1104, 21}, 0.13026950515838204`], 
         ArrowBox[{1105, 849}, 0.13026950515838204`], 
         ArrowBox[{1106, 849}, 0.13026950515838204`], 
         ArrowBox[{1107, 866}, 0.13026950515838204`], 
         ArrowBox[{1108, 866}, 0.13026950515838204`], 
         ArrowBox[{1109, 797}, 0.13026950515838204`], 
         ArrowBox[{1110, 833}, 0.13026950515838204`], 
         ArrowBox[{1111, 802}, 0.13026950515838204`], 
         ArrowBox[{1112, 837}, 0.13026950515838204`], 
         ArrowBox[{1113, 76}, 0.13026950515838204`], 
         ArrowBox[{1114, 76}, 0.13026950515838204`], 
         ArrowBox[{1115, 76}, 0.13026950515838204`], 
         ArrowBox[{1116, 76}, 0.13026950515838204`], 
         ArrowBox[{1117, 11}, 0.13026950515838204`], 
         ArrowBox[{1118, 11}, 0.13026950515838204`], 
         ArrowBox[{1119, 21}, 0.13026950515838204`], 
         ArrowBox[{1120, 21}, 0.13026950515838204`], 
         ArrowBox[{1121, 773}, 0.13026950515838204`], 
         ArrowBox[{1122, 814}, 0.13026950515838204`], 
         ArrowBox[{1123, 790}, 0.13026950515838204`], 
         ArrowBox[{1124, 828}, 0.13026950515838204`], 
         ArrowBox[{1125, 816}, 0.13026950515838204`], 
         ArrowBox[{1126, 816}, 0.13026950515838204`], 
         ArrowBox[{1127, 820}, 0.13026950515838204`], 
         ArrowBox[{1128, 820}, 0.13026950515838204`], 
         ArrowBox[{1129, 15}, 0.13026950515838204`], 
         ArrowBox[{1130, 15}, 0.13026950515838204`], 
         ArrowBox[{1131, 15}, 0.13026950515838204`], 
         ArrowBox[{1132, 15}, 0.13026950515838204`], 
         ArrowBox[{1133, 11}, 0.13026950515838204`], 
         ArrowBox[{1134, 20}, 0.13026950515838204`], 
         ArrowBox[{1135, 21}, 0.13026950515838204`], 
         ArrowBox[{1136, 22}, 0.13026950515838204`], 
         ArrowBox[{1137, 773}, 0.13026950515838204`], 
         ArrowBox[{1138, 814}, 0.13026950515838204`], 
         ArrowBox[{1139, 782}, 0.13026950515838204`], 
         ArrowBox[{1140, 820}, 0.13026950515838204`], 
         ArrowBox[{1141, 833}, 0.13026950515838204`], 
         ArrowBox[{1142, 833}, 0.13026950515838204`], 
         ArrowBox[{1143, 837}, 0.13026950515838204`], 
         ArrowBox[{1144, 837}, 0.13026950515838204`], 
         ArrowBox[{1145, 11}, 0.13026950515838204`], 
         ArrowBox[{1146, 11}, 0.13026950515838204`], 
         ArrowBox[{1147, 15}, 0.13026950515838204`], 
         ArrowBox[{1148, 15}, 0.13026950515838204`], 
         ArrowBox[{1149, 11}, 0.13026950515838204`], 
         ArrowBox[{1150, 20}, 0.13026950515838204`], 
         ArrowBox[{1151, 13}, 0.13026950515838204`], 
         ArrowBox[{1152, 47}, 0.13026950515838204`], 
         ArrowBox[{1153, 769}, 0.13026950515838204`], 
         ArrowBox[{1154, 769}, 0.13026950515838204`], 
         ArrowBox[{1155, 788}, 0.13026950515838204`], 
         ArrowBox[{1156, 788}, 0.13026950515838204`], 
         ArrowBox[{1157, 771}, 0.13026950515838204`], 
         ArrowBox[{1158, 813}, 0.13026950515838204`], 
         ArrowBox[{1159, 779}, 0.13026950515838204`], 
         ArrowBox[{1160, 818}, 0.13026950515838204`], 
         ArrowBox[{1161, 15}, 0.13026950515838204`], 
         ArrowBox[{1162, 15}, 0.13026950515838204`], 
         ArrowBox[{1163, 15}, 0.13026950515838204`], 
         ArrowBox[{1164, 15}, 0.13026950515838204`], 
         ArrowBox[{1165, 11}, 0.13026950515838204`], 
         ArrowBox[{1166, 11}, 0.13026950515838204`], 
         ArrowBox[{1167, 21}, 0.13026950515838204`], 
         ArrowBox[{1168, 21}, 0.13026950515838204`], 
         ArrowBox[{1169, 769}, 0.13026950515838204`], 
         ArrowBox[{1170, 769}, 0.13026950515838204`], 
         ArrowBox[{1171, 779}, 0.13026950515838204`], 
         ArrowBox[{1172, 779}, 0.13026950515838204`], 
         ArrowBox[{1173, 793}, 0.13026950515838204`], 
         ArrowBox[{1174, 831}, 0.13026950515838204`], 
         ArrowBox[{1175, 800}, 0.13026950515838204`], 
         ArrowBox[{1176, 835}, 0.13026950515838204`], 
         ArrowBox[{1177, 11}, 0.13026950515838204`], 
         ArrowBox[{1178, 11}, 0.13026950515838204`], 
         ArrowBox[{1179, 15}, 0.13026950515838204`], 
         ArrowBox[{1180, 15}, 0.13026950515838204`], 
         ArrowBox[{1181, 11}, 0.13026950515838204`], 
         ArrowBox[{1182, 11}, 0.13026950515838204`], 
         ArrowBox[{1183, 13}, 0.13026950515838204`], 
         ArrowBox[{1184, 13}, 0.13026950515838204`], 
         ArrowBox[{1185, 769}, 0.13026950515838204`], 
         ArrowBox[{1186, 811}, 0.13026950515838204`], 
         ArrowBox[{1187, 779}, 0.13026950515838204`], 
         ArrowBox[{1188, 818}, 0.13026950515838204`], 
         ArrowBox[{1189, 813}, 0.13026950515838204`], 
         ArrowBox[{1190, 813}, 0.13026950515838204`], 
         ArrowBox[{1191, 818}, 0.13026950515838204`], 
         ArrowBox[{1192, 818}, 0.13026950515838204`], 
         ArrowBox[{1193, 11}, 0.13026950515838204`], 
         ArrowBox[{1194, 11}, 0.13026950515838204`], 
         ArrowBox[{1195, 15}, 0.13026950515838204`], 
         ArrowBox[{1196, 15}, 0.13026950515838204`], 
         ArrowBox[{1197, 11}, 0.13026950515838204`], 
         ArrowBox[{1198, 20}, 0.13026950515838204`], 
         ArrowBox[{1199, 13}, 0.13026950515838204`], 
         ArrowBox[{1200, 47}, 0.13026950515838204`], 
         ArrowBox[{1201, 769}, 0.13026950515838204`], 
         ArrowBox[{1202, 811}, 0.13026950515838204`], 
         ArrowBox[{1203, 779}, 0.13026950515838204`], 
         ArrowBox[{1204, 818}, 0.13026950515838204`], 
         ArrowBox[{1205, 831}, 0.13026950515838204`], 
         ArrowBox[{1206, 831}, 0.13026950515838204`], 
         ArrowBox[{1207, 835}, 0.13026950515838204`], 
         ArrowBox[{1208, 835}, 0.13026950515838204`], 
         ArrowBox[{1209, 11}, 0.13026950515838204`], 
         ArrowBox[{1210, 11}, 0.13026950515838204`], 
         ArrowBox[{1211, 11}, 0.13026950515838204`], 
         ArrowBox[{1212, 11}, 0.13026950515838204`], 
         ArrowBox[{1213, 11}, 0.13026950515838204`], 
         ArrowBox[{1214, 20}, 0.13026950515838204`], 
         ArrowBox[{1215, 13}, 0.13026950515838204`], 
         ArrowBox[{1216, 47}, 0.13026950515838204`], 
         ArrowBox[{1217, 861}, 0.13026950515838204`], 
         ArrowBox[{1218, 861}, 0.13026950515838204`], 
         ArrowBox[{1219, 866}, 0.13026950515838204`], 
         ArrowBox[{1220, 866}, 0.13026950515838204`], 
         ArrowBox[{1221, 775}, 0.13026950515838204`], 
         ArrowBox[{1222, 775}, 0.13026950515838204`], 
         ArrowBox[{1223, 790}, 0.13026950515838204`], 
         ArrowBox[{1224, 790}, 0.13026950515838204`], 
         ArrowBox[{1225, 76}, 0.13026950515838204`], 
         ArrowBox[{1226, 76}, 0.13026950515838204`], 
         ArrowBox[{1227, 76}, 0.13026950515838204`], 
         ArrowBox[{1228, 76}, 0.13026950515838204`], 
         ArrowBox[{1229, 15}, 0.13026950515838204`], 
         ArrowBox[{1230, 15}, 0.13026950515838204`], 
         ArrowBox[{1231, 21}, 0.13026950515838204`], 
         ArrowBox[{1232, 21}, 0.13026950515838204`], 
         ArrowBox[{1233, 849}, 0.13026950515838204`], 
         ArrowBox[{1234, 849}, 0.13026950515838204`], 
         ArrowBox[{1235, 866}, 0.13026950515838204`], 
         ArrowBox[{1236, 866}, 0.13026950515838204`], 
         ArrowBox[{1237, 775}, 0.13026950515838204`], 
         ArrowBox[{1238, 775}, 0.13026950515838204`], 
         ArrowBox[{1239, 782}, 0.13026950515838204`], 
         ArrowBox[{1240, 782}, 0.13026950515838204`], 
         ArrowBox[{1241, 76}, 0.13026950515838204`], 
         ArrowBox[{1242, 76}, 0.13026950515838204`], 
         ArrowBox[{1243, 76}, 0.13026950515838204`], 
         ArrowBox[{1244, 76}, 0.13026950515838204`], 
         ArrowBox[{1245, 11}, 0.13026950515838204`], 
         ArrowBox[{1246, 11}, 0.13026950515838204`], 
         ArrowBox[{1247, 21}, 0.13026950515838204`], 
         ArrowBox[{1248, 21}, 0.13026950515838204`], 
         ArrowBox[{1249, 773}, 0.13026950515838204`], 
         ArrowBox[{1250, 773}, 0.13026950515838204`], 
         ArrowBox[{1251, 790}, 0.13026950515838204`], 
         ArrowBox[{1252, 790}, 0.13026950515838204`], 
         ArrowBox[{1253, 775}, 0.13026950515838204`], 
         ArrowBox[{1254, 816}, 0.13026950515838204`], 
         ArrowBox[{1255, 782}, 0.13026950515838204`], 
         ArrowBox[{1256, 820}, 0.13026950515838204`], 
         ArrowBox[{1257, 15}, 0.13026950515838204`], 
         ArrowBox[{1258, 15}, 0.13026950515838204`], 
         ArrowBox[{1259, 15}, 0.13026950515838204`], 
         ArrowBox[{1260, 15}, 0.13026950515838204`], 
         ArrowBox[{1261, 11}, 0.13026950515838204`], 
         ArrowBox[{1262, 11}, 0.13026950515838204`], 
         ArrowBox[{1263, 21}, 0.13026950515838204`], 
         ArrowBox[{1264, 21}, 0.13026950515838204`], 
         ArrowBox[{1265, 773}, 0.13026950515838204`], 
         ArrowBox[{1266, 773}, 0.13026950515838204`], 
         ArrowBox[{1267, 782}, 0.13026950515838204`], 
         ArrowBox[{1268, 782}, 0.13026950515838204`], 
         ArrowBox[{1269, 775}, 0.13026950515838204`], 
         ArrowBox[{1270, 816}, 0.13026950515838204`], 
         ArrowBox[{1271, 782}, 0.13026950515838204`], 
         ArrowBox[{1272, 820}, 0.13026950515838204`], 
         ArrowBox[{1273, 11}, 0.13026950515838204`], 
         ArrowBox[{1274, 11}, 0.13026950515838204`], 
         ArrowBox[{1275, 15}, 0.13026950515838204`], 
         ArrowBox[{1276, 15}, 0.13026950515838204`], 
         ArrowBox[{1277, 11}, 0.13026950515838204`], 
         ArrowBox[{1278, 11}, 0.13026950515838204`], 
         ArrowBox[{1279, 13}, 0.13026950515838204`], 
         ArrowBox[{1280, 13}, 0.13026950515838204`], 
         ArrowBox[{1281, 846}, 0.13026950515838204`], 
         ArrowBox[{1282, 888}, 0.13026950515838204`], 
         ArrowBox[{1283, 864}, 0.13026950515838204`], 
         ArrowBox[{1284, 904}, 0.13026950515838204`], 
         ArrowBox[{1285, 831}, 0.13026950515838204`], 
         ArrowBox[{1286, 831}, 0.13026950515838204`], 
         ArrowBox[{1287, 835}, 0.13026950515838204`], 
         ArrowBox[{1288, 835}, 0.13026950515838204`], 
         ArrowBox[{1289, 344}, 0.13026950515838204`], 
         ArrowBox[{1290, 344}, 0.13026950515838204`], 
         ArrowBox[{1291, 344}, 0.13026950515838204`], 
         ArrowBox[{1292, 344}, 0.13026950515838204`], 
         ArrowBox[{1293, 268}, 0.13026950515838204`], 
         ArrowBox[{1294, 305}, 0.13026950515838204`], 
         ArrowBox[{1295, 278}, 0.13026950515838204`], 
         ArrowBox[{1296, 314}, 0.13026950515838204`], 
         ArrowBox[{1297, 867}, 0.13026950515838204`], 
         ArrowBox[{1298, 907}, 0.13026950515838204`], 
         ArrowBox[{1299, 874}, 0.13026950515838204`], 
         ArrowBox[{1300, 915}, 0.13026950515838204`], 
         ArrowBox[{1301, 831}, 0.13026950515838204`], 
         ArrowBox[{1302, 831}, 0.13026950515838204`], 
         ArrowBox[{1303, 835}, 0.13026950515838204`], 
         ArrowBox[{1304, 835}, 0.13026950515838204`], 
         ArrowBox[{1305, 337}, 0.13026950515838204`], 
         ArrowBox[{1306, 337}, 0.13026950515838204`], 
         ArrowBox[{1307, 344}, 0.13026950515838204`], 
         ArrowBox[{1308, 344}, 0.13026950515838204`], 
         ArrowBox[{1309, 289}, 0.13026950515838204`], 
         ArrowBox[{1310, 319}, 0.13026950515838204`], 
         ArrowBox[{1311, 290}, 0.13026950515838204`], 
         ArrowBox[{1312, 320}, 0.13026950515838204`], 
         ArrowBox[{1313, 811}, 0.13026950515838204`], 
         ArrowBox[{1314, 811}, 0.13026950515838204`], 
         ArrowBox[{1315, 818}, 0.13026950515838204`], 
         ArrowBox[{1316, 818}, 0.13026950515838204`], 
         ArrowBox[{1317, 831}, 0.13026950515838204`], 
         ArrowBox[{1318, 831}, 0.13026950515838204`], 
         ArrowBox[{1319, 835}, 0.13026950515838204`], 
         ArrowBox[{1320, 835}, 0.13026950515838204`], 
         ArrowBox[{1321, 268}, 0.13026950515838204`], 
         ArrowBox[{1322, 305}, 0.13026950515838204`], 
         ArrowBox[{1323, 277}, 0.13026950515838204`], 
         ArrowBox[{1324, 313}, 0.13026950515838204`], 
         ArrowBox[{1325, 305}, 0.13026950515838204`], 
         ArrowBox[{1326, 305}, 0.13026950515838204`], 
         ArrowBox[{1327, 306}, 0.13026950515838204`], 
         ArrowBox[{1328, 306}, 0.13026950515838204`], 
         ArrowBox[{1329, 829}, 0.13026950515838204`], 
         ArrowBox[{1330, 829}, 0.13026950515838204`], 
         ArrowBox[{1331, 835}, 0.13026950515838204`], 
         ArrowBox[{1332, 835}, 0.13026950515838204`], 
         ArrowBox[{1333, 831}, 0.13026950515838204`], 
         ArrowBox[{1334, 831}, 0.13026950515838204`], 
         ArrowBox[{1335, 835}, 0.13026950515838204`], 
         ArrowBox[{1336, 835}, 0.13026950515838204`], 
         ArrowBox[{1337, 268}, 0.13026950515838204`], 
         ArrowBox[{1338, 305}, 0.13026950515838204`], 
         ArrowBox[{1339, 268}, 0.13026950515838204`], 
         ArrowBox[{1340, 305}, 0.13026950515838204`], 
         ArrowBox[{1341, 319}, 0.13026950515838204`], 
         ArrowBox[{1342, 319}, 0.13026950515838204`], 
         ArrowBox[{1343, 320}, 0.13026950515838204`], 
         ArrowBox[{1344, 320}, 0.13026950515838204`], 
         ArrowBox[{1345, 861}, 0.13026950515838204`], 
         ArrowBox[{1346, 861}, 0.13026950515838204`], 
         ArrowBox[{1347, 866}, 0.13026950515838204`], 
         ArrowBox[{1348, 866}, 0.13026950515838204`], 
         ArrowBox[{1349, 851}, 0.13026950515838204`], 
         ArrowBox[{1350, 892}, 0.13026950515838204`], 
         ArrowBox[{1351, 866}, 0.13026950515838204`], 
         ArrowBox[{1352, 906}, 0.13026950515838204`], 
         ArrowBox[{1353, 344}, 0.13026950515838204`], 
         ArrowBox[{1354, 344}, 0.13026950515838204`], 
         ArrowBox[{1355, 344}, 0.13026950515838204`], 
         ArrowBox[{1356, 344}, 0.13026950515838204`], 
         ArrowBox[{1357, 344}, 0.13026950515838204`], 
         ArrowBox[{1358, 344}, 0.13026950515838204`], 
         ArrowBox[{1359, 332}, 0.13026950515838204`], 
         ArrowBox[{1360, 332}, 0.13026950515838204`], 
         ArrowBox[{1361, 849}, 0.13026950515838204`], 
         ArrowBox[{1362, 849}, 0.13026950515838204`], 
         ArrowBox[{1363, 866}, 0.13026950515838204`], 
         ArrowBox[{1364, 866}, 0.13026950515838204`], 
         ArrowBox[{1365, 871}, 0.13026950515838204`], 
         ArrowBox[{1366, 911}, 0.13026950515838204`], 
         ArrowBox[{1367, 878}, 0.13026950515838204`], 
         ArrowBox[{1368, 918}, 0.13026950515838204`], 
         ArrowBox[{1369, 344}, 0.13026950515838204`], 
         ArrowBox[{1370, 344}, 0.13026950515838204`], 
         ArrowBox[{1371, 344}, 0.13026950515838204`], 
         ArrowBox[{1372, 344}, 0.13026950515838204`], 
         ArrowBox[{1373, 337}, 0.13026950515838204`], 
         ArrowBox[{1374, 337}, 0.13026950515838204`], 
         ArrowBox[{1375, 332}, 0.13026950515838204`], 
         ArrowBox[{1376, 332}, 0.13026950515838204`], 
         ArrowBox[{1377, 849}, 0.13026950515838204`], 
         ArrowBox[{1378, 891}, 0.13026950515838204`], 
         ArrowBox[{1379, 866}, 0.13026950515838204`], 
         ArrowBox[{1380, 906}, 0.13026950515838204`], 
         ArrowBox[{1381, 816}, 0.13026950515838204`], 
         ArrowBox[{1382, 816}, 0.13026950515838204`], 
         ArrowBox[{1383, 820}, 0.13026950515838204`], 
         ArrowBox[{1384, 820}, 0.13026950515838204`], 
         ArrowBox[{1385, 344}, 0.13026950515838204`], 
         ArrowBox[{1386, 344}, 0.13026950515838204`], 
         ArrowBox[{1387, 344}, 0.13026950515838204`], 
         ArrowBox[{1388, 344}, 0.13026950515838204`], 
         ArrowBox[{1389, 268}, 0.13026950515838204`], 
         ArrowBox[{1390, 305}, 0.13026950515838204`], 
         ArrowBox[{1391, 278}, 0.13026950515838204`], 
         ArrowBox[{1392, 314}, 0.13026950515838204`], 
         ArrowBox[{1393, 849}, 0.13026950515838204`], 
         ArrowBox[{1394, 891}, 0.13026950515838204`], 
         ArrowBox[{1395, 857}, 0.13026950515838204`], 
         ArrowBox[{1396, 898}, 0.13026950515838204`], 
         ArrowBox[{1397, 833}, 0.13026950515838204`], 
         ArrowBox[{1398, 833}, 0.13026950515838204`], 
         ArrowBox[{1399, 837}, 0.13026950515838204`], 
         ArrowBox[{1400, 837}, 0.13026950515838204`], 
         ArrowBox[{1401, 337}, 0.13026950515838204`], 
         ArrowBox[{1402, 337}, 0.13026950515838204`], 
         ArrowBox[{1403, 344}, 0.13026950515838204`], 
         ArrowBox[{1404, 344}, 0.13026950515838204`], 
         ArrowBox[{1405, 268}, 0.13026950515838204`], 
         ArrowBox[{1406, 305}, 0.13026950515838204`], 
         ArrowBox[{1407, 270}, 0.13026950515838204`], 
         ArrowBox[{1408, 306}, 0.13026950515838204`], 
         ArrowBox[{1409, 846}, 0.13026950515838204`], 
         ArrowBox[{1410, 846}, 0.13026950515838204`], 
         ArrowBox[{1411, 864}, 0.13026950515838204`], 
         ArrowBox[{1412, 864}, 0.13026950515838204`], 
         ArrowBox[{1413, 771}, 0.13026950515838204`], 
         ArrowBox[{1414, 813}, 0.13026950515838204`], 
         ArrowBox[{1415, 779}, 0.13026950515838204`], 
         ArrowBox[{1416, 818}, 0.13026950515838204`], 
         ArrowBox[{1417, 344}, 0.13026950515838204`], 
         ArrowBox[{1418, 344}, 0.13026950515838204`], 
         ArrowBox[{1419, 344}, 0.13026950515838204`], 
         ArrowBox[{1420, 344}, 0.13026950515838204`], 
         ArrowBox[{1421, 268}, 0.13026950515838204`], 
         ArrowBox[{1422, 268}, 0.13026950515838204`], 
         ArrowBox[{1423, 278}, 0.13026950515838204`], 
         ArrowBox[{1424, 278}, 0.13026950515838204`], 
         ArrowBox[{1425, 846}, 0.13026950515838204`], 
         ArrowBox[{1426, 846}, 0.13026950515838204`], 
         ArrowBox[{1427, 854}, 0.13026950515838204`], 
         ArrowBox[{1428, 854}, 0.13026950515838204`], 
         ArrowBox[{1429, 793}, 0.13026950515838204`], 
         ArrowBox[{1430, 831}, 0.13026950515838204`], 
         ArrowBox[{1431, 800}, 0.13026950515838204`], 
         ArrowBox[{1432, 835}, 0.13026950515838204`], 
         ArrowBox[{1433, 337}, 0.13026950515838204`], 
         ArrowBox[{1434, 337}, 0.13026950515838204`], 
         ArrowBox[{1435, 344}, 0.13026950515838204`], 
         ArrowBox[{1436, 344}, 0.13026950515838204`], 
         ArrowBox[{1437, 268}, 0.13026950515838204`], 
         ArrowBox[{1438, 268}, 0.13026950515838204`], 
         ArrowBox[{1439, 270}, 0.13026950515838204`], 
         ArrowBox[{1440, 270}, 0.13026950515838204`], 
         ArrowBox[{1441, 769}, 0.13026950515838204`], 
         ArrowBox[{1442, 811}, 0.13026950515838204`], 
         ArrowBox[{1443, 779}, 0.13026950515838204`], 
         ArrowBox[{1444, 818}, 0.13026950515838204`], 
         ArrowBox[{1445, 813}, 0.13026950515838204`], 
         ArrowBox[{1446, 813}, 0.13026950515838204`], 
         ArrowBox[{1447, 818}, 0.13026950515838204`], 
         ArrowBox[{1448, 818}, 0.13026950515838204`], 
         ArrowBox[{1449, 268}, 0.13026950515838204`], 
         ArrowBox[{1450, 268}, 0.13026950515838204`], 
         ArrowBox[{1451, 277}, 0.13026950515838204`], 
         ArrowBox[{1452, 277}, 0.13026950515838204`], 
         ArrowBox[{1453, 268}, 0.13026950515838204`], 
         ArrowBox[{1454, 305}, 0.13026950515838204`], 
         ArrowBox[{1455, 270}, 0.13026950515838204`], 
         ArrowBox[{1456, 306}, 0.13026950515838204`], 
         ArrowBox[{1457, 769}, 0.13026950515838204`], 
         ArrowBox[{1458, 811}, 0.13026950515838204`], 
         ArrowBox[{1459, 779}, 0.13026950515838204`], 
         ArrowBox[{1460, 818}, 0.13026950515838204`], 
         ArrowBox[{1461, 831}, 0.13026950515838204`], 
         ArrowBox[{1462, 831}, 0.13026950515838204`], 
         ArrowBox[{1463, 835}, 0.13026950515838204`], 
         ArrowBox[{1464, 835}, 0.13026950515838204`], 
         ArrowBox[{1465, 268}, 0.13026950515838204`], 
         ArrowBox[{1466, 268}, 0.13026950515838204`], 
         ArrowBox[{1467, 268}, 0.13026950515838204`], 
         ArrowBox[{1468, 268}, 0.13026950515838204`], 
         ArrowBox[{1469, 268}, 0.13026950515838204`], 
         ArrowBox[{1470, 305}, 0.13026950515838204`], 
         ArrowBox[{1471, 270}, 0.13026950515838204`], 
         ArrowBox[{1472, 306}, 0.13026950515838204`], 
         ArrowBox[{1473, 861}, 0.13026950515838204`], 
         ArrowBox[{1474, 861}, 0.13026950515838204`], 
         ArrowBox[{1475, 866}, 0.13026950515838204`], 
         ArrowBox[{1476, 866}, 0.13026950515838204`], 
         ArrowBox[{1477, 851}, 0.13026950515838204`], 
         ArrowBox[{1478, 851}, 0.13026950515838204`], 
         ArrowBox[{1479, 866}, 0.13026950515838204`], 
         ArrowBox[{1480, 866}, 0.13026950515838204`], 
         ArrowBox[{1481, 344}, 0.13026950515838204`], 
         ArrowBox[{1482, 344}, 0.13026950515838204`], 
         ArrowBox[{1483, 344}, 0.13026950515838204`], 
         ArrowBox[{1484, 344}, 0.13026950515838204`], 
         ArrowBox[{1485, 344}, 0.13026950515838204`], 
         ArrowBox[{1486, 344}, 0.13026950515838204`], 
         ArrowBox[{1487, 332}, 0.13026950515838204`], 
         ArrowBox[{1488, 332}, 0.13026950515838204`], 
         ArrowBox[{1489, 849}, 0.13026950515838204`], 
         ArrowBox[{1490, 849}, 0.13026950515838204`], 
         ArrowBox[{1491, 866}, 0.13026950515838204`], 
         ArrowBox[{1492, 866}, 0.13026950515838204`], 
         ArrowBox[{1493, 851}, 0.13026950515838204`], 
         ArrowBox[{1494, 851}, 0.13026950515838204`], 
         ArrowBox[{1495, 857}, 0.13026950515838204`], 
         ArrowBox[{1496, 857}, 0.13026950515838204`], 
         ArrowBox[{1497, 344}, 0.13026950515838204`], 
         ArrowBox[{1498, 344}, 0.13026950515838204`], 
         ArrowBox[{1499, 344}, 0.13026950515838204`], 
         ArrowBox[{1500, 344}, 0.13026950515838204`], 
         ArrowBox[{1501, 337}, 0.13026950515838204`], 
         ArrowBox[{1502, 337}, 0.13026950515838204`], 
         ArrowBox[{1503, 332}, 0.13026950515838204`], 
         ArrowBox[{1504, 332}, 0.13026950515838204`], 
         ArrowBox[{1505, 849}, 0.13026950515838204`], 
         ArrowBox[{1506, 849}, 0.13026950515838204`], 
         ArrowBox[{1507, 866}, 0.13026950515838204`], 
         ArrowBox[{1508, 866}, 0.13026950515838204`], 
         ArrowBox[{1509, 775}, 0.13026950515838204`], 
         ArrowBox[{1510, 816}, 0.13026950515838204`], 
         ArrowBox[{1511, 782}, 0.13026950515838204`], 
         ArrowBox[{1512, 820}, 0.13026950515838204`], 
         ArrowBox[{1513, 344}, 0.13026950515838204`], 
         ArrowBox[{1514, 344}, 0.13026950515838204`], 
         ArrowBox[{1515, 344}, 0.13026950515838204`], 
         ArrowBox[{1516, 344}, 0.13026950515838204`], 
         ArrowBox[{1517, 268}, 0.13026950515838204`], 
         ArrowBox[{1518, 268}, 0.13026950515838204`], 
         ArrowBox[{1519, 278}, 0.13026950515838204`], 
         ArrowBox[{1520, 278}, 0.13026950515838204`], 
         ArrowBox[{1521, 849}, 0.13026950515838204`], 
         ArrowBox[{1522, 849}, 0.13026950515838204`], 
         ArrowBox[{1523, 857}, 0.13026950515838204`], 
         ArrowBox[{1524, 857}, 0.13026950515838204`], 
         ArrowBox[{1525, 775}, 0.13026950515838204`], 
         ArrowBox[{1526, 816}, 0.13026950515838204`], 
         ArrowBox[{1527, 782}, 0.13026950515838204`], 
         ArrowBox[{1528, 820}, 0.13026950515838204`], 
         ArrowBox[{1529, 337}, 0.13026950515838204`], 
         ArrowBox[{1530, 337}, 0.13026950515838204`], 
         ArrowBox[{1531, 344}, 0.13026950515838204`], 
         ArrowBox[{1532, 344}, 0.13026950515838204`], 
         ArrowBox[{1533, 268}, 0.13026950515838204`], 
         ArrowBox[{1534, 268}, 0.13026950515838204`], 
         ArrowBox[{1535, 270}, 0.13026950515838204`], 
         ArrowBox[{1536, 270}, 0.13026950515838204`], 
         ArrowBox[{1537, 927}, 0.13026950515838204`], 
         ArrowBox[{1538, 812}, 0.13026950515838204`], 
         ArrowBox[{1539, 941}, 0.13026950515838204`], 
         ArrowBox[{1540, 969}, 0.13026950515838204`], 
         ArrowBox[{1541, 778}, 0.13026950515838204`], 
         ArrowBox[{1542, 778}, 0.13026950515838204`], 
         ArrowBox[{1543, 781}, 0.13026950515838204`], 
         ArrowBox[{1544, 781}, 0.13026950515838204`], 
         ArrowBox[{1545, 676}, 0.13026950515838204`], 
         ArrowBox[{1546, 676}, 0.13026950515838204`], 
         ArrowBox[{1547, 676}, 0.13026950515838204`], 
         ArrowBox[{1548, 676}, 0.13026950515838204`], 
         ArrowBox[{1549, 670}, 0.13026950515838204`], 
         ArrowBox[{1550, 690}, 0.13026950515838204`], 
         ArrowBox[{1551, 598}, 0.13026950515838204`], 
         ArrowBox[{1552, 600}, 0.13026950515838204`], 
         ArrowBox[{1553, 944}, 0.13026950515838204`], 
         ArrowBox[{1554, 830}, 0.13026950515838204`], 
         ArrowBox[{1555, 950}, 0.13026950515838204`], 
         ArrowBox[{1556, 781}, 0.13026950515838204`], 
         ArrowBox[{1557, 778}, 0.13026950515838204`], 
         ArrowBox[{1558, 778}, 0.13026950515838204`], 
         ArrowBox[{1559, 781}, 0.13026950515838204`], 
         ArrowBox[{1560, 781}, 0.13026950515838204`], 
         ArrowBox[{1561, 670}, 0.13026950515838204`], 
         ArrowBox[{1562, 670}, 0.13026950515838204`], 
         ArrowBox[{1563, 676}, 0.13026950515838204`], 
         ArrowBox[{1564, 676}, 0.13026950515838204`], 
         ArrowBox[{1565, 680}, 0.13026950515838204`], 
         ArrowBox[{1566, 699}, 0.13026950515838204`], 
         ArrowBox[{1567, 619}, 0.13026950515838204`], 
         ArrowBox[{1568, 621}, 0.13026950515838204`], 
         ArrowBox[{1569, 812}, 0.13026950515838204`], 
         ArrowBox[{1570, 812}, 0.13026950515838204`], 
         ArrowBox[{1571, 815}, 0.13026950515838204`], 
         ArrowBox[{1572, 815}, 0.13026950515838204`], 
         ArrowBox[{1573, 778}, 0.13026950515838204`], 
         ArrowBox[{1574, 778}, 0.13026950515838204`], 
         ArrowBox[{1575, 781}, 0.13026950515838204`], 
         ArrowBox[{1576, 781}, 0.13026950515838204`], 
         ArrowBox[{1577, 670}, 0.13026950515838204`], 
         ArrowBox[{1578, 690}, 0.13026950515838204`], 
         ArrowBox[{1579, 676}, 0.13026950515838204`], 
         ArrowBox[{1580, 696}, 0.13026950515838204`], 
         ArrowBox[{1581, 690}, 0.13026950515838204`], 
         ArrowBox[{1582, 690}, 0.13026950515838204`], 
         ArrowBox[{1583, 639}, 0.13026950515838204`], 
         ArrowBox[{1584, 639}, 0.13026950515838204`], 
         ArrowBox[{1585, 830}, 0.13026950515838204`], 
         ArrowBox[{1586, 830}, 0.13026950515838204`], 
         ArrowBox[{1587, 781}, 0.13026950515838204`], 
         ArrowBox[{1588, 781}, 0.13026950515838204`], 
         ArrowBox[{1589, 778}, 0.13026950515838204`], 
         ArrowBox[{1590, 778}, 0.13026950515838204`], 
         ArrowBox[{1591, 781}, 0.13026950515838204`], 
         ArrowBox[{1592, 781}, 0.13026950515838204`], 
         ArrowBox[{1593, 670}, 0.13026950515838204`], 
         ArrowBox[{1594, 690}, 0.13026950515838204`], 
         ArrowBox[{1595, 670}, 0.13026950515838204`], 
         ArrowBox[{1596, 690}, 0.13026950515838204`], 
         ArrowBox[{1597, 699}, 0.13026950515838204`], 
         ArrowBox[{1598, 699}, 0.13026950515838204`], 
         ArrowBox[{1599, 621}, 0.13026950515838204`], 
         ArrowBox[{1600, 621}, 0.13026950515838204`], 
         ArrowBox[{1601, 847}, 0.13026950515838204`], 
         ArrowBox[{1602, 847}, 0.13026950515838204`], 
         ArrowBox[{1603, 850}, 0.13026950515838204`], 
         ArrowBox[{1604, 850}, 0.13026950515838204`], 
         ArrowBox[{1605, 930}, 0.13026950515838204`], 
         ArrowBox[{1606, 894}, 0.13026950515838204`], 
         ArrowBox[{1607, 943}, 0.13026950515838204`], 
         ArrowBox[{1608, 971}, 0.13026950515838204`], 
         ArrowBox[{1609, 720}, 0.13026950515838204`], 
         ArrowBox[{1610, 720}, 0.13026950515838204`], 
         ArrowBox[{1611, 720}, 0.13026950515838204`], 
         ArrowBox[{1612, 720}, 0.13026950515838204`], 
         ArrowBox[{1613, 676}, 0.13026950515838204`], 
         ArrowBox[{1614, 676}, 0.13026950515838204`], 
         ArrowBox[{1615, 598}, 0.13026950515838204`], 
         ArrowBox[{1616, 598}, 0.13026950515838204`], 
         ArrowBox[{1617, 868}, 0.13026950515838204`], 
         ArrowBox[{1618, 868}, 0.13026950515838204`], 
         ArrowBox[{1619, 850}, 0.13026950515838204`], 
         ArrowBox[{1620, 850}, 0.13026950515838204`], 
         ArrowBox[{1621, 948}, 0.13026950515838204`], 
         ArrowBox[{1622, 914}, 0.13026950515838204`], 
         ArrowBox[{1623, 952}, 0.13026950515838204`], 
         ArrowBox[{1624, 917}, 0.13026950515838204`], 
         ArrowBox[{1625, 720}, 0.13026950515838204`], 
         ArrowBox[{1626, 720}, 0.13026950515838204`], 
         ArrowBox[{1627, 720}, 0.13026950515838204`], 
         ArrowBox[{1628, 720}, 0.13026950515838204`], 
         ArrowBox[{1629, 670}, 0.13026950515838204`], 
         ArrowBox[{1630, 670}, 0.13026950515838204`], 
         ArrowBox[{1631, 598}, 0.13026950515838204`], 
         ArrowBox[{1632, 598}, 0.13026950515838204`], 
         ArrowBox[{1633, 929}, 0.13026950515838204`], 
         ArrowBox[{1634, 961}, 0.13026950515838204`], 
         ArrowBox[{1635, 943}, 0.13026950515838204`], 
         ArrowBox[{1636, 971}, 0.13026950515838204`], 
         ArrowBox[{1637, 894}, 0.13026950515838204`], 
         ArrowBox[{1638, 894}, 0.13026950515838204`], 
         ArrowBox[{1639, 897}, 0.13026950515838204`], 
         ArrowBox[{1640, 897}, 0.13026950515838204`], 
         ArrowBox[{1641, 676}, 0.13026950515838204`], 
         ArrowBox[{1642, 676}, 0.13026950515838204`], 
         ArrowBox[{1643, 676}, 0.13026950515838204`], 
         ArrowBox[{1644, 676}, 0.13026950515838204`], 
         ArrowBox[{1645, 670}, 0.13026950515838204`], 
         ArrowBox[{1646, 690}, 0.13026950515838204`], 
         ArrowBox[{1647, 598}, 0.13026950515838204`], 
         ArrowBox[{1648, 600}, 0.13026950515838204`], 
         ArrowBox[{1649, 929}, 0.13026950515838204`], 
         ArrowBox[{1650, 961}, 0.13026950515838204`], 
         ArrowBox[{1651, 935}, 0.13026950515838204`], 
         ArrowBox[{1652, 897}, 0.13026950515838204`], 
         ArrowBox[{1653, 914}, 0.13026950515838204`], 
         ArrowBox[{1654, 914}, 0.13026950515838204`], 
         ArrowBox[{1655, 917}, 0.13026950515838204`], 
         ArrowBox[{1656, 917}, 0.13026950515838204`], 
         ArrowBox[{1657, 670}, 0.13026950515838204`], 
         ArrowBox[{1658, 670}, 0.13026950515838204`], 
         ArrowBox[{1659, 676}, 0.13026950515838204`], 
         ArrowBox[{1660, 676}, 0.13026950515838204`], 
         ArrowBox[{1661, 670}, 0.13026950515838204`], 
         ArrowBox[{1662, 690}, 0.13026950515838204`], 
         ArrowBox[{1663, 652}, 0.13026950515838204`], 
         ArrowBox[{1664, 639}, 0.13026950515838204`], 
         ArrowBox[{1665, 927}, 0.13026950515838204`], 
         ArrowBox[{1666, 927}, 0.13026950515838204`], 
         ArrowBox[{1667, 941}, 0.13026950515838204`], 
         ArrowBox[{1668, 941}, 0.13026950515838204`], 
         ArrowBox[{1669, 928}, 0.13026950515838204`], 
         ArrowBox[{1670, 933}, 0.13026950515838204`], 
         ArrowBox[{1671, 932}, 0.13026950515838204`], 
         ArrowBox[{1672, 815}, 0.13026950515838204`], 
         ArrowBox[{1673, 676}, 0.13026950515838204`], 
         ArrowBox[{1674, 676}, 0.13026950515838204`], 
         ArrowBox[{1675, 676}, 0.13026950515838204`], 
         ArrowBox[{1676, 676}, 0.13026950515838204`], 
         ArrowBox[{1677, 670}, 0.13026950515838204`], 
         ArrowBox[{1678, 670}, 0.13026950515838204`], 
         ArrowBox[{1679, 598}, 0.13026950515838204`], 
         ArrowBox[{1680, 598}, 0.13026950515838204`], 
         ArrowBox[{1681, 927}, 0.13026950515838204`], 
         ArrowBox[{1682, 927}, 0.13026950515838204`], 
         ArrowBox[{1683, 932}, 0.13026950515838204`], 
         ArrowBox[{1684, 932}, 0.13026950515838204`], 
         ArrowBox[{1685, 945}, 0.13026950515838204`], 
         ArrowBox[{1686, 778}, 0.13026950515838204`], 
         ArrowBox[{1687, 950}, 0.13026950515838204`], 
         ArrowBox[{1688, 781}, 0.13026950515838204`], 
         ArrowBox[{1689, 670}, 0.13026950515838204`], 
         ArrowBox[{1690, 670}, 0.13026950515838204`], 
         ArrowBox[{1691, 676}, 0.13026950515838204`], 
         ArrowBox[{1692, 676}, 0.13026950515838204`], 
         ArrowBox[{1693, 670}, 0.13026950515838204`], 
         ArrowBox[{1694, 670}, 0.13026950515838204`], 
         ArrowBox[{1695, 652}, 0.13026950515838204`], 
         ArrowBox[{1696, 652}, 0.13026950515838204`], 
         ArrowBox[{1697, 927}, 0.13026950515838204`], 
         ArrowBox[{1698, 812}, 0.13026950515838204`], 
         ArrowBox[{1699, 932}, 0.13026950515838204`], 
         ArrowBox[{1700, 815}, 0.13026950515838204`], 
         ArrowBox[{1701, 933}, 0.13026950515838204`], 
         ArrowBox[{1702, 933}, 0.13026950515838204`], 
         ArrowBox[{1703, 815}, 0.13026950515838204`], 
         ArrowBox[{1704, 815}, 0.13026950515838204`], 
         ArrowBox[{1705, 670}, 0.13026950515838204`], 
         ArrowBox[{1706, 670}, 0.13026950515838204`], 
         ArrowBox[{1707, 676}, 0.13026950515838204`], 
         ArrowBox[{1708, 676}, 0.13026950515838204`], 
         ArrowBox[{1709, 670}, 0.13026950515838204`], 
         ArrowBox[{1710, 690}, 0.13026950515838204`], 
         ArrowBox[{1711, 652}, 0.13026950515838204`], 
         ArrowBox[{1712, 639}, 0.13026950515838204`], 
         ArrowBox[{1713, 927}, 0.13026950515838204`], 
         ArrowBox[{1714, 812}, 0.13026950515838204`], 
         ArrowBox[{1715, 932}, 0.13026950515838204`], 
         ArrowBox[{1716, 815}, 0.13026950515838204`], 
         ArrowBox[{1717, 778}, 0.13026950515838204`], 
         ArrowBox[{1718, 778}, 0.13026950515838204`], 
         ArrowBox[{1719, 781}, 0.13026950515838204`], 
         ArrowBox[{1720, 781}, 0.13026950515838204`], 
         ArrowBox[{1721, 670}, 0.13026950515838204`], 
         ArrowBox[{1722, 670}, 0.13026950515838204`], 
         ArrowBox[{1723, 670}, 0.13026950515838204`], 
         ArrowBox[{1724, 670}, 0.13026950515838204`], 
         ArrowBox[{1725, 670}, 0.13026950515838204`], 
         ArrowBox[{1726, 690}, 0.13026950515838204`], 
         ArrowBox[{1727, 652}, 0.13026950515838204`], 
         ArrowBox[{1728, 639}, 0.13026950515838204`], 
         ArrowBox[{1729, 847}, 0.13026950515838204`], 
         ArrowBox[{1730, 847}, 0.13026950515838204`], 
         ArrowBox[{1731, 850}, 0.13026950515838204`], 
         ArrowBox[{1732, 850}, 0.13026950515838204`], 
         ArrowBox[{1733, 930}, 0.13026950515838204`], 
         ArrowBox[{1734, 930}, 0.13026950515838204`], 
         ArrowBox[{1735, 943}, 0.13026950515838204`], 
         ArrowBox[{1736, 943}, 0.13026950515838204`], 
         ArrowBox[{1737, 720}, 0.13026950515838204`], 
         ArrowBox[{1738, 720}, 0.13026950515838204`], 
         ArrowBox[{1739, 720}, 0.13026950515838204`], 
         ArrowBox[{1740, 720}, 0.13026950515838204`], 
         ArrowBox[{1741, 676}, 0.13026950515838204`], 
         ArrowBox[{1742, 676}, 0.13026950515838204`], 
         ArrowBox[{1743, 598}, 0.13026950515838204`], 
         ArrowBox[{1744, 598}, 0.13026950515838204`], 
         ArrowBox[{1745, 868}, 0.13026950515838204`], 
         ArrowBox[{1746, 868}, 0.13026950515838204`], 
         ArrowBox[{1747, 850}, 0.13026950515838204`], 
         ArrowBox[{1748, 850}, 0.13026950515838204`], 
         ArrowBox[{1749, 930}, 0.13026950515838204`], 
         ArrowBox[{1750, 930}, 0.13026950515838204`], 
         ArrowBox[{1751, 935}, 0.13026950515838204`], 
         ArrowBox[{1752, 935}, 0.13026950515838204`], 
         ArrowBox[{1753, 720}, 0.13026950515838204`], 
         ArrowBox[{1754, 720}, 0.13026950515838204`], 
         ArrowBox[{1755, 720}, 0.13026950515838204`], 
         ArrowBox[{1756, 720}, 0.13026950515838204`], 
         ArrowBox[{1757, 670}, 0.13026950515838204`], 
         ArrowBox[{1758, 670}, 0.13026950515838204`], 
         ArrowBox[{1759, 598}, 0.13026950515838204`], 
         ArrowBox[{1760, 598}, 0.13026950515838204`], 
         ArrowBox[{1761, 929}, 0.13026950515838204`], 
         ArrowBox[{1762, 929}, 0.13026950515838204`], 
         ArrowBox[{1763, 943}, 0.13026950515838204`], 
         ArrowBox[{1764, 943}, 0.13026950515838204`], 
         ArrowBox[{1765, 930}, 0.13026950515838204`], 
         ArrowBox[{1766, 894}, 0.13026950515838204`], 
         ArrowBox[{1767, 935}, 0.13026950515838204`], 
         ArrowBox[{1768, 897}, 0.13026950515838204`], 
         ArrowBox[{1769, 676}, 0.13026950515838204`], 
         ArrowBox[{1770, 676}, 0.13026950515838204`], 
         ArrowBox[{1771, 676}, 0.13026950515838204`], 
         ArrowBox[{1772, 676}, 0.13026950515838204`], 
         ArrowBox[{1773, 670}, 0.13026950515838204`], 
         ArrowBox[{1774, 670}, 0.13026950515838204`], 
         ArrowBox[{1775, 598}, 0.13026950515838204`], 
         ArrowBox[{1776, 598}, 0.13026950515838204`], 
         ArrowBox[{1777, 929}, 0.13026950515838204`], 
         ArrowBox[{1778, 929}, 0.13026950515838204`], 
         ArrowBox[{1779, 935}, 0.13026950515838204`], 
         ArrowBox[{1780, 935}, 0.13026950515838204`], 
         ArrowBox[{1781, 930}, 0.13026950515838204`], 
         ArrowBox[{1782, 894}, 0.13026950515838204`], 
         ArrowBox[{1783, 935}, 0.13026950515838204`], 
         ArrowBox[{1784, 897}, 0.13026950515838204`], 
         ArrowBox[{1785, 670}, 0.13026950515838204`], 
         ArrowBox[{1786, 670}, 0.13026950515838204`], 
         ArrowBox[{1787, 676}, 0.13026950515838204`], 
         ArrowBox[{1788, 676}, 0.13026950515838204`], 
         ArrowBox[{1789, 670}, 0.13026950515838204`], 
         ArrowBox[{1790, 670}, 0.13026950515838204`], 
         ArrowBox[{1791, 652}, 0.13026950515838204`], 
         ArrowBox[{1792, 652}, 0.13026950515838204`], 
         ArrowBox[{1793, 770}, 0.13026950515838204`], 
         ArrowBox[{1794, 772}, 0.13026950515838204`], 
         ArrowBox[{1795, 774}, 0.13026950515838204`], 
         ArrowBox[{1796, 776}, 0.13026950515838204`], 
         ArrowBox[{1797, 778}, 0.13026950515838204`], 
         ArrowBox[{1798, 778}, 0.13026950515838204`], 
         ArrowBox[{1799, 781}, 0.13026950515838204`], 
         ArrowBox[{1800, 781}, 0.13026950515838204`], 
         ArrowBox[{1801, 990}, 0.13026950515838204`], 
         ArrowBox[{1802, 990}, 0.13026950515838204`], 
         ArrowBox[{1803, 990}, 0.13026950515838204`], 
         ArrowBox[{1804, 990}, 0.13026950515838204`], 
         ArrowBox[{1805, 934}, 0.13026950515838204`], 
         ArrowBox[{1806, 963}, 0.13026950515838204`], 
         ArrowBox[{1807, 943}, 0.13026950515838204`], 
         ArrowBox[{1808, 971}, 0.13026950515838204`], 
         ArrowBox[{1809, 792}, 0.13026950515838204`], 
         ArrowBox[{1810, 794}, 0.13026950515838204`], 
         ArrowBox[{1811, 796}, 0.13026950515838204`], 
         ArrowBox[{1812, 798}, 0.13026950515838204`], 
         ArrowBox[{1813, 778}, 0.13026950515838204`], 
         ArrowBox[{1814, 778}, 0.13026950515838204`], 
         ArrowBox[{1815, 781}, 0.13026950515838204`], 
         ArrowBox[{1816, 781}, 0.13026950515838204`], 
         ArrowBox[{1817, 985}, 0.13026950515838204`], 
         ArrowBox[{1818, 985}, 0.13026950515838204`], 
         ArrowBox[{1819, 990}, 0.13026950515838204`], 
         ArrowBox[{1820, 990}, 0.13026950515838204`], 
         ArrowBox[{1821, 951}, 0.13026950515838204`], 
         ArrowBox[{1822, 974}, 0.13026950515838204`], 
         ArrowBox[{1823, 952}, 0.13026950515838204`], 
         ArrowBox[{1824, 917}, 0.13026950515838204`], 
         ArrowBox[{1825, 812}, 0.13026950515838204`], 
         ArrowBox[{1826, 812}, 0.13026950515838204`], 
         ArrowBox[{1827, 815}, 0.13026950515838204`], 
         ArrowBox[{1828, 815}, 0.13026950515838204`], 
         ArrowBox[{1829, 778}, 0.13026950515838204`], 
         ArrowBox[{1830, 778}, 0.13026950515838204`], 
         ArrowBox[{1831, 781}, 0.13026950515838204`], 
         ArrowBox[{1832, 781}, 0.13026950515838204`], 
         ArrowBox[{1833, 934}, 0.13026950515838204`], 
         ArrowBox[{1834, 963}, 0.13026950515838204`], 
         ArrowBox[{1835, 942}, 0.13026950515838204`], 
         ArrowBox[{1836, 970}, 0.13026950515838204`], 
         ArrowBox[{1837, 963}, 0.13026950515838204`], 
         ArrowBox[{1838, 963}, 0.13026950515838204`], 
         ArrowBox[{1839, 897}, 0.13026950515838204`], 
         ArrowBox[{1840, 897}, 0.13026950515838204`], 
         ArrowBox[{1841, 830}, 0.13026950515838204`], 
         ArrowBox[{1842, 830}, 0.13026950515838204`], 
         ArrowBox[{1843, 781}, 0.13026950515838204`], 
         ArrowBox[{1844, 781}, 0.13026950515838204`], 
         ArrowBox[{1845, 778}, 0.13026950515838204`], 
         ArrowBox[{1846, 778}, 0.13026950515838204`], 
         ArrowBox[{1847, 781}, 0.13026950515838204`], 
         ArrowBox[{1848, 781}, 0.13026950515838204`], 
         ArrowBox[{1849, 934}, 0.13026950515838204`], 
         ArrowBox[{1850, 963}, 0.13026950515838204`], 
         ArrowBox[{1851, 934}, 0.13026950515838204`], 
         ArrowBox[{1852, 963}, 0.13026950515838204`], 
         ArrowBox[{1853, 974}, 0.13026950515838204`], 
         ArrowBox[{1854, 974}, 0.13026950515838204`], 
         ArrowBox[{1855, 917}, 0.13026950515838204`], 
         ArrowBox[{1856, 917}, 0.13026950515838204`], 
         ArrowBox[{1857, 847}, 0.13026950515838204`], 
         ArrowBox[{1858, 847}, 0.13026950515838204`], 
         ArrowBox[{1859, 850}, 0.13026950515838204`], 
         ArrowBox[{1860, 850}, 0.13026950515838204`], 
         ArrowBox[{1861, 853}, 0.13026950515838204`], 
         ArrowBox[{1862, 855}, 0.13026950515838204`], 
         ArrowBox[{1863, 850}, 0.13026950515838204`], 
         ArrowBox[{1864, 858}, 0.13026950515838204`], 
         ArrowBox[{1865, 990}, 0.13026950515838204`], 
         ArrowBox[{1866, 990}, 0.13026950515838204`], 
         ArrowBox[{1867, 990}, 0.13026950515838204`], 
         ArrowBox[{1868, 990}, 0.13026950515838204`], 
         ArrowBox[{1869, 990}, 0.13026950515838204`], 
         ArrowBox[{1870, 990}, 0.13026950515838204`], 
         ArrowBox[{1871, 850}, 0.13026950515838204`], 
         ArrowBox[{1872, 850}, 0.13026950515838204`], 
         ArrowBox[{1873, 868}, 0.13026950515838204`], 
         ArrowBox[{1874, 868}, 0.13026950515838204`], 
         ArrowBox[{1875, 850}, 0.13026950515838204`], 
         ArrowBox[{1876, 850}, 0.13026950515838204`], 
         ArrowBox[{1877, 873}, 0.13026950515838204`], 
         ArrowBox[{1878, 875}, 0.13026950515838204`], 
         ArrowBox[{1879, 877}, 0.13026950515838204`], 
         ArrowBox[{1880, 879}, 0.13026950515838204`], 
         ArrowBox[{1881, 990}, 0.13026950515838204`], 
         ArrowBox[{1882, 990}, 0.13026950515838204`], 
         ArrowBox[{1883, 990}, 0.13026950515838204`], 
         ArrowBox[{1884, 990}, 0.13026950515838204`], 
         ArrowBox[{1885, 985}, 0.13026950515838204`], 
         ArrowBox[{1886, 985}, 0.13026950515838204`], 
         ArrowBox[{1887, 850}, 0.13026950515838204`], 
         ArrowBox[{1888, 850}, 0.13026950515838204`], 
         ArrowBox[{1889, 868}, 0.13026950515838204`], 
         ArrowBox[{1890, 890}, 0.13026950515838204`], 
         ArrowBox[{1891, 850}, 0.13026950515838204`], 
         ArrowBox[{1892, 858}, 0.13026950515838204`], 
         ArrowBox[{1893, 894}, 0.13026950515838204`], 
         ArrowBox[{1894, 894}, 0.13026950515838204`], 
         ArrowBox[{1895, 897}, 0.13026950515838204`], 
         ArrowBox[{1896, 897}, 0.13026950515838204`], 
         ArrowBox[{1897, 990}, 0.13026950515838204`], 
         ArrowBox[{1898, 990}, 0.13026950515838204`], 
         ArrowBox[{1899, 990}, 0.13026950515838204`], 
         ArrowBox[{1900, 990}, 0.13026950515838204`], 
         ArrowBox[{1901, 934}, 0.13026950515838204`], 
         ArrowBox[{1902, 963}, 0.13026950515838204`], 
         ArrowBox[{1903, 943}, 0.13026950515838204`], 
         ArrowBox[{1904, 971}, 0.13026950515838204`], 
         ArrowBox[{1905, 868}, 0.13026950515838204`], 
         ArrowBox[{1906, 890}, 0.13026950515838204`], 
         ArrowBox[{1907, 910}, 0.13026950515838204`], 
         ArrowBox[{1908, 912}, 0.13026950515838204`], 
         ArrowBox[{1909, 914}, 0.13026950515838204`], 
         ArrowBox[{1910, 914}, 0.13026950515838204`], 
         ArrowBox[{1911, 917}, 0.13026950515838204`], 
         ArrowBox[{1912, 917}, 0.13026950515838204`], 
         ArrowBox[{1913, 985}, 0.13026950515838204`], 
         ArrowBox[{1914, 985}, 0.13026950515838204`], 
         ArrowBox[{1915, 990}, 0.13026950515838204`], 
         ArrowBox[{1916, 990}, 0.13026950515838204`], 
         ArrowBox[{1917, 934}, 0.13026950515838204`], 
         ArrowBox[{1918, 963}, 0.13026950515838204`], 
         ArrowBox[{1919, 935}, 0.13026950515838204`], 
         ArrowBox[{1920, 897}, 0.13026950515838204`], 
         ArrowBox[{1921, 770}, 0.13026950515838204`], 
         ArrowBox[{1922, 770}, 0.13026950515838204`], 
         ArrowBox[{1923, 774}, 0.13026950515838204`], 
         ArrowBox[{1924, 774}, 0.13026950515838204`], 
         ArrowBox[{1925, 928}, 0.13026950515838204`], 
         ArrowBox[{1926, 933}, 0.13026950515838204`], 
         ArrowBox[{1927, 932}, 0.13026950515838204`], 
         ArrowBox[{1928, 815}, 0.13026950515838204`], 
         ArrowBox[{1929, 990}, 0.13026950515838204`], 
         ArrowBox[{1930, 990}, 0.13026950515838204`], 
         ArrowBox[{1931, 990}, 0.13026950515838204`], 
         ArrowBox[{1932, 990}, 0.13026950515838204`], 
         ArrowBox[{1933, 934}, 0.13026950515838204`], 
         ArrowBox[{1934, 934}, 0.13026950515838204`], 
         ArrowBox[{1935, 943}, 0.13026950515838204`], 
         ArrowBox[{1936, 943}, 0.13026950515838204`], 
         ArrowBox[{1937, 770}, 0.13026950515838204`], 
         ArrowBox[{1938, 770}, 0.13026950515838204`], 
         ArrowBox[{1939, 947}, 0.13026950515838204`], 
         ArrowBox[{1940, 947}, 0.13026950515838204`], 
         ArrowBox[{1941, 945}, 0.13026950515838204`], 
         ArrowBox[{1942, 778}, 0.13026950515838204`], 
         ArrowBox[{1943, 950}, 0.13026950515838204`], 
         ArrowBox[{1944, 781}, 0.13026950515838204`], 
         ArrowBox[{1945, 985}, 0.13026950515838204`], 
         ArrowBox[{1946, 985}, 0.13026950515838204`], 
         ArrowBox[{1947, 990}, 0.13026950515838204`], 
         ArrowBox[{1948, 990}, 0.13026950515838204`], 
         ArrowBox[{1949, 934}, 0.13026950515838204`], 
         ArrowBox[{1950, 934}, 0.13026950515838204`], 
         ArrowBox[{1951, 935}, 0.13026950515838204`], 
         ArrowBox[{1952, 935}, 0.13026950515838204`], 
         ArrowBox[{1953, 927}, 0.13026950515838204`], 
         ArrowBox[{1954, 812}, 0.13026950515838204`], 
         ArrowBox[{1955, 932}, 0.13026950515838204`], 
         ArrowBox[{1956, 815}, 0.13026950515838204`], 
         ArrowBox[{1957, 933}, 0.13026950515838204`], 
         ArrowBox[{1958, 933}, 0.13026950515838204`], 
         ArrowBox[{1959, 815}, 0.13026950515838204`], 
         ArrowBox[{1960, 815}, 0.13026950515838204`], 
         ArrowBox[{1961, 934}, 0.13026950515838204`], 
         ArrowBox[{1962, 934}, 0.13026950515838204`], 
         ArrowBox[{1963, 942}, 0.13026950515838204`], 
         ArrowBox[{1964, 942}, 0.13026950515838204`], 
         ArrowBox[{1965, 934}, 0.13026950515838204`], 
         ArrowBox[{1966, 963}, 0.13026950515838204`], 
         ArrowBox[{1967, 935}, 0.13026950515838204`], 
         ArrowBox[{1968, 897}, 0.13026950515838204`], 
         ArrowBox[{1969, 927}, 0.13026950515838204`], 
         ArrowBox[{1970, 812}, 0.13026950515838204`], 
         ArrowBox[{1971, 932}, 0.13026950515838204`], 
         ArrowBox[{1972, 815}, 0.13026950515838204`], 
         ArrowBox[{1973, 778}, 0.13026950515838204`], 
         ArrowBox[{1974, 778}, 0.13026950515838204`], 
         ArrowBox[{1975, 781}, 0.13026950515838204`], 
         ArrowBox[{1976, 781}, 0.13026950515838204`], 
         ArrowBox[{1977, 934}, 0.13026950515838204`], 
         ArrowBox[{1978, 934}, 0.13026950515838204`], 
         ArrowBox[{1979, 934}, 0.13026950515838204`], 
         ArrowBox[{1980, 934}, 0.13026950515838204`], 
         ArrowBox[{1981, 934}, 0.13026950515838204`], 
         ArrowBox[{1982, 963}, 0.13026950515838204`], 
         ArrowBox[{1983, 935}, 0.13026950515838204`], 
         ArrowBox[{1984, 897}, 0.13026950515838204`], 
         ArrowBox[{1985, 847}, 0.13026950515838204`], 
         ArrowBox[{1986, 847}, 0.13026950515838204`], 
         ArrowBox[{1987, 850}, 0.13026950515838204`], 
         ArrowBox[{1988, 850}, 0.13026950515838204`], 
         ArrowBox[{1989, 853}, 0.13026950515838204`], 
         ArrowBox[{1990, 853}, 0.13026950515838204`], 
         ArrowBox[{1991, 850}, 0.13026950515838204`], 
         ArrowBox[{1992, 850}, 0.13026950515838204`], 
         ArrowBox[{1993, 990}, 0.13026950515838204`], 
         ArrowBox[{1994, 990}, 0.13026950515838204`], 
         ArrowBox[{1995, 990}, 0.13026950515838204`], 
         ArrowBox[{1996, 990}, 0.13026950515838204`], 
         ArrowBox[{1997, 990}, 0.13026950515838204`], 
         ArrowBox[{1998, 990}, 0.13026950515838204`], 
         ArrowBox[{1999, 850}, 0.13026950515838204`], 
         ArrowBox[{2000, 850}, 0.13026950515838204`], 
         ArrowBox[{2001, 868}, 0.13026950515838204`], 
         ArrowBox[{2002, 868}, 0.13026950515838204`], 
         ArrowBox[{2003, 850}, 0.13026950515838204`], 
         ArrowBox[{2004, 850}, 0.13026950515838204`], 
         ArrowBox[{2005, 853}, 0.13026950515838204`], 
         ArrowBox[{2006, 853}, 0.13026950515838204`], 
         ArrowBox[{2007, 910}, 0.13026950515838204`], 
         ArrowBox[{2008, 910}, 0.13026950515838204`], 
         ArrowBox[{2009, 990}, 0.13026950515838204`], 
         ArrowBox[{2010, 990}, 0.13026950515838204`], 
         ArrowBox[{2011, 990}, 0.13026950515838204`], 
         ArrowBox[{2012, 990}, 0.13026950515838204`], 
         ArrowBox[{2013, 985}, 0.13026950515838204`], 
         ArrowBox[{2014, 985}, 0.13026950515838204`], 
         ArrowBox[{2015, 850}, 0.13026950515838204`], 
         ArrowBox[{2016, 850}, 0.13026950515838204`], 
         ArrowBox[{2017, 868}, 0.13026950515838204`], 
         ArrowBox[{2018, 868}, 0.13026950515838204`], 
         ArrowBox[{2019, 850}, 0.13026950515838204`], 
         ArrowBox[{2020, 850}, 0.13026950515838204`], 
         ArrowBox[{2021, 930}, 0.13026950515838204`], 
         ArrowBox[{2022, 894}, 0.13026950515838204`], 
         ArrowBox[{2023, 935}, 0.13026950515838204`], 
         ArrowBox[{2024, 897}, 0.13026950515838204`], 
         ArrowBox[{2025, 990}, 0.13026950515838204`], 
         ArrowBox[{2026, 990}, 0.13026950515838204`], 
         ArrowBox[{2027, 990}, 0.13026950515838204`], 
         ArrowBox[{2028, 990}, 0.13026950515838204`], 
         ArrowBox[{2029, 934}, 0.13026950515838204`], 
         ArrowBox[{2030, 934}, 0.13026950515838204`], 
         ArrowBox[{2031, 943}, 0.13026950515838204`], 
         ArrowBox[{2032, 943}, 0.13026950515838204`], 
         ArrowBox[{2033, 868}, 0.13026950515838204`], 
         ArrowBox[{2034, 868}, 0.13026950515838204`], 
         ArrowBox[{2035, 910}, 0.13026950515838204`], 
         ArrowBox[{2036, 910}, 0.13026950515838204`], 
         ArrowBox[{2037, 930}, 0.13026950515838204`], 
         ArrowBox[{2038, 894}, 0.13026950515838204`], 
         ArrowBox[{2039, 935}, 0.13026950515838204`], 
         ArrowBox[{2040, 897}, 0.13026950515838204`], 
         ArrowBox[{2041, 985}, 0.13026950515838204`], 
         ArrowBox[{2042, 985}, 0.13026950515838204`], 
         ArrowBox[{2043, 990}, 0.13026950515838204`], 
         ArrowBox[{2044, 990}, 0.13026950515838204`], 
         ArrowBox[{2045, 934}, 0.13026950515838204`], 
         ArrowBox[{2046, 934}, 0.13026950515838204`], 
         ArrowBox[{2047, 935}, 0.13026950515838204`], 
         ArrowBox[{2048, 935}, 0.13026950515838204`]}, 
        {GrayLevel[0.85], EdgeForm[GrayLevel[0]], 
         DiskBox[1, 0.13026950515838204`], DiskBox[2, 0.13026950515838204`], 
         DiskBox[3, 0.13026950515838204`], DiskBox[4, 0.13026950515838204`], 
         DiskBox[5, 0.13026950515838204`], DiskBox[6, 0.13026950515838204`], 
         DiskBox[7, 0.13026950515838204`], DiskBox[8, 0.13026950515838204`], 
         DiskBox[9, 0.13026950515838204`], DiskBox[10, 0.13026950515838204`], 
         DiskBox[11, 0.13026950515838204`], DiskBox[12, 0.13026950515838204`],
          DiskBox[13, 0.13026950515838204`], 
         DiskBox[14, 0.13026950515838204`], DiskBox[15, 0.13026950515838204`],
          DiskBox[16, 0.13026950515838204`], 
         DiskBox[17, 0.13026950515838204`], DiskBox[18, 0.13026950515838204`],
          DiskBox[19, 0.13026950515838204`], 
         DiskBox[20, 0.13026950515838204`], DiskBox[21, 0.13026950515838204`],
          DiskBox[22, 0.13026950515838204`], 
         DiskBox[23, 0.13026950515838204`], DiskBox[24, 0.13026950515838204`],
          DiskBox[25, 0.13026950515838204`], 
         DiskBox[26, 0.13026950515838204`], DiskBox[27, 0.13026950515838204`],
          DiskBox[28, 0.13026950515838204`], 
         DiskBox[29, 0.13026950515838204`], DiskBox[30, 0.13026950515838204`],
          DiskBox[31, 0.13026950515838204`], 
         DiskBox[32, 0.13026950515838204`], DiskBox[33, 0.13026950515838204`],
          DiskBox[34, 0.13026950515838204`], 
         DiskBox[35, 0.13026950515838204`], DiskBox[36, 0.13026950515838204`],
          DiskBox[37, 0.13026950515838204`], 
         DiskBox[38, 0.13026950515838204`], DiskBox[39, 0.13026950515838204`],
          DiskBox[40, 0.13026950515838204`], 
         DiskBox[41, 0.13026950515838204`], DiskBox[42, 0.13026950515838204`],
          DiskBox[43, 0.13026950515838204`], 
         DiskBox[44, 0.13026950515838204`], DiskBox[45, 0.13026950515838204`],
          DiskBox[46, 0.13026950515838204`], 
         DiskBox[47, 0.13026950515838204`], DiskBox[48, 0.13026950515838204`],
          DiskBox[49, 0.13026950515838204`], 
         DiskBox[50, 0.13026950515838204`], DiskBox[51, 0.13026950515838204`],
          DiskBox[52, 0.13026950515838204`], 
         DiskBox[53, 0.13026950515838204`], DiskBox[54, 0.13026950515838204`],
          DiskBox[55, 0.13026950515838204`], 
         DiskBox[56, 0.13026950515838204`], DiskBox[57, 0.13026950515838204`],
          DiskBox[58, 0.13026950515838204`], 
         DiskBox[59, 0.13026950515838204`], DiskBox[60, 0.13026950515838204`],
          DiskBox[61, 0.13026950515838204`], 
         DiskBox[62, 0.13026950515838204`], DiskBox[63, 0.13026950515838204`],
          DiskBox[64, 0.13026950515838204`], 
         DiskBox[65, 0.13026950515838204`], DiskBox[66, 0.13026950515838204`],
          DiskBox[67, 0.13026950515838204`], 
         DiskBox[68, 0.13026950515838204`], DiskBox[69, 0.13026950515838204`],
          DiskBox[70, 0.13026950515838204`], 
         DiskBox[71, 0.13026950515838204`], DiskBox[72, 0.13026950515838204`],
          DiskBox[73, 0.13026950515838204`], 
         DiskBox[74, 0.13026950515838204`], DiskBox[75, 0.13026950515838204`],
          DiskBox[76, 0.13026950515838204`], 
         DiskBox[77, 0.13026950515838204`], DiskBox[78, 0.13026950515838204`],
          DiskBox[79, 0.13026950515838204`], 
         DiskBox[80, 0.13026950515838204`], DiskBox[81, 0.13026950515838204`],
          DiskBox[82, 0.13026950515838204`], 
         DiskBox[83, 0.13026950515838204`], DiskBox[84, 0.13026950515838204`],
          DiskBox[85, 0.13026950515838204`], 
         DiskBox[86, 0.13026950515838204`], DiskBox[87, 0.13026950515838204`],
          DiskBox[88, 0.13026950515838204`], 
         DiskBox[89, 0.13026950515838204`], DiskBox[90, 0.13026950515838204`],
          DiskBox[91, 0.13026950515838204`], 
         DiskBox[92, 0.13026950515838204`], DiskBox[93, 0.13026950515838204`],
          DiskBox[94, 0.13026950515838204`], 
         DiskBox[95, 0.13026950515838204`], DiskBox[96, 0.13026950515838204`],
          DiskBox[97, 0.13026950515838204`], 
         DiskBox[98, 0.13026950515838204`], DiskBox[99, 0.13026950515838204`],
          DiskBox[100, 0.13026950515838204`], 
         DiskBox[101, 0.13026950515838204`], 
         DiskBox[102, 0.13026950515838204`], 
         DiskBox[103, 0.13026950515838204`], 
         DiskBox[104, 0.13026950515838204`], 
         DiskBox[105, 0.13026950515838204`], 
         DiskBox[106, 0.13026950515838204`], 
         DiskBox[107, 0.13026950515838204`], 
         DiskBox[108, 0.13026950515838204`], 
         DiskBox[109, 0.13026950515838204`], 
         DiskBox[110, 0.13026950515838204`], 
         DiskBox[111, 0.13026950515838204`], 
         DiskBox[112, 0.13026950515838204`], 
         DiskBox[113, 0.13026950515838204`], 
         DiskBox[114, 0.13026950515838204`], 
         DiskBox[115, 0.13026950515838204`], 
         DiskBox[116, 0.13026950515838204`], 
         DiskBox[117, 0.13026950515838204`], 
         DiskBox[118, 0.13026950515838204`], 
         DiskBox[119, 0.13026950515838204`], 
         DiskBox[120, 0.13026950515838204`], 
         DiskBox[121, 0.13026950515838204`], 
         DiskBox[122, 0.13026950515838204`], 
         DiskBox[123, 0.13026950515838204`], 
         DiskBox[124, 0.13026950515838204`], 
         DiskBox[125, 0.13026950515838204`], 
         DiskBox[126, 0.13026950515838204`], 
         DiskBox[127, 0.13026950515838204`], 
         DiskBox[128, 0.13026950515838204`], 
         DiskBox[129, 0.13026950515838204`], 
         DiskBox[130, 0.13026950515838204`], 
         DiskBox[131, 0.13026950515838204`], 
         DiskBox[132, 0.13026950515838204`], 
         DiskBox[133, 0.13026950515838204`], 
         DiskBox[134, 0.13026950515838204`], 
         DiskBox[135, 0.13026950515838204`], 
         DiskBox[136, 0.13026950515838204`], 
         DiskBox[137, 0.13026950515838204`], 
         DiskBox[138, 0.13026950515838204`], 
         DiskBox[139, 0.13026950515838204`], 
         DiskBox[140, 0.13026950515838204`], 
         DiskBox[141, 0.13026950515838204`], 
         DiskBox[142, 0.13026950515838204`], 
         DiskBox[143, 0.13026950515838204`], 
         DiskBox[144, 0.13026950515838204`], 
         DiskBox[145, 0.13026950515838204`], 
         DiskBox[146, 0.13026950515838204`], 
         DiskBox[147, 0.13026950515838204`], 
         DiskBox[148, 0.13026950515838204`], 
         DiskBox[149, 0.13026950515838204`], 
         DiskBox[150, 0.13026950515838204`], 
         DiskBox[151, 0.13026950515838204`], 
         DiskBox[152, 0.13026950515838204`], 
         DiskBox[153, 0.13026950515838204`], 
         DiskBox[154, 0.13026950515838204`], 
         DiskBox[155, 0.13026950515838204`], 
         DiskBox[156, 0.13026950515838204`], 
         DiskBox[157, 0.13026950515838204`], 
         DiskBox[158, 0.13026950515838204`], 
         DiskBox[159, 0.13026950515838204`], 
         DiskBox[160, 0.13026950515838204`], 
         DiskBox[161, 0.13026950515838204`], 
         DiskBox[162, 0.13026950515838204`], 
         DiskBox[163, 0.13026950515838204`], 
         DiskBox[164, 0.13026950515838204`], 
         DiskBox[165, 0.13026950515838204`], 
         DiskBox[166, 0.13026950515838204`], 
         DiskBox[167, 0.13026950515838204`], 
         DiskBox[168, 0.13026950515838204`], 
         DiskBox[169, 0.13026950515838204`], 
         DiskBox[170, 0.13026950515838204`], 
         DiskBox[171, 0.13026950515838204`], 
         DiskBox[172, 0.13026950515838204`], 
         DiskBox[173, 0.13026950515838204`], 
         DiskBox[174, 0.13026950515838204`], 
         DiskBox[175, 0.13026950515838204`], 
         DiskBox[176, 0.13026950515838204`], 
         DiskBox[177, 0.13026950515838204`], 
         DiskBox[178, 0.13026950515838204`], 
         DiskBox[179, 0.13026950515838204`], 
         DiskBox[180, 0.13026950515838204`], 
         DiskBox[181, 0.13026950515838204`], 
         DiskBox[182, 0.13026950515838204`], 
         DiskBox[183, 0.13026950515838204`], 
         DiskBox[184, 0.13026950515838204`], 
         DiskBox[185, 0.13026950515838204`], 
         DiskBox[186, 0.13026950515838204`], 
         DiskBox[187, 0.13026950515838204`], 
         DiskBox[188, 0.13026950515838204`], 
         DiskBox[189, 0.13026950515838204`], 
         DiskBox[190, 0.13026950515838204`], 
         DiskBox[191, 0.13026950515838204`], 
         DiskBox[192, 0.13026950515838204`], 
         DiskBox[193, 0.13026950515838204`], 
         DiskBox[194, 0.13026950515838204`], 
         DiskBox[195, 0.13026950515838204`], 
         DiskBox[196, 0.13026950515838204`], 
         DiskBox[197, 0.13026950515838204`], 
         DiskBox[198, 0.13026950515838204`], 
         DiskBox[199, 0.13026950515838204`], 
         DiskBox[200, 0.13026950515838204`], 
         DiskBox[201, 0.13026950515838204`], 
         DiskBox[202, 0.13026950515838204`], 
         DiskBox[203, 0.13026950515838204`], 
         DiskBox[204, 0.13026950515838204`], 
         DiskBox[205, 0.13026950515838204`], 
         DiskBox[206, 0.13026950515838204`], 
         DiskBox[207, 0.13026950515838204`], 
         DiskBox[208, 0.13026950515838204`], 
         DiskBox[209, 0.13026950515838204`], 
         DiskBox[210, 0.13026950515838204`], 
         DiskBox[211, 0.13026950515838204`], 
         DiskBox[212, 0.13026950515838204`], 
         DiskBox[213, 0.13026950515838204`], 
         DiskBox[214, 0.13026950515838204`], 
         DiskBox[215, 0.13026950515838204`], 
         DiskBox[216, 0.13026950515838204`], 
         DiskBox[217, 0.13026950515838204`], 
         DiskBox[218, 0.13026950515838204`], 
         DiskBox[219, 0.13026950515838204`], 
         DiskBox[220, 0.13026950515838204`], 
         DiskBox[221, 0.13026950515838204`], 
         DiskBox[222, 0.13026950515838204`], 
         DiskBox[223, 0.13026950515838204`], 
         DiskBox[224, 0.13026950515838204`], 
         DiskBox[225, 0.13026950515838204`], 
         DiskBox[226, 0.13026950515838204`], 
         DiskBox[227, 0.13026950515838204`], 
         DiskBox[228, 0.13026950515838204`], 
         DiskBox[229, 0.13026950515838204`], 
         DiskBox[230, 0.13026950515838204`], 
         DiskBox[231, 0.13026950515838204`], 
         DiskBox[232, 0.13026950515838204`], 
         DiskBox[233, 0.13026950515838204`], 
         DiskBox[234, 0.13026950515838204`], 
         DiskBox[235, 0.13026950515838204`], 
         DiskBox[236, 0.13026950515838204`], 
         DiskBox[237, 0.13026950515838204`], 
         DiskBox[238, 0.13026950515838204`], 
         DiskBox[239, 0.13026950515838204`], 
         DiskBox[240, 0.13026950515838204`], 
         DiskBox[241, 0.13026950515838204`], 
         DiskBox[242, 0.13026950515838204`], 
         DiskBox[243, 0.13026950515838204`], 
         DiskBox[244, 0.13026950515838204`], 
         DiskBox[245, 0.13026950515838204`], 
         DiskBox[246, 0.13026950515838204`], 
         DiskBox[247, 0.13026950515838204`], 
         DiskBox[248, 0.13026950515838204`], 
         DiskBox[249, 0.13026950515838204`], 
         DiskBox[250, 0.13026950515838204`], 
         DiskBox[251, 0.13026950515838204`], 
         DiskBox[252, 0.13026950515838204`], 
         DiskBox[253, 0.13026950515838204`], 
         DiskBox[254, 0.13026950515838204`], 
         DiskBox[255, 0.13026950515838204`], 
         DiskBox[256, 0.13026950515838204`], 
         DiskBox[257, 0.13026950515838204`], 
         DiskBox[258, 0.13026950515838204`], 
         DiskBox[259, 0.13026950515838204`], 
         DiskBox[260, 0.13026950515838204`], 
         DiskBox[261, 0.13026950515838204`], 
         DiskBox[262, 0.13026950515838204`], 
         DiskBox[263, 0.13026950515838204`], 
         DiskBox[264, 0.13026950515838204`], 
         DiskBox[265, 0.13026950515838204`], 
         DiskBox[266, 0.13026950515838204`], 
         DiskBox[267, 0.13026950515838204`], 
         DiskBox[268, 0.13026950515838204`], 
         DiskBox[269, 0.13026950515838204`], 
         DiskBox[270, 0.13026950515838204`], 
         DiskBox[271, 0.13026950515838204`], 
         DiskBox[272, 0.13026950515838204`], 
         DiskBox[273, 0.13026950515838204`], 
         DiskBox[274, 0.13026950515838204`], 
         DiskBox[275, 0.13026950515838204`], 
         DiskBox[276, 0.13026950515838204`], 
         DiskBox[277, 0.13026950515838204`], 
         DiskBox[278, 0.13026950515838204`], 
         DiskBox[279, 0.13026950515838204`], 
         DiskBox[280, 0.13026950515838204`], 
         DiskBox[281, 0.13026950515838204`], 
         DiskBox[282, 0.13026950515838204`], 
         DiskBox[283, 0.13026950515838204`], 
         DiskBox[284, 0.13026950515838204`], 
         DiskBox[285, 0.13026950515838204`], 
         DiskBox[286, 0.13026950515838204`], 
         DiskBox[287, 0.13026950515838204`], 
         DiskBox[288, 0.13026950515838204`], 
         DiskBox[289, 0.13026950515838204`], 
         DiskBox[290, 0.13026950515838204`], 
         DiskBox[291, 0.13026950515838204`], 
         DiskBox[292, 0.13026950515838204`], 
         DiskBox[293, 0.13026950515838204`], 
         DiskBox[294, 0.13026950515838204`], 
         DiskBox[295, 0.13026950515838204`], 
         DiskBox[296, 0.13026950515838204`], 
         DiskBox[297, 0.13026950515838204`], 
         DiskBox[298, 0.13026950515838204`], 
         DiskBox[299, 0.13026950515838204`], 
         DiskBox[300, 0.13026950515838204`], 
         DiskBox[301, 0.13026950515838204`], 
         DiskBox[302, 0.13026950515838204`], 
         DiskBox[303, 0.13026950515838204`], 
         DiskBox[304, 0.13026950515838204`], 
         DiskBox[305, 0.13026950515838204`], 
         DiskBox[306, 0.13026950515838204`], 
         DiskBox[307, 0.13026950515838204`], 
         DiskBox[308, 0.13026950515838204`], 
         DiskBox[309, 0.13026950515838204`], 
         DiskBox[310, 0.13026950515838204`], 
         DiskBox[311, 0.13026950515838204`], 
         DiskBox[312, 0.13026950515838204`], 
         DiskBox[313, 0.13026950515838204`], 
         DiskBox[314, 0.13026950515838204`], 
         DiskBox[315, 0.13026950515838204`], 
         DiskBox[316, 0.13026950515838204`], 
         DiskBox[317, 0.13026950515838204`], 
         DiskBox[318, 0.13026950515838204`], 
         DiskBox[319, 0.13026950515838204`], 
         DiskBox[320, 0.13026950515838204`], 
         DiskBox[321, 0.13026950515838204`], 
         DiskBox[322, 0.13026950515838204`], 
         DiskBox[323, 0.13026950515838204`], 
         DiskBox[324, 0.13026950515838204`], 
         DiskBox[325, 0.13026950515838204`], 
         DiskBox[326, 0.13026950515838204`], 
         DiskBox[327, 0.13026950515838204`], 
         DiskBox[328, 0.13026950515838204`], 
         DiskBox[329, 0.13026950515838204`], 
         DiskBox[330, 0.13026950515838204`], 
         DiskBox[331, 0.13026950515838204`], 
         DiskBox[332, 0.13026950515838204`], 
         DiskBox[333, 0.13026950515838204`], 
         DiskBox[334, 0.13026950515838204`], 
         DiskBox[335, 0.13026950515838204`], 
         DiskBox[336, 0.13026950515838204`], 
         DiskBox[337, 0.13026950515838204`], 
         DiskBox[338, 0.13026950515838204`], 
         DiskBox[339, 0.13026950515838204`], 
         DiskBox[340, 0.13026950515838204`], 
         DiskBox[341, 0.13026950515838204`], 
         DiskBox[342, 0.13026950515838204`], 
         DiskBox[343, 0.13026950515838204`], 
         DiskBox[344, 0.13026950515838204`], 
         DiskBox[345, 0.13026950515838204`], 
         DiskBox[346, 0.13026950515838204`], 
         DiskBox[347, 0.13026950515838204`], 
         DiskBox[348, 0.13026950515838204`], 
         DiskBox[349, 0.13026950515838204`], 
         DiskBox[350, 0.13026950515838204`], 
         DiskBox[351, 0.13026950515838204`], 
         DiskBox[352, 0.13026950515838204`], 
         DiskBox[353, 0.13026950515838204`], 
         DiskBox[354, 0.13026950515838204`], 
         DiskBox[355, 0.13026950515838204`], 
         DiskBox[356, 0.13026950515838204`], 
         DiskBox[357, 0.13026950515838204`], 
         DiskBox[358, 0.13026950515838204`], 
         DiskBox[359, 0.13026950515838204`], 
         DiskBox[360, 0.13026950515838204`], 
         DiskBox[361, 0.13026950515838204`], 
         DiskBox[362, 0.13026950515838204`], 
         DiskBox[363, 0.13026950515838204`], 
         DiskBox[364, 0.13026950515838204`], 
         DiskBox[365, 0.13026950515838204`], 
         DiskBox[366, 0.13026950515838204`], 
         DiskBox[367, 0.13026950515838204`], 
         DiskBox[368, 0.13026950515838204`], 
         DiskBox[369, 0.13026950515838204`], 
         DiskBox[370, 0.13026950515838204`], 
         DiskBox[371, 0.13026950515838204`], 
         DiskBox[372, 0.13026950515838204`], 
         DiskBox[373, 0.13026950515838204`], 
         DiskBox[374, 0.13026950515838204`], 
         DiskBox[375, 0.13026950515838204`], 
         DiskBox[376, 0.13026950515838204`], 
         DiskBox[377, 0.13026950515838204`], 
         DiskBox[378, 0.13026950515838204`], 
         DiskBox[379, 0.13026950515838204`], 
         DiskBox[380, 0.13026950515838204`], 
         DiskBox[381, 0.13026950515838204`], 
         DiskBox[382, 0.13026950515838204`], 
         DiskBox[383, 0.13026950515838204`], 
         DiskBox[384, 0.13026950515838204`], 
         DiskBox[385, 0.13026950515838204`], 
         DiskBox[386, 0.13026950515838204`], 
         DiskBox[387, 0.13026950515838204`], 
         DiskBox[388, 0.13026950515838204`], 
         DiskBox[389, 0.13026950515838204`], 
         DiskBox[390, 0.13026950515838204`], 
         DiskBox[391, 0.13026950515838204`], 
         DiskBox[392, 0.13026950515838204`], 
         DiskBox[393, 0.13026950515838204`], 
         DiskBox[394, 0.13026950515838204`], 
         DiskBox[395, 0.13026950515838204`], 
         DiskBox[396, 0.13026950515838204`], 
         DiskBox[397, 0.13026950515838204`], 
         DiskBox[398, 0.13026950515838204`], 
         DiskBox[399, 0.13026950515838204`], 
         DiskBox[400, 0.13026950515838204`], 
         DiskBox[401, 0.13026950515838204`], 
         DiskBox[402, 0.13026950515838204`], 
         DiskBox[403, 0.13026950515838204`], 
         DiskBox[404, 0.13026950515838204`], 
         DiskBox[405, 0.13026950515838204`], 
         DiskBox[406, 0.13026950515838204`], 
         DiskBox[407, 0.13026950515838204`], 
         DiskBox[408, 0.13026950515838204`], 
         DiskBox[409, 0.13026950515838204`], 
         DiskBox[410, 0.13026950515838204`], 
         DiskBox[411, 0.13026950515838204`], 
         DiskBox[412, 0.13026950515838204`], 
         DiskBox[413, 0.13026950515838204`], 
         DiskBox[414, 0.13026950515838204`], 
         DiskBox[415, 0.13026950515838204`], 
         DiskBox[416, 0.13026950515838204`], 
         DiskBox[417, 0.13026950515838204`], 
         DiskBox[418, 0.13026950515838204`], 
         DiskBox[419, 0.13026950515838204`], 
         DiskBox[420, 0.13026950515838204`], 
         DiskBox[421, 0.13026950515838204`], 
         DiskBox[422, 0.13026950515838204`], 
         DiskBox[423, 0.13026950515838204`], 
         DiskBox[424, 0.13026950515838204`], 
         DiskBox[425, 0.13026950515838204`], 
         DiskBox[426, 0.13026950515838204`], 
         DiskBox[427, 0.13026950515838204`], 
         DiskBox[428, 0.13026950515838204`], 
         DiskBox[429, 0.13026950515838204`], 
         DiskBox[430, 0.13026950515838204`], 
         DiskBox[431, 0.13026950515838204`], 
         DiskBox[432, 0.13026950515838204`], 
         DiskBox[433, 0.13026950515838204`], 
         DiskBox[434, 0.13026950515838204`], 
         DiskBox[435, 0.13026950515838204`], 
         DiskBox[436, 0.13026950515838204`], 
         DiskBox[437, 0.13026950515838204`], 
         DiskBox[438, 0.13026950515838204`], 
         DiskBox[439, 0.13026950515838204`], 
         DiskBox[440, 0.13026950515838204`], 
         DiskBox[441, 0.13026950515838204`], 
         DiskBox[442, 0.13026950515838204`], 
         DiskBox[443, 0.13026950515838204`], 
         DiskBox[444, 0.13026950515838204`], 
         DiskBox[445, 0.13026950515838204`], 
         DiskBox[446, 0.13026950515838204`], 
         DiskBox[447, 0.13026950515838204`], 
         DiskBox[448, 0.13026950515838204`], 
         DiskBox[449, 0.13026950515838204`], 
         DiskBox[450, 0.13026950515838204`], 
         DiskBox[451, 0.13026950515838204`], 
         DiskBox[452, 0.13026950515838204`], 
         DiskBox[453, 0.13026950515838204`], 
         DiskBox[454, 0.13026950515838204`], 
         DiskBox[455, 0.13026950515838204`], 
         DiskBox[456, 0.13026950515838204`], 
         DiskBox[457, 0.13026950515838204`], 
         DiskBox[458, 0.13026950515838204`], 
         DiskBox[459, 0.13026950515838204`], 
         DiskBox[460, 0.13026950515838204`], 
         DiskBox[461, 0.13026950515838204`], 
         DiskBox[462, 0.13026950515838204`], 
         DiskBox[463, 0.13026950515838204`], 
         DiskBox[464, 0.13026950515838204`], 
         DiskBox[465, 0.13026950515838204`], 
         DiskBox[466, 0.13026950515838204`], 
         DiskBox[467, 0.13026950515838204`], 
         DiskBox[468, 0.13026950515838204`], 
         DiskBox[469, 0.13026950515838204`], 
         DiskBox[470, 0.13026950515838204`], 
         DiskBox[471, 0.13026950515838204`], 
         DiskBox[472, 0.13026950515838204`], 
         DiskBox[473, 0.13026950515838204`], 
         DiskBox[474, 0.13026950515838204`], 
         DiskBox[475, 0.13026950515838204`], 
         DiskBox[476, 0.13026950515838204`], 
         DiskBox[477, 0.13026950515838204`], 
         DiskBox[478, 0.13026950515838204`], 
         DiskBox[479, 0.13026950515838204`], 
         DiskBox[480, 0.13026950515838204`], 
         DiskBox[481, 0.13026950515838204`], 
         DiskBox[482, 0.13026950515838204`], 
         DiskBox[483, 0.13026950515838204`], 
         DiskBox[484, 0.13026950515838204`], 
         DiskBox[485, 0.13026950515838204`], 
         DiskBox[486, 0.13026950515838204`], 
         DiskBox[487, 0.13026950515838204`], 
         DiskBox[488, 0.13026950515838204`], 
         DiskBox[489, 0.13026950515838204`], 
         DiskBox[490, 0.13026950515838204`], 
         DiskBox[491, 0.13026950515838204`], 
         DiskBox[492, 0.13026950515838204`], 
         DiskBox[493, 0.13026950515838204`], 
         DiskBox[494, 0.13026950515838204`], 
         DiskBox[495, 0.13026950515838204`], 
         DiskBox[496, 0.13026950515838204`], 
         DiskBox[497, 0.13026950515838204`], 
         DiskBox[498, 0.13026950515838204`], 
         DiskBox[499, 0.13026950515838204`], 
         DiskBox[500, 0.13026950515838204`], 
         DiskBox[501, 0.13026950515838204`], 
         DiskBox[502, 0.13026950515838204`], 
         DiskBox[503, 0.13026950515838204`], 
         DiskBox[504, 0.13026950515838204`], 
         DiskBox[505, 0.13026950515838204`], 
         DiskBox[506, 0.13026950515838204`], 
         DiskBox[507, 0.13026950515838204`], 
         DiskBox[508, 0.13026950515838204`], 
         DiskBox[509, 0.13026950515838204`], 
         DiskBox[510, 0.13026950515838204`], 
         DiskBox[511, 0.13026950515838204`], 
         DiskBox[512, 0.13026950515838204`], 
         DiskBox[513, 0.13026950515838204`], 
         DiskBox[514, 0.13026950515838204`], 
         DiskBox[515, 0.13026950515838204`], 
         DiskBox[516, 0.13026950515838204`], 
         DiskBox[517, 0.13026950515838204`], 
         DiskBox[518, 0.13026950515838204`], 
         DiskBox[519, 0.13026950515838204`], 
         DiskBox[520, 0.13026950515838204`], 
         DiskBox[521, 0.13026950515838204`], 
         DiskBox[522, 0.13026950515838204`], 
         DiskBox[523, 0.13026950515838204`], 
         DiskBox[524, 0.13026950515838204`], 
         DiskBox[525, 0.13026950515838204`], 
         DiskBox[526, 0.13026950515838204`], 
         DiskBox[527, 0.13026950515838204`], 
         DiskBox[528, 0.13026950515838204`], 
         DiskBox[529, 0.13026950515838204`], 
         DiskBox[530, 0.13026950515838204`], 
         DiskBox[531, 0.13026950515838204`], 
         DiskBox[532, 0.13026950515838204`], 
         DiskBox[533, 0.13026950515838204`], 
         DiskBox[534, 0.13026950515838204`], 
         DiskBox[535, 0.13026950515838204`], 
         DiskBox[536, 0.13026950515838204`], 
         DiskBox[537, 0.13026950515838204`], 
         DiskBox[538, 0.13026950515838204`], 
         DiskBox[539, 0.13026950515838204`], 
         DiskBox[540, 0.13026950515838204`], 
         DiskBox[541, 0.13026950515838204`], 
         DiskBox[542, 0.13026950515838204`], 
         DiskBox[543, 0.13026950515838204`], 
         DiskBox[544, 0.13026950515838204`], 
         DiskBox[545, 0.13026950515838204`], 
         DiskBox[546, 0.13026950515838204`], 
         DiskBox[547, 0.13026950515838204`], 
         DiskBox[548, 0.13026950515838204`], 
         DiskBox[549, 0.13026950515838204`], 
         DiskBox[550, 0.13026950515838204`], 
         DiskBox[551, 0.13026950515838204`], 
         DiskBox[552, 0.13026950515838204`], 
         DiskBox[553, 0.13026950515838204`], 
         DiskBox[554, 0.13026950515838204`], 
         DiskBox[555, 0.13026950515838204`], 
         DiskBox[556, 0.13026950515838204`], 
         DiskBox[557, 0.13026950515838204`], 
         DiskBox[558, 0.13026950515838204`], 
         DiskBox[559, 0.13026950515838204`], 
         DiskBox[560, 0.13026950515838204`], 
         DiskBox[561, 0.13026950515838204`], 
         DiskBox[562, 0.13026950515838204`], 
         DiskBox[563, 0.13026950515838204`], 
         DiskBox[564, 0.13026950515838204`], 
         DiskBox[565, 0.13026950515838204`], 
         DiskBox[566, 0.13026950515838204`], 
         DiskBox[567, 0.13026950515838204`], 
         DiskBox[568, 0.13026950515838204`], 
         DiskBox[569, 0.13026950515838204`], 
         DiskBox[570, 0.13026950515838204`], 
         DiskBox[571, 0.13026950515838204`], 
         DiskBox[572, 0.13026950515838204`], 
         DiskBox[573, 0.13026950515838204`], 
         DiskBox[574, 0.13026950515838204`], 
         DiskBox[575, 0.13026950515838204`], 
         DiskBox[576, 0.13026950515838204`], 
         DiskBox[577, 0.13026950515838204`], 
         DiskBox[578, 0.13026950515838204`], 
         DiskBox[579, 0.13026950515838204`], 
         DiskBox[580, 0.13026950515838204`], 
         DiskBox[581, 0.13026950515838204`], 
         DiskBox[582, 0.13026950515838204`], 
         DiskBox[583, 0.13026950515838204`], 
         DiskBox[584, 0.13026950515838204`], 
         DiskBox[585, 0.13026950515838204`], 
         DiskBox[586, 0.13026950515838204`], 
         DiskBox[587, 0.13026950515838204`], 
         DiskBox[588, 0.13026950515838204`], 
         DiskBox[589, 0.13026950515838204`], 
         DiskBox[590, 0.13026950515838204`], 
         DiskBox[591, 0.13026950515838204`], 
         DiskBox[592, 0.13026950515838204`], 
         DiskBox[593, 0.13026950515838204`], 
         DiskBox[594, 0.13026950515838204`], 
         DiskBox[595, 0.13026950515838204`], 
         DiskBox[596, 0.13026950515838204`], 
         DiskBox[597, 0.13026950515838204`], 
         DiskBox[598, 0.13026950515838204`], 
         DiskBox[599, 0.13026950515838204`], 
         DiskBox[600, 0.13026950515838204`], 
         DiskBox[601, 0.13026950515838204`], 
         DiskBox[602, 0.13026950515838204`], 
         DiskBox[603, 0.13026950515838204`], 
         DiskBox[604, 0.13026950515838204`], 
         DiskBox[605, 0.13026950515838204`], 
         DiskBox[606, 0.13026950515838204`], 
         DiskBox[607, 0.13026950515838204`], 
         DiskBox[608, 0.13026950515838204`], 
         DiskBox[609, 0.13026950515838204`], 
         DiskBox[610, 0.13026950515838204`], 
         DiskBox[611, 0.13026950515838204`], 
         DiskBox[612, 0.13026950515838204`], 
         DiskBox[613, 0.13026950515838204`], 
         DiskBox[614, 0.13026950515838204`], 
         DiskBox[615, 0.13026950515838204`], 
         DiskBox[616, 0.13026950515838204`], 
         DiskBox[617, 0.13026950515838204`], 
         DiskBox[618, 0.13026950515838204`], 
         DiskBox[619, 0.13026950515838204`], 
         DiskBox[620, 0.13026950515838204`], 
         DiskBox[621, 0.13026950515838204`], 
         DiskBox[622, 0.13026950515838204`], 
         DiskBox[623, 0.13026950515838204`], 
         DiskBox[624, 0.13026950515838204`], 
         DiskBox[625, 0.13026950515838204`], 
         DiskBox[626, 0.13026950515838204`], 
         DiskBox[627, 0.13026950515838204`], 
         DiskBox[628, 0.13026950515838204`], 
         DiskBox[629, 0.13026950515838204`], 
         DiskBox[630, 0.13026950515838204`], 
         DiskBox[631, 0.13026950515838204`], 
         DiskBox[632, 0.13026950515838204`], 
         DiskBox[633, 0.13026950515838204`], 
         DiskBox[634, 0.13026950515838204`], 
         DiskBox[635, 0.13026950515838204`], 
         DiskBox[636, 0.13026950515838204`], 
         DiskBox[637, 0.13026950515838204`], 
         DiskBox[638, 0.13026950515838204`], 
         DiskBox[639, 0.13026950515838204`], 
         DiskBox[640, 0.13026950515838204`], 
         DiskBox[641, 0.13026950515838204`], 
         DiskBox[642, 0.13026950515838204`], 
         DiskBox[643, 0.13026950515838204`], 
         DiskBox[644, 0.13026950515838204`], 
         DiskBox[645, 0.13026950515838204`], 
         DiskBox[646, 0.13026950515838204`], 
         DiskBox[647, 0.13026950515838204`], 
         DiskBox[648, 0.13026950515838204`], 
         DiskBox[649, 0.13026950515838204`], 
         DiskBox[650, 0.13026950515838204`], 
         DiskBox[651, 0.13026950515838204`], 
         DiskBox[652, 0.13026950515838204`], 
         DiskBox[653, 0.13026950515838204`], 
         DiskBox[654, 0.13026950515838204`], 
         DiskBox[655, 0.13026950515838204`], 
         DiskBox[656, 0.13026950515838204`], 
         DiskBox[657, 0.13026950515838204`], 
         DiskBox[658, 0.13026950515838204`], 
         DiskBox[659, 0.13026950515838204`], 
         DiskBox[660, 0.13026950515838204`], 
         DiskBox[661, 0.13026950515838204`], 
         DiskBox[662, 0.13026950515838204`], 
         DiskBox[663, 0.13026950515838204`], 
         DiskBox[664, 0.13026950515838204`], 
         DiskBox[665, 0.13026950515838204`], 
         DiskBox[666, 0.13026950515838204`], 
         DiskBox[667, 0.13026950515838204`], 
         DiskBox[668, 0.13026950515838204`], 
         DiskBox[669, 0.13026950515838204`], 
         DiskBox[670, 0.13026950515838204`], 
         DiskBox[671, 0.13026950515838204`], 
         DiskBox[672, 0.13026950515838204`], 
         DiskBox[673, 0.13026950515838204`], 
         DiskBox[674, 0.13026950515838204`], 
         DiskBox[675, 0.13026950515838204`], 
         DiskBox[676, 0.13026950515838204`], 
         DiskBox[677, 0.13026950515838204`], 
         DiskBox[678, 0.13026950515838204`], 
         DiskBox[679, 0.13026950515838204`], 
         DiskBox[680, 0.13026950515838204`], 
         DiskBox[681, 0.13026950515838204`], 
         DiskBox[682, 0.13026950515838204`], 
         DiskBox[683, 0.13026950515838204`], 
         DiskBox[684, 0.13026950515838204`], 
         DiskBox[685, 0.13026950515838204`], 
         DiskBox[686, 0.13026950515838204`], 
         DiskBox[687, 0.13026950515838204`], 
         DiskBox[688, 0.13026950515838204`], 
         DiskBox[689, 0.13026950515838204`], 
         DiskBox[690, 0.13026950515838204`], 
         DiskBox[691, 0.13026950515838204`], 
         DiskBox[692, 0.13026950515838204`], 
         DiskBox[693, 0.13026950515838204`], 
         DiskBox[694, 0.13026950515838204`], 
         DiskBox[695, 0.13026950515838204`], 
         DiskBox[696, 0.13026950515838204`], 
         DiskBox[697, 0.13026950515838204`], 
         DiskBox[698, 0.13026950515838204`], 
         DiskBox[699, 0.13026950515838204`], 
         DiskBox[700, 0.13026950515838204`], 
         DiskBox[701, 0.13026950515838204`], 
         DiskBox[702, 0.13026950515838204`], 
         DiskBox[703, 0.13026950515838204`], 
         DiskBox[704, 0.13026950515838204`], 
         DiskBox[705, 0.13026950515838204`], 
         DiskBox[706, 0.13026950515838204`], 
         DiskBox[707, 0.13026950515838204`], 
         DiskBox[708, 0.13026950515838204`], 
         DiskBox[709, 0.13026950515838204`], 
         DiskBox[710, 0.13026950515838204`], 
         DiskBox[711, 0.13026950515838204`], 
         DiskBox[712, 0.13026950515838204`], 
         DiskBox[713, 0.13026950515838204`], 
         DiskBox[714, 0.13026950515838204`], 
         DiskBox[715, 0.13026950515838204`], 
         DiskBox[716, 0.13026950515838204`], 
         DiskBox[717, 0.13026950515838204`], 
         DiskBox[718, 0.13026950515838204`], 
         DiskBox[719, 0.13026950515838204`], 
         DiskBox[720, 0.13026950515838204`], 
         DiskBox[721, 0.13026950515838204`], 
         DiskBox[722, 0.13026950515838204`], 
         DiskBox[723, 0.13026950515838204`], 
         DiskBox[724, 0.13026950515838204`], 
         DiskBox[725, 0.13026950515838204`], 
         DiskBox[726, 0.13026950515838204`], 
         DiskBox[727, 0.13026950515838204`], 
         DiskBox[728, 0.13026950515838204`], 
         DiskBox[729, 0.13026950515838204`], 
         DiskBox[730, 0.13026950515838204`], 
         DiskBox[731, 0.13026950515838204`], 
         DiskBox[732, 0.13026950515838204`], 
         DiskBox[733, 0.13026950515838204`], 
         DiskBox[734, 0.13026950515838204`], 
         DiskBox[735, 0.13026950515838204`], 
         DiskBox[736, 0.13026950515838204`], 
         DiskBox[737, 0.13026950515838204`], 
         DiskBox[738, 0.13026950515838204`], 
         DiskBox[739, 0.13026950515838204`], 
         DiskBox[740, 0.13026950515838204`], 
         DiskBox[741, 0.13026950515838204`], 
         DiskBox[742, 0.13026950515838204`], 
         DiskBox[743, 0.13026950515838204`], 
         DiskBox[744, 0.13026950515838204`], 
         DiskBox[745, 0.13026950515838204`], 
         DiskBox[746, 0.13026950515838204`], 
         DiskBox[747, 0.13026950515838204`], 
         DiskBox[748, 0.13026950515838204`], 
         DiskBox[749, 0.13026950515838204`], 
         DiskBox[750, 0.13026950515838204`], 
         DiskBox[751, 0.13026950515838204`], 
         DiskBox[752, 0.13026950515838204`], 
         DiskBox[753, 0.13026950515838204`], 
         DiskBox[754, 0.13026950515838204`], 
         DiskBox[755, 0.13026950515838204`], 
         DiskBox[756, 0.13026950515838204`], 
         DiskBox[757, 0.13026950515838204`], 
         DiskBox[758, 0.13026950515838204`], 
         DiskBox[759, 0.13026950515838204`], 
         DiskBox[760, 0.13026950515838204`], 
         DiskBox[761, 0.13026950515838204`], 
         DiskBox[762, 0.13026950515838204`], 
         DiskBox[763, 0.13026950515838204`], 
         DiskBox[764, 0.13026950515838204`], 
         DiskBox[765, 0.13026950515838204`], 
         DiskBox[766, 0.13026950515838204`], 
         DiskBox[767, 0.13026950515838204`], 
         DiskBox[768, 0.13026950515838204`], 
         DiskBox[769, 0.13026950515838204`], 
         DiskBox[770, 0.13026950515838204`], 
         DiskBox[771, 0.13026950515838204`], 
         DiskBox[772, 0.13026950515838204`], 
         DiskBox[773, 0.13026950515838204`], 
         DiskBox[774, 0.13026950515838204`], 
         DiskBox[775, 0.13026950515838204`], 
         DiskBox[776, 0.13026950515838204`], 
         DiskBox[777, 0.13026950515838204`], 
         DiskBox[778, 0.13026950515838204`], 
         DiskBox[779, 0.13026950515838204`], 
         DiskBox[780, 0.13026950515838204`], 
         DiskBox[781, 0.13026950515838204`], 
         DiskBox[782, 0.13026950515838204`], 
         DiskBox[783, 0.13026950515838204`], 
         DiskBox[784, 0.13026950515838204`], 
         DiskBox[785, 0.13026950515838204`], 
         DiskBox[786, 0.13026950515838204`], 
         DiskBox[787, 0.13026950515838204`], 
         DiskBox[788, 0.13026950515838204`], 
         DiskBox[789, 0.13026950515838204`], 
         DiskBox[790, 0.13026950515838204`], 
         DiskBox[791, 0.13026950515838204`], 
         DiskBox[792, 0.13026950515838204`], 
         DiskBox[793, 0.13026950515838204`], 
         DiskBox[794, 0.13026950515838204`], 
         DiskBox[795, 0.13026950515838204`], 
         DiskBox[796, 0.13026950515838204`], 
         DiskBox[797, 0.13026950515838204`], 
         DiskBox[798, 0.13026950515838204`], 
         DiskBox[799, 0.13026950515838204`], 
         DiskBox[800, 0.13026950515838204`], 
         DiskBox[801, 0.13026950515838204`], 
         DiskBox[802, 0.13026950515838204`], 
         DiskBox[803, 0.13026950515838204`], 
         DiskBox[804, 0.13026950515838204`], 
         DiskBox[805, 0.13026950515838204`], 
         DiskBox[806, 0.13026950515838204`], 
         DiskBox[807, 0.13026950515838204`], 
         DiskBox[808, 0.13026950515838204`], 
         DiskBox[809, 0.13026950515838204`], 
         DiskBox[810, 0.13026950515838204`], 
         DiskBox[811, 0.13026950515838204`], 
         DiskBox[812, 0.13026950515838204`], 
         DiskBox[813, 0.13026950515838204`], 
         DiskBox[814, 0.13026950515838204`], 
         DiskBox[815, 0.13026950515838204`], 
         DiskBox[816, 0.13026950515838204`], 
         DiskBox[817, 0.13026950515838204`], 
         DiskBox[818, 0.13026950515838204`], 
         DiskBox[819, 0.13026950515838204`], 
         DiskBox[820, 0.13026950515838204`], 
         DiskBox[821, 0.13026950515838204`], 
         DiskBox[822, 0.13026950515838204`], 
         DiskBox[823, 0.13026950515838204`], 
         DiskBox[824, 0.13026950515838204`], 
         DiskBox[825, 0.13026950515838204`], 
         DiskBox[826, 0.13026950515838204`], 
         DiskBox[827, 0.13026950515838204`], 
         DiskBox[828, 0.13026950515838204`], 
         DiskBox[829, 0.13026950515838204`], 
         DiskBox[830, 0.13026950515838204`], 
         DiskBox[831, 0.13026950515838204`], 
         DiskBox[832, 0.13026950515838204`], 
         DiskBox[833, 0.13026950515838204`], 
         DiskBox[834, 0.13026950515838204`], 
         DiskBox[835, 0.13026950515838204`], 
         DiskBox[836, 0.13026950515838204`], 
         DiskBox[837, 0.13026950515838204`], 
         DiskBox[838, 0.13026950515838204`], 
         DiskBox[839, 0.13026950515838204`], 
         DiskBox[840, 0.13026950515838204`], 
         DiskBox[841, 0.13026950515838204`], 
         DiskBox[842, 0.13026950515838204`], 
         DiskBox[843, 0.13026950515838204`], 
         DiskBox[844, 0.13026950515838204`], 
         DiskBox[845, 0.13026950515838204`], 
         DiskBox[846, 0.13026950515838204`], 
         DiskBox[847, 0.13026950515838204`], 
         DiskBox[848, 0.13026950515838204`], 
         DiskBox[849, 0.13026950515838204`], 
         DiskBox[850, 0.13026950515838204`], 
         DiskBox[851, 0.13026950515838204`], 
         DiskBox[852, 0.13026950515838204`], 
         DiskBox[853, 0.13026950515838204`], 
         DiskBox[854, 0.13026950515838204`], 
         DiskBox[855, 0.13026950515838204`], 
         DiskBox[856, 0.13026950515838204`], 
         DiskBox[857, 0.13026950515838204`], 
         DiskBox[858, 0.13026950515838204`], 
         DiskBox[859, 0.13026950515838204`], 
         DiskBox[860, 0.13026950515838204`], 
         DiskBox[861, 0.13026950515838204`], 
         DiskBox[862, 0.13026950515838204`], 
         DiskBox[863, 0.13026950515838204`], 
         DiskBox[864, 0.13026950515838204`], 
         DiskBox[865, 0.13026950515838204`], 
         DiskBox[866, 0.13026950515838204`], 
         DiskBox[867, 0.13026950515838204`], 
         DiskBox[868, 0.13026950515838204`], 
         DiskBox[869, 0.13026950515838204`], 
         DiskBox[870, 0.13026950515838204`], 
         DiskBox[871, 0.13026950515838204`], 
         DiskBox[872, 0.13026950515838204`], 
         DiskBox[873, 0.13026950515838204`], 
         DiskBox[874, 0.13026950515838204`], 
         DiskBox[875, 0.13026950515838204`], 
         DiskBox[876, 0.13026950515838204`], 
         DiskBox[877, 0.13026950515838204`], 
         DiskBox[878, 0.13026950515838204`], 
         DiskBox[879, 0.13026950515838204`], 
         DiskBox[880, 0.13026950515838204`], 
         DiskBox[881, 0.13026950515838204`], 
         DiskBox[882, 0.13026950515838204`], 
         DiskBox[883, 0.13026950515838204`], 
         DiskBox[884, 0.13026950515838204`], 
         DiskBox[885, 0.13026950515838204`], 
         DiskBox[886, 0.13026950515838204`], 
         DiskBox[887, 0.13026950515838204`], 
         DiskBox[888, 0.13026950515838204`], 
         DiskBox[889, 0.13026950515838204`], 
         DiskBox[890, 0.13026950515838204`], 
         DiskBox[891, 0.13026950515838204`], 
         DiskBox[892, 0.13026950515838204`], 
         DiskBox[893, 0.13026950515838204`], 
         DiskBox[894, 0.13026950515838204`], 
         DiskBox[895, 0.13026950515838204`], 
         DiskBox[896, 0.13026950515838204`], 
         DiskBox[897, 0.13026950515838204`], 
         DiskBox[898, 0.13026950515838204`], 
         DiskBox[899, 0.13026950515838204`], 
         DiskBox[900, 0.13026950515838204`], 
         DiskBox[901, 0.13026950515838204`], 
         DiskBox[902, 0.13026950515838204`], 
         DiskBox[903, 0.13026950515838204`], 
         DiskBox[904, 0.13026950515838204`], 
         DiskBox[905, 0.13026950515838204`], 
         DiskBox[906, 0.13026950515838204`], 
         DiskBox[907, 0.13026950515838204`], 
         DiskBox[908, 0.13026950515838204`], 
         DiskBox[909, 0.13026950515838204`], 
         DiskBox[910, 0.13026950515838204`], 
         DiskBox[911, 0.13026950515838204`], 
         DiskBox[912, 0.13026950515838204`], 
         DiskBox[913, 0.13026950515838204`], 
         DiskBox[914, 0.13026950515838204`], 
         DiskBox[915, 0.13026950515838204`], 
         DiskBox[916, 0.13026950515838204`], 
         DiskBox[917, 0.13026950515838204`], 
         DiskBox[918, 0.13026950515838204`], 
         DiskBox[919, 0.13026950515838204`], 
         DiskBox[920, 0.13026950515838204`], 
         DiskBox[921, 0.13026950515838204`], 
         DiskBox[922, 0.13026950515838204`], 
         DiskBox[923, 0.13026950515838204`], 
         DiskBox[924, 0.13026950515838204`], 
         DiskBox[925, 0.13026950515838204`], 
         DiskBox[926, 0.13026950515838204`], 
         DiskBox[927, 0.13026950515838204`], 
         DiskBox[928, 0.13026950515838204`], 
         DiskBox[929, 0.13026950515838204`], 
         DiskBox[930, 0.13026950515838204`], 
         DiskBox[931, 0.13026950515838204`], 
         DiskBox[932, 0.13026950515838204`], 
         DiskBox[933, 0.13026950515838204`], 
         DiskBox[934, 0.13026950515838204`], 
         DiskBox[935, 0.13026950515838204`], 
         DiskBox[936, 0.13026950515838204`], 
         DiskBox[937, 0.13026950515838204`], 
         DiskBox[938, 0.13026950515838204`], 
         DiskBox[939, 0.13026950515838204`], 
         DiskBox[940, 0.13026950515838204`], 
         DiskBox[941, 0.13026950515838204`], 
         DiskBox[942, 0.13026950515838204`], 
         DiskBox[943, 0.13026950515838204`], 
         DiskBox[944, 0.13026950515838204`], 
         DiskBox[945, 0.13026950515838204`], 
         DiskBox[946, 0.13026950515838204`], 
         DiskBox[947, 0.13026950515838204`], 
         DiskBox[948, 0.13026950515838204`], 
         DiskBox[949, 0.13026950515838204`], 
         DiskBox[950, 0.13026950515838204`], 
         DiskBox[951, 0.13026950515838204`], 
         DiskBox[952, 0.13026950515838204`], 
         DiskBox[953, 0.13026950515838204`], 
         DiskBox[954, 0.13026950515838204`], 
         DiskBox[955, 0.13026950515838204`], 
         DiskBox[956, 0.13026950515838204`], 
         DiskBox[957, 0.13026950515838204`], 
         DiskBox[958, 0.13026950515838204`], 
         DiskBox[959, 0.13026950515838204`], 
         DiskBox[960, 0.13026950515838204`], 
         DiskBox[961, 0.13026950515838204`], 
         DiskBox[962, 0.13026950515838204`], 
         DiskBox[963, 0.13026950515838204`], 
         DiskBox[964, 0.13026950515838204`], 
         DiskBox[965, 0.13026950515838204`], 
         DiskBox[966, 0.13026950515838204`], 
         DiskBox[967, 0.13026950515838204`], 
         DiskBox[968, 0.13026950515838204`], 
         DiskBox[969, 0.13026950515838204`], 
         DiskBox[970, 0.13026950515838204`], 
         DiskBox[971, 0.13026950515838204`], 
         DiskBox[972, 0.13026950515838204`], 
         DiskBox[973, 0.13026950515838204`], 
         DiskBox[974, 0.13026950515838204`], 
         DiskBox[975, 0.13026950515838204`], 
         DiskBox[976, 0.13026950515838204`], 
         DiskBox[977, 0.13026950515838204`], 
         DiskBox[978, 0.13026950515838204`], 
         DiskBox[979, 0.13026950515838204`], 
         DiskBox[980, 0.13026950515838204`], 
         DiskBox[981, 0.13026950515838204`], 
         DiskBox[982, 0.13026950515838204`], 
         DiskBox[983, 0.13026950515838204`], 
         DiskBox[984, 0.13026950515838204`], 
         DiskBox[985, 0.13026950515838204`], 
         DiskBox[986, 0.13026950515838204`], 
         DiskBox[987, 0.13026950515838204`], 
         DiskBox[988, 0.13026950515838204`], 
         DiskBox[989, 0.13026950515838204`], 
         DiskBox[990, 0.13026950515838204`], 
         DiskBox[991, 0.13026950515838204`], 
         DiskBox[992, 0.13026950515838204`], 
         DiskBox[993, 0.13026950515838204`], 
         DiskBox[994, 0.13026950515838204`], 
         DiskBox[995, 0.13026950515838204`], 
         DiskBox[996, 0.13026950515838204`], 
         DiskBox[997, 0.13026950515838204`], 
         DiskBox[998, 0.13026950515838204`], 
         DiskBox[999, 0.13026950515838204`], 
         DiskBox[1000, 0.13026950515838204`], 
         DiskBox[1001, 0.13026950515838204`], 
         DiskBox[1002, 0.13026950515838204`], 
         DiskBox[1003, 0.13026950515838204`], 
         DiskBox[1004, 0.13026950515838204`], 
         DiskBox[1005, 0.13026950515838204`], 
         DiskBox[1006, 0.13026950515838204`], 
         DiskBox[1007, 0.13026950515838204`], 
         DiskBox[1008, 0.13026950515838204`], 
         DiskBox[1009, 0.13026950515838204`], 
         DiskBox[1010, 0.13026950515838204`], 
         DiskBox[1011, 0.13026950515838204`], 
         DiskBox[1012, 0.13026950515838204`], 
         DiskBox[1013, 0.13026950515838204`], 
         DiskBox[1014, 0.13026950515838204`], 
         DiskBox[1015, 0.13026950515838204`], 
         DiskBox[1016, 0.13026950515838204`], 
         DiskBox[1017, 0.13026950515838204`], 
         DiskBox[1018, 0.13026950515838204`], 
         DiskBox[1019, 0.13026950515838204`], 
         DiskBox[1020, 0.13026950515838204`], 
         DiskBox[1021, 0.13026950515838204`], 
         DiskBox[1022, 0.13026950515838204`], 
         DiskBox[1023, 0.13026950515838204`], 
         DiskBox[1024, 0.13026950515838204`], 
         DiskBox[1025, 0.13026950515838204`], 
         DiskBox[1026, 0.13026950515838204`], 
         DiskBox[1027, 0.13026950515838204`], 
         DiskBox[1028, 0.13026950515838204`], 
         DiskBox[1029, 0.13026950515838204`], 
         DiskBox[1030, 0.13026950515838204`], 
         DiskBox[1031, 0.13026950515838204`], 
         DiskBox[1032, 0.13026950515838204`], 
         DiskBox[1033, 0.13026950515838204`], 
         DiskBox[1034, 0.13026950515838204`], 
         DiskBox[1035, 0.13026950515838204`], 
         DiskBox[1036, 0.13026950515838204`], 
         DiskBox[1037, 0.13026950515838204`], 
         DiskBox[1038, 0.13026950515838204`], 
         DiskBox[1039, 0.13026950515838204`], 
         DiskBox[1040, 0.13026950515838204`], 
         DiskBox[1041, 0.13026950515838204`], 
         DiskBox[1042, 0.13026950515838204`], 
         DiskBox[1043, 0.13026950515838204`], 
         DiskBox[1044, 0.13026950515838204`], 
         DiskBox[1045, 0.13026950515838204`], 
         DiskBox[1046, 0.13026950515838204`], 
         DiskBox[1047, 0.13026950515838204`], 
         DiskBox[1048, 0.13026950515838204`], 
         DiskBox[1049, 0.13026950515838204`], 
         DiskBox[1050, 0.13026950515838204`], 
         DiskBox[1051, 0.13026950515838204`], 
         DiskBox[1052, 0.13026950515838204`], 
         DiskBox[1053, 0.13026950515838204`], 
         DiskBox[1054, 0.13026950515838204`], 
         DiskBox[1055, 0.13026950515838204`], 
         DiskBox[1056, 0.13026950515838204`], 
         DiskBox[1057, 0.13026950515838204`], 
         DiskBox[1058, 0.13026950515838204`], 
         DiskBox[1059, 0.13026950515838204`], 
         DiskBox[1060, 0.13026950515838204`], 
         DiskBox[1061, 0.13026950515838204`], 
         DiskBox[1062, 0.13026950515838204`], 
         DiskBox[1063, 0.13026950515838204`], 
         DiskBox[1064, 0.13026950515838204`], 
         DiskBox[1065, 0.13026950515838204`], 
         DiskBox[1066, 0.13026950515838204`], 
         DiskBox[1067, 0.13026950515838204`], 
         DiskBox[1068, 0.13026950515838204`], 
         DiskBox[1069, 0.13026950515838204`], 
         DiskBox[1070, 0.13026950515838204`], 
         DiskBox[1071, 0.13026950515838204`], 
         DiskBox[1072, 0.13026950515838204`], 
         DiskBox[1073, 0.13026950515838204`], 
         DiskBox[1074, 0.13026950515838204`], 
         DiskBox[1075, 0.13026950515838204`], 
         DiskBox[1076, 0.13026950515838204`], 
         DiskBox[1077, 0.13026950515838204`], 
         DiskBox[1078, 0.13026950515838204`], 
         DiskBox[1079, 0.13026950515838204`], 
         DiskBox[1080, 0.13026950515838204`], 
         DiskBox[1081, 0.13026950515838204`], 
         DiskBox[1082, 0.13026950515838204`], 
         DiskBox[1083, 0.13026950515838204`], 
         DiskBox[1084, 0.13026950515838204`], 
         DiskBox[1085, 0.13026950515838204`], 
         DiskBox[1086, 0.13026950515838204`], 
         DiskBox[1087, 0.13026950515838204`], 
         DiskBox[1088, 0.13026950515838204`], 
         DiskBox[1089, 0.13026950515838204`], 
         DiskBox[1090, 0.13026950515838204`], 
         DiskBox[1091, 0.13026950515838204`], 
         DiskBox[1092, 0.13026950515838204`], 
         DiskBox[1093, 0.13026950515838204`], 
         DiskBox[1094, 0.13026950515838204`], 
         DiskBox[1095, 0.13026950515838204`], 
         DiskBox[1096, 0.13026950515838204`], 
         DiskBox[1097, 0.13026950515838204`], 
         DiskBox[1098, 0.13026950515838204`], 
         DiskBox[1099, 0.13026950515838204`], 
         DiskBox[1100, 0.13026950515838204`], 
         DiskBox[1101, 0.13026950515838204`], 
         DiskBox[1102, 0.13026950515838204`], 
         DiskBox[1103, 0.13026950515838204`], 
         DiskBox[1104, 0.13026950515838204`], 
         DiskBox[1105, 0.13026950515838204`], 
         DiskBox[1106, 0.13026950515838204`], 
         DiskBox[1107, 0.13026950515838204`], 
         DiskBox[1108, 0.13026950515838204`], 
         DiskBox[1109, 0.13026950515838204`], 
         DiskBox[1110, 0.13026950515838204`], 
         DiskBox[1111, 0.13026950515838204`], 
         DiskBox[1112, 0.13026950515838204`], 
         DiskBox[1113, 0.13026950515838204`], 
         DiskBox[1114, 0.13026950515838204`], 
         DiskBox[1115, 0.13026950515838204`], 
         DiskBox[1116, 0.13026950515838204`], 
         DiskBox[1117, 0.13026950515838204`], 
         DiskBox[1118, 0.13026950515838204`], 
         DiskBox[1119, 0.13026950515838204`], 
         DiskBox[1120, 0.13026950515838204`], 
         DiskBox[1121, 0.13026950515838204`], 
         DiskBox[1122, 0.13026950515838204`], 
         DiskBox[1123, 0.13026950515838204`], 
         DiskBox[1124, 0.13026950515838204`], 
         DiskBox[1125, 0.13026950515838204`], 
         DiskBox[1126, 0.13026950515838204`], 
         DiskBox[1127, 0.13026950515838204`], 
         DiskBox[1128, 0.13026950515838204`], 
         DiskBox[1129, 0.13026950515838204`], 
         DiskBox[1130, 0.13026950515838204`], 
         DiskBox[1131, 0.13026950515838204`], 
         DiskBox[1132, 0.13026950515838204`], 
         DiskBox[1133, 0.13026950515838204`], 
         DiskBox[1134, 0.13026950515838204`], 
         DiskBox[1135, 0.13026950515838204`], 
         DiskBox[1136, 0.13026950515838204`], 
         DiskBox[1137, 0.13026950515838204`], 
         DiskBox[1138, 0.13026950515838204`], 
         DiskBox[1139, 0.13026950515838204`], 
         DiskBox[1140, 0.13026950515838204`], 
         DiskBox[1141, 0.13026950515838204`], 
         DiskBox[1142, 0.13026950515838204`], 
         DiskBox[1143, 0.13026950515838204`], 
         DiskBox[1144, 0.13026950515838204`], 
         DiskBox[1145, 0.13026950515838204`], 
         DiskBox[1146, 0.13026950515838204`], 
         DiskBox[1147, 0.13026950515838204`], 
         DiskBox[1148, 0.13026950515838204`], 
         DiskBox[1149, 0.13026950515838204`], 
         DiskBox[1150, 0.13026950515838204`], 
         DiskBox[1151, 0.13026950515838204`], 
         DiskBox[1152, 0.13026950515838204`], 
         DiskBox[1153, 0.13026950515838204`], 
         DiskBox[1154, 0.13026950515838204`], 
         DiskBox[1155, 0.13026950515838204`], 
         DiskBox[1156, 0.13026950515838204`], 
         DiskBox[1157, 0.13026950515838204`], 
         DiskBox[1158, 0.13026950515838204`], 
         DiskBox[1159, 0.13026950515838204`], 
         DiskBox[1160, 0.13026950515838204`], 
         DiskBox[1161, 0.13026950515838204`], 
         DiskBox[1162, 0.13026950515838204`], 
         DiskBox[1163, 0.13026950515838204`], 
         DiskBox[1164, 0.13026950515838204`], 
         DiskBox[1165, 0.13026950515838204`], 
         DiskBox[1166, 0.13026950515838204`], 
         DiskBox[1167, 0.13026950515838204`], 
         DiskBox[1168, 0.13026950515838204`], 
         DiskBox[1169, 0.13026950515838204`], 
         DiskBox[1170, 0.13026950515838204`], 
         DiskBox[1171, 0.13026950515838204`], 
         DiskBox[1172, 0.13026950515838204`], 
         DiskBox[1173, 0.13026950515838204`], 
         DiskBox[1174, 0.13026950515838204`], 
         DiskBox[1175, 0.13026950515838204`], 
         DiskBox[1176, 0.13026950515838204`], 
         DiskBox[1177, 0.13026950515838204`], 
         DiskBox[1178, 0.13026950515838204`], 
         DiskBox[1179, 0.13026950515838204`], 
         DiskBox[1180, 0.13026950515838204`], 
         DiskBox[1181, 0.13026950515838204`], 
         DiskBox[1182, 0.13026950515838204`], 
         DiskBox[1183, 0.13026950515838204`], 
         DiskBox[1184, 0.13026950515838204`], 
         DiskBox[1185, 0.13026950515838204`], 
         DiskBox[1186, 0.13026950515838204`], 
         DiskBox[1187, 0.13026950515838204`], 
         DiskBox[1188, 0.13026950515838204`], 
         DiskBox[1189, 0.13026950515838204`], 
         DiskBox[1190, 0.13026950515838204`], 
         DiskBox[1191, 0.13026950515838204`], 
         DiskBox[1192, 0.13026950515838204`], 
         DiskBox[1193, 0.13026950515838204`], 
         DiskBox[1194, 0.13026950515838204`], 
         DiskBox[1195, 0.13026950515838204`], 
         DiskBox[1196, 0.13026950515838204`], 
         DiskBox[1197, 0.13026950515838204`], 
         DiskBox[1198, 0.13026950515838204`], 
         DiskBox[1199, 0.13026950515838204`], 
         DiskBox[1200, 0.13026950515838204`], 
         DiskBox[1201, 0.13026950515838204`], 
         DiskBox[1202, 0.13026950515838204`], 
         DiskBox[1203, 0.13026950515838204`], 
         DiskBox[1204, 0.13026950515838204`], 
         DiskBox[1205, 0.13026950515838204`], 
         DiskBox[1206, 0.13026950515838204`], 
         DiskBox[1207, 0.13026950515838204`], 
         DiskBox[1208, 0.13026950515838204`], 
         DiskBox[1209, 0.13026950515838204`], 
         DiskBox[1210, 0.13026950515838204`], 
         DiskBox[1211, 0.13026950515838204`], 
         DiskBox[1212, 0.13026950515838204`], 
         DiskBox[1213, 0.13026950515838204`], 
         DiskBox[1214, 0.13026950515838204`], 
         DiskBox[1215, 0.13026950515838204`], 
         DiskBox[1216, 0.13026950515838204`], 
         DiskBox[1217, 0.13026950515838204`], 
         DiskBox[1218, 0.13026950515838204`], 
         DiskBox[1219, 0.13026950515838204`], 
         DiskBox[1220, 0.13026950515838204`], 
         DiskBox[1221, 0.13026950515838204`], 
         DiskBox[1222, 0.13026950515838204`], 
         DiskBox[1223, 0.13026950515838204`], 
         DiskBox[1224, 0.13026950515838204`], 
         DiskBox[1225, 0.13026950515838204`], 
         DiskBox[1226, 0.13026950515838204`], 
         DiskBox[1227, 0.13026950515838204`], 
         DiskBox[1228, 0.13026950515838204`], 
         DiskBox[1229, 0.13026950515838204`], 
         DiskBox[1230, 0.13026950515838204`], 
         DiskBox[1231, 0.13026950515838204`], 
         DiskBox[1232, 0.13026950515838204`], 
         DiskBox[1233, 0.13026950515838204`], 
         DiskBox[1234, 0.13026950515838204`], 
         DiskBox[1235, 0.13026950515838204`], 
         DiskBox[1236, 0.13026950515838204`], 
         DiskBox[1237, 0.13026950515838204`], 
         DiskBox[1238, 0.13026950515838204`], 
         DiskBox[1239, 0.13026950515838204`], 
         DiskBox[1240, 0.13026950515838204`], 
         DiskBox[1241, 0.13026950515838204`], 
         DiskBox[1242, 0.13026950515838204`], 
         DiskBox[1243, 0.13026950515838204`], 
         DiskBox[1244, 0.13026950515838204`], 
         DiskBox[1245, 0.13026950515838204`], 
         DiskBox[1246, 0.13026950515838204`], 
         DiskBox[1247, 0.13026950515838204`], 
         DiskBox[1248, 0.13026950515838204`], 
         DiskBox[1249, 0.13026950515838204`], 
         DiskBox[1250, 0.13026950515838204`], 
         DiskBox[1251, 0.13026950515838204`], 
         DiskBox[1252, 0.13026950515838204`], 
         DiskBox[1253, 0.13026950515838204`], 
         DiskBox[1254, 0.13026950515838204`], 
         DiskBox[1255, 0.13026950515838204`], 
         DiskBox[1256, 0.13026950515838204`], 
         DiskBox[1257, 0.13026950515838204`], 
         DiskBox[1258, 0.13026950515838204`], 
         DiskBox[1259, 0.13026950515838204`], 
         DiskBox[1260, 0.13026950515838204`], 
         DiskBox[1261, 0.13026950515838204`], 
         DiskBox[1262, 0.13026950515838204`], 
         DiskBox[1263, 0.13026950515838204`], 
         DiskBox[1264, 0.13026950515838204`], 
         DiskBox[1265, 0.13026950515838204`], 
         DiskBox[1266, 0.13026950515838204`], 
         DiskBox[1267, 0.13026950515838204`], 
         DiskBox[1268, 0.13026950515838204`], 
         DiskBox[1269, 0.13026950515838204`], 
         DiskBox[1270, 0.13026950515838204`], 
         DiskBox[1271, 0.13026950515838204`], 
         DiskBox[1272, 0.13026950515838204`], 
         DiskBox[1273, 0.13026950515838204`], 
         DiskBox[1274, 0.13026950515838204`], 
         DiskBox[1275, 0.13026950515838204`], 
         DiskBox[1276, 0.13026950515838204`], 
         DiskBox[1277, 0.13026950515838204`], 
         DiskBox[1278, 0.13026950515838204`], 
         DiskBox[1279, 0.13026950515838204`], 
         DiskBox[1280, 0.13026950515838204`], 
         DiskBox[1281, 0.13026950515838204`], 
         DiskBox[1282, 0.13026950515838204`], 
         DiskBox[1283, 0.13026950515838204`], 
         DiskBox[1284, 0.13026950515838204`], 
         DiskBox[1285, 0.13026950515838204`], 
         DiskBox[1286, 0.13026950515838204`], 
         DiskBox[1287, 0.13026950515838204`], 
         DiskBox[1288, 0.13026950515838204`], 
         DiskBox[1289, 0.13026950515838204`], 
         DiskBox[1290, 0.13026950515838204`], 
         DiskBox[1291, 0.13026950515838204`], 
         DiskBox[1292, 0.13026950515838204`], 
         DiskBox[1293, 0.13026950515838204`], 
         DiskBox[1294, 0.13026950515838204`], 
         DiskBox[1295, 0.13026950515838204`], 
         DiskBox[1296, 0.13026950515838204`], 
         DiskBox[1297, 0.13026950515838204`], 
         DiskBox[1298, 0.13026950515838204`], 
         DiskBox[1299, 0.13026950515838204`], 
         DiskBox[1300, 0.13026950515838204`], 
         DiskBox[1301, 0.13026950515838204`], 
         DiskBox[1302, 0.13026950515838204`], 
         DiskBox[1303, 0.13026950515838204`], 
         DiskBox[1304, 0.13026950515838204`], 
         DiskBox[1305, 0.13026950515838204`], 
         DiskBox[1306, 0.13026950515838204`], 
         DiskBox[1307, 0.13026950515838204`], 
         DiskBox[1308, 0.13026950515838204`], 
         DiskBox[1309, 0.13026950515838204`], 
         DiskBox[1310, 0.13026950515838204`], 
         DiskBox[1311, 0.13026950515838204`], 
         DiskBox[1312, 0.13026950515838204`], 
         DiskBox[1313, 0.13026950515838204`], 
         DiskBox[1314, 0.13026950515838204`], 
         DiskBox[1315, 0.13026950515838204`], 
         DiskBox[1316, 0.13026950515838204`], 
         DiskBox[1317, 0.13026950515838204`], 
         DiskBox[1318, 0.13026950515838204`], 
         DiskBox[1319, 0.13026950515838204`], 
         DiskBox[1320, 0.13026950515838204`], 
         DiskBox[1321, 0.13026950515838204`], 
         DiskBox[1322, 0.13026950515838204`], 
         DiskBox[1323, 0.13026950515838204`], 
         DiskBox[1324, 0.13026950515838204`], 
         DiskBox[1325, 0.13026950515838204`], 
         DiskBox[1326, 0.13026950515838204`], 
         DiskBox[1327, 0.13026950515838204`], 
         DiskBox[1328, 0.13026950515838204`], 
         DiskBox[1329, 0.13026950515838204`], 
         DiskBox[1330, 0.13026950515838204`], 
         DiskBox[1331, 0.13026950515838204`], 
         DiskBox[1332, 0.13026950515838204`], 
         DiskBox[1333, 0.13026950515838204`], 
         DiskBox[1334, 0.13026950515838204`], 
         DiskBox[1335, 0.13026950515838204`], 
         DiskBox[1336, 0.13026950515838204`], 
         DiskBox[1337, 0.13026950515838204`], 
         DiskBox[1338, 0.13026950515838204`], 
         DiskBox[1339, 0.13026950515838204`], 
         DiskBox[1340, 0.13026950515838204`], 
         DiskBox[1341, 0.13026950515838204`], 
         DiskBox[1342, 0.13026950515838204`], 
         DiskBox[1343, 0.13026950515838204`], 
         DiskBox[1344, 0.13026950515838204`], 
         DiskBox[1345, 0.13026950515838204`], 
         DiskBox[1346, 0.13026950515838204`], 
         DiskBox[1347, 0.13026950515838204`], 
         DiskBox[1348, 0.13026950515838204`], 
         DiskBox[1349, 0.13026950515838204`], 
         DiskBox[1350, 0.13026950515838204`], 
         DiskBox[1351, 0.13026950515838204`], 
         DiskBox[1352, 0.13026950515838204`], 
         DiskBox[1353, 0.13026950515838204`], 
         DiskBox[1354, 0.13026950515838204`], 
         DiskBox[1355, 0.13026950515838204`], 
         DiskBox[1356, 0.13026950515838204`], 
         DiskBox[1357, 0.13026950515838204`], 
         DiskBox[1358, 0.13026950515838204`], 
         DiskBox[1359, 0.13026950515838204`], 
         DiskBox[1360, 0.13026950515838204`], 
         DiskBox[1361, 0.13026950515838204`], 
         DiskBox[1362, 0.13026950515838204`], 
         DiskBox[1363, 0.13026950515838204`], 
         DiskBox[1364, 0.13026950515838204`], 
         DiskBox[1365, 0.13026950515838204`], 
         DiskBox[1366, 0.13026950515838204`], 
         DiskBox[1367, 0.13026950515838204`], 
         DiskBox[1368, 0.13026950515838204`], 
         DiskBox[1369, 0.13026950515838204`], 
         DiskBox[1370, 0.13026950515838204`], 
         DiskBox[1371, 0.13026950515838204`], 
         DiskBox[1372, 0.13026950515838204`], 
         DiskBox[1373, 0.13026950515838204`], 
         DiskBox[1374, 0.13026950515838204`], 
         DiskBox[1375, 0.13026950515838204`], 
         DiskBox[1376, 0.13026950515838204`], 
         DiskBox[1377, 0.13026950515838204`], 
         DiskBox[1378, 0.13026950515838204`], 
         DiskBox[1379, 0.13026950515838204`], 
         DiskBox[1380, 0.13026950515838204`], 
         DiskBox[1381, 0.13026950515838204`], 
         DiskBox[1382, 0.13026950515838204`], 
         DiskBox[1383, 0.13026950515838204`], 
         DiskBox[1384, 0.13026950515838204`], 
         DiskBox[1385, 0.13026950515838204`], 
         DiskBox[1386, 0.13026950515838204`], 
         DiskBox[1387, 0.13026950515838204`], 
         DiskBox[1388, 0.13026950515838204`], 
         DiskBox[1389, 0.13026950515838204`], 
         DiskBox[1390, 0.13026950515838204`], 
         DiskBox[1391, 0.13026950515838204`], 
         DiskBox[1392, 0.13026950515838204`], 
         DiskBox[1393, 0.13026950515838204`], 
         DiskBox[1394, 0.13026950515838204`], 
         DiskBox[1395, 0.13026950515838204`], 
         DiskBox[1396, 0.13026950515838204`], 
         DiskBox[1397, 0.13026950515838204`], 
         DiskBox[1398, 0.13026950515838204`], 
         DiskBox[1399, 0.13026950515838204`], 
         DiskBox[1400, 0.13026950515838204`], 
         DiskBox[1401, 0.13026950515838204`], 
         DiskBox[1402, 0.13026950515838204`], 
         DiskBox[1403, 0.13026950515838204`], 
         DiskBox[1404, 0.13026950515838204`], 
         DiskBox[1405, 0.13026950515838204`], 
         DiskBox[1406, 0.13026950515838204`], 
         DiskBox[1407, 0.13026950515838204`], 
         DiskBox[1408, 0.13026950515838204`], 
         DiskBox[1409, 0.13026950515838204`], 
         DiskBox[1410, 0.13026950515838204`], 
         DiskBox[1411, 0.13026950515838204`], 
         DiskBox[1412, 0.13026950515838204`], 
         DiskBox[1413, 0.13026950515838204`], 
         DiskBox[1414, 0.13026950515838204`], 
         DiskBox[1415, 0.13026950515838204`], 
         DiskBox[1416, 0.13026950515838204`], 
         DiskBox[1417, 0.13026950515838204`], 
         DiskBox[1418, 0.13026950515838204`], 
         DiskBox[1419, 0.13026950515838204`], 
         DiskBox[1420, 0.13026950515838204`], 
         DiskBox[1421, 0.13026950515838204`], 
         DiskBox[1422, 0.13026950515838204`], 
         DiskBox[1423, 0.13026950515838204`], 
         DiskBox[1424, 0.13026950515838204`], 
         DiskBox[1425, 0.13026950515838204`], 
         DiskBox[1426, 0.13026950515838204`], 
         DiskBox[1427, 0.13026950515838204`], 
         DiskBox[1428, 0.13026950515838204`], 
         DiskBox[1429, 0.13026950515838204`], 
         DiskBox[1430, 0.13026950515838204`], 
         DiskBox[1431, 0.13026950515838204`], 
         DiskBox[1432, 0.13026950515838204`], 
         DiskBox[1433, 0.13026950515838204`], 
         DiskBox[1434, 0.13026950515838204`], 
         DiskBox[1435, 0.13026950515838204`], 
         DiskBox[1436, 0.13026950515838204`], 
         DiskBox[1437, 0.13026950515838204`], 
         DiskBox[1438, 0.13026950515838204`], 
         DiskBox[1439, 0.13026950515838204`], 
         DiskBox[1440, 0.13026950515838204`], 
         DiskBox[1441, 0.13026950515838204`], 
         DiskBox[1442, 0.13026950515838204`], 
         DiskBox[1443, 0.13026950515838204`], 
         DiskBox[1444, 0.13026950515838204`], 
         DiskBox[1445, 0.13026950515838204`], 
         DiskBox[1446, 0.13026950515838204`], 
         DiskBox[1447, 0.13026950515838204`], 
         DiskBox[1448, 0.13026950515838204`], 
         DiskBox[1449, 0.13026950515838204`], 
         DiskBox[1450, 0.13026950515838204`], 
         DiskBox[1451, 0.13026950515838204`], 
         DiskBox[1452, 0.13026950515838204`], 
         DiskBox[1453, 0.13026950515838204`], 
         DiskBox[1454, 0.13026950515838204`], 
         DiskBox[1455, 0.13026950515838204`], 
         DiskBox[1456, 0.13026950515838204`], 
         DiskBox[1457, 0.13026950515838204`], 
         DiskBox[1458, 0.13026950515838204`], 
         DiskBox[1459, 0.13026950515838204`], 
         DiskBox[1460, 0.13026950515838204`], 
         DiskBox[1461, 0.13026950515838204`], 
         DiskBox[1462, 0.13026950515838204`], 
         DiskBox[1463, 0.13026950515838204`], 
         DiskBox[1464, 0.13026950515838204`], 
         DiskBox[1465, 0.13026950515838204`], 
         DiskBox[1466, 0.13026950515838204`], 
         DiskBox[1467, 0.13026950515838204`], 
         DiskBox[1468, 0.13026950515838204`], 
         DiskBox[1469, 0.13026950515838204`], 
         DiskBox[1470, 0.13026950515838204`], 
         DiskBox[1471, 0.13026950515838204`], 
         DiskBox[1472, 0.13026950515838204`], 
         DiskBox[1473, 0.13026950515838204`], 
         DiskBox[1474, 0.13026950515838204`], 
         DiskBox[1475, 0.13026950515838204`], 
         DiskBox[1476, 0.13026950515838204`], 
         DiskBox[1477, 0.13026950515838204`], 
         DiskBox[1478, 0.13026950515838204`], 
         DiskBox[1479, 0.13026950515838204`], 
         DiskBox[1480, 0.13026950515838204`], 
         DiskBox[1481, 0.13026950515838204`], 
         DiskBox[1482, 0.13026950515838204`], 
         DiskBox[1483, 0.13026950515838204`], 
         DiskBox[1484, 0.13026950515838204`], 
         DiskBox[1485, 0.13026950515838204`], 
         DiskBox[1486, 0.13026950515838204`], 
         DiskBox[1487, 0.13026950515838204`], 
         DiskBox[1488, 0.13026950515838204`], 
         DiskBox[1489, 0.13026950515838204`], 
         DiskBox[1490, 0.13026950515838204`], 
         DiskBox[1491, 0.13026950515838204`], 
         DiskBox[1492, 0.13026950515838204`], 
         DiskBox[1493, 0.13026950515838204`], 
         DiskBox[1494, 0.13026950515838204`], 
         DiskBox[1495, 0.13026950515838204`], 
         DiskBox[1496, 0.13026950515838204`], 
         DiskBox[1497, 0.13026950515838204`], 
         DiskBox[1498, 0.13026950515838204`], 
         DiskBox[1499, 0.13026950515838204`], 
         DiskBox[1500, 0.13026950515838204`], 
         DiskBox[1501, 0.13026950515838204`], 
         DiskBox[1502, 0.13026950515838204`], 
         DiskBox[1503, 0.13026950515838204`], 
         DiskBox[1504, 0.13026950515838204`], 
         DiskBox[1505, 0.13026950515838204`], 
         DiskBox[1506, 0.13026950515838204`], 
         DiskBox[1507, 0.13026950515838204`], 
         DiskBox[1508, 0.13026950515838204`], 
         DiskBox[1509, 0.13026950515838204`], 
         DiskBox[1510, 0.13026950515838204`], 
         DiskBox[1511, 0.13026950515838204`], 
         DiskBox[1512, 0.13026950515838204`], 
         DiskBox[1513, 0.13026950515838204`], 
         DiskBox[1514, 0.13026950515838204`], 
         DiskBox[1515, 0.13026950515838204`], 
         DiskBox[1516, 0.13026950515838204`], 
         DiskBox[1517, 0.13026950515838204`], 
         DiskBox[1518, 0.13026950515838204`], 
         DiskBox[1519, 0.13026950515838204`], 
         DiskBox[1520, 0.13026950515838204`], 
         DiskBox[1521, 0.13026950515838204`], 
         DiskBox[1522, 0.13026950515838204`], 
         DiskBox[1523, 0.13026950515838204`], 
         DiskBox[1524, 0.13026950515838204`], 
         DiskBox[1525, 0.13026950515838204`], 
         DiskBox[1526, 0.13026950515838204`], 
         DiskBox[1527, 0.13026950515838204`], 
         DiskBox[1528, 0.13026950515838204`], 
         DiskBox[1529, 0.13026950515838204`], 
         DiskBox[1530, 0.13026950515838204`], 
         DiskBox[1531, 0.13026950515838204`], 
         DiskBox[1532, 0.13026950515838204`], 
         DiskBox[1533, 0.13026950515838204`], 
         DiskBox[1534, 0.13026950515838204`], 
         DiskBox[1535, 0.13026950515838204`], 
         DiskBox[1536, 0.13026950515838204`], 
         DiskBox[1537, 0.13026950515838204`], 
         DiskBox[1538, 0.13026950515838204`], 
         DiskBox[1539, 0.13026950515838204`], 
         DiskBox[1540, 0.13026950515838204`], 
         DiskBox[1541, 0.13026950515838204`], 
         DiskBox[1542, 0.13026950515838204`], 
         DiskBox[1543, 0.13026950515838204`], 
         DiskBox[1544, 0.13026950515838204`], 
         DiskBox[1545, 0.13026950515838204`], 
         DiskBox[1546, 0.13026950515838204`], 
         DiskBox[1547, 0.13026950515838204`], 
         DiskBox[1548, 0.13026950515838204`], 
         DiskBox[1549, 0.13026950515838204`], 
         DiskBox[1550, 0.13026950515838204`], 
         DiskBox[1551, 0.13026950515838204`], 
         DiskBox[1552, 0.13026950515838204`], 
         DiskBox[1553, 0.13026950515838204`], 
         DiskBox[1554, 0.13026950515838204`], 
         DiskBox[1555, 0.13026950515838204`], 
         DiskBox[1556, 0.13026950515838204`], 
         DiskBox[1557, 0.13026950515838204`], 
         DiskBox[1558, 0.13026950515838204`], 
         DiskBox[1559, 0.13026950515838204`], 
         DiskBox[1560, 0.13026950515838204`], 
         DiskBox[1561, 0.13026950515838204`], 
         DiskBox[1562, 0.13026950515838204`], 
         DiskBox[1563, 0.13026950515838204`], 
         DiskBox[1564, 0.13026950515838204`], 
         DiskBox[1565, 0.13026950515838204`], 
         DiskBox[1566, 0.13026950515838204`], 
         DiskBox[1567, 0.13026950515838204`], 
         DiskBox[1568, 0.13026950515838204`], 
         DiskBox[1569, 0.13026950515838204`], 
         DiskBox[1570, 0.13026950515838204`], 
         DiskBox[1571, 0.13026950515838204`], 
         DiskBox[1572, 0.13026950515838204`], 
         DiskBox[1573, 0.13026950515838204`], 
         DiskBox[1574, 0.13026950515838204`], 
         DiskBox[1575, 0.13026950515838204`], 
         DiskBox[1576, 0.13026950515838204`], 
         DiskBox[1577, 0.13026950515838204`], 
         DiskBox[1578, 0.13026950515838204`], 
         DiskBox[1579, 0.13026950515838204`], 
         DiskBox[1580, 0.13026950515838204`], 
         DiskBox[1581, 0.13026950515838204`], 
         DiskBox[1582, 0.13026950515838204`], 
         DiskBox[1583, 0.13026950515838204`], 
         DiskBox[1584, 0.13026950515838204`], 
         DiskBox[1585, 0.13026950515838204`], 
         DiskBox[1586, 0.13026950515838204`], 
         DiskBox[1587, 0.13026950515838204`], 
         DiskBox[1588, 0.13026950515838204`], 
         DiskBox[1589, 0.13026950515838204`], 
         DiskBox[1590, 0.13026950515838204`], 
         DiskBox[1591, 0.13026950515838204`], 
         DiskBox[1592, 0.13026950515838204`], 
         DiskBox[1593, 0.13026950515838204`], 
         DiskBox[1594, 0.13026950515838204`], 
         DiskBox[1595, 0.13026950515838204`], 
         DiskBox[1596, 0.13026950515838204`], 
         DiskBox[1597, 0.13026950515838204`], 
         DiskBox[1598, 0.13026950515838204`], 
         DiskBox[1599, 0.13026950515838204`], 
         DiskBox[1600, 0.13026950515838204`], 
         DiskBox[1601, 0.13026950515838204`], 
         DiskBox[1602, 0.13026950515838204`], 
         DiskBox[1603, 0.13026950515838204`], 
         DiskBox[1604, 0.13026950515838204`], 
         DiskBox[1605, 0.13026950515838204`], 
         DiskBox[1606, 0.13026950515838204`], 
         DiskBox[1607, 0.13026950515838204`], 
         DiskBox[1608, 0.13026950515838204`], 
         DiskBox[1609, 0.13026950515838204`], 
         DiskBox[1610, 0.13026950515838204`], 
         DiskBox[1611, 0.13026950515838204`], 
         DiskBox[1612, 0.13026950515838204`], 
         DiskBox[1613, 0.13026950515838204`], 
         DiskBox[1614, 0.13026950515838204`], 
         DiskBox[1615, 0.13026950515838204`], 
         DiskBox[1616, 0.13026950515838204`], 
         DiskBox[1617, 0.13026950515838204`], 
         DiskBox[1618, 0.13026950515838204`], 
         DiskBox[1619, 0.13026950515838204`], 
         DiskBox[1620, 0.13026950515838204`], 
         DiskBox[1621, 0.13026950515838204`], 
         DiskBox[1622, 0.13026950515838204`], 
         DiskBox[1623, 0.13026950515838204`], 
         DiskBox[1624, 0.13026950515838204`], 
         DiskBox[1625, 0.13026950515838204`], 
         DiskBox[1626, 0.13026950515838204`], 
         DiskBox[1627, 0.13026950515838204`], 
         DiskBox[1628, 0.13026950515838204`], 
         DiskBox[1629, 0.13026950515838204`], 
         DiskBox[1630, 0.13026950515838204`], 
         DiskBox[1631, 0.13026950515838204`], 
         DiskBox[1632, 0.13026950515838204`], 
         DiskBox[1633, 0.13026950515838204`], 
         DiskBox[1634, 0.13026950515838204`], 
         DiskBox[1635, 0.13026950515838204`], 
         DiskBox[1636, 0.13026950515838204`], 
         DiskBox[1637, 0.13026950515838204`], 
         DiskBox[1638, 0.13026950515838204`], 
         DiskBox[1639, 0.13026950515838204`], 
         DiskBox[1640, 0.13026950515838204`], 
         DiskBox[1641, 0.13026950515838204`], 
         DiskBox[1642, 0.13026950515838204`], 
         DiskBox[1643, 0.13026950515838204`], 
         DiskBox[1644, 0.13026950515838204`], 
         DiskBox[1645, 0.13026950515838204`], 
         DiskBox[1646, 0.13026950515838204`], 
         DiskBox[1647, 0.13026950515838204`], 
         DiskBox[1648, 0.13026950515838204`], 
         DiskBox[1649, 0.13026950515838204`], 
         DiskBox[1650, 0.13026950515838204`], 
         DiskBox[1651, 0.13026950515838204`], 
         DiskBox[1652, 0.13026950515838204`], 
         DiskBox[1653, 0.13026950515838204`], 
         DiskBox[1654, 0.13026950515838204`], 
         DiskBox[1655, 0.13026950515838204`], 
         DiskBox[1656, 0.13026950515838204`], 
         DiskBox[1657, 0.13026950515838204`], 
         DiskBox[1658, 0.13026950515838204`], 
         DiskBox[1659, 0.13026950515838204`], 
         DiskBox[1660, 0.13026950515838204`], 
         DiskBox[1661, 0.13026950515838204`], 
         DiskBox[1662, 0.13026950515838204`], 
         DiskBox[1663, 0.13026950515838204`], 
         DiskBox[1664, 0.13026950515838204`], 
         DiskBox[1665, 0.13026950515838204`], 
         DiskBox[1666, 0.13026950515838204`], 
         DiskBox[1667, 0.13026950515838204`], 
         DiskBox[1668, 0.13026950515838204`], 
         DiskBox[1669, 0.13026950515838204`], 
         DiskBox[1670, 0.13026950515838204`], 
         DiskBox[1671, 0.13026950515838204`], 
         DiskBox[1672, 0.13026950515838204`], 
         DiskBox[1673, 0.13026950515838204`], 
         DiskBox[1674, 0.13026950515838204`], 
         DiskBox[1675, 0.13026950515838204`], 
         DiskBox[1676, 0.13026950515838204`], 
         DiskBox[1677, 0.13026950515838204`], 
         DiskBox[1678, 0.13026950515838204`], 
         DiskBox[1679, 0.13026950515838204`], 
         DiskBox[1680, 0.13026950515838204`], 
         DiskBox[1681, 0.13026950515838204`], 
         DiskBox[1682, 0.13026950515838204`], 
         DiskBox[1683, 0.13026950515838204`], 
         DiskBox[1684, 0.13026950515838204`], 
         DiskBox[1685, 0.13026950515838204`], 
         DiskBox[1686, 0.13026950515838204`], 
         DiskBox[1687, 0.13026950515838204`], 
         DiskBox[1688, 0.13026950515838204`], 
         DiskBox[1689, 0.13026950515838204`], 
         DiskBox[1690, 0.13026950515838204`], 
         DiskBox[1691, 0.13026950515838204`], 
         DiskBox[1692, 0.13026950515838204`], 
         DiskBox[1693, 0.13026950515838204`], 
         DiskBox[1694, 0.13026950515838204`], 
         DiskBox[1695, 0.13026950515838204`], 
         DiskBox[1696, 0.13026950515838204`], 
         DiskBox[1697, 0.13026950515838204`], 
         DiskBox[1698, 0.13026950515838204`], 
         DiskBox[1699, 0.13026950515838204`], 
         DiskBox[1700, 0.13026950515838204`], 
         DiskBox[1701, 0.13026950515838204`], 
         DiskBox[1702, 0.13026950515838204`], 
         DiskBox[1703, 0.13026950515838204`], 
         DiskBox[1704, 0.13026950515838204`], 
         DiskBox[1705, 0.13026950515838204`], 
         DiskBox[1706, 0.13026950515838204`], 
         DiskBox[1707, 0.13026950515838204`], 
         DiskBox[1708, 0.13026950515838204`], 
         DiskBox[1709, 0.13026950515838204`], 
         DiskBox[1710, 0.13026950515838204`], 
         DiskBox[1711, 0.13026950515838204`], 
         DiskBox[1712, 0.13026950515838204`], 
         DiskBox[1713, 0.13026950515838204`], 
         DiskBox[1714, 0.13026950515838204`], 
         DiskBox[1715, 0.13026950515838204`], 
         DiskBox[1716, 0.13026950515838204`], 
         DiskBox[1717, 0.13026950515838204`], 
         DiskBox[1718, 0.13026950515838204`], 
         DiskBox[1719, 0.13026950515838204`], 
         DiskBox[1720, 0.13026950515838204`], 
         DiskBox[1721, 0.13026950515838204`], 
         DiskBox[1722, 0.13026950515838204`], 
         DiskBox[1723, 0.13026950515838204`], 
         DiskBox[1724, 0.13026950515838204`], 
         DiskBox[1725, 0.13026950515838204`], 
         DiskBox[1726, 0.13026950515838204`], 
         DiskBox[1727, 0.13026950515838204`], 
         DiskBox[1728, 0.13026950515838204`], 
         DiskBox[1729, 0.13026950515838204`], 
         DiskBox[1730, 0.13026950515838204`], 
         DiskBox[1731, 0.13026950515838204`], 
         DiskBox[1732, 0.13026950515838204`], 
         DiskBox[1733, 0.13026950515838204`], 
         DiskBox[1734, 0.13026950515838204`], 
         DiskBox[1735, 0.13026950515838204`], 
         DiskBox[1736, 0.13026950515838204`], 
         DiskBox[1737, 0.13026950515838204`], 
         DiskBox[1738, 0.13026950515838204`], 
         DiskBox[1739, 0.13026950515838204`], 
         DiskBox[1740, 0.13026950515838204`], 
         DiskBox[1741, 0.13026950515838204`], 
         DiskBox[1742, 0.13026950515838204`], 
         DiskBox[1743, 0.13026950515838204`], 
         DiskBox[1744, 0.13026950515838204`], 
         DiskBox[1745, 0.13026950515838204`], 
         DiskBox[1746, 0.13026950515838204`], 
         DiskBox[1747, 0.13026950515838204`], 
         DiskBox[1748, 0.13026950515838204`], 
         DiskBox[1749, 0.13026950515838204`], 
         DiskBox[1750, 0.13026950515838204`], 
         DiskBox[1751, 0.13026950515838204`], 
         DiskBox[1752, 0.13026950515838204`], 
         DiskBox[1753, 0.13026950515838204`], 
         DiskBox[1754, 0.13026950515838204`], 
         DiskBox[1755, 0.13026950515838204`], 
         DiskBox[1756, 0.13026950515838204`], 
         DiskBox[1757, 0.13026950515838204`], 
         DiskBox[1758, 0.13026950515838204`], 
         DiskBox[1759, 0.13026950515838204`], 
         DiskBox[1760, 0.13026950515838204`], 
         DiskBox[1761, 0.13026950515838204`], 
         DiskBox[1762, 0.13026950515838204`], 
         DiskBox[1763, 0.13026950515838204`], 
         DiskBox[1764, 0.13026950515838204`], 
         DiskBox[1765, 0.13026950515838204`], 
         DiskBox[1766, 0.13026950515838204`], 
         DiskBox[1767, 0.13026950515838204`], 
         DiskBox[1768, 0.13026950515838204`], 
         DiskBox[1769, 0.13026950515838204`], 
         DiskBox[1770, 0.13026950515838204`], 
         DiskBox[1771, 0.13026950515838204`], 
         DiskBox[1772, 0.13026950515838204`], 
         DiskBox[1773, 0.13026950515838204`], 
         DiskBox[1774, 0.13026950515838204`], 
         DiskBox[1775, 0.13026950515838204`], 
         DiskBox[1776, 0.13026950515838204`], 
         DiskBox[1777, 0.13026950515838204`], 
         DiskBox[1778, 0.13026950515838204`], 
         DiskBox[1779, 0.13026950515838204`], 
         DiskBox[1780, 0.13026950515838204`], 
         DiskBox[1781, 0.13026950515838204`], 
         DiskBox[1782, 0.13026950515838204`], 
         DiskBox[1783, 0.13026950515838204`], 
         DiskBox[1784, 0.13026950515838204`], 
         DiskBox[1785, 0.13026950515838204`], 
         DiskBox[1786, 0.13026950515838204`], 
         DiskBox[1787, 0.13026950515838204`], 
         DiskBox[1788, 0.13026950515838204`], 
         DiskBox[1789, 0.13026950515838204`], 
         DiskBox[1790, 0.13026950515838204`], 
         DiskBox[1791, 0.13026950515838204`], 
         DiskBox[1792, 0.13026950515838204`], 
         DiskBox[1793, 0.13026950515838204`], 
         DiskBox[1794, 0.13026950515838204`], 
         DiskBox[1795, 0.13026950515838204`], 
         DiskBox[1796, 0.13026950515838204`], 
         DiskBox[1797, 0.13026950515838204`], 
         DiskBox[1798, 0.13026950515838204`], 
         DiskBox[1799, 0.13026950515838204`], 
         DiskBox[1800, 0.13026950515838204`], 
         DiskBox[1801, 0.13026950515838204`], 
         DiskBox[1802, 0.13026950515838204`], 
         DiskBox[1803, 0.13026950515838204`], 
         DiskBox[1804, 0.13026950515838204`], 
         DiskBox[1805, 0.13026950515838204`], 
         DiskBox[1806, 0.13026950515838204`], 
         DiskBox[1807, 0.13026950515838204`], 
         DiskBox[1808, 0.13026950515838204`], 
         DiskBox[1809, 0.13026950515838204`], 
         DiskBox[1810, 0.13026950515838204`], 
         DiskBox[1811, 0.13026950515838204`], 
         DiskBox[1812, 0.13026950515838204`], 
         DiskBox[1813, 0.13026950515838204`], 
         DiskBox[1814, 0.13026950515838204`], 
         DiskBox[1815, 0.13026950515838204`], 
         DiskBox[1816, 0.13026950515838204`], 
         DiskBox[1817, 0.13026950515838204`], 
         DiskBox[1818, 0.13026950515838204`], 
         DiskBox[1819, 0.13026950515838204`], 
         DiskBox[1820, 0.13026950515838204`], 
         DiskBox[1821, 0.13026950515838204`], 
         DiskBox[1822, 0.13026950515838204`], 
         DiskBox[1823, 0.13026950515838204`], 
         DiskBox[1824, 0.13026950515838204`], 
         DiskBox[1825, 0.13026950515838204`], 
         DiskBox[1826, 0.13026950515838204`], 
         DiskBox[1827, 0.13026950515838204`], 
         DiskBox[1828, 0.13026950515838204`], 
         DiskBox[1829, 0.13026950515838204`], 
         DiskBox[1830, 0.13026950515838204`], 
         DiskBox[1831, 0.13026950515838204`], 
         DiskBox[1832, 0.13026950515838204`], 
         DiskBox[1833, 0.13026950515838204`], 
         DiskBox[1834, 0.13026950515838204`], 
         DiskBox[1835, 0.13026950515838204`], 
         DiskBox[1836, 0.13026950515838204`], 
         DiskBox[1837, 0.13026950515838204`], 
         DiskBox[1838, 0.13026950515838204`], 
         DiskBox[1839, 0.13026950515838204`], 
         DiskBox[1840, 0.13026950515838204`], 
         DiskBox[1841, 0.13026950515838204`], 
         DiskBox[1842, 0.13026950515838204`], 
         DiskBox[1843, 0.13026950515838204`], 
         DiskBox[1844, 0.13026950515838204`], 
         DiskBox[1845, 0.13026950515838204`], 
         DiskBox[1846, 0.13026950515838204`], 
         DiskBox[1847, 0.13026950515838204`], 
         DiskBox[1848, 0.13026950515838204`], 
         DiskBox[1849, 0.13026950515838204`], 
         DiskBox[1850, 0.13026950515838204`], 
         DiskBox[1851, 0.13026950515838204`], 
         DiskBox[1852, 0.13026950515838204`], 
         DiskBox[1853, 0.13026950515838204`], 
         DiskBox[1854, 0.13026950515838204`], 
         DiskBox[1855, 0.13026950515838204`], 
         DiskBox[1856, 0.13026950515838204`], 
         DiskBox[1857, 0.13026950515838204`], 
         DiskBox[1858, 0.13026950515838204`], 
         DiskBox[1859, 0.13026950515838204`], 
         DiskBox[1860, 0.13026950515838204`], 
         DiskBox[1861, 0.13026950515838204`], 
         DiskBox[1862, 0.13026950515838204`], 
         DiskBox[1863, 0.13026950515838204`], 
         DiskBox[1864, 0.13026950515838204`], 
         DiskBox[1865, 0.13026950515838204`], 
         DiskBox[1866, 0.13026950515838204`], 
         DiskBox[1867, 0.13026950515838204`], 
         DiskBox[1868, 0.13026950515838204`], 
         DiskBox[1869, 0.13026950515838204`], 
         DiskBox[1870, 0.13026950515838204`], 
         DiskBox[1871, 0.13026950515838204`], 
         DiskBox[1872, 0.13026950515838204`], 
         DiskBox[1873, 0.13026950515838204`], 
         DiskBox[1874, 0.13026950515838204`], 
         DiskBox[1875, 0.13026950515838204`], 
         DiskBox[1876, 0.13026950515838204`], 
         DiskBox[1877, 0.13026950515838204`], 
         DiskBox[1878, 0.13026950515838204`], 
         DiskBox[1879, 0.13026950515838204`], 
         DiskBox[1880, 0.13026950515838204`], 
         DiskBox[1881, 0.13026950515838204`], 
         DiskBox[1882, 0.13026950515838204`], 
         DiskBox[1883, 0.13026950515838204`], 
         DiskBox[1884, 0.13026950515838204`], 
         DiskBox[1885, 0.13026950515838204`], 
         DiskBox[1886, 0.13026950515838204`], 
         DiskBox[1887, 0.13026950515838204`], 
         DiskBox[1888, 0.13026950515838204`], 
         DiskBox[1889, 0.13026950515838204`], 
         DiskBox[1890, 0.13026950515838204`], 
         DiskBox[1891, 0.13026950515838204`], 
         DiskBox[1892, 0.13026950515838204`], 
         DiskBox[1893, 0.13026950515838204`], 
         DiskBox[1894, 0.13026950515838204`], 
         DiskBox[1895, 0.13026950515838204`], 
         DiskBox[1896, 0.13026950515838204`], 
         DiskBox[1897, 0.13026950515838204`], 
         DiskBox[1898, 0.13026950515838204`], 
         DiskBox[1899, 0.13026950515838204`], 
         DiskBox[1900, 0.13026950515838204`], 
         DiskBox[1901, 0.13026950515838204`], 
         DiskBox[1902, 0.13026950515838204`], 
         DiskBox[1903, 0.13026950515838204`], 
         DiskBox[1904, 0.13026950515838204`], 
         DiskBox[1905, 0.13026950515838204`], 
         DiskBox[1906, 0.13026950515838204`], 
         DiskBox[1907, 0.13026950515838204`], 
         DiskBox[1908, 0.13026950515838204`], 
         DiskBox[1909, 0.13026950515838204`], 
         DiskBox[1910, 0.13026950515838204`], 
         DiskBox[1911, 0.13026950515838204`], 
         DiskBox[1912, 0.13026950515838204`], 
         DiskBox[1913, 0.13026950515838204`], 
         DiskBox[1914, 0.13026950515838204`], 
         DiskBox[1915, 0.13026950515838204`], 
         DiskBox[1916, 0.13026950515838204`], 
         DiskBox[1917, 0.13026950515838204`], 
         DiskBox[1918, 0.13026950515838204`], 
         DiskBox[1919, 0.13026950515838204`], 
         DiskBox[1920, 0.13026950515838204`], 
         DiskBox[1921, 0.13026950515838204`], 
         DiskBox[1922, 0.13026950515838204`], 
         DiskBox[1923, 0.13026950515838204`], 
         DiskBox[1924, 0.13026950515838204`], 
         DiskBox[1925, 0.13026950515838204`], 
         DiskBox[1926, 0.13026950515838204`], 
         DiskBox[1927, 0.13026950515838204`], 
         DiskBox[1928, 0.13026950515838204`], 
         DiskBox[1929, 0.13026950515838204`], 
         DiskBox[1930, 0.13026950515838204`], 
         DiskBox[1931, 0.13026950515838204`], 
         DiskBox[1932, 0.13026950515838204`], 
         DiskBox[1933, 0.13026950515838204`], 
         DiskBox[1934, 0.13026950515838204`], 
         DiskBox[1935, 0.13026950515838204`], 
         DiskBox[1936, 0.13026950515838204`], 
         DiskBox[1937, 0.13026950515838204`], 
         DiskBox[1938, 0.13026950515838204`], 
         DiskBox[1939, 0.13026950515838204`], 
         DiskBox[1940, 0.13026950515838204`], 
         DiskBox[1941, 0.13026950515838204`], 
         DiskBox[1942, 0.13026950515838204`], 
         DiskBox[1943, 0.13026950515838204`], 
         DiskBox[1944, 0.13026950515838204`], 
         DiskBox[1945, 0.13026950515838204`], 
         DiskBox[1946, 0.13026950515838204`], 
         DiskBox[1947, 0.13026950515838204`], 
         DiskBox[1948, 0.13026950515838204`], 
         DiskBox[1949, 0.13026950515838204`], 
         DiskBox[1950, 0.13026950515838204`], 
         DiskBox[1951, 0.13026950515838204`], 
         DiskBox[1952, 0.13026950515838204`], 
         DiskBox[1953, 0.13026950515838204`], 
         DiskBox[1954, 0.13026950515838204`], 
         DiskBox[1955, 0.13026950515838204`], 
         DiskBox[1956, 0.13026950515838204`], 
         DiskBox[1957, 0.13026950515838204`], 
         DiskBox[1958, 0.13026950515838204`], 
         DiskBox[1959, 0.13026950515838204`], 
         DiskBox[1960, 0.13026950515838204`], 
         DiskBox[1961, 0.13026950515838204`], 
         DiskBox[1962, 0.13026950515838204`], 
         DiskBox[1963, 0.13026950515838204`], 
         DiskBox[1964, 0.13026950515838204`], 
         DiskBox[1965, 0.13026950515838204`], 
         DiskBox[1966, 0.13026950515838204`], 
         DiskBox[1967, 0.13026950515838204`], 
         DiskBox[1968, 0.13026950515838204`], 
         DiskBox[1969, 0.13026950515838204`], 
         DiskBox[1970, 0.13026950515838204`], 
         DiskBox[1971, 0.13026950515838204`], 
         DiskBox[1972, 0.13026950515838204`], 
         DiskBox[1973, 0.13026950515838204`], 
         DiskBox[1974, 0.13026950515838204`], 
         DiskBox[1975, 0.13026950515838204`], 
         DiskBox[1976, 0.13026950515838204`], 
         DiskBox[1977, 0.13026950515838204`], 
         DiskBox[1978, 0.13026950515838204`], 
         DiskBox[1979, 0.13026950515838204`], 
         DiskBox[1980, 0.13026950515838204`], 
         DiskBox[1981, 0.13026950515838204`], 
         DiskBox[1982, 0.13026950515838204`], 
         DiskBox[1983, 0.13026950515838204`], 
         DiskBox[1984, 0.13026950515838204`], 
         DiskBox[1985, 0.13026950515838204`], 
         DiskBox[1986, 0.13026950515838204`], 
         DiskBox[1987, 0.13026950515838204`], 
         DiskBox[1988, 0.13026950515838204`], 
         DiskBox[1989, 0.13026950515838204`], 
         DiskBox[1990, 0.13026950515838204`], 
         DiskBox[1991, 0.13026950515838204`], 
         DiskBox[1992, 0.13026950515838204`], 
         DiskBox[1993, 0.13026950515838204`], 
         DiskBox[1994, 0.13026950515838204`], 
         DiskBox[1995, 0.13026950515838204`], 
         DiskBox[1996, 0.13026950515838204`], 
         DiskBox[1997, 0.13026950515838204`], 
         DiskBox[1998, 0.13026950515838204`], 
         DiskBox[1999, 0.13026950515838204`], 
         DiskBox[2000, 0.13026950515838204`], 
         DiskBox[2001, 0.13026950515838204`], 
         DiskBox[2002, 0.13026950515838204`], 
         DiskBox[2003, 0.13026950515838204`], 
         DiskBox[2004, 0.13026950515838204`], 
         DiskBox[2005, 0.13026950515838204`], 
         DiskBox[2006, 0.13026950515838204`], 
         DiskBox[2007, 0.13026950515838204`], 
         DiskBox[2008, 0.13026950515838204`], 
         DiskBox[2009, 0.13026950515838204`], 
         DiskBox[2010, 0.13026950515838204`], 
         DiskBox[2011, 0.13026950515838204`], 
         DiskBox[2012, 0.13026950515838204`], 
         DiskBox[2013, 0.13026950515838204`], 
         DiskBox[2014, 0.13026950515838204`], 
         DiskBox[2015, 0.13026950515838204`], 
         DiskBox[2016, 0.13026950515838204`], 
         DiskBox[2017, 0.13026950515838204`], 
         DiskBox[2018, 0.13026950515838204`], 
         DiskBox[2019, 0.13026950515838204`], 
         DiskBox[2020, 0.13026950515838204`], 
         DiskBox[2021, 0.13026950515838204`], 
         DiskBox[2022, 0.13026950515838204`], 
         DiskBox[2023, 0.13026950515838204`], 
         DiskBox[2024, 0.13026950515838204`], 
         DiskBox[2025, 0.13026950515838204`], 
         DiskBox[2026, 0.13026950515838204`], 
         DiskBox[2027, 0.13026950515838204`], 
         DiskBox[2028, 0.13026950515838204`], 
         DiskBox[2029, 0.13026950515838204`], 
         DiskBox[2030, 0.13026950515838204`], 
         DiskBox[2031, 0.13026950515838204`], 
         DiskBox[2032, 0.13026950515838204`], 
         DiskBox[2033, 0.13026950515838204`], 
         DiskBox[2034, 0.13026950515838204`], 
         DiskBox[2035, 0.13026950515838204`], 
         DiskBox[2036, 0.13026950515838204`], 
         DiskBox[2037, 0.13026950515838204`], 
         DiskBox[2038, 0.13026950515838204`], 
         DiskBox[2039, 0.13026950515838204`], 
         DiskBox[2040, 0.13026950515838204`], 
         DiskBox[2041, 0.13026950515838204`], 
         DiskBox[2042, 0.13026950515838204`], 
         DiskBox[2043, 0.13026950515838204`], 
         DiskBox[2044, 0.13026950515838204`], 
         DiskBox[2045, 0.13026950515838204`], 
         DiskBox[2046, 0.13026950515838204`], 
         DiskBox[2047, 0.13026950515838204`], 
         DiskBox[2048, 0.13026950515838204`]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaseStyle->{
    EdgeForm[
     GrayLevel[0]]},
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.6775727968246837`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
Eine Analyse der zusammenh\[ADoubleDot]ngenden Komponenten und ihrer Gr\
\[ODoubleDot]\[SZ]en erlaubt uns, sehr elegant Tab. 1 aus Li et al. (2004) zu \
reproduzieren:\
\>", "Text",
 CellChangeTimes->{{3.677398244020945*^9, 3.6773982529285603`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Length", ",", 
   RowBox[{"WeaklyConnectedComponents", "[", 
    RowBox[{"Graph", "[", "asp2", "]"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1764", ",", "151", ",", "109", ",", "9", ",", "7", ",", "7", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677572796949484*^9}]
}, Open  ]],

Cell[TextData[{
 "Den dominanten Attraktor k\[ODoubleDot]nnen wir n\[ADoubleDot]her \
betrachten. Hierzu w\[ADoubleDot]hlen wir eine radiale Einbettung des Graphen \
um den Fixpunkt (das letzte Element aus der Zeitreihe ",
 StyleBox["res1",
  FontWeight->"Bold"],
 ") herum."
}], "Text",
 CellChangeTimes->{{3.677398299608843*^9, 3.6773983107170625`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gYeast2", " ", "=", " ", 
   RowBox[{"Subgraph", "[", 
    RowBox[{"gYeast", ",", 
     RowBox[{
      RowBox[{"WeaklyConnectedComponents", "[", 
       RowBox[{"Graph", "[", "asp2", "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"GraphLayout", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<RadialEmbedding\>\"", ",", " ", 
        RowBox[{"\"\<RootVertex\>\"", "\[Rule]", 
         RowBox[{"IntegerString", "[", 
          RowBox[{
           RowBox[{"FromDigits", "[", 
            RowBox[{
             RowBox[{"res1", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], ",", "2"}], "]"}], ",", "2", 
           ",", "12"}], "]"}]}]}], "}"}]}], ",", 
     RowBox[{"VertexStyle", "\[Rule]", "LightGray"}], ",", 
     RowBox[{"VertexSize", "\[Rule]", "25"}], ",", 
     RowBox[{"VertexShapeFunction", "\[Rule]", "\"\<Circle\>\""}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"EdgeForm", "[", "Black", "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.606369350319416*^9, 3.606369378644113*^9}, 
   3.60636945550296*^9, {3.606369488856518*^9, 3.606369607065452*^9}, {
   3.60636966193372*^9, 3.6063696676698236`*^9}, 3.6063698485132113`*^9, {
   3.606370039184112*^9, 3.606370044774291*^9}, {3.606370254403411*^9, 
   3.6063702583619432`*^9}, {3.60637336397526*^9, 3.606373370774135*^9}, {
   3.606373669179887*^9, 3.60637366937854*^9}, {3.606375076626831*^9, 
   3.606375090455801*^9}, {3.606375162861309*^9, 3.606375165323412*^9}, {
   3.642044273298571*^9, 3.642044307542845*^9}, 3.6420443798922462`*^9}],

Cell[TextData[{
 "Mit einer Kombination aus ",
 StyleBox["HighlightGraph",
  FontWeight->"Bold"],
 " und ",
 StyleBox["PathGraph",
  FontWeight->"Bold"],
 " k\[ODoubleDot]nnen wir die in ",
 StyleBox["res1",
  FontWeight->"Bold"],
 " abgelegte Zeitreihe als Pfad in dem Attraktorgraphen einzeichnen. Die \
resultierende Darstellung entspricht Abb. 2 in Li et al. (2004)."
}], "Text",
 CellChangeTimes->{{3.677398351902135*^9, 3.6773984167554493`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"gYeast2", ",", 
   RowBox[{"PathGraph", "[", 
    RowBox[{
     RowBox[{"Drop", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"IntegerString", "[", 
           RowBox[{
            RowBox[{"FromDigits", "[", 
             RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "12"}], "]"}], 
          "&"}], ",", "res1"}], "]"}], ",", 
       RowBox[{"-", "3"}]}], "]"}], ",", 
     RowBox[{"DirectedEdges", "\[Rule]", "True"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
   RowBox[{"VertexStyle", "\[Rule]", "LightGray"}], ",", 
   RowBox[{"GraphHighlightStyle", "->", "\"\<Dashed\>\""}], ",", 
   RowBox[{"VertexSize", "\[Rule]", "25"}], ",", 
   RowBox[{"VertexShapeFunction", "\[Rule]", "\"\<Circle\>\""}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"EdgeForm", "[", "Black", "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "001100100101", "010000100010", "010000100011", "010010000111", 
       "010010100011", "010010100110", "010010100111", "010010110011", 
       "010100100010", "010100100011", "010110000111", "010110100011", 
       "010110100110", "010110100111", "010110110011", "001110110001", 
       "001100000100", "001100000101", "001100010100", "001100010101", 
       "001100100100", "001100110100", "001100110101", "001110010101", 
       "001110110100", "001110110101", "011000000100", "011000000101", 
       "011000010100", "011000010101", "011000100100", "011000100101", 
       "011000110100", "011000110101", "011010010101", "011010110100", 
       "011010110101", "011100000100", "011100000101", "011100010100", 
       "011100010101", "011100100100", "011100100101", "011100110100", 
       "011100110101", "011110010101", "011110110100", "011110110101", 
       "001110100000", "010010000110", "010010010010", "010010010011", 
       "010010100010", "010010110010", "010110000110", "010110100010", 
       "010110110010", "010000010010", "010010010110", "010110010110", 
       "010000000110", "010000000111", "010000010011", "010000010110", 
       "010000010111", "010000100110", "010000100111", "010000110010", 
       "010000110011", "010000110110", "010000110111", "010010010111", 
       "010010110110", "010010110111", "010100000110", "010100000111", 
       "010100010110", "010100010111", "010100100110", "010100100111", 
       "010100110010", "010100110011", "010100110110", "010100110111", 
       "010110010111", "010110110110", "010110110111", "001110010110", 
       "011000010010", "011010010110", "011110010110", "001100000110", 
       "001100000111", "001100010110", "001100010111", "001100100110", 
       "001100100111", "001100110010", "001100110011", "001100110110", 
       "001100110111", "001110010111", "001110110110", "001110110111", 
       "011000000110", "011000000111", "011000010011", "011000010110", 
       "011000010111", "011000100110", "011000100111", "011000110010", 
       "011000110011", "011000110110", "011000110111", "011010010111", 
       "011010110110", "011010110111", "011100000110", "011100000111", 
       "011100010110", "011100010111", "011100100110", "011100100111", 
       "011100110010", "011100110011", "011100110110", "011100110111", 
       "011110010111", "011110110110", "011110110111", "001100100000", 
       "001100100001", "001110100001", "011000000001", "011000100000", 
       "011000100001", "011010100001", "011010110001", "011100100000", 
       "011100100001", "011110100001", "011110110001", "001110000000", 
       "011100011100", "010001110010", "010011010110", "010011010111", 
       "010011100110", "010011110010", "010011110011", "010011110110", 
       "010111100110", "010111110110", "010001010110", "010001100110", 
       "010001100111", "010001110011", "010011100111", "010011110111", 
       "010101100110", "010101100111", "010111100111", "010111110111", 
       "010001010101", "010001110100", "010001110101", "010101110100", 
       "010101110101", "010001010111", "010001110110", "010001110111", 
       "010101110110", "010101110111", "011001010110", "011100011110", 
       "011100011101", "011100111100", "011100111101", "001101110110", 
       "001101110111", "011001010111", "011001110110", "011001110111", 
       "011100011111", "011100111110", "011100111111", "011101110110", 
       "011101110111", "010000000001", "010000100000", "010000100001", 
       "010010100001", "010010110001", "010100100000", "010100100001", 
       "010110100001", "010110110001", "010010000101", "010010100100", 
       "010010100101", "010110000101", "010110100100", "010110100101", 
       "001110000101", "001110100100", "001110100101", "011010000101", 
       "011010100100", "011010100101", "011110000101", "011110100100", 
       "011110100101", "001110110000", "011000000000", "011010000000", 
       "011010000001", "011010010000", "011010010001", "011010100000", 
       "011010110000", "011110100000", "011110110000", "001111000000", 
       "010101010111", "001110000110", "001110100010", "001110110010", 
       "011010000110", "011010010010", "011010010011", "011010100010", 
       "011010110010", "011110000110", "011110100010", "011110110010", 
       "001100100010", "001100100011", "001110000111", "001110100011", 
       "001110100110", "001110100111", "001110110011", "011000100010", 
       "011000100011", "011010000111", "011010100011", "011010100110", 
       "011010100111", "011010110011", "011100100010", "011100100011", 
       "011110000111", "011110100011", "011110100110", "011110100111", 
       "011110110011", "001100110000", "001100110001", "011000010001", 
       "011000110000", "011000110001", "011100110000", "011100110001", 
       "001100000000", "001110000001", "001110010000", "001110010001", 
       "011100000000", "011110000000", "011110000001", "011110010000", 
       "011110010001", "001111001010", "011100001100", "011100101000", 
       "011100111000", "011100111010", "011101101100", "011101111100", 
       "011110001100", "011110001101", "011110011100", "011110011101", 
       "011110101000", "011110101001", "011110101100", "011110111000", 
       "011110111001", "011110111010", "011110111011", "011110111100", 
       "011111101100", "011111101101", "011111111100", "011111111101", 
       "011001100001", "011001110001", "010001100001", "010001110001", 
       "010001000101", "010001100100", "010001100101", "010011100101", 
       "010011110101", "010101100100", "010101100101", "010111100101", 
       "010111110101", "001111100110", "001111110110", "011001110010", 
       "011011010110", "011011010111", "011011100110", "011011110010", 
       "011011110011", "011011110110", "011101111110", "011110011110", 
       "011110011111", "011110101110", "011110111110", "011111100110", 
       "011111110110", "011111111110", "011111111111", "001101100100", 
       "001101100101", "001111100101", "001111110101", "011001000101", 
       "011001100100", "011001100101", "011011100101", "011011110101", 
       "011101100100", "011101100101", "011111100101", "011111110101", 
       "011100001101", "011100101001", "011100101100", "011100101101", 
       "011100111001", "011100111011", "011101101101", "011101111101", 
       "011110101101", "011110111101", "001101100110", "001101100111", 
       "001111100111", "001111110111", "011001100110", "011001100111", 
       "011001110011", "011011100111", "011011110111", "011100101110", 
       "011100101111", "011101100110", "011101100111", "011101111111", 
       "011110101111", "011110111111", "011111100111", "011111110111", 
       "001101110100", "001101110101", "011001010101", "011001110100", 
       "011001110101", "011101110100", "011101110101", "010000010001", 
       "010000110000", "010000110001", "010100110000", "010100110001", 
       "010000000100", "010000000101", "010000010100", "010000010101", 
       "010000100100", "010000100101", "010000110100", "010000110101", 
       "010010010101", "010010110100", "010010110101", "010100000100", 
       "010100000101", "010100010100", "010100010101", "010100100100", 
       "010100100101", "010100110100", "010100110101", "010110010101", 
       "010110110100", "010110110101", "010000000000", "010010000000", 
       "010010000001", "010010010000", "010010010001", "010010100000", 
       "010010110000", "010110100000", "010110110000", "001110000100", 
       "011010000100", "011110000100", "011000010000", "001110010100", 
       "011010010100", "011110010100", "001101000000", "001101000001", 
       "001111000001", "011001000000", "011001000001", "011011000000", 
       "011011000001", "011101000000", "011101000001", "011111000000", 
       "011111000001", "000011001110", "001100010011", "011100010011", 
       "010101110011", "001101110011", "011101110011", "001101010111", 
       "011101010111", "010100010011", "010100000000", "010110000000", 
       "010110000001", "010110010000", "010110010001", "001001001000", 
       "001001001001", "001001001010", "001001001011", "001001011000", 
       "001001011001", "001001011010", "001001011011", "001011001000", 
       "001011001001", "001011001010", "001011001011", "001011011000", 
       "001011011001", "001011011010", "001011011011", "001100001000", 
       "001100001001", "001100001010", "001100001011", "001100011010", 
       "001100011011", "001101001000", "001101001001", "001101001010", 
       "001101001011", "001101001100", "001101001101", "001101011000", 
       "001101011001", "001101011010", "001101011011", "001101101000", 
       "001101101001", "001101101010", "001101101011", "001101111010", 
       "001101111011", "001110001000", "001110001001", "001110001010", 
       "001110001011", "001110011010", "001110011011", "001111001000", 
       "001111001001", "001111001011", "001111001100", "001111001101", 
       "001111011000", "001111011001", "001111011010", "001111011011", 
       "001111101000", "001111101001", "001111101010", "001111101011", 
       "001111111010", "001111111011", "000000001111", "010001010100", 
       "010101010101", "010101010110", "001001000000", "001001000001", 
       "001011000000", "001011000001", "010001000000", "010001000001", 
       "010011000000", "010011000001", "010101000000", "010101000001", 
       "010111000000", "010111000001", "010100000010", "010110000010", 
       "010110000011", "001100000010", "001110000010", "001110000011", 
       "011100000010", "011110000010", "011110000011", "000000001110", 
       "000001000110", "000001001110", "000001001111", "000001011110", 
       "000001011111", "000001100010", "000001101110", "000010001110", 
       "000010001111", "000011000110", "000011000111", "000011001111", 
       "000011011110", "000011011111", "000011100010", "000011100011", 
       "000011101110", "000011101111", "000100001110", "000101101110", 
       "000110001110", "000110001111", "000111101110", "000111101111", 
       "010000001110", "010001001110", "010001001111", "010001011110", 
       "010001011111", "010001101110", "010010001110", "010010001111", 
       "010011001110", "010011001111", "010011011110", "010011011111", 
       "010011101110", "010011101111", "000000101111", "010001100000", 
       "010001110000", "010011100000", "010011100001", "010011110000", 
       "010011110001", "011001100000", "011001110000", "011011100000", 
       "011011100001", "011011110000", "011011110001", "001111100100", 
       "001111110100", "011001000100", "011011000100", "011011000101", 
       "011011010100", "011011010101", "011011100100", "011011110100", 
       "011111100100", "011111110100", "000000001000", "000000001001", 
       "000000001010", "000000001011", "000000011010", "000000011011", 
       "000000101010", "000001001100", "000001001101", "000001101000", 
       "000001101001", "000001101010", "000001101011", "000001111010", 
       "000001111011", "000010001000", "000010001001", "000010001010", 
       "000010001011", "000010011010", "000010011011", "000010101010", 
       "000010101011", "000011001100", "000011001101", "000011101000", 
       "000011101001", "000011101010", "000011101011", "000011111010", 
       "000011111011", "000100101010", "000110101010", "000110101011", 
       "010000001000", "010000001001", "010000001010", "010000001011", 
       "010000011010", "010000011011", "010000101010", "010001001100", 
       "010001001101", "010001101000", "010001101001", "010001101010", 
       "010001101011", "010001111010", "010001111011", "010010001000", 
       "010010001001", "010010001010", "010010001011", "010010011010", 
       "010010011011", "010010101010", "010010101011", "010011001100", 
       "010011001101", "010011101000", "010011101001", "010011101010", 
       "010011101011", "010011111010", "010011111011", "000100011000", 
       "000100011001", "000101011100", "000101011101", "000101111000", 
       "000101111001", "000110011000", "000110011001", "000111011100", 
       "000111011101", "000111111000", "000111111001", "000001001000", 
       "000001001001", "000001001010", "000001001011", "000001011000", 
       "000001011001", "000001011010", "000001011011", "000011001000", 
       "000011001001", "000011001010", "000011001011", "000011011000", 
       "000011011001", "000011011010", "000011011011", "000100001000", 
       "000100001001", "000100001010", "000100001011", "000100011010", 
       "000100011011", "000101001000", "000101001001", "000101001010", 
       "000101001011", "000101001100", "000101001101", "000101011000", 
       "000101011001", "000101011010", "000101011011", "000101101000", 
       "000101101001", "000101101010", "000101101011", "000101111010", 
       "000101111011", "000110001000", "000110001001", "000110001010", 
       "000110001011", "000110011010", "000110011011", "000111001000", 
       "000111001001", "000111001010", "000111001011", "000111001100", 
       "000111001101", "000111011000", "000111011001", "000111011010", 
       "000111011011", "000111101000", "000111101001", "000111101010", 
       "000111101011", "000111111010", "000111111011", "010001001000", 
       "010001001001", "010001001010", "010001001011", "010001011000", 
       "010001011001", "010001011010", "010001011011", "010011001000", 
       "010011001001", "010011001010", "010011001011", "010011011000", 
       "010011011001", "010011011010", "010011011011", "000001000010", 
       "000001000011", "000001010010", "000001010011", "000011000010", 
       "000011000011", "000011010010", "000011010011", "000101001110", 
       "000101001111", "000101011110", "000101011111", "000111001110", 
       "000111001111", "000111011110", "000111011111", "001000001000", 
       "001000001001", "001000001010", "001000001011", "001000011010", 
       "001000011011", "001000101010", "001001001100", "001001001101", 
       "001001101000", "001001101001", "001001101010", "001001101011", 
       "001001111010", "001001111011", "001010001000", "001010001001", 
       "001010001010", "001010001011", "001010011010", "001010011011", 
       "001010101010", "001010101011", "001011001100", "001011001101", 
       "001011101000", "001011101001", "001011101010", "001011101011", 
       "001011111010", "001011111011", "001100101010", "001110101010", 
       "001110101011", "001000001110", "001001001110", "001001001111", 
       "001001011110", "001001011111", "001001101110", "001010001110", 
       "001010001111", "001011001110", "001011001111", "001011011110", 
       "001011011111", "001011101110", "001011101111", "001100001110", 
       "001101101110", "001110001110", "001110001111", "001111101110", 
       "001111101111", "001100011000", "001100011001", "001101011100", 
       "001101011101", "001101111000", "001101111001", "001110011000", 
       "001110011001", "001111011100", "001111011101", "001111111000", 
       "001111111001", "001101001110", "001101001111", "001101011110", 
       "001101011111", "001111001110", "001111001111", "001111011110", 
       "001111011111", "010100101010", "010110101010", "010110101011", 
       "000001000111", "000001100011", "000001101111", "000100001111", 
       "000101101111", "010000001111", "010001101111", "000000100111", 
       "000001000000", "000001000001", "000011000000", "000011000001", 
       "000101000000", "000101000001", "000111000000", "000111000001", 
       "000100000010", "000110000010", "000110000011", "000001010000", 
       "000001010001", "000011010000", "000011010001", "010100001000", 
       "010100001001", "010100001010", "010100001011", "010100011010", 
       "010100011011", "010101001000", "010101001001", "010101001010", 
       "010101001011", "010101001100", "010101001101", "010101011000", 
       "010101011001", "010101011010", "010101011011", "010101101000", 
       "010101101001", "010101101010", "010101101011", "010101111010", 
       "010101111011", "010110001000", "010110001001", "010110001010", 
       "010110001011", "010110011010", "010110011011", "010111001000", 
       "010111001001", "010111001010", "010111001011", "010111001100", 
       "010111001101", "010111011000", "010111011001", "010111011010", 
       "010111011011", "010111101000", "010111101001", "010111101010", 
       "010111101011", "010111111010", "010111111011", "000101000010", 
       "000101000011", "000101000110", "000101010010", "000101010011", 
       "000101100010", "000111000010", "000111000011", "000111000110", 
       "000111000111", "000111010010", "000111010011", "000111100010", 
       "000111100011", "010101001110", "010101001111", "010101011110", 
       "010101011111", "010111001110", "010111001111", "010111011110", 
       "010111011111", "011000001000", "011000001001", "011000001010", 
       "011000001011", "011000011010", "011000011011", "011000101010", 
       "011001001100", "011001001101", "011001101000", "011001101001", 
       "011001101010", "011001101011", "011001111010", "011001111011", 
       "011010001000", "011010001001", "011010001010", "011010001011", 
       "011010011010", "011010011011", "011010101010", "011010101011", 
       "011011001100", "011011001101", "011011101000", "011011101001", 
       "011011101010", "011011101011", "011011111010", "011011111011", 
       "001001000110", "001001100010", "001011000110", "001011000111", 
       "001011100010", "001011100011", "011000001110", "011001001110", 
       "011001001111", "011001011110", "011001011111", "011001101110", 
       "011010001110", "011010001111", "011011001110", "011011001111", 
       "011011011110", "011011011111", "011011101110", "011011101111", 
       "011001001000", "011001001001", "011001001010", "011001001011", 
       "011001011000", "011001011001", "011001011010", "011001011011", 
       "011011001000", "011011001001", "011011001010", "011011001011", 
       "011011011000", "011011011001", "011011011010", "011011011011", 
       "001001000010", "001001000011", "001001010010", "001001010011", 
       "001011000010", "001011000011", "001011010010", "001011010011", 
       "011100101010", "011110101010", "011110101011", "011001000110", 
       "011001100010", "011011000110", "011011000111", "011011100010", 
       "011011100011", "011100001110", "011101101110", "011110001110", 
       "011110001111", "011111101110", "011111101111", "001101000111", 
       "001101100011", "011101000111", "011101100011", "010001000010", 
       "010001000011", "010001010010", "010001010011", "010011000010", 
       "010011000011", "010011010010", "010011010011", "010101000010", 
       "010101000011", "010101000110", "010101010010", "010101010011", 
       "010101100010", "010111000010", "010111000011", "010111000110", 
       "010111000111", "010111010010", "010111010011", "010111100010", 
       "010111100011", "011100001000", "011100001001", "011100001010", 
       "011100001011", "011100011010", "011100011011", "011101001000", 
       "011101001001", "011101001010", "011101001011", "011101001100", 
       "011101001101", "011101011000", "011101011001", "011101011010", 
       "011101011011", "011101101000", "011101101001", "011101101010", 
       "011101101011", "011101111010", "011101111011", "011110001000", 
       "011110001001", "011110001010", "011110001011", "011110011010", 
       "011110011011", "011111001000", "011111001001", "011111001010", 
       "011111001011", "011111001100", "011111001101", "011111011000", 
       "011111011001", "011111011010", "011111011011", "011111101000", 
       "011111101001", "011111101010", "011111101011", "011111111010", 
       "011111111011", "001101000010", "001101000011", "001101000110", 
       "001101010010", "001101010011", "001101100010", "001111000010", 
       "001111000011", "001111000110", "001111000111", "001111010010", 
       "001111010011", "001111100010", "001111100011", "011001000010", 
       "011001000011", "011001010010", "011001010011", "011011000010", 
       "011011000011", "011011010010", "011011010011", "011101000010", 
       "011101000011", "011101000110", "011101001110", "011101001111", 
       "011101010010", "011101010011", "011101011110", "011101011111", 
       "011101100010", "011111000010", "011111000011", "011111000110", 
       "011111000111", "011111001110", "011111001111", "011111010010", 
       "011111010011", "011111011110", "011111011111", "011111100010", 
       "011111100011", "010100001110", "010101101110", "010110001110", 
       "010110001111", "010111101110", "010111101111", "000101000111", 
       "000101100011", "000000101110", "000001100110", "000001100111", 
       "000001110011", "000001111111", "000010101111", "000010111111", 
       "000011100111", "000011110111", "000100101110", "000100101111", 
       "000101111111", "000110101111", "000110111111", "010000101110", 
       "010000101111", "010001111111", "010010101111", "010010111111", 
       "000000110101", "000100000000", "000110000000", "000110000001", 
       "000110010000", "000110010001", "000101010000", "000101010001", 
       "000101100000", "000101110000", "000111010000", "000111010001", 
       "000111100000", "000111100001", "000111110000", "000111110001", 
       "000101000100", "000111000100", "000111000101", "000111010100", 
       "000111010101", "010100011000", "010100011001", "010101011100", 
       "010101011101", "010101111000", "010101111001", "010110011000", 
       "010110011001", "010111011100", "010111011101", "010111111000", 
       "010111111001", "000101010100", "000101100001", "000101110001", 
       "001001010000", "001001010001", "001011010000", "001011010001", 
       "010101110010", "010111010110", "010111010111", "010111110010", 
       "010111110011", "010101000101", "010001010000", "010001010001", 
       "010011010000", "010011010001", "010101010000", "010101010001", 
       "010101100000", "010101110000", "010111010000", "010111010001", 
       "010111100000", "010111100001", "010111110000", "010111110001", 
       "010101000100", "010111000100", "010111000101", "010111010100", 
       "010111010101", "010101010100", "010101100001", "010101110001", 
       "001101010000", "001101010001", "001101100000", "001101110000", 
       "001111010000", "001111010001", "001111100000", "001111100001", 
       "001111110000", "001111110001", "011001010000", "011001010001", 
       "011011010000", "011011010001", "011101010000", "011101010001", 
       "011101100000", "011101110000", "011111010000", "011111010001", 
       "011111100000", "011111100001", "011111110000", "011111110001", 
       "001101000100", "001111000100", "001111000101", "001111010100", 
       "001111010101", "011101000100", "011111000100", "011111000101", 
       "011111010100", "011111010101", "011100011000", "011100011001", 
       "011101011100", "011101011101", "011101111000", "011101111001", 
       "011110011000", "011110011001", "011111011100", "011111011101", 
       "011111111000", "011111111001", "001101110010", "001111010110", 
       "001111010111", "001111110010", "001111110011", "011101110010", 
       "011111010110", "011111010111", "011111110010", "011111110011", 
       "001101010100", "011101010100", "001101100001", "001101110001", 
       "011101100001", "011101110001", "001101000101", "011101000101", 
       "000101110010", "000111010110", "000111010111", "000111110010", 
       "000111110011", "000101000101", "000000101011", "000100101011", 
       "010000101011", "001000001111", "001001101111", "001100001111", 
       "001101101111", "010100101011", "010100001111", "010101101111", 
       "000000000110", "000000000111", "000000010011", "000000010110", 
       "000000010111", "000000100110", "000000110010", "000000110011", 
       "000000110110", "000000110111", "000010010111", "000010110110", 
       "000010110111", "000000110001", "000110100000", "000110110000", 
       "000100010000", "000100000001", "000100010001", "010100010000", 
       "010100000001", "010100010001", "001100010000", "011100010000", 
       "001100000001", "011100000001", "001100010001", "011100010001", 
       "001110010010", "001110010011", "011110010010", "011110010011", 
       "001100010010", "011100010010", "001101010110", "011101010110", 
       "001101010101", "011101010101", "010110010010", "010110010011", 
       "000110010010", "000110010011", "010001000110", "010001100010", 
       "010011000110", "010011000111", "010011100010", "010011100011", 
       "010101000111", "010101100011", "000000001100", "000000011000", 
       "000000011001", "000000101000", "000000111000", "000000111010", 
       "000001011100", "000001011101", "000001101100", "000001111000", 
       "000001111001", "000001111100", "000010001100", "000010001101", 
       "000010011000", "000010011001", "000010011100", "000010011101", 
       "000010101000", "000010101001", "000010101100", "000010111000", 
       "000010111001", "000010111010", "000010111011", "000010111100", 
       "000011011100", "000011011101", "000011101100", "000011101101", 
       "000011111000", "000011111001", "000011111100", "000011111101", 
       "000100001100", "000100101000", "000100111000", "000100111010", 
       "000101101100", "000101111100", "000110001100", "000110001101", 
       "000110011100", "000110011101", "000110101000", "000110101001", 
       "000110101100", "000110111000", "000110111001", "000110111010", 
       "000110111011", "000110111100", "000111101100", "000111101101", 
       "000111111100", "000111111101", "010000001100", "010000011000", 
       "010000011001", "010000101000", "010000111000", "010000111010", 
       "010001011100", "010001011101", "010001101100", "010001111000", 
       "010001111001", "010001111100", "010010001100", "010010001101", 
       "010010011000", "010010011001", "010010011100", "010010011101", 
       "010010101000", "010010101001", "010010101100", "010010111000", 
       "010010111001", "010010111010", "010010111011", "010010111100", 
       "010011011100", "010011011101", "010011101100", "010011101101", 
       "010011111000", "010011111001", "010011111100", "010011111101", 
       "000001110010", "000001111110", "000010011110", "000010011111", 
       "000010101110", "000010111110", "000011010110", "000011010111", 
       "000011100110", "000011110010", "000011110011", "000011110110", 
       "000011111110", "000011111111", "000101111110", "000110011110", 
       "000110011111", "000110101110", "000110111110", "000111111110", 
       "000111111111", "010001111110", "010010011110", "010010011111", 
       "010010101110", "010010111110", "010011111110", "010011111111", 
       "000001010100", "000000011100", "000100011100", "010000011100", 
       "000000011110", "000001010110", "000100011110", "010000011110", 
       "000000001101", "000000101001", "000000101100", "000000101101", 
       "000000111001", "000000111011", "000001101101", "000001111101", 
       "000010101101", "000010111101", "000100001101", "000100101001", 
       "000100101100", "000100101101", "000100111001", "000100111011", 
       "000101101101", "000101111101", "000110101101", "000110111101", 
       "010000001101", "010000101001", "010000101100", "010000101101", 
       "010000111001", "010000111011", "010001101101", "010001111101", 
       "010010101101", "010010111101", "000001010101", "000001110100", 
       "000001110101", "000000011101", "000000111100", "000000111101", 
       "000100011101", "000100111100", "000100111101", "010000011101", 
       "010000111100", "010000111101", "000000011111", "000000111110", 
       "000000111111", "000001010111", "000001110110", "000001110111", 
       "000100011111", "000100111110", "000100111111", "010000011111", 
       "010000111110", "010000111111", "001000011110", "001100011110", 
       "001000011101", "001000111100", "001000111101", "001100011101", 
       "001100111100", "001100111101", "001000011111", "001000111110", 
       "001000111111", "001100011111", "001100111110", "001100111111", 
       "000000000100", "000000000101", "000000010100", "000000010101", 
       "000000100100", "000000100101", "000000110100", "000010010101", 
       "000010110100", "000010110101", "000000110000", "000110000100", 
       "000110010100", "010000010000", "010010000100", "010110000100", 
       "010010010100", "010110010100", "011001010100", "010100010010", 
       "001000101011", "001100101011", "000000000010", "000010000010", 
       "000010000011", "000000000011", "000100000011", "000010000110", 
       "000010010010", "000010010011", "000010100010", "000010110010", 
       "000000010010", "000010010110", "000000100010", "000000100011", 
       "000010000111", "000010100011", "000010100110", "000010100111", 
       "000010110011", "000000010001", "000001100000", "000001110000", 
       "000011100000", "000011100001", "000011110000", "000011110001", 
       "000001000100", "000011000100", "000011000101", "000011010100", 
       "000011010101", "000011100100", "000011110100", "000111100100", 
       "000111110100", "001000001100", "001000011000", "001000011001", 
       "001000101000", "001000111000", "001000111010", "001001011100", 
       "001001011101", "001001101100", "001001111000", "001001111001", 
       "001001111100", "001010001100", "001010001101", "001010011000", 
       "001010011001", "001010011100", "001010011101", "001010101000", 
       "001010101001", "001010101100", "001010111000", "001010111001", 
       "001010111010", "001010111011", "001010111100", "001011011100", 
       "001011011101", "001011101100", "001011101101", "001011111000", 
       "001011111001", "001011111100", "001011111101", "001100001100", 
       "001100101000", "001100111000", "001100111010", "001101101100", 
       "001101111100", "001110001100", "001110001101", "001110011100", 
       "001110011101", "001110101000", "001110101001", "001110101100", 
       "001110111000", "001110111001", "001110111010", "001110111011", 
       "001110111100", "001111101100", "001111101101", "001111111100", 
       "001111111101", "001000011100", "001100011100", "000001100001", 
       "000001110001", "000001000101", "000001100100", "000001100101", 
       "000011100101", "000011110101", "001001111110", "001010011110", 
       "001010011111", "001010101110", "001010111110", "001011111110", 
       "001011111111", "001101111110", "001110011110", "001110011111", 
       "001110101110", "001110111110", "001111111110", "001111111111", 
       "001000001101", "001000101001", "001000101100", "001000101101", 
       "001000111001", "001000111011", "001001101101", "001001111101", 
       "001010101101", "001010111101", "001100001101", "001100101001", 
       "001100101100", "001100101101", "001100111001", "001100111011", 
       "001101101101", "001101111101", "001110101101", "001110111101", 
       "001000101110", "001000101111", "001001111111", "001010101111", 
       "001010111111", "001100101110", "001100101111", "001101111111", 
       "001110101111", "001110111111", "000010010100", "001000000010", 
       "001010000010", "001010000011", "011000000010", "011010000010", 
       "011010000011", "001100000011", "011100000011", "011000101011", 
       "011100101011", "001000000011", "010000000010", "010010000010", 
       "010010000011", "010000000011", "010100000011", "011000000011", 
       "001001000111", "001001100011", "011000001111", "011001101111", 
       "010001000111", "010001100011", "011001000111", "011001100011", 
       "011100001111", "011101101111", "001001100000", "001001110000", 
       "001011100000", "001011100001", "001011110000", "001011110001", 
       "001001000100", "001011000100", "001011000101", "001011010100", 
       "001011010101", "001011100100", "001011110100", "010001000100", 
       "010011000100", "010011000101", "010011010100", "010011010101", 
       "010011100100", "010011110100", "010111100100", 
       "010111110100"}, {CompressedData["
1:eJw12mWYFUQbBuA9u+ccOkUkpQQFFASlUxoFkZQGQUCku6Wku6UkFAUUkA5p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       "], Null}, {BaseStyle -> {
         EdgeForm[
          GrayLevel[0]]}, GraphHighlight -> {"000011001110", "000000110001", 
         DirectedEdge["000000101111", "000000100111"], "000000100111", 
         DirectedEdge["000000100111", "000000110101"], 
         DirectedEdge["001110000000", "001111000000"], "000000101111", 
         DirectedEdge["000000001111", "000000101111"], "001111000000", 
         "000000110101", 
         DirectedEdge["000000110101", "000000110001"], "000000001111", 
         "010000110000", 
         DirectedEdge["001100110000", "001110110000"], "001110110000", 
         DirectedEdge["001111000000", "001111001010"], "001100110000", 
         "001111001010", 
         DirectedEdge["000000110001", "000000110000"], 
         DirectedEdge["010000110000", "001100110000"], "000000110000", 
         DirectedEdge["000011001110", "000000001111"], 
         DirectedEdge["001111001010", "000011001110"], "001110000000", 
         DirectedEdge["001110110000", "001110000000"]}, 
       GraphHighlightStyle -> {"Dashed"}, 
       GraphLayout -> {"RadialEmbedding", "RootVertex" -> "000000110000"}, 
       ImageSize -> 400, 
       VertexShapeFunction -> {
        "Circle", "001111001010" -> "Circle", "000011001110" -> "Circle", 
         "000000100111" -> "Circle", "001110110000" -> "Circle", 
         "010000110000" -> "Circle", "000000110000" -> "Circle", 
         "000000001111" -> "Circle", "001100110000" -> "Circle", 
         "001111000000" -> "Circle", "001110000000" -> "Circle", 
         "000000110001" -> "Circle", "000000101111" -> "Circle", 
         "000000110101" -> "Circle"}, 
       VertexSize -> {
        25, "001111001010" -> 25, "001100110000" -> 25, "000000001111" -> 25, 
         "000000101111" -> 25, "000000100111" -> 25, "000000110101" -> 25, 
         "001111000000" -> 25, "001110000000" -> 25, "000011001110" -> 25, 
         "001110110000" -> 25, "000000110000" -> 25, "000000110001" -> 25, 
         "010000110000" -> 25}, VertexStyle -> {
         GrayLevel[0.85], "010000110000" -> GrayLevel[0.85], "001111000000" -> 
         GrayLevel[0.85], "001111001010" -> GrayLevel[0.85], "000000100111" -> 
         GrayLevel[0.85], "000000110000" -> GrayLevel[0.85], "000000110001" -> 
         GrayLevel[0.85], "000000110101" -> GrayLevel[0.85], "001110000000" -> 
         GrayLevel[0.85], "000000001111" -> GrayLevel[0.85], "000011001110" -> 
         GrayLevel[0.85], "001110110000" -> GrayLevel[0.85], "000000101111" -> 
         GrayLevel[0.85], "001100110000" -> GrayLevel[0.85]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.5], Arrowheads[0.014371188669271503`], 
        EdgeForm[GrayLevel[0]], 
        ArrowBox[{{1.5908215039309024`, 4.768001439242577}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{0.8326952071195937, 4.499316557109851}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8374899200231045, 4.488793172102863}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.842296315576224, 4.478275117833211}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8471143878522742, 4.46776240727051}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8519441309101854, 4.457255053377786}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8567855387944903, 4.446753069111458}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8616386055353367, 4.436256467421327}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8665033251485017, 4.425765261250555}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8713796916353935, 4.415279463535648}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8762676989830513, 4.404799087206451}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8811673411641685, 4.394324145186115}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8860786121370907, 4.383854650391094}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.891001505845816, 4.373390615731129}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{0.8959360162200216, 4.362932054109221}, {
         1.5908215039309024`, 4.768001439242577}}, 0.05577520655383945], 
        ArrowBox[{{2.6415760632745204`, 4.474098960280289}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{1.6248023913779175`, 4.695511090935768}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.6454802941820628`, 4.652153607812534}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.6663745947786062`, 4.608899992822111}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.6757302753595749`, 4.589709786899239}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.6851285520521753`, 4.570540406165772}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.689843649462496, 4.560963554795836}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.7569686649311578`, 4.427443380167117}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.8336966385847777`, 4.280854818970042}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{1.8463079386406065`, 4.257336078832784}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.048700462318285, 3.8996891613732023`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.2661935233248975`, 3.5510190886354707`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.2720403814901466`, 3.5420881046277524`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.2778971533878103`, 3.5331636187215825`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.283763831796012, 3.5242456419215786`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.289640409480663, 3.5153341852243303`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.2955268791954655`, 3.506429259618386}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3014232336819234`, 3.4975308760842427`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3073294656693513`, 3.48863904559433}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3132455678748904`, 3.4797537791129978`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3191715330035008`, 3.4708750875964984`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.325107353747991, 3.462002981992981}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3310530227890096`, 3.4531374732424736`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.337008532795063, 3.4442785722768647`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.342973876422528, 3.435426290019901}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3489490463156475`, 3.4265806373871657`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3549340351065533`, 3.417741625286065}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.360928835415269, 3.4089092646158186`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.366933439849717, 3.400083566267446}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3729478410057334`, 3.391264541123748}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3789720314670753`, 3.3824522000592996`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.3850060038054233`, 3.373646553940433}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{2.391049750580402, 3.3648476136252254`}, {
         2.6415760632745204`, 4.474098960280289}}, 0.05577520655383945], 
        ArrowBox[{{3.7111823657857173`, 4.2726890848719385`}, {
         4.46577750048209, 4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{0.9058398626119466, 4.342031401557828}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.910809186417417, 4.331589336400553}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9157901024638875, 4.321152795825706}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9207826046094834, 4.310721792702392}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9257866866980429, 4.300296339892881}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9308023425591312, 4.289876450252606}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9358295660080369, 4.279462136630136}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9408683508457809, 4.269053411867164}, {
         1.6454802941820628`, 4.652153607812534}}, 0.05577520655383945], 
        ArrowBox[{{0.9509805798206212, 4.248252780252016}, {
         1.6757302753595749`, 4.589709786899239}}, 0.05577520655383945], 
        ArrowBox[{{0.9560540114885185, 4.237860899048712}, {
         1.6757302753595749`, 4.589709786899239}}, 0.05577520655383945], 
        ArrowBox[{{0.9611389796068703, 4.227474658002611}, {
         1.6757302753595749`, 4.589709786899239}}, 0.05577520655383945], 
        ArrowBox[{{0.9764630398918062, 4.196349903843438}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{0.9815940909680645, 4.185986351427147}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{0.9867366470017895, 4.175628503133588}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{0.9918907016517906, 4.165276371734828}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{0.9970562485626999, 4.1549299699958855`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0022332813649797`, 4.144589310674716}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0074217936749275`, 4.13425440652219}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0126217790946868`, 4.123925270282084}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0178332312122542`, 4.11360191469106}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0230561436014831`, 4.103284352478657}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0282905098221011`, 4.0929725963672645`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0335363234197086`, 4.082666659072116}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0387935779257909`, 4.072366553301268}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.044062266857729, 4.062072291755587}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0493423837188, 4.051783887128735}, {1.7569686649311578`, 
         4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0546339219981906`, 4.041501352107151}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0599368751710045`, 4.031224699370031}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0652512366982698`, 4.020953941589327}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0705770000269492`, 4.010689091429715}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.075914158589942, 4.000430161548588}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0812627058061004`, 3.9901771645960418`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.086622635080225, 3.979930113214853}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.091993939803098, 3.9696890200404678`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.0973766133514573`, 3.9594538977009854`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.102770649088031, 3.9492247588171425`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.1081760403615366`, 3.9390016160022983`}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.1135927805066874`, 3.928784481862418}, {
         1.7569686649311578`, 4.427443380167117}}, 0.05577520655383945], 
        ArrowBox[{{1.1190208628442093`, 3.9185733689960403`}, {
         1.8336966385847777`, 4.280854818970042}}, 0.05577520655383945], 
        ArrowBox[{{1.1244602806808217`, 3.908368289994331}, {
         1.8336966385847777`, 4.280854818970042}}, 0.05577520655383945], 
        ArrowBox[{{1.1299110273092872`, 3.898169257440963}, {
         1.8336966385847777`, 4.280854818970042}}, 0.05577520655383945], 
        ArrowBox[{{1.1353730960083954`, 3.887976283912172}, {
         1.8336966385847777`, 4.280854818970042}}, 0.05577520655383945], 
        ArrowBox[{{1.1463311726638832`, 3.867608564195888}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.1739240273684644`, 3.8167961767296807`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.2017985763542978`, 3.766137772988543}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.2074072140004564`, 3.756024707796107}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.2130270781581665`, 3.7459178769040182`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.2412945535947344`, 3.6954776728678853`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.2698416464844584`, 3.645195192436727}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.287103752865292, 3.6151020565352905`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.3044660133170183`, 3.5850665932112173`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.321928235158106, 3.555089135789716}, {2.048700462318285, 
         3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.3424269087964422`, 3.5201891922764226`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.3571517867376652`, 3.495309568732903}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.3957591589674703`, 3.430814781756257}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.428789825710071, 3.3764610998514826`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.434831036641942, 3.3666003354638177`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.440883193653324, 3.356746285568371}, {2.048700462318285, 
         3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.446946289281417, 3.3468989623159846`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4530203160499333`, 3.3370583778492096`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.459105266469102, 3.3272245443022834`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4652011330356878`, 3.3173974738011225`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4713079082329887`, 3.307577178463303}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4774255845308595`, 3.297763670398046}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4835541543857058`, 3.287956961706204}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4896936102405025`, 3.2781570644802436`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.4958439445248057`, 3.268363990804236}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5020051496547495`, 3.258577752753834}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5081772180330724`, 3.2487983623962657`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5143601420491084`, 3.239025831790311}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.520553914078814, 3.2292601729862964`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5267585264847625`, 3.219501398026071}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5329739716161637`, 3.2097495189429956`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5392002418088708`, 3.2000045477619308`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5454373293853862`, 3.1902664964992153`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5516852266548735`, 3.1805353771626574`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5579439259131682`, 3.170811201751519}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5642134194427886`, 3.161093982256496}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5704936995129373`, 3.1513837306597106`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5767847583795174`, 3.1416804589346903`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5830865882851484`, 3.1319841790463565`}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{1.5893991814591573`, 3.122294902951011}, {
         2.048700462318285, 3.8996891613732023`}}, 0.05577520655383945], 
        ArrowBox[{{3.0789507232536852`, 3.778532425436193}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{3.1211205160450515`, 3.718469857170345}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{3.5383513575950154`, 3.175470515480196}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{3.979451834654216, 2.684065623596669}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{3.98626033782275, 2.677037647606416}, {3.7111823657857173`,
          4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{3.993076640951309, 2.6700172363951635`}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{3.9999007356348395`, 2.6630043986196466`}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{4.006732613458677, 2.655999142927265}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{4.013572265998563, 2.649001477956067}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{4.020419684820649, 2.6420114123347416`}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{4.027274861481512, 2.635028954682608}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        ArrowBox[{{4.034137787528164, 2.6280541136096023`}, {
         3.7111823657857173`, 4.2726890848719385`}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{4.46577750048209, 4.59244785593508}, {5.159423727333477, 
          5.000942411669477}}, 0.05577520655383945]}, 
        ArrowBox[{{0.4118805106158998, 3.542163901910693}, {
         1.1190208628442093`, 3.9185733689960403`}}, 0.05577520655383945], 
        ArrowBox[{{0.4472103767462041, 3.4763213355863645`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.4531413038897565, 3.4653705228595166`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.45908438761597026`, 3.454426302833226}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.4650396205965368, 3.4434886890026037`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.4710069954881728, 3.4325576948546166`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.47698650493261674`, 3.4216333338680682`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.48297814155665186`, 3.4107156195135824`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.488981897972101, 3.3998045652535858`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.4949977667758496, 3.3889001845422966`}, {
         1.1739240273684644`, 3.8167961767296807`}}, 0.05577520655383945], 
        ArrowBox[{{0.5070658118610876, 3.367111497541533}, {
         1.2074072140004564`, 3.756024707796107}}, 0.05577520655383945], 
        ArrowBox[{{0.5191822172888667, 3.345349665980149}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5252585364648823, 3.334478854537031}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.531346923297157, 3.3236147971945256`}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5374473702782083, 3.3127575073488966`}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5435598698856943, 3.3019069983880645`}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5496844145824085, 3.291063283691586}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5558209968162835, 3.280226376630644}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5619696090204229, 3.2693962905680234`}, {
         1.2412945535947344`, 3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5681302436130817, 3.2585730388581}, {1.2412945535947344`,
          3.6954776728678853`}}, 0.05577520655383945], 
        ArrowBox[{{0.5804875495629052, 3.2369470918716896`}, {
         1.287103752865292, 3.6151020565352905`}}, 0.05577520655383945], 
        ArrowBox[{{0.5866842056825039, 3.226144423261755}, {1.287103752865292,
          3.6151020565352905`}}, 0.05577520655383945], 
        ArrowBox[{{0.5928928537155223, 3.215348642337582}, {1.287103752865292,
          3.6151020565352905`}}, 0.05577520655383945], 
        ArrowBox[{{0.5991134860061926, 3.204559762411244}, {1.287103752865292,
          3.6151020565352905`}}, 0.05577520655383945], 
        ArrowBox[{{0.6053460948839682, 3.193777796786307}, {1.287103752865292,
          3.6151020565352905`}}, 0.05577520655383945], 
        ArrowBox[{{0.617847211644829, 3.1722346616122454`}, {
         1.321928235158106, 3.555089135789716}}, 0.05577520655383945], 
        ArrowBox[{{0.6241157041130219, 3.1614735186275604`}, {
         1.321928235158106, 3.555089135789716}}, 0.05577520655383945], 
        ArrowBox[{{0.6303961423385562, 3.1507193430731126`}, {
         1.321928235158106, 3.555089135789716}}, 0.05577520655383945], 
        ArrowBox[{{0.6366885185771398, 3.139972148209673}, {1.321928235158106,
          3.555089135789716}}, 0.05577520655383945], 
        ArrowBox[{{0.6429928250697667, 3.1292319472894077`}, {
         1.321928235158106, 3.555089135789716}}, 0.05577520655383945], 
        ArrowBox[{{0.6493090540427122, 3.1184987535558495`}, {
         1.3424269087964422`, 3.5201891922764226`}}, 0.05577520655383945], 
        ArrowBox[{{0.6556371977075521, 3.1077725802439087`}, {
         1.3424269087964422`, 3.5201891922764226`}}, 0.05577520655383945], 
        ArrowBox[{{0.6619772482611719, 3.097053440579823}, {
         1.3571517867376652`, 3.495309568732903}}, 0.05577520655383945], 
        ArrowBox[{{0.6683291978857735, 3.086341347781161}, {
         1.3571517867376652`, 3.495309568732903}}, 0.05577520655383945], 
        ArrowBox[{{0.6746930387488916, 3.075636315056803}, {
         1.3571517867376652`, 3.495309568732903}}, 0.05577520655383945], 
        ArrowBox[{{0.68106876300339, 3.064938355606925}, {1.3957591589674703`,
          3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.6874563627874828, 3.0542474826229773`}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.6938558302247433, 3.0435637092876773`}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.700267157424106, 3.032887048774982}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.7066903364798875, 3.022217514250083}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.7131253594717819, 3.0115551188693805`}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.7195722184648865, 3.0008998757804752`}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.726030905509699, 2.990251798122147}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.7325014126421365, 2.9796108990243386`}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{0.7389837318835344, 2.968977191608144}, {
         1.3957591589674703`, 3.430814781756257}}, 0.05577520655383945], 
        ArrowBox[{{2.397103264339588, 3.3560553899634717`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.4031665376184934`, 3.34726989379672}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.4092395629406136`, 3.3384911359581917`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.4153223328174205`, 3.3297191272728046`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.421414839748362, 3.3209538785571597`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.427517076220881, 3.31219540061952}, {3.0789507232536852`,
          3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.4336290347104272`, 3.3034437042598004`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.439750707680459, 3.2946988002695514`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.445882087582455, 3.2859606994319526`}, {
         3.0789507232536852`, 3.778532425436193}}, 0.05577520655383945], 
        ArrowBox[{{2.4520231668559296`, 3.277229412521784}, {
         3.1211205160450515`, 3.718469857170345}}, 0.05577520655383945], 
        ArrowBox[{{2.4581739379284295`, 3.2685049503054424`}, {
         3.1211205160450515`, 3.718469857170345}}, 0.05577520655383945], 
        ArrowBox[{{2.4643343932155553`, 3.259787323540893}, {
         3.1211205160450515`, 3.718469857170345}}, 0.05577520655383945], 
        ArrowBox[{{2.470504525120967, 3.2510765429776773`}, {
         3.1211205160450515`, 3.718469857170345}}, 0.05577520655383945], 
        ArrowBox[{{2.4766843260363895`, 3.2423726193568942`}, {
         3.1211205160450515`, 3.718469857170345}}, 0.05577520655383945], 
        ArrowBox[{{2.482873788341627, 3.2336755634111896`}, {
         3.1211205160450515`, 3.718469857170345}}, 0.05577520655383945], 
        ArrowBox[{{2.5895653986288343`, 3.086886725319652}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{2.69900884278204, 2.9421379939752175`}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.0190590691824672`, 2.5489408900596144`}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.3593941426790392`, 2.173164164204132}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.3667703544334593`, 2.165447965275602}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.3741551300293517`, 2.157739961957688}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.3815484603606896`, 2.1500401637549826`}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.388950336310897, 2.142348580161964}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        ArrowBox[{{3.3963607487528593`, 2.134665220662976}, {
         3.5383513575950154`, 3.175470515480196}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{4.708792601742663, 3.0866055893240025`}, {
          4.46577750048209, 4.59244785593508}}, 0.05577520655383945]}, 
        ArrowBox[{{4.814627648130082, 2.984911543671071}, {4.46577750048209, 
         4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.82110156451798, 2.978810796263634}, {4.46577750048209, 
         4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.827582251438889, 2.9727172415244016`}, {4.46577750048209,
          4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.834069700901594, 2.966630886967221}, {4.46577750048209, 
         4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.840563904906545, 2.9605517400970633`}, {4.46577750048209,
          4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.847064855445859, 2.95447980841001}, {4.46577750048209, 
         4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.853572544503338, 2.9484150993932454`}, {4.46577750048209,
          4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.860086964054472, 2.9423576205250486`}, {4.46577750048209,
          4.59244785593508}}, 0.05577520655383945], 
        ArrowBox[{{4.866608106066453, 2.9363073792747825`}, {4.46577750048209,
          4.59244785593508}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{5.159423727333477, 5.000942411669477}, {
          5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945]}, 
        ArrowBox[{{0., 2.6429868427313643`}, {0.6874563627874828, 
         3.0542474826229773`}}, 0.05577520655383945], 
        ArrowBox[{{1.908319463378863, 2.6610115000980095`}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{1.9910255152547212`, 2.5495813598020467`}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.001467959242941, 2.535730372164804}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.0084423995705194`, 2.526506051813178}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.0154270786682265`, 2.5172894818582296`}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.0224219879233853`, 2.5080806736647405`}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.0294271187107054`, 2.498879638587919}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.0364424623922925`, 2.489686387973384}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.043468010317655, 2.480500933157166}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.050503753823726, 2.4713232854656715`}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.057549684234857, 2.462153456215688}, {
         2.5895653986288343`, 3.086886725319652}}, 0.05577520655383945], 
        ArrowBox[{{2.075209020925124, 2.439263162951703}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.11428281088879, 2.3890776409364713`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.211484562843088, 2.2669145421096433`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.329042086225458, 2.124035421784769}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.41886594351372, 2.018259045191839}, {3.0190590691824672`,
          2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.5331147120059008`, 1.8877370942328549`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.6377847007365354`, 1.7719087869971588`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.669130290131788, 1.7378919501547543`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.676990271887787, 1.729409521809771}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.6848596680401036`, 1.7209358267462074`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.6927384688851372`, 1.7124708754128166`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7006266647076878`, 1.704014678247571}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.708524245780966, 1.6955672456776485`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.716431202366614, 1.6871285881194202`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7243475247147133`, 1.6786987159784346`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7322732030637953`, 1.6702776396494086`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7402082276408546`, 1.6618653695162129`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7481525886613634`, 1.653461915951861}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7561062763292767`, 1.6450672893184937`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.764069280837055, 1.6366814999673647`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        ArrowBox[{{2.7720415923656647`, 1.6283045582388347`}, {
         3.0190590691824672`, 2.5489408900596144`}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{4.054772977309685, 2.6071753758237843`}, {
          4.708792601742663, 3.0866055893240025`}}, 0.05577520655383945]}, 
        ArrowBox[{{4.148487317735704, 2.514076504145846}, {4.708792601742663, 
         3.0866055893240025`}}, 0.05577520655383945], 
        ArrowBox[{{4.229411349441348, 2.435885553728423}, {4.708792601742663, 
         3.0866055893240025`}}, 0.05577520655383945], 
        ArrowBox[{{4.2364952880032645`, 2.4291352962247057`}, {
         4.708792601742663, 3.0866055893240025`}}, 0.05577520655383945], 
        ArrowBox[{{4.2435867179651945`, 2.4223929091837153`}, {
         4.708792601742663, 3.0866055893240025`}}, 0.05577520655383945], 
        ArrowBox[{{4.250685630582832, 2.4156584009193622`}, {
         4.708792601742663, 3.0866055893240025`}}, 0.05577520655383945], 
        ArrowBox[{{4.257792017102639, 2.4089317797358403`}, {
         4.708792601742663, 3.0866055893240025`}}, 0.05577520655383945], 
        ArrowBox[{{5.440567478361202, 3.4967381423959507`}, {
         5.159423727333477, 5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.476088384639159, 3.464400726142708}, {5.159423727333477, 
         5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.48797646775074, 3.4536742677879797`}, {5.159423727333477,
          5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.4998883437434225`, 3.44297423791706}, {5.159423727333477,
          5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.511823953863983, 3.4323006893059578`}, {
         5.159423727333477, 5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.517800640829817, 3.426973861929632}, {5.159423727333477, 
         5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.5237832392421335`, 3.421653674600064}, {
         5.159423727333477, 5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.529771741723902, 3.4163401338774753`}, {
         5.159423727333477, 5.000942411669477}}, 0.05577520655383945], 
        ArrowBox[{{5.535766140890813, 3.4110332463138953`}, {
         5.159423727333477, 5.000942411669477}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{5.8314039428966575`, 5.439880628095979}, {
          6.630904539978427, 5.721101979319924}}, 0.05577520655383945]}, 
        ArrowBox[{{1.1852774815032934`, 2.293833543324597}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.192521037376034, 2.2837030401545118`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.1997758381161905`, 2.2735805867769328`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2070418747780032`, 2.2634661956736677`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2143191384018586`, 2.253359879316579}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2216076200143018`, 2.2432616501675797`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.228907310628042, 2.233171520678602}, {1.908319463378863, 
         2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2362182012419662`, 2.2230895032915976`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.243540282841158, 2.2130156104385135`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2508735463968907`, 2.2029498545412736`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2582179828666558`, 2.192892248011775}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2655735831941684`, 2.182842803251863}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2729403383093771`, 2.1728015326533185`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2803182391284729`, 2.162768448597845}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2877072765539026`, 2.1527435634570455`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.2951074414743893`, 2.1427268895924216`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3025187247649246`, 2.132718439355343}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3099411172867974`, 2.122718225087043}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3173746098875885`, 2.1127262591185962`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3248191934012041`, 2.1027425537709084`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3322748586478674`, 2.0927671213547017`}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3397415964341377`, 2.082799974170489}, {
         1.908319463378863, 2.6610115000980095`}}, 0.05577520655383945], 
        ArrowBox[{{1.3472193975529283`, 2.0728411245085647`}, {
         1.9910255152547212`, 2.5495813598020467`}}, 0.05577520655383945], 
        ArrowBox[{{1.3547082527834853`, 2.06289058464902}, {
         1.9910255152547212`, 2.5495813598020467`}}, 0.05577520655383945], 
        ArrowBox[{{1.437812580945005, 1.9539865949632924`}, {
         2.075209020925124, 2.439263162951703}}, 0.05577520655383945], 
        ArrowBox[{{1.445433361349366, 1.9441367268327463`}, {
         2.075209020925124, 2.439263162951703}}, 0.05577520655383945], 
        ArrowBox[{{1.4530650747597118`, 1.9342953272075425`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.4607077117655205`, 1.9244624082229231`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.4683612629427998`, 1.9146379820036774`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.4760257188540997`, 1.9048220606641202`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.4837010700485234`, 1.8950146563080787`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.491387307061741, 1.8852157810288803`}, {2.11428281088879,
          2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.4990844204159952`, 1.8754254469093325`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.5067924006201245`, 1.8656436660217128`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.5145112381695593`, 1.8558704504277515`}, {
         2.11428281088879, 2.3890776409364713`}}, 0.05577520655383945], 
        ArrowBox[{{1.522240923546354, 1.8461058121786111`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5299814472191677`, 1.836349763314895}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5377327996433117`, 1.8266023158665963`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.545494971260739, 1.816863481853109}, {2.211484562843088, 
         2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5532679525000646`, 1.8071332732832097`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5610517337765657`, 1.7974117021550313`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5688463054922117`, 1.787698780456064}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5766516580356633`, 1.7779945201631282`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5844677817822852`, 1.7682989332423604`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.5922946670941638`, 1.7586120316492133`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6001323043201126`, 1.7489338273284165`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.607980683795688, 1.7392643322139874`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.615839795843204, 1.7296035582291935`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6237096307717351`, 1.7199515172865585`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6315901788771345`, 1.7103082212878284`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6394814304420482`, 1.7006736821239725`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6473833757359237`, 1.6910479116751596`}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6552960050150176`, 1.681430921810744}, {
         2.211484562843088, 2.2669145421096433`}}, 0.05577520655383945], 
        ArrowBox[{{1.6632193085224252`, 1.6718227243892523`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.6711532764880541`, 1.6622233312583807`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.6790978991286867`, 1.6526327542549577`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.6910347891721287`, 1.6382634448550988`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.702995597071336, 1.6239140382145303`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.7109827403171316`, 1.6143588438715692`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.7189804891249683`, 1.604812524676853}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.726988833632971, 1.5952750924017716`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.7350077639661983`, 1.5857465588067488`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.7430372702366643`, 1.5762269356412437`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.751077342543331, 1.5667162346437244`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.759127970972136, 1.557214467541658}, {2.329042086225458, 
         2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.767189145596003, 1.5477216460514915`}, {
         2.329042086225458, 2.124035421784769}}, 0.05577520655383945], 
        ArrowBox[{{1.7752608564748567`, 1.5382377818786397`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.7833430936556063`, 1.5287628867174927`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.791435847172206, 1.5192969722513556`}, {2.41886594351372,
          2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.7995391070456321`, 1.5098400501524711`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8076528632839057`, 1.500392132081993}, {2.41886594351372,
          2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8157771058821108`, 1.4909532296899677`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8239118248223942`, 1.4815233546153337`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8320570100739868`, 1.4721025184858885`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8402126515932142`, 1.4626907329182863`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8483787393235094`, 1.4532880095180278`}, {
         2.41886594351372, 2.018259045191839}}, 0.05577520655383945], 
        ArrowBox[{{1.8565552631954247`, 1.4438943598794278`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.864742213126636, 1.4345097955856287`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.8770421647979347`, 1.4204500094769479`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.8934784972379273`, 1.401735534616071}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9058329998918317`, 1.387723658913198}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9140822937310933`, 1.3783938493055947`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.922341942694155, 1.3690732058102322`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9306119365962005`, 1.3597617399202244`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9388922652396534`, 1.3504594631173639`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9471829184141978`, 1.3411663868721124`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9554838858967845`, 1.3318825226435882`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9637951574516475`, 1.3226078818795495`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9721167228303145`, 1.3133424760163805`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9804485717716158`, 1.304086316479081}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.9887906940017075`, 1.2948394146812445`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{1.99714307923408, 1.2856017820250534`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{2.0055057171695587`, 1.2763734299012608`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{2.0138785974963334`, 1.2671543696891705`}, {
         2.5331147120059008`, 1.8877370942328549`}}, 0.05577520655383945], 
        ArrowBox[{{2.022261709889973, 1.2579446127566216`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{2.0306550440133986`, 1.2487441704600162`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{2.0390585895169586`, 1.2395530541442348`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{2.0474723360383997`, 1.2303712751426703`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{2.0558962732028885`, 1.2211988447772004`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{2.0643303906230273`, 1.2120357743581778`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{2.0727746778988614`, 1.2028820751844123`}, {
         2.6377847007365354`, 1.7719087869971588`}}, 0.05577520655383945], 
        ArrowBox[{{3.470932364742226, 2.058286030135423}, {4.054772977309685, 
         2.6071753758237843`}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{3.478436073201552, 2.050693758729042}, {
          4.054772977309685, 2.6071753758237843`}}, 0.05577520655383945]}, 
        ArrowBox[{{3.485948207809451, 2.0431098244345316`}, {
         4.054772977309685, 2.6071753758237843`}}, 0.05577520655383945], 
        ArrowBox[{{3.493468759302856, 2.035534236603497}, {4.054772977309685, 
         2.6071753758237843`}}, 0.05577520655383945], 
        ArrowBox[{{3.500997718408313, 2.0279670045772518`}, {
         4.054772977309685, 2.6071753758237843`}}, 0.05577520655383945], 
        ArrowBox[{{3.5085350758420075`, 2.0204081376868057`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.516080822309763, 2.012857645252862}, {4.148487317735704, 
         2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.5236349485070617`, 2.005315536585787}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.5311974451190524`, 1.9977818209856126`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.5387683028205634`, 1.9902565077420231`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.546347512276113, 1.9827396061343405`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.5539350641399174`, 1.975231125431515}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.561530949055914, 1.9677310748921109`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.569135157657758, 1.9602394637643012`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.576747680568844, 1.9527563012858513`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.584368508402309, 1.9452815966841062`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.5919976317610587`, 1.9378153591759846`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.599635041237759, 1.930357597967963}, {4.148487317735704, 
         2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.607280727414868, 1.9229083222560694`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.614934680864634, 1.915467541225861}, {4.148487317735704, 
         2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.622596892149109, 1.9080352640524278`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.630267351820164, 1.9006114999003705`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.6379460504195027`, 1.893196257923794}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.6456329784786643`, 1.88578954726629}, {4.148487317735704,
          2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.6533281265190416`, 1.8783913770609395`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.6610314850518924`, 1.8710017564302825`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{3.668743044578351, 1.8636206944863236`}, {
         4.148487317735704, 2.514076504145846}}, 0.05577520655383945], 
        ArrowBox[{{4.8731359624981865`, 2.930264383102882}, {
         5.440567478361202, 3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.87967052530029, 2.9242286394608588`}, {5.440567478361202,
          3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.886211786415119, 2.918200155791272}, {5.440567478361202, 
         3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.892759737776768, 2.912178939527731}, {5.440567478361202, 
         3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.899314371311083, 2.9061649980948854`}, {
         5.440567478361202, 3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.905875678935665, 2.900158338908411}, {5.440567478361202, 
         3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.912443652559891, 2.8941589693750087`}, {
         5.440567478361202, 3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.919018284084918, 2.888166896892387}, {5.440567478361202, 
         3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.925599565403688, 2.8821821288492577`}, {
         5.440567478361202, 3.4967381423959507`}}, 0.05577520655383945], 
        ArrowBox[{{4.9321874884009524`, 2.876204672625324}, {
         5.476088384639159, 3.464400726142708}}, 0.05577520655383945], 
        ArrowBox[{{4.93878204495326, 2.8702345355912797`}, {5.476088384639159,
          3.464400726142708}}, 0.05577520655383945], 
        ArrowBox[{{4.94538322692899, 2.864271725108784}, {5.476088384639159, 
         3.464400726142708}}, 0.05577520655383945], 
        ArrowBox[{{4.95199102618835, 2.8583162485304703`}, {5.48797646775074, 
         3.4536742677879797`}}, 0.05577520655383945], 
        ArrowBox[{{4.958605434583386, 2.852368113199921}, {
         5.4998883437434225`, 3.44297423791706}}, 0.05577520655383945], 
        ArrowBox[{{4.965226443957997, 2.8464273264516704`}, {
         5.4998883437434225`, 3.44297423791706}}, 0.05577520655383945], 
        ArrowBox[{{4.971854046147939, 2.8404938956111945`}, {
         5.4998883437434225`, 3.44297423791706}}, 0.05577520655383945], 
        ArrowBox[{{6.082458066468294, 3.997012998322271}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.098521450729298, 3.98295027403429}, {5.8314039428966575`,
          5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.10388631170051, 3.978274600537482}, {5.8314039428966575`,
          5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.109256361426986, 3.9736048872888583`}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.114631593287018, 3.9689411400465575`}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.12001200065251, 3.9642833645613544`}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.125397576888983, 3.9596315665766655`}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.130788315355582, 3.954985751828538}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.13618420940509, 3.950345926045637}, {5.8314039428966575`,
          5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.141585252383932, 3.9457120949492444`}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        ArrowBox[{{6.146991437632182, 3.9410842642532495`}, {
         5.8314039428966575`, 5.439880628095979}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{6.630904539978427, 5.721101979319924}, {
          8.388443576916167, 5.298519947952482}}, 0.05577520655383945]}, 
        ArrowBox[{{1.070996575564795, 1.1309906169263275`}, {
         1.6910347891721287`, 1.6382634448550988`}}, 0.05577520655383945], 
        ArrowBox[{{1.0795314711952422`, 1.120733928410397}, {
         1.6910347891721287`, 1.6382634448550988`}}, 0.05577520655383945], 
        ArrowBox[{{1.2613776967919499`, 0.9075536066199188}, {
         1.864742213126636, 1.4345097955856287`}}, 0.05577520655383945], 
        ArrowBox[{{1.2701605888226677`, 0.8975084630016239}, {
         1.8770421647979347`, 1.4204500094769479`}}, 0.05577520655383945], 
        ArrowBox[{{1.2789546299849306`, 0.8874730784662983}, {
         1.8770421647979347`, 1.4204500094769479`}}, 0.05577520655383945], 
        ArrowBox[{{1.2877598094349718`, 0.8774474653883875}, {
         1.8934784972379273`, 1.401735534616071}}, 0.05577520655383945], 
        ArrowBox[{{1.296576116315288, 0.8674316361302798}, {
         1.8934784972379273`, 1.401735534616071}}, 0.05577520655383945], 
        ArrowBox[{{1.4391414441706232`, 0.7085190082710486}, {
         2.0306550440133986`, 1.2487441704600162`}}, 0.05577520655383945], 
        ArrowBox[{{5.541766429351291, 3.405733018453141}, {6.082458066468294, 
         3.997012998322271}}, 0.05577520655383945], 
        ArrowBox[{{5.547772599706484, 3.400439456830834}, {6.082458066468294, 
         3.997012998322271}}, 0.05577520655383945], 
        ArrowBox[{{5.5537846445503, 3.3951525679743595`}, {6.082458066468294, 
         3.997012998322271}}, 0.05577520655383945], 
        ArrowBox[{{5.559802556469399, 3.389872358402883}, {6.082458066468294, 
         3.997012998322271}}, 0.05577520655383945], 
        ArrowBox[{{5.565826328043207, 3.3845988346273295`}, {
         6.082458066468294, 3.997012998322271}}, 0.05577520655383945], 
        ArrowBox[{{6.67233309389966, 4.545891689844322}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.677072487458858, 4.5418528536590825`}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.681816362988226, 4.537819282784285}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.68656471463818, 4.533790982193646}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.691317536553619, 4.529767956854391}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.696074822873926, 4.525750211727235}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.7008365677329795`, 4.521737751766386}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.705602765259165, 4.51773058191953}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.710373409575371, 4.513728707127833}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.715148494799006, 4.509732132325935}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.727105598174198, 4.499763915101112}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.7390903282550045`, 4.489828930417855}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.743891935082644, 4.485864258815701}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.748697941486649, 4.48190492156247}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.753508341540824, 4.477950923540346}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.758323129313556, 4.474002269624933}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.76314229886782, 4.470058964685239}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.767965844261187, 4.466121013583679}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.772793759545838, 4.4621884211760685`}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.777626038768558, 4.45826119231161}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.782462675970756, 4.4543393318329}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.787303665188464, 4.450422844575907}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.792149000452351, 4.446511735369978}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.796998675787724, 4.442606009037831}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.81887576271634, 4.425096982581352}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.840840068555613, 4.407697493826359}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.8457328148240935`, 4.403845860018165}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.85553112331751, 4.396158903597256}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.865346479470402, 4.388493727021275}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.870260535293518, 4.384669317994061}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.875178834870259, 4.380850368097349}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.880101372135959, 4.377036882040215}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.8850281410207295`, 4.373228864524996}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.889959135449466, 4.369426320247286}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.894894349341849, 4.365629253895934}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.899833776612363, 4.361837670153028}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.904777411170291, 4.3580515736939}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.909725246919731, 4.354270969187114}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.914677277759599, 4.350495861294463}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.9196334975836375`, 4.34672625467096}, {6.630904539978427,
          5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.924593900280428, 4.342962153964837}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.92955847973339, 4.339203563817536}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.934527229820794, 4.335450488863704}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.939500144415767, 4.3317029337311865`}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.944477217386303, 4.327960903041022}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.949458442595265, 4.324224401407442}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.954443813900401, 4.3204934334378535`}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{6.95943332515434, 4.316768003732842}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.0271938053158145`, 4.267019072545112}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.095692428362796, 4.218291488296528}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.100795341834946, 4.214722969957511}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.105902214792582, 4.21116012030664}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.111013040938519, 4.207602943737199}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.1161278139706905`, 4.2040514446354775`}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.121246527582166, 4.2005056273807595`}, {
         6.630904539978427, 5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.126369175461157, 4.196965496345328}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.131495751291023, 4.19343105589445}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.136626248750279, 4.189902310386381}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        ArrowBox[{{7.141760661512604, 4.186379264172345}, {6.630904539978427, 
         5.721101979319924}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{8.388443576916167, 5.298519947952482}, {
          8.804283593291188, 5.984360003239441}}, 0.05577520655383945]}, 
        ArrowBox[{{0.45493998448163, 0.6189302286477112}, {1.070996575564795, 
         1.1309906169263275`}}, 0.05577520655383945], 
        ArrowBox[{{0.6673815986233613, 0.36988259779469423`}, {
         1.2701605888226677`, 0.8975084630016239}}, 0.05577520655383945], 
        ArrowBox[{{0.6861541006098193, 0.34848420034057526`}, {
         1.2877598094349718`, 0.8774474653883875}}, 0.05577520655383945], 
        ArrowBox[{{6.206796954074826, 3.8905757797757}, {6.727105598174198, 
         4.499763915101112}}, 0.05577520655383945], 
        ArrowBox[{{6.212264324782052, 3.88602039686765}, {6.727105598174198, 
         4.499763915101112}}, 0.05577520655383945], 
        ArrowBox[{{6.217736750605653, 3.8814710879647087`}, {
         6.727105598174198, 4.499763915101112}}, 0.05577520655383945], 
        ArrowBox[{{6.2232142247976805`, 3.8769278586765434`}, {
         6.727105598174198, 4.499763915101112}}, 0.05577520655383945], 
        ArrowBox[{{6.300425148557725, 3.813964131722682}, {6.81887576271634, 
         4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.305977534309578, 3.809512764702114}, {6.81887576271634, 
         4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.31153485962181, 3.8050675660267768`}, {6.81887576271634, 
         4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.3170971176417865`, 3.8006285411779617`}, {
         6.81887576271634, 4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.322664301510792, 3.796195695629346}, {6.81887576271634, 
         4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.328236404364036, 3.7917690348469897`}, {6.81887576271634,
          4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.333813419330664, 3.7873485642893234`}, {6.81887576271634,
          4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.339395339533763, 3.782934289407147}, {6.81887576271634, 
         4.425096982581352}}, 0.05577520655383945], 
        ArrowBox[{{6.356170462702098, 3.7697286932069067`}, {6.85553112331751,
          4.396158903597256}}, 0.05577520655383945], 
        ArrowBox[{{6.3617719349611175`, 3.765339255381784}, {6.85553112331751,
          4.396158903597256}}, 0.05577520655383945], 
        ArrowBox[{{6.367378277981489, 3.7609560403714157`}, {6.85553112331751,
          4.396158903597256}}, 0.05577520655383945], 
        ArrowBox[{{6.50051251147558, 3.6597549996815397`}, {
         7.0271938053158145`, 4.267019072545112}}, 0.05577520655383945], 
        ArrowBox[{{6.534923775365421, 3.634475957521868}, {
         7.0271938053158145`, 4.267019072545112}}, 0.05577520655383945], 
        ArrowBox[{{6.583959703253862, 3.5990576695185785`}, {
         7.0271938053158145`, 4.267019072545112}}, 0.05577520655383945], 
        ArrowBox[{{6.6187735171786795`, 3.5743359500190097`}, {
         7.0271938053158145`, 4.267019072545112}}, 0.05577520655383945], 
        ArrowBox[{{6.624591799786012, 3.570238238048847}, {
         7.0271938053158145`, 4.267019072545112}}, 0.05577520655383945], 
        ArrowBox[{{6.630414629076462, 3.5661469894688347`}, {
         7.0271938053158145`, 4.267019072545112}}, 0.05577520655383945], 
        ArrowBox[{{7.741707417826749, 4.75028015378079}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{7.917645215347358, 4.644146256246418}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{8.155002488542817, 4.5165076574528}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{8.636778580076802, 4.306734142529214}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{8.912327064208169, 4.213670191936605}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{8.917433989331593, 4.212118943335833}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{8.922542633877555, 4.210573366634183}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{8.927652991546681, 4.209033463737479}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{9.017354923193691, 4.1830055777340105`}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{9.4016634533873, 4.092372622355965}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{9.733788264510698, 4.040294380207342}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{9.768243839184294, 4.036246367511571}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.30881693606766, 4.0054084138708195`}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.849428464899256`, 4.035565127106645}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.854731971015498`, 4.036165026525421}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.860034807708573`, 4.036770814808786}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.865336968439648`, 4.037382491209756}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.870638446670732`, 4.0380000549740815`}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.87593923586467, 4.038623505340258}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.886538720996759`, 4.0398880627958444`}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.897135371555823`, 4.041176157339311}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.90243261753676, 4.041829029038126}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.907729135275758`, 4.042487782617356}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.91302491824178, 4.043152417264705}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.918319959904697`, 4.043822932160622}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.923614253735291`, 4.044499326478309}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.92890779320527, 4.045181599383719}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.934200571787267`, 4.045869750035551}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.939492582954857`, 4.046563777585261}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.944783820182563`, 4.047263681177055}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.950074276945859`, 4.047969459947897}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.95536394672118, 4.048681113027505}, {8.388443576916167, 
         5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.960652822985937`, 4.04939863953835}, {8.388443576916167,
          5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.965940899218513`, 4.050122038595666}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.971228168898284`, 4.050851309307443}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.976514625505613`, 4.051586450774431}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.981800262521874`, 4.0523274620901395`}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.987085073429444`, 4.0530743423408415`}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        ArrowBox[{{10.992369051711725`, 4.053827090605575}, {
         8.388443576916167, 5.298519947952482}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{8.804283593291188, 5.984360003239441}, {9.22720541426489,
           6.667335858470613}}, 0.05577520655383945]}, 
        ArrowBox[{{6.008021692602426, 3.027662881394911}, {6.50051251147558, 
         3.6597549996815397`}}, 0.05577520655383945], 
        ArrowBox[{{6.014447400345469, 3.022887302164518}, {6.50051251147558, 
         3.6597549996815397`}}, 0.05577520655383945], 
        ArrowBox[{{6.0208784071292145`, 3.018118861252421}, {6.50051251147558,
          3.6597549996815397`}}, 0.05577520655383945], 
        ArrowBox[{{6.02731470502371, 3.0133575645384925`}, {6.50051251147558, 
         3.6597549996815397`}}, 0.05577520655383945], 
        ArrowBox[{{6.033756286092477, 3.0086034178937986`}, {6.50051251147558,
          3.6597549996815397`}}, 0.05577520655383945], 
        ArrowBox[{{6.040203142392524, 3.0038564271805894`}, {6.50051251147558,
          3.6597549996815397`}}, 0.05577520655383945], 
        ArrowBox[{{6.046655265974353, 2.9991165982522885`}, {
         6.534923775365421, 3.634475957521868}}, 0.05577520655383945], 
        ArrowBox[{{6.053112648881973, 2.994383936953489}, {6.534923775365421, 
         3.634475957521868}}, 0.05577520655383945], 
        ArrowBox[{{6.0595752831529035`, 2.9896584491199487`}, {
         6.534923775365421, 3.634475957521868}}, 0.05577520655383945], 
        ArrowBox[{{6.066043160818195, 2.984940140578577}, {6.534923775365421, 
         3.634475957521868}}, 0.05577520655383945], 
        ArrowBox[{{6.072516273902427, 2.9802290171474315`}, {
         6.534923775365421, 3.634475957521868}}, 0.05577520655383945], 
        ArrowBox[{{6.078994614423728, 2.97552508463571}, {6.534923775365421, 
         3.634475957521868}}, 0.05577520655383945], 
        ArrowBox[{{6.085478174393775, 2.9708283488437415`}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.0919669458178145`, 2.966138815562985}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.098460920694664, 2.9614564905760155`}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.104960091016724, 2.956781379656517}, {6.583959703253862, 
         3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.111464448769992, 2.9521134885692852`}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.117973985934063, 2.947452823070205}, {6.583959703253862, 
         3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.124488694482154, 2.9427993889062583`}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.131008566381097, 2.9381531918155046`}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.137533593591362, 2.933514237527084}, {6.583959703253862, 
         3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.144063768067061, 2.9288825317612037`}, {
         6.583959703253862, 3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{6.150599081755956, 2.924258080229132}, {6.583959703253862, 
         3.5990576695185785`}}, 0.05577520655383945], 
        ArrowBox[{{7.1468989832468655`, 4.182861921596541}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.152041207617069, 4.179350286996152}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.157187328282447, 4.175844364701302}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.162337338897414, 4.172344159035075}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.167491233111589, 4.168849674313511}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.172649004569804, 4.165360914845592}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.177810646912105, 4.161877884933243}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.182976153773771, 4.158400588871324}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.18814551878531, 4.15492903094762}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.193318735572477, 4.1514632154428455`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.198495797756275, 4.148003146630632}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.203676698952966, 4.144548828777526}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.208861432774078, 4.141100266142982}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.214049992826412, 4.137657462979356}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.219242372712056, 4.1342204235319056`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.224438566028381, 4.130789152038779}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.229638566368059, 4.127363652731012}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.234842367319066, 4.123943929832524}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.240049962464697, 4.120529987560111}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.245261345383561, 4.117121830123441}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.2504765096496016`, 4.113719461725049}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.255695448832096, 4.11032288656033}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.260918156495669, 4.1069321088175395`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.266144626200299, 4.103547132677779}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.271374851501324, 4.100167962315001}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.276608825949452, 4.096794601895996}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.281846543090767, 4.093427055580392}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.287087996466736, 4.090065327520646}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.292333179614227, 4.086709421862042}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.2975820860655, 4.083359342742685}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.302834709348225, 4.080015094293493}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.308091042985495, 4.076676680638197}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.313351080495822, 4.073344105893333}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.318614815393153, 4.070017374168234}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.323882241186876, 4.0666964895650315`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.3291533513818266`, 4.063381456178646}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.334428139478297, 4.060072278096782}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.339706598972047, 4.056768959399926}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.344988723354307, 4.053471504161337}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.350274506111788, 4.050179916447046}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.355563940726692, 4.046894200315847}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.360857020676716, 4.043614359819296}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.366153739435061, 4.0403403990017015`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.371454090470445, 4.037072321900123}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.3767580672471045`, 4.033810132544365}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.382065663224806, 4.030553834956972}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.38737687185885, 4.027303433153224}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.392691686600087, 4.024058931141131}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.398010100894919, 4.020820332921423}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.403332108185309, 4.01758764248756}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.4086577019087905`, 4.01436086382571}, {7.741707417826749,
          4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.413986875498474, 4.01114000091475}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.419319622383054, 4.007925057726271}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.424655935986823, 4.004716038224555}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.429995809729672, 4.001512946366583}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.435339237027101, 3.9983157861020313`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.4406862112902346`, 3.9951245613732542`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.446036725925817, 3.9919392761152928`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.451390774336227, 3.988759934255863}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.4567483499194935`, 3.9855865397153494`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.462109446069286, 3.982419096406807}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.46747405617494, 3.979257608235949}, {7.741707417826749, 
         4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.472842173621455, 3.9761020791011488`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.478213791789508, 3.9729525128934284`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.4835889040554555`, 3.9698089134964603`}, {
         7.741707417826749, 4.75028015378079}}, 0.05577520655383945], 
        ArrowBox[{{7.488967503791365, 3.9666712847865453`}, {
         7.917645215347358, 4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.494349584364953, 3.9635396306326562`}, {
         7.917645215347358, 4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.499735139139693, 3.9604139548963673`}, {
         7.917645215347358, 4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.505124161474761, 3.9572942614318896`}, {
         7.917645215347358, 4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.510516644725053, 3.954180554086059}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.515912582241199, 3.951072836698329}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.521311967369572, 3.947971113100767}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.526714793452289, 3.944875387118051}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.532121053827229, 3.9417856625674617`}, {
         7.917645215347358, 4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.537530741828033, 3.93870194325888}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.542943850784118, 3.935624232994784}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.548360374020678, 3.93255253557024}, {7.917645215347358, 
         4.644146256246418}}, 0.05577520655383945], 
        ArrowBox[{{7.553780304858707, 3.929486854772896}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.559203636614981, 3.926427194382992}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.57277680112659, 3.918804407431548}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.58637107496448, 3.9112193303332736`}, {8.155002488542817,
          4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.591814671648473, 3.90819587135684}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.597261622351255, 3.9051784590413554`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.602711920356288, 3.902167097107534}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.608165558942918, 3.8991617892686277`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.613622531386363, 3.896162539230427}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.619082830957732, 3.8931693506912497`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.624546450924034, 3.890182227341941}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.630013384548182, 3.8872011728658658`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.635483625089, 3.8842261909389055`}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.640957165801241, 3.8812572852294576`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.646433999935584, 3.87829445939842}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.651914120738647, 3.8753377170991996`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.657397521452996, 3.8723870619777}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.662884195317154, 3.869442497672318}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.668374135565605, 3.8665040278139395`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.673867335428807, 3.863571656025938}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.6793637881332, 3.8606453859241645`}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.684863486901211, 3.857725221116949}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.690366424951264, 3.854811165205091}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.695872595497791, 3.8519032217818587`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.723451697904048, 3.837455317231588}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.751110592604663, 3.8231607595480117`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.7566518716308295`, 3.8203202884965277`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.767743875129839, 3.814657814944532}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.77884842696016, 3.809019989388802}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.784405391385958, 3.806210328304158}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.789965472350549, 3.803406839636918}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.795528662997903, 3.80060952684401}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.80109495646815, 3.7978183933747482`}, {8.155002488542817,
          4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.806664345897602, 3.795033442670827}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.812236824418747, 3.792254678166315}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.817812385160269, 3.789482103287657}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.823391021247047, 3.786715721453663}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.8289727258001705`, 3.7839555360755037`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.834557491936945, 3.7812015505567143`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.840145312770899, 3.778453768293181}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.845736181411796, 3.7757121926731427`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.851330090965642, 3.772976827077186}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.856927034534692, 3.770247674878237}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.86252700521746, 3.767524739441564}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.8681299961087285`, 3.7648080241247657`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.873736000299554, 3.7620975322777728`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.879345010877277, 3.7593932672428423`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.884957020925533, 3.756695232354553}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.890572023524259, 3.7540034309398003`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.896190011749701, 3.7513178663177937`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.901810978674419, 3.7486385418000534`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.9074349173673095`, 3.745965460690403}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.913061820893598, 3.743298626284969}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.918691682314855, 3.7406380418721747`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.924324494689005, 3.7379837107327383`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.929960251070332, 3.735335636139662}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.935598944509491, 3.7326938213582403`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.941240568053516, 3.730058269646044}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.946885114745826, 3.7274289842529216`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.952532577626238, 3.7248059684209958`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.958182949730971, 3.7221892253846587`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.963836224092657, 3.7195787583705675`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.9694923937403495`, 3.716974570597638}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.975151451699533, 3.7143766652770465`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.980813390992131, 3.7117850456122206`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.986478204636509, 3.7091997147988396`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.992145885647495, 3.7066206760248237`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{7.997816427036375, 3.7040479324703384`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.003489821810915, 3.7014814873077855`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.009166062975355, 3.698921343701799}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.014845143530431, 3.6963675048092455`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.020527056473375, 3.693819973779215}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.026211794797927, 3.6912787537530205`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.031899351494342, 3.6887438478641927`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.037589719549402, 3.686215259238475}, {8.155002488542817, 
         4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.043282891946422, 3.6836929909938236`}, {
         8.155002488542817, 4.5165076574528}}, 0.05577520655383945], 
        ArrowBox[{{8.057528045856884, 3.6774149924405943`}, {
         8.636778580076802, 4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.071790573235347, 3.6711765640692144`}, {
         8.636778580076802, 4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.077500424140677, 3.6686922831513096`}, {
         8.636778580076802, 4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.083213030174827, 3.666214344221724}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.08892838429369, 3.663742750335956}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.094646479449768, 3.661277504541683}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.10036730859219, 3.658818609878753}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.106090864666704, 3.656366069379181}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.235576532689993, 3.60287022832798}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.501300757691034, 3.504658495131018}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.643368062508598, 3.458296726600965}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.649313951666002, 3.456447280422231}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.65526189085972, 3.454604437947139}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.661211872755457, 3.45276820144806}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.667163890016406, 3.450938573189223}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.673117935303242, 3.449115555426709}, {8.636778580076802, 
         4.306734142529214}}, 0.05577520655383945], 
        ArrowBox[{{8.702918325075023, 3.440099702451044}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.708884384252062, 3.4383163945874857`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.714852420010235, 3.4365397127844215`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.720822424990468, 3.4347696592326447`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.726794391831259, 3.4330062361147737`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.732768313168691, 3.4312494456052534`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.73874418163643, 3.429499289870349}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.74472198986575, 3.4277557710681448`}, {9.017354923193691,
          4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.750701730485526, 3.426018891348539}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.75668339612225, 3.4242886528532486`}, {9.017354923193691,
          4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.762666979400045, 3.422565057715796}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.768652472940667, 3.4208481080615147`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.774639869363515, 3.4191378060075435`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.780629161285646, 3.417434153662822}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.786620341321772, 3.4157371531280933`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.792613402084285, 3.4140468064958966`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.798608336183255, 3.4123631158505665`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.80460513622644, 3.4106860832682298`}, {9.017354923193691,
          4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.810603794819299, 3.4090157108168047`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.816604304564999, 3.4073520005559947`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.822606658064423, 3.4056949545372905`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.828610847916185, 3.404044574803966}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.834616866716628, 3.40240086339107}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.840624707059844, 3.400763822325435}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.84663436153768, 3.399133453625663}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.852645822739742, 3.3975097593021335`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.85865908325341, 3.3958927413569935`}, {9.017354923193691,
          4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.864674135663847, 3.394282401784154}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.870690972554005, 3.3926787425692986`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.876709586504637, 3.391081765689867}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.8827299700943, 3.3894914731150605`}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.888752115899372, 3.3879078668058424`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.894776016494061, 3.3863309487149245`}, {
         9.017354923193691, 4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.900801664450407, 3.384760720786775}, {9.017354923193691, 
         4.1830055777340105`}}, 0.05577520655383945], 
        ArrowBox[{{8.906829052338308, 3.3831971849576137`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{8.912858172725484, 3.381640343155407}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{8.918889018177552, 3.380090197299869}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{8.924921581257987, 3.378546749302452}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{8.93095585452815, 3.3770100010663553`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{8.936991830547294, 3.375479954486514}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.03379294103235, 3.3519121486701033`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.188891012753613, 3.3179160972520023`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.298921446023243, 3.2965694655630857`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.381712244694437, 3.2820050403625887`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.41857635703982, 3.2759306707470133`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.42472427512651, 3.2749421606360345`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.430873287105626, 3.2739604780392444`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.437023385394939, 3.272985624167138}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.443174562410876, 3.2720176002217896`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.449326810568536, 3.27105640739685}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.461634489962833, 3.26915451984069}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.50782514034199, 3.2622660008676396`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.547902262076024, 3.2566072959281316`}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.575671401768453, 3.252859253682071}, {9.4016634533873, 
         4.092372622355965}}, 0.05577520655383945], 
        ArrowBox[{{9.603458923612386, 3.2492500197316163`}, {
         9.733788264510698, 4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.609636355019465, 3.248466827385503}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.61581465230736, 3.247690495199813}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.621993807857733, 3.2469210241318285`}, {
         9.733788264510698, 4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.62817381405118, 3.2461584151303713`}, {9.733788264510698,
          4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.634354663267255, 3.245402669135796}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.640536347884465, 3.2446537870800025`}, {
         9.733788264510698, 4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.646718860280295, 3.243911769886422}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.652902192831204, 3.243176618470022}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.65908633791264, 3.242448333737305}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.665271287899051, 3.241726916586302}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.67145703516389, 3.241012367906581}, {9.733788264510698, 
         4.040294380207342}}, 0.05577520655383945], 
        ArrowBox[{{9.683830891017772, 3.239603879476901}, {10.30881693606766, 
         4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{9.755038798215068, 3.2320386445270746`}, {
         10.30881693606766, 4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{9.826337505424343, 3.225383332547054}, {10.30881693606766, 
         4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{9.832541301982888, 3.2248476485913846`}, {
         10.30881693606766, 4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{9.972268473745793, 3.214617267154125}, {10.30881693606766, 
         4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{10.51686701007871, 3.2080751712097015`}, {
         10.30881693606766, 4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{10.926648475347433`, 3.2381307572659885`}, {
         10.30881693606766, 4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{10.932837438247368`, 3.23881689665662}, {10.30881693606766,
          4.0054084138708195`}}, 0.05577520655383945], 
        ArrowBox[{{10.97613831076398, 3.2438122416118453`}, {
         10.886538720996759`, 4.0398880627958444`}}, 0.05577520655383945], 
        ArrowBox[{{10.982320934194176`, 3.244553333077558}, {
         10.886538720996759`, 4.0398880627958444`}}, 0.05577520655383945], 
        ArrowBox[{{10.988502730873652`, 3.245301289529352}, {
         10.886538720996759`, 4.0398880627958444`}}, 0.05577520655383945], 
        ArrowBox[{{11.15233990340667, 4.895666343606759}, {8.804283593291188, 
         5.984360003239441}}, 0.05577520655383945], 
        ArrowBox[{{11.157148773239273`, 4.8967015041446}, {8.804283593291188, 
         5.984360003239441}}, 0.05577520655383945], 
        ArrowBox[{{11.161956368169696`, 4.897742569652108}, {
         8.804283593291188, 5.984360003239441}}, 0.05577520655383945], 
        ArrowBox[{{11.17877280590413, 4.901432777815097}, {8.804283593291188, 
         5.984360003239441}}, 0.05577520655383945], 
        ArrowBox[{{11.209960603621447`, 4.9084776482196615`}, {
         8.804283593291188, 5.984360003239441}}, 0.05577520655383945], 
        ArrowBox[{{11.229124775528485`, 4.9129366130920085`}, {
         8.804283593291188, 5.984360003239441}}, 0.05577520655383945], 
        ArrowBox[{{11.233912377920642`, 4.914066059744405}, {
         8.804283593291188, 5.984360003239441}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{9.22720541426489, 6.667335858470613}, {9.818269775626112,
           7.287655869413179}}, 0.05577520655383945]}, 
        ArrowBox[{{7.172171065572073, 3.225013146325872}, {7.57277680112659, 
         3.918804407431548}}, 0.05577520655383945], 
        ArrowBox[{{7.178376909602201, 3.2215301654526947`}, {7.57277680112659,
          3.918804407431548}}, 0.05577520655383945], 
        ArrowBox[{{7.184586617453444, 3.218054077955033}, {7.57277680112659, 
         3.918804407431548}}, 0.05577520655383945], 
        ArrowBox[{{7.190800181468729, 3.2145848881191865`}, {7.57277680112659,
          3.918804407431548}}, 0.05577520655383945], 
        ArrowBox[{{7.344215851467155, 3.1317560596699314`}, {
         7.723451697904048, 3.837455317231588}}, 0.05577520655383945], 
        ArrowBox[{{7.366314340771927, 3.1202651572721045`}, {
         7.723451697904048, 3.837455317231588}}, 0.05577520655383945], 
        ArrowBox[{{7.37263638164194, 3.116997825772689}, {7.723451697904048, 
         3.837455317231588}}, 0.05577520655383945], 
        ArrowBox[{{7.378962046795367, 3.113737516545651}, {7.723451697904048, 
         3.837455317231588}}, 0.05577520655383945], 
        ArrowBox[{{7.397960709933258, 3.103998762657742}, {7.767743875129839, 
         3.814657814944532}}, 0.05577520655383945], 
        ArrowBox[{{7.404300794175208, 3.1007665826358126`}, {
         7.767743875129839, 3.814657814944532}}, 0.05577520655383945], 
        ArrowBox[{{7.410644463655782, 3.097541444900701}, {7.767743875129839, 
         3.814657814944532}}, 0.05577520655383945], 
        ArrowBox[{{7.725712207358569, 2.9482171326882227`}, {
         8.057528045856884, 3.6774149924405943`}}, 0.05577520655383945], 
        ArrowBox[{{7.73222507594949, 2.9453489976484146`}, {8.057528045856884,
          3.6774149924405943`}}, 0.05577520655383945], 
        ArrowBox[{{7.73874112542177, 2.942488096537926}, {8.057528045856884, 
         3.6774149924405943`}}, 0.05577520655383945], 
        ArrowBox[{{7.74526034774059, 2.939634432884481}, {8.057528045856884, 
         3.6774149924405943`}}, 0.05577520655383945], 
        ArrowBox[{{7.7975273833019125`, 2.9170660924902334`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.804074799030509, 2.914277723223779}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.810625307043923, 2.911496626200048}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.817178899264842, 2.9087228048483595`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.823735567612159, 2.9059562625890614`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.830295304000967, 2.9031970028335223`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.83685810034258, 2.9004450289841355`}, {8.235576532689993,
          3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.843423948544535, 2.897700344434308}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.849992840510611, 2.8949629525684584`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.856564768140828, 2.8922328567620124`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.863139723331468, 2.889510060381401}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.869717697975075, 2.8867945667840527`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.876298683960474, 2.8840863793183917`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.882882673172775, 2.881385501323832}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.889469657493384, 2.878691936130778}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.896059628800016, 2.876005687060611}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.902652578966698, 2.873326757425697}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.909248499863791, 2.870655150529373}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.9158473833579865`, 2.8679908696659453`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.922449221312325, 2.865333918120691}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.929054005586208, 2.862684299169846}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.935661728035395, 2.860042016080606}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.942272380512032, 2.85740707211112}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.948885954864645, 2.854779470510489}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.955502442938162, 2.852159214518757}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.962121836573914, 2.849546307366915}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.968744127609652, 2.846940752276887}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.975369307879554, 2.8443425524615362`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.981997369214234, 2.841751711124653}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.9886283034407555`, 2.8391682314609543`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{7.995262102382636, 2.8365921166560817`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.001898757859866, 2.8340233698865944`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.008538261688907, 2.831461994319964}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.015180605682714, 2.8289079931145746`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.021825781650735, 2.8263613694197183`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.028473781398933, 2.823822126375588}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.03512459672978, 2.8212902671132776`}, {8.235576532689993,
          3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.041778219442284, 2.818765794754774}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.048434641331985, 2.816248712412957}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.055093854190977, 2.8137390231915926`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.061755849807907, 2.8112367301853327`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.068420619967998, 2.808741836479708}, {8.235576532689993, 
         3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.075088156453042, 2.8062543451511237`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.081758451041429, 2.8037742592668593`}, {
         8.235576532689993, 3.60287022832798}}, 0.05577520655383945], 
        ArrowBox[{{8.118494004649342, 2.7902662954221755`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.168719521114845, 2.772208417180617}, {8.501300757691034, 
         3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.225821284563686, 2.7522493099862153`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.269613004435712, 2.7373506300975814`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.276359692651468, 2.735086595201966}, {8.501300757691034, 
         3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.286484428472994, 2.7317045934783097`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.29661478352159, 2.7283394608354747`}, {8.501300757691034,
          3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.303371461467943, 2.7261054153976128`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.310130616025791, 2.7238788742342086`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.316892238860541, 2.7216598400907674`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.32365632163457, 2.7194483157035396`}, {8.501300757691034,
          3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.330422856007207, 2.7172443037995144`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.337191833634773, 2.7150478070964166`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.343963246170564, 2.7128588283027053`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.35073708526488, 2.710677370117569}, {8.501300757691034, 
         3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.357513342565028, 2.7085034352309227`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.364292009715331, 2.7063370263234052`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.371073078357146, 2.704178146066374}, {8.501300757691034, 
         3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.37785654012886, 2.7020267971219036`}, {8.501300757691034,
          3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.384642386665917, 2.6998829821427828`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.391430609600816, 2.6977467037725082`}, {
         8.501300757691034, 3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.398221200563126, 2.695617964645286}, {8.501300757691034, 
         3.504658495131018}}, 0.05577520655383945], 
        ArrowBox[{{8.74748436759547, 2.597108064355889}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.754386492380004, 2.595374764223793}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.761290537637876, 2.5936491295676625`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.76819649485584, 2.591931162515345}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.775104355518287, 2.5902208651852323`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.782014111107266, 2.5885182396862607`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.78892575310249, 2.5868232881179063`}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.795839272981338, 2.58513601257018}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.80275466221888, 2.5834564151236314`}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.809671912287884, 2.5817844978493394`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.816591014658814, 2.580120262808915}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.823511960799856, 2.5784637120544938`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.830434742176923, 2.5768148476287385`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.837359350253664, 2.5751736715648317`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.844285776491471, 2.5735401858864773`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.851214012349502, 2.571914392607896}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.858144049284679, 2.570296293733822}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.865075878751703, 2.5686858912595047`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.872009492203064, 2.5670831871706987`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.878944881089058, 2.5654881834436694`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.885882036857783, 2.5639008820451856`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.892820950955166, 2.562321284932519}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.899761614824959, 2.560749394053442}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.906704019908762, 2.5591852113462217`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.913648157646026, 2.5576287387396235`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.920594019474066, 2.556079978152905}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.927541596828068, 2.554538931495813}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.934490881141107, 2.553005600668583}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.941441863844151, 2.551479987561936}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.948394536366074, 2.5499620940570784`}, {9.03379294103235,
          3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.955348890133665, 2.548451922025695}, {9.03379294103235, 
         3.3519121486701033`}}, 0.05577520655383945], 
        ArrowBox[{{8.962304916571654, 2.5469494733299483`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{8.969262607102673, 2.5454547498224853`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{8.976221953147334, 2.5439677533464176`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{8.9831829461242, 2.5424884857353325`}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{8.990145577449804, 2.5410169488132883`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{8.99710983853865, 2.5395531443948087`}, {9.188891012753613,
          3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.004075720803243, 2.5380970742848836`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.011043215654084, 2.5366487402789666`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.018012314499686, 2.5352081441629695`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.024983008746583, 2.533775287713265}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.031955289799344, 2.532350172696681}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.03892914906058, 2.5309328008705014`}, {9.188891012753613,
          3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.045904577930958, 2.5295231739824597`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.052881567809207, 2.52812129377074}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.05986011009213, 2.526727161963975}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.06684019617462, 2.525340780281242}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.073821817449664, 2.5239621504320624`}, {
         9.188891012753613, 3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.080804965308355, 2.522591274116399}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.087789631139906, 2.521228153024654}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.094775806331654, 2.519872788837665}, {9.188891012753613, 
         3.3179160972520023`}}, 0.05577520655383945], 
        ArrowBox[{{9.101763482269087, 2.518525183226706}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.10875265033582, 2.517185337853486}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.11574330191365, 2.5158532543701417`}, {9.298921446023243,
          3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.12273542838253, 2.514528934419241}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.129729021120607, 2.513212379633778}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.136724071504208, 2.5119035916371706`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.14372057090787, 2.510602572043261}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.150718510704342, 2.5093093224563123`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.157717882264595, 2.5080238444710066`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.164718676957836, 2.506746139672442}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.171720886151517, 2.5054762096361323`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.178724501211345, 2.5042140559280046`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.185729513501293, 2.5029596801043965`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.192735914383615, 2.5017130837120565`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.199743695218848, 2.500474268288137}, {9.298921446023243, 
         3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.206752847365827, 2.4992432353601997`}, {
         9.298921446023243, 3.2965694655630857`}}, 0.05577520655383945], 
        ArrowBox[{{9.213763362181709, 2.4980199864462076`}, {
         9.381712244694437, 3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.220775231021944, 2.496804523054526}, {9.381712244694437, 
         3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.227788445240337, 2.4955968466839193`}, {
         9.381712244694437, 3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.234802996189025, 2.494396958823552}, {9.381712244694437, 
         3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.25234516498934, 2.491431323590895}, {9.381712244694437, 
         3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.269895499096906, 2.488514398623627}, {9.381712244694437, 
         3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.276917888730688, 2.4873612725591707`}, {
         9.381712244694437, 3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.283941554514174, 2.486215945160085}, {9.381712244694437, 
         3.2820050403625887`}}, 0.05577520655383945], 
        ArrowBox[{{9.333142219491622, 2.4784171334164036`}, {
         9.461634489962833, 3.26915451984069}}, 0.05577520655383945], 
        ArrowBox[{{9.340175782555773, 2.47733424537428}, {9.461634489962833, 
         3.26915451984069}}, 0.05577520655383945], 
        ArrowBox[{{9.34721054376751, 2.476259168361665}, {9.461634489962833, 
         3.26915451984069}}, 0.05577520655383945], 
        ArrowBox[{{9.354246494452395, 2.475191903704215}, {9.50782514034199, 
         3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.361283625934533, 2.4741324527179556`}, {9.50782514034199,
          3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.36832192953657, 2.4730808167092757`}, {9.50782514034199, 
         3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.375361396579704, 2.4720369969749267`}, {9.50782514034199,
          3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.3824020183837, 2.471000994802024}, {9.50782514034199, 
         3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.389443786266904, 2.4699728114680424`}, {9.50782514034199,
          3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.396486691546242, 2.468952448240816}, {9.50782514034199, 
         3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.403530725537237, 2.4679399063785334`}, {9.50782514034199,
          3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.410575879554028, 2.466935187129743}, {9.50782514034199, 
         3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.417622144909366, 2.4659382917333446`}, {9.50782514034199,
          3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.424669512914633, 2.4649492214185917`}, {9.50782514034199,
          3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.431717974879852, 2.463967977405086}, {9.50782514034199, 
         3.2622660008676396`}}, 0.05577520655383945], 
        ArrowBox[{{9.459922588493738, 2.460121288417837}, {9.575671401768453, 
         3.252859253682071}}, 0.05577520655383945], 
        ArrowBox[{{9.481087109276432, 2.4573185061652856`}, {
         9.575671401768453, 3.252859253682071}}, 0.05577520655383945], 
        ArrowBox[{{9.48814400992248, 2.4563999153091496`}, {9.575671401768453,
          3.252859253682071}}, 0.05577520655383945], 
        ArrowBox[{{9.495201926259275, 2.455489161296252}, {9.575671401768453, 
         3.252859253682071}}, 0.05577520655383945], 
        ArrowBox[{{9.60118663328264, 2.44276901294346}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.60825961624673, 2.441983794579645}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.61533346678927, 2.441206430835316}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.622408176187628, 2.440436922669024}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.629483735718111, 2.4396752710296354`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.63656013665598, 2.4389214768563283`}, {9.755038798215068,
          3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.643637370275458, 2.438175541078592}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.650715427849743, 2.4374374646162273`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.657794300651014, 2.4367072483793413`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.664873979950446, 2.4359848932683494`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.671954457018222, 2.435270400173975}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.679035723123535, 2.434563769977246}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.68611776953461, 2.433865003549494}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.69320058751871, 2.433174101752355}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.700284168342147, 2.432491065437768}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.707368503270287, 2.431815895447972}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.714453583567572, 2.4311485926155045`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.721539400497521, 2.4304891577632075`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.728625945322747, 2.4298375917042145`}, {
         9.755038798215068, 3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.735713209304969, 2.429193895241961}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.742801183705009, 2.428558069170177}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.74988985978282, 2.427930114272886}, {9.755038798215068, 
         3.2320386445270746`}}, 0.05577520655383945], 
        ArrowBox[{{9.771160010669508, 2.4260934843226405`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.77825140604079, 2.4254970217694485`}, {9.972268473745793,
          3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.785343459376842, 2.424908434165271}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.792436161932585, 2.424327722235885}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.799529504962143, 2.4237548866973535`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.806623479718848, 2.423189928256031}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.813718077455253, 2.422632847608556}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.820813289423143, 2.4220836454418553`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.827909106873543, 2.4215423224331376`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.835005521056738, 2.421008879249901}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.842102523222271, 2.420483316549922}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.849200104618962, 2.4199656349812626`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.856298256494917, 2.4194558351822675`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.86339697009754, 2.41895391778156}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.870496236673539, 2.418459883398045}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.877596047468941, 2.417973732640907}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.884696393729106, 2.41749546610961}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.891797266698727, 2.4170250843938943`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.898898657621855, 2.4165625880737807`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.906000557741894, 2.4161079777195633`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.913102958301629, 2.4156612538918134`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.92020585054322, 2.4152224171413783`}, {9.972268473745793,
          3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.927309225708225, 2.414791468009379}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.934413075037607, 2.4143684070272107`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.941517389771741, 2.4139532347165424`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.948622161150432, 2.413545951589316}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.95572738041292, 2.4131465581477425`}, {9.972268473745793,
          3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.962833038797891, 2.4127550548843084`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.969939127543492, 2.412371442281769}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.977045637887338, 2.411995720813148}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.984152561066526, 2.411627890941742}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.991259888317645, 2.411267953121114}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{9.998367610876778, 2.410915907795098}, {9.972268473745793, 
         3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.005475719979529`, 2.4105717553977932`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.012584206861023`, 2.410235496353568}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.019693062755916`, 2.409907131077058}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.026802278898415`, 2.4095866599731623`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.033911846522276`, 2.409274083437049}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.041021756860827`, 2.40896940185415}, {9.972268473745793,
          3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.048132001146971`, 2.408672615600163}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.055242570613197`, 2.408383725041049}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.0623534564916, 2.4081027305330327`}, {9.972268473745793,
          3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.069464650013876`, 2.4078296324226054`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.076576142411348`, 2.4075644310465165`}, {
         9.972268473745793, 3.214617267154125}}, 0.05577520655383945], 
        ArrowBox[{{10.129920976856818`, 2.405827160543713}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.197508742605528`, 2.4042644871367616`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.218855247486797`, 2.4039191500981385`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.225970990141619`, 2.4038198406849816`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.233086838686612`, 2.4037284329505617`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.243760790854097`, 2.4036061372404642`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.354063962397339`, 2.4033835297643407`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.507037450025306`, 2.4062176934444466`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.599484647651675`, 2.4097027681859755`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.68476775916889, 2.4141039246570273`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.730936095748582`, 2.4169622614528317`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.741587314204274`, 2.4176691960492427`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.762886144698651`, 2.4191362842838418`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.787728437255263`, 2.4209375527261576`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.80192082965659, 2.422010193875745}, {10.51686701007871, 
         3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.809016123778045`, 2.4225583336564664`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.816110804847686`, 2.4231143520098426`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.823204864117189`, 2.4236782482502583`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.830298292839005`, 2.4242500216823837`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.837391082266363`, 2.4248296716011755`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.844483223653276`, 2.425417197291879}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.851574708254557`, 2.4260125980300256`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.85866552732583, 2.42661587308144}, {10.51686701007871, 
         3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.865755672123539`, 2.427227021702234}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.872845133904962`, 2.4278460431388122`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.879933903928213`, 2.4284729366278714`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.887021973452267`, 2.429107701396399}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.894109333736958`, 2.42975033666168}, {10.51686701007871,
          3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.901195976042994`, 2.430400841631293}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.90828189163197, 2.4310592155031117`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.915367071766378`, 2.4317254574653084`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.922451507709612`, 2.4323995666963523`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.929535190725993`, 2.433081542365013}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.93661811208076, 2.433771383630357}, {10.51686701007871, 
         3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.943700263040096`, 2.4344690896417562`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.950781634871138`, 2.4351746595388812`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.957862218841974`, 2.435888092451707}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.964942006221674`, 2.436609387500514}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.972020988280283`, 2.437338543795886}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.979099156288843`, 2.4380755604387145`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.986176501519395`, 2.4388204365201966`}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{10.993253015245, 2.4395731711218414`}, {10.51686701007871, 
         3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{11.00032868873974, 2.440333763315466}, {10.51686701007871, 
         3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{11.007403513278739`, 2.441102212163197}, {
         10.51686701007871, 3.2080751712097015`}}, 0.05577520655383945], 
        ArrowBox[{{11.337746128774008`, 4.116168158049847}, {
         11.17877280590413, 4.901432777815097}}, 0.05577520655383945], 
        ArrowBox[{{11.343512156824366`, 4.117431602922823}, {
         11.17877280590413, 4.901432777815097}}, 0.05577520655383945], 
        ArrowBox[{{11.349276628895845`, 4.118702128074797}, {
         11.17877280590413, 4.901432777815097}}, 0.05577520655383945], 
        ArrowBox[{{11.355039536294344`, 4.119979731589539}, {
         11.17877280590413, 4.901432777815097}}, 0.05577520655383945], 
        ArrowBox[{{11.360800870328159`, 4.121264411540144}, {
         11.17877280590413, 4.901432777815097}}, 0.05577520655383945], 
        ArrowBox[{{11.366560622307919`, 4.122556165989033}, {
         11.17877280590413, 4.901432777815097}}, 0.05577520655383945], 
        ArrowBox[{{11.383830299065298`, 4.126473856789592}, {
         11.209960603621447`, 4.9084776482196615`}}, 0.05577520655383945], 
        ArrowBox[{{11.403959847894459`, 4.131124875238917}, {
         11.209960603621447`, 4.9084776482196615`}}, 0.05577520655383945], 
        ArrowBox[{{11.355465250905299`, 5.78228215399813}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.36389865519153, 5.7852003759554425`}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.368112301446487`, 5.78666829172322}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.372323899547393`, 5.788142073559056}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.376533441327751`, 5.789621718605213}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.399648799829508`, 5.797864442459353}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.422700352159886`, 5.806283957312379}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.426884582573988`, 5.80783373384624}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.43106665087166, 5.809389335407313}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.435246548943661`, 5.810950758979209}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.441512309149935`, 5.813303803981215}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.447773140776485`, 5.815669931426646}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.451944276937823`, 5.81725461265225}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.456113202390734`, 5.818845100637514}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.460279909051465`, 5.8204413922984}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.464444388840565`, 5.822043484539621}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.4686066336829, 5.823651374254639}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.472766635507668`, 5.825265058325677}, {9.22720541426489,
          6.667335858470613}}, 0.05577520655383945], 
        ArrowBox[{{11.47692438624842, 5.826884533623721}, {9.22720541426489, 
         6.667335858470613}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{9.818269775626112, 7.287655869413179}, {
          10.310247556049253`, 8.010816537836144}}, 0.05577520655383945]}, 
        ArrowBox[{{6.959078598990364, 2.4291688709190034`}, {
         7.344215851467155, 3.1317560596699314`}}, 0.05577520655383945], 
        ArrowBox[{{6.969714717740356, 2.4235931483086297`}, {
         7.344215851467155, 3.1317560596699314`}}, 0.05577520655383945], 
        ArrowBox[{{6.976810616793813, 2.4198858455683734`}, {
         7.344215851467155, 3.1317560596699314`}}, 0.05577520655383945], 
        ArrowBox[{{6.983910628215989, 2.416186424696167}, {7.344215851467155, 
         3.1317560596699314`}}, 0.05577520655383945], 
        ArrowBox[{{6.991014743251995, 2.412494890253697}, {7.344215851467155, 
         3.1317560596699314`}}, 0.05577520655383945], 
        ArrowBox[{{7.810504752220147, 2.0499772244824914`}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.818015011601361, 2.047203800423384}, {8.118494004649342, 
         2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.825528346077976, 2.0444387177795456`}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.8330447463854425`, 2.0416819799605523`}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.840564203255427, 2.038933590365681}, {8.118494004649342, 
         2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.848086707415829, 2.03619355238392}, {8.118494004649342, 
         2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.8556122495907905`, 2.0334618693939612`}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.863140820500707, 2.0307385447641897`}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.8706724108622375`, 2.028023581852687}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.878207011388323, 2.0253169840072216`}, {
         8.118494004649342, 2.7902662954221755`}}, 0.05577520655383945], 
        ArrowBox[{{7.8857446127881925`, 2.0226187545652445`}, {
         8.168719521114845, 2.772208417180617}}, 0.05577520655383945], 
        ArrowBox[{{7.89328520576736, 2.0199288968539015`}, {8.168719521114845,
          2.772208417180617}}, 0.05577520655383945], 
        ArrowBox[{{7.900828781027668, 2.017247414189998}, {8.168719521114845, 
         2.772208417180617}}, 0.05577520655383945], 
        ArrowBox[{{7.908375329267278, 2.0145743098800217`}, {
         8.168719521114845, 2.772208417180617}}, 0.05577520655383945], 
        ArrowBox[{{7.915924841180679, 2.0119095872201287`}, {
         8.168719521114845, 2.772208417180617}}, 0.05577520655383945], 
        ArrowBox[{{7.923477307458715, 2.009253249496137}, {8.225821284563686, 
         2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.931032718788577, 2.0066052999835264`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.938591065853832, 2.003965741947434}, {8.225821284563686, 
         2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.946152339334425, 2.0013345786426493`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.953716529906689, 1.9987118133136113`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.9612836282433666`, 1.9960974491943997`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.968853625013608, 1.9934914895087399`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.976426510882995, 1.990893937469992}, {8.225821284563686, 
         2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.984002276513542, 1.9883047962811489`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.991580912563717, 1.9857240691348297`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{7.999162409688445, 1.983151759213281}, {8.225821284563686, 
         2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{8.006746758539125, 1.9805878696883736`}, {
         8.225821284563686, 2.7522493099862153`}}, 0.05577520655383945], 
        ArrowBox[{{8.021923974006372, 1.9754853644640162`}, {
         8.276359692651468, 2.735086595201966}}, 0.05577520655383945], 
        ArrowBox[{{8.029516821908192, 1.972946755056375}, {8.286484428472994, 
         2.7317045934783097`}}, 0.05577520655383945], 
        ArrowBox[{{8.03711248410651, 1.970416578628969}, {8.286484428472994, 
         2.7317045934783097`}}, 0.05577520655383945], 
        ArrowBox[{{9.108065554394276, 1.7033684134339095`}, {9.25234516498934,
          2.491431323590895}}, 0.05577520655383945], 
        ArrowBox[{{9.115959902660771, 1.70203606872174}, {9.25234516498934, 
         2.491431323590895}}, 0.05577520655383945], 
        ArrowBox[{{9.123855725551232, 1.700712491044678}, {9.25234516498934, 
         2.491431323590895}}, 0.05577520655383945], 
        ArrowBox[{{9.13175301332947, 1.699397682034804}, {9.25234516498934, 
         2.491431323590895}}, 0.05577520655383945], 
        ArrowBox[{{9.337564733937421, 1.6682955396127888`}, {
         9.459922588493738, 2.460121288417837}}, 0.05577520655383945], 
        ArrowBox[{{9.345497887090675, 1.667218061988061}, {9.459922588493738, 
         2.460121288417837}}, 0.05577520655383945], 
        ArrowBox[{{9.353432231828922, 1.666149394331871}, {9.459922588493738, 
         2.460121288417837}}, 0.05577520655383945], 
        ArrowBox[{{9.361367758368475, 1.6650895379619763`}, {
         9.459922588493738, 2.460121288417837}}, 0.05577520655383945], 
        ArrowBox[{{9.369304456924183, 1.6640384941852622`}, {
         9.459922588493738, 2.460121288417837}}, 0.05577520655383945], 
        ArrowBox[{{9.377242317709454, 1.6629962642977514`}, {
         9.481087109276432, 2.4573185061652856`}}, 0.05577520655383945], 
        ArrowBox[{{10.055168235302828`, 1.6067334624350593`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.063169307123237`, 1.606452879631946}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.071170685581512`, 1.6061811817257734`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.0791723608113, 1.605918369051568}, {10.129920976856818`,
          2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.087174322945891`, 1.605664441933401}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.095176562118212`, 1.605419400684383}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.103179068460854`, 1.6051832456066712`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.111181832106077`, 1.6049559769914632`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.119184843185822`, 1.6047375951189995`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.12718809183173, 1.6045281002585625`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.135191568175141`, 1.6043274926684772`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.143195262347122`, 1.6041357725961092`}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.151199164478468`, 1.603952940277864}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.159203264699716`, 1.603778995939189}, {
         10.129920976856818`, 2.405827160543713}}, 0.05577520655383945], 
        ArrowBox[{{10.16720755314117, 1.6036139397945712`}, {
         10.197508742605528`, 2.4042644871367616`}}, 0.05577520655383945], 
        ArrowBox[{{10.175212019932877`, 1.6034577720475394`}, {
         10.197508742605528`, 2.4042644871367616`}}, 0.05577520655383945], 
        ArrowBox[{{10.183216655204687`, 1.6033104928906612`}, {
         10.197508742605528`, 2.4042644871367616`}}, 0.05577520655383945], 
        ArrowBox[{{10.191221449086234`, 1.6031721025055417`}, {
         10.197508742605528`, 2.4042644871367616`}}, 0.05577520655383945], 
        ArrowBox[{{10.199226391706958`, 1.6030426010628291`}, {
         10.197508742605528`, 2.4042644871367616`}}, 0.05577520655383945], 
        ArrowBox[{{10.223242013295906`, 1.6027074319311865`}, {
         10.233086838686612`, 2.4037284329505617`}}, 0.05577520655383945], 
        ArrowBox[{{10.231247452164245`, 1.602613487745348}, {
         10.243760790854097`, 2.4036061372404642`}}, 0.05577520655383945], 
        ArrowBox[{{10.239252990416448`, 1.6025284331907343`}, {
         10.243760790854097`, 2.4036061372404642`}}, 0.05577520655383945], 
        ArrowBox[{{10.247258618181037`, 1.6024522683722235`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.255264325586426`, 1.6023849933837324`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.263270102760924`, 1.6023266083082186`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.271275939832758`, 1.6022771132176743`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.283284786153335`, 1.6022195394341843`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.295293711713517`, 1.6021819684113616`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.311305678135435`, 1.6021629892919211`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.327317647219642`, 1.6021795709084188`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.34332953998993, 1.6022317131790684`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.359341277470469`, 1.6023194158466882`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.367347063297334`, 1.6023766022010326`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.375352780686192`, 1.6024426784787007`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.383358419765347`, 1.6025176445982137`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.391363970663193`, 1.6026015004671335`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.399369423508237`, 1.6026942459820583`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.407374768429104`, 1.6027958810286256`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.415379995554556`, 1.6029064054815123`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.423385095013495`, 1.603025819204431}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.431390056934989`, 1.6031541220501353`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.439394871448263`, 1.6032913138604172`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.447399528682736`, 1.6034373944661091`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.455404018768014`, 1.6035923636870812`}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.463408331833909`, 1.603756221332243}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.471412458010457`, 1.603928967199547}, {
         10.354063962397339`, 2.4033835297643407`}}, 0.05577520655383945], 
        ArrowBox[{{10.47941638742793, 1.6041106010759822`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.487420110216808`, 1.604301122737577}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.507428448422733`, 1.6048163093829615`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.527435279318677`, 1.605387039216919}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.539438590204846`, 1.6057561360358497`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.551441269649226`, 1.6061452258033997`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.55944268869966, 1.6064157256446405`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.567443802442584`, 1.6066951104286362`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.575444601011979`, 1.6069833798108828`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.583445074542206`, 1.6072805334359233`}, {
         10.507037450025306`, 2.4062176934444466`}}, 0.05577520655383945], 
        ArrowBox[{{10.591445213168042`, 1.6075865709373414`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.59944500702465, 1.607901491937767}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.607444446247646`, 1.6082252960488788`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.615443520973066`, 1.6085579828713996`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.623442221337406`, 1.6088995519950986`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.631440537477618`, 1.6092500029987944`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.639438459531126`, 1.6096093354503518`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.647435977635848`, 1.6099775489066852`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.65543308193019, 1.610354642913757}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.663429762553074`, 1.6107406170065808`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.671426009643945`, 1.6111354707092191`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.679421813342781`, 1.6115392035347815`}, {
         10.599484647651675`, 2.4097027681859755`}}, 0.05577520655383945], 
        ArrowBox[{{10.687417163790112`, 1.6119518149854386`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.695412051127011`, 1.6123733045524027`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.707403492235336`, 1.6130221842310224`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.71939383589462, 1.6136910366991044`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.731383048838463`, 1.6143798601009607`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.743371097803607`, 1.6150886525254968`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.751362467367361`, 1.615572273741182}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.759353294970936`, 1.6160647686088545`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.767343570760994`, 1.6165661365212296`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.775333284884876`, 1.6170763768600809`}, {
         10.68476775916889, 2.4141039246570273`}}, 0.05577520655383945], 
        ArrowBox[{{10.79131098872696, 1.6181234722895974`}, {
         10.741587314204274`, 2.4176691960492427`}}, 0.05577520655383945], 
        ArrowBox[{{10.799298958743346`, 1.6186603260891097`}, {
         10.741587314204274`, 2.4176691960492427`}}, 0.05577520655383945], 
        ArrowBox[{{10.807286327689969`, 1.6192060497327923`}, {
         10.762886144698651`, 2.4191362842838418`}}, 0.05577520655383945], 
        ArrowBox[{{10.815273085717754`, 1.619760642547722}, {
         10.762886144698651`, 2.4191362842838418`}}, 0.05577520655383945], 
        ArrowBox[{{10.823259222978379`, 1.6203241038500424`}, {
         10.762886144698651`, 2.4191362842838418`}}, 0.05577520655383945], 
        ArrowBox[{{10.831244729624288`, 1.6208964329449573`}, {
         10.762886144698651`, 2.4191362842838418`}}, 0.05577520655383945], 
        ArrowBox[{{10.84322178565095, 1.6217715521516798`}, {
         10.787728437255263`, 2.4209375527261576`}}, 0.05577520655383945], 
        ArrowBox[{{10.855197367409906`, 1.6226666198733328`}, {
         10.787728437255263`, 2.4209375527261576`}}, 0.05577520655383945], 
        ArrowBox[{{11.549064340502412`, 3.342514751635023}, {
         11.383830299065298`, 4.126473856789592}}, 0.05577520655383945], 
        ArrowBox[{{11.555780329284447`, 3.34403829882341}, {
         11.383830299065298`, 4.126473856789592}}, 0.05577520655383945], 
        ArrowBox[{{11.562494441940807`, 3.3455700927369305`}, {
         11.383830299065298`, 4.126473856789592}}, 0.05577520655383945], 
        ArrowBox[{{11.569206668345124`, 3.3471101310653006`}, {
         11.383830299065298`, 4.126473856789592}}, 0.05577520655383945], 
        ArrowBox[{{11.575916998373913`, 3.348658411485813}, {
         11.383830299065298`, 4.126473856789592}}, 0.05577520655383945], 
        ArrowBox[{{11.585978915574827`, 3.3509962809278084`}, {
         11.403959847894459`, 4.131124875238917}}, 0.05577520655383945], 
        ArrowBox[{{11.61109552608046, 5.023065706557577}, {
         11.355465250905299`, 5.78228215399813}}, 0.05577520655383945], 
        ArrowBox[{{11.61637020317856, 5.024878582221272}, {
         11.355465250905299`, 5.78228215399813}}, 0.05577520655383945], 
        ArrowBox[{{11.621642350738174`, 5.026698801101215}, {
         11.355465250905299`, 5.78228215399813}}, 0.05577520655383945], 
        ArrowBox[{{11.647964787828249`, 5.035909919714343}, {
         11.399648799829508`, 5.797864442459353}}, 0.05577520655383945], 
        ArrowBox[{{11.653221543647913`, 5.037774123274495}, {
         11.399648799829508`, 5.797864442459353}}, 0.05577520655383945], 
        ArrowBox[{{11.671599639333822`, 5.044356442797801}, {
         11.399648799829508`, 5.797864442459353}}, 0.05577520655383945], 
        ArrowBox[{{11.692563602446562`, 5.051988665983814}, {
         11.399648799829508`, 5.797864442459353}}, 0.05577520655383945], 
        ArrowBox[{{11.716096825726513`, 5.060714338447621}, {
         11.435246548943661`, 5.810950758979209}}, 0.05577520655383945], 
        ArrowBox[{{11.721318975403141`, 5.062673391641422}, {
         11.441512309149935`, 5.813303803981215}}, 0.05577520655383945], 
        ArrowBox[{{11.726538392040387`, 5.064639714765454}, {
         11.441512309149935`, 5.813303803981215}}, 0.05577520655383945], 
        ArrowBox[{{11.443573267683107`, 6.691807714165314}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.62528343655102, 6.799319805067546}, {9.818269775626112, 
         7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.66954628186046, 6.828910684504702}, {9.818269775626112, 
         7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.675398114949713`, 6.832929996334662}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.685610161157248`, 6.84000532397144}, {9.818269775626112,
          7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.754632396641796`, 6.889931330880305}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.817695983734934`, 6.938931351377337}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.823222168443541`, 6.943387818661774}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.839721398933065`, 6.956854893969313}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.868305547212389`, 6.980772190201956}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.887154097009018`, 6.996962083391309}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.897849220606151`, 7.00630066807081}, {9.818269775626112,
          7.287655869413179}}, 0.05577520655383945], 
        ArrowBox[{{11.913787991873136`, 7.020426612095337}, {
         9.818269775626112, 7.287655869413179}}, 0.05577520655383945], 
        {Hue[1, 1, 0.7], Opacity[1], AbsoluteDashing[{6, 3}], CapForm["Butt"],
          ArrowBox[{{10.310247556049253`, 8.010816537836144}, {
          10.311845441812252`, 8.811896441105564}}, 0.05577520655383945]}, 
        ArrowBox[{{6.5826119417250855`, 1.7220463744304473`}, {
         6.959078598990364, 2.4291688709190034`}}, 0.05577520655383945], 
        ArrowBox[{{6.590487106249128, 1.7179096491499726`}, {
         6.959078598990364, 2.4291688709190034`}}, 0.05577520655383945], 
        ArrowBox[{{7.532578008932136, 1.2986528670799284`}, {
         7.810504752220147, 2.0499772244824914`}}, 0.05577520655383945], 
        ArrowBox[{{7.54927089099639, 1.2924989707433223`}, {7.825528346077976,
          2.0444387177795456`}}, 0.05577520655383945], 
        ArrowBox[{{7.557622446893575, 1.2894359287222175`}, {
         7.8330447463854425`, 2.0416819799605523`}}, 0.05577520655383945], 
        ArrowBox[{{10.240082304444236`, 0.8014029158462961}, {
         10.247258618181037`, 1.6024522683722235`}}, 0.05577520655383945], 
        ArrowBox[{{10.257872842866332`, 0.8012632935529584}, {
         10.263270102760924`, 1.6023266083082186`}}, 0.05577520655383945], 
        ArrowBox[{{10.266768217390592`, 0.801208299007909}, {
         10.271275939832758`, 1.6022771132176743`}}, 0.05577520655383945], 
        ArrowBox[{{10.275663647498732`, 0.8011631822917504}, {
         10.283284786153335`, 1.6022195394341843`}}, 0.05577520655383945], 
        ArrowBox[{{10.28455912222196, 0.8011279434601128}, {
         10.283284786153335`, 1.6022195394341843`}}, 0.05577520655383945], 
        ArrowBox[{{10.306797932237922`, 0.8010830623809895}, {
         10.311305678135435`, 1.6021629892919211`}}, 0.05577520655383945], 
        ArrowBox[{{10.320141247888383`, 0.8010857676651355}, {
         10.311305678135435`, 1.6021629892919211`}}, 0.05577520655383945], 
        ArrowBox[{{10.342380037877293`, 0.8011396663339898}, {
         10.34332953998993, 1.6022317131790684`}}, 0.05577520655383945], 
        ArrowBox[{{10.35572320988462, 0.8012016393062513}, {10.34332953998993,
          1.6022317131790684`}}, 0.05577520655383945], 
        ArrowBox[{{10.515821191474044`, 0.8036787642653884}, {
         10.507428448422733`, 1.6048163093829615`}}, 0.05577520655383945], 
        ArrowBox[{{10.524713724723226`, 0.8039102048389157}, {
         10.507428448422733`, 1.6048163093829615`}}, 0.05577520655383945], 
        ArrowBox[{{10.53360599548853, 0.8041515199096647}, {
         10.507428448422733`, 1.6048163093829615`}}, 0.05577520655383945], 
        ArrowBox[{{10.542497992805066`, 0.8044027091800707}, {
         10.507428448422733`, 1.6048163093829615`}}, 0.05577520655383945], 
        ArrowBox[{{10.560281123233967`, 0.8049347090687444}, {
         10.539438590204846`, 1.6057561360358497`}}, 0.05577520655383945], 
        ArrowBox[{{10.569172234418286`, 0.8052155190310106}, {
         10.539438590204846`, 1.6057561360358497`}}, 0.05577520655383945], 
        ArrowBox[{{10.746913245904347`, 0.8129044751170973}, {
         10.707403492235336`, 1.6130221842310224`}}, 0.05577520655383945], 
        ArrowBox[{{10.75579539206167, 0.8133925242609212}, {
         10.707403492235336`, 1.6130221842310224`}}, 0.05577520655383945], 
        ArrowBox[{{10.773558031145583`, 0.8143982103488572}, {
         10.731383048838463`, 1.6143798601009607`}}, 0.05577520655383945], 
        ArrowBox[{{10.782438502169397`, 0.8149158460528767}, {
         10.731383048838463`, 1.6143798601009607`}}, 0.05577520655383945], 
        ArrowBox[{{10.897827835141644`, 0.8225422055735381}, {
         10.84322178565095, 1.6217715521516798`}}, 0.05577520655383945], 
        ArrowBox[{{10.906699186116015`, 0.8231978306313064}, {
         10.84322178565095, 1.6217715521516798`}}, 0.05577520655383945], 
        ArrowBox[{{11.76416541906283, 2.5699747160287085`}, {
         11.585978915574827`, 3.3509962809278084`}}, 0.05577520655383945], 
        ArrowBox[{{11.771829998398434`, 2.5717630104137656`}, {
         11.585978915574827`, 3.3509962809278084`}}, 0.05577520655383945], 
        ArrowBox[{{11.927801749804555`, 4.285195485833846}, {
         11.671599639333822`, 5.044356442797801}}, 0.05577520655383945], 
        ArrowBox[{{11.9341036021743, 4.287450089458022}, {11.671599639333822`,
          5.044356442797801}}, 0.05577520655383945], 
        ArrowBox[{{11.94040230890467, 4.289713466209024}, {
         11.671599639333822`, 5.044356442797801}}, 0.05577520655383945], 
        ArrowBox[{{11.946697857782164`, 4.291985611698047}, {
         11.671599639333822`, 5.044356442797801}}, 0.05577520655383945], 
        ArrowBox[{{11.952990236599396`, 4.294266521519292}, {
         11.671599639333822`, 5.044356442797801}}, 0.05577520655383945], 
        ArrowBox[{{11.95927943315513, 4.29655619124996}, {11.671599639333822`,
          5.044356442797801}}, 0.05577520655383945], 
        ArrowBox[{{11.965565435254314`, 4.29885461645027}, {
         11.692563602446562`, 5.051988665983814}}, 0.05577520655383945], 
        ArrowBox[{{11.971848230708053`, 4.301161792663454}, {
         11.692563602446562`, 5.051988665983814}}, 0.05577520655383945], 
        ArrowBox[{{11.631895919988395`, 5.89210676209719}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.63620702664248, 5.894059669248225}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.640515244138774`, 5.8960189417989675`}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.644820563078696`, 5.897984575475171}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.649122974069986`, 5.89995656598871}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.65342246772673, 5.901934909037596}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.65771903466938, 5.903919600305979}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.662012665524768`, 5.90591063546416}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.666303350926139`, 5.907908010168601}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.670591081513153`, 5.909911720061934}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.674875847931926`, 5.91192176077297}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.679157640835033`, 5.913938127916712}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.683436450881542`, 5.915960817094357}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.687712268737023`, 5.917989823893313}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.691985085073577`, 5.920025143887206}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.696254890569852`, 5.922066772635887}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.700521675911066`, 5.924114705685446}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.70478543178902, 5.926168938568221}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.70904614890213, 5.928229466802804}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.713303817955438`, 5.930296285894055}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.71755842966064, 5.93236939133311}, {11.443573267683107`,
          6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.721809974736093`, 5.934448778597392}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.726058443906851`, 5.936534443150617}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.730303827904677`, 5.938626380442807}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.734546117468065`, 5.9407245859103055`}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.738785303342256`, 5.942829054975775}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.743021376279268`, 5.944939783048216}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.747254327037902`, 5.9470567655229765`}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.751484146383778`, 5.949179997781757}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.755710825089341`, 5.951309475192625}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.759934353933891`, 5.953445193110025}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.764154723703603`, 5.955587146874787}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.768371925191534`, 5.957735331814137}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.772585949197662`, 5.959889743241707}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.776796786528891`, 5.962050376457546}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.781004427999083`, 5.964217226748129}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.785208864429062`, 5.966390289386371}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.789410086646654`, 5.968569559631631}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.793608085486692`, 5.970755032729729}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.79780285179104, 5.972946703912949}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.80199437640862, 5.975144568400058}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.806182650195417`, 5.977348621396308}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.810367664014517`, 5.979558858093455}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.81454940873611, 5.981775273669761}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.818727875237522`, 5.983997863290011}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.82290305440323, 5.986226622105519}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.82707493712488, 5.988461545254143}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.831243514301315`, 5.990702627860291}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.835408776838584`, 5.992949865034934}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.839570715649966`, 5.995203251875617}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.843729321655998`, 5.997462783466471}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.84788458578448, 5.99972845487822}, {11.443573267683107`,
          6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.852036498970506`, 6.0020002611681935`}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.85618505215648, 6.004278197380337}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.860330236292139`, 6.006562258545227}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.864472042334562`, 6.008852439680074}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.868610461248206`, 6.011148735788738}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.87274548400491, 6.013451141861741}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.876877101583927`, 6.015759652876275}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.881005304971936`, 6.018074263796212}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.885130085163066`, 6.020394969572118}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.889251433158911`, 6.022721765141265}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.893369339968558`, 6.025054645427637}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.897483796608592`, 6.027393605341944}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.901594794103135`, 6.029738639781633}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.905702323483847`, 6.032089743630902}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.90980637578996, 6.034446911760705}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.913906942068287`, 6.036810139028766}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.918004013373247`, 6.039179420279596}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.922097580766886`, 6.041554750344492}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.926187635318891`, 6.04393612404156}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.930274168106614`, 6.04632353617572}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.934357170215089`, 6.048716981538718}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.938436632737051`, 6.05111645490914}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.942512546772962`, 6.053521951052419}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.946584903431019`, 6.055933464720853}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.950653693827183`, 6.05835099065361}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.954718909085194`, 6.0607745235767405`}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.95878054033659, 6.063204058203193}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.962838578720735`, 6.065639589232823}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.966893015384818`, 6.068081111352402}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.970943841483898`, 6.070528619235635}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.9749910481809, 6.072982107543167}, {11.443573267683107`,
          6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.979034626646655`, 6.075441570922595}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.983074568059902`, 6.077907004008484}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.987110863607317`, 6.080378401422374}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.991143504483528`, 6.082855757772795}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.99517248189114, 6.0853390676552745`}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{11.999197787040744`, 6.087828325652356}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{12.003219411150948`, 6.090323526333602}, {
         11.443573267683107`, 6.691807714165314}}, 0.05577520655383945], 
        ArrowBox[{{12.00723734544828, 6.09282466425555}, {11.62528343655102, 
         6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.011251581167638`, 6.095331733961979}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.01526210955167, 6.097844729983532}, {11.62528343655102, 
         6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.019268921851216`, 6.100363646837989}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.025272153523296`, 6.104153111657226}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.031266974873077`, 6.107955867382899}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.035258835505521`, 6.1104984124886155`}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.039246936429674`, 6.113046850822625}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.043231268945298`, 6.115601176825388}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.047211824360389`, 6.118161384924521}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.05118859399117, 6.120727469534809}, {11.62528343655102, 
         6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.055161569162133`, 6.123299425058216}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.05913074120604, 6.125877245883897}, {11.62528343655102, 
         6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.063096101463957`, 6.128460926388216}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.067057641285261`, 6.13105046093475}, {11.62528343655102,
          6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.071015352027663`, 6.133645843874305}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.074969225057231`, 6.1362470695449325`}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.0789192517484, 6.138854132271932}, {11.62528343655102, 
         6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.082865423484002`, 6.141467026367874}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.086807731655274`, 6.144085746132603}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.090746167661882`, 6.146710285853262}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.094680722911942`, 6.149340639804288}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.098611388822036`, 6.151976802247442}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.102538156817227`, 6.15461876743181}, {11.62528343655102,
          6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.106461018331085`, 6.157266529593817}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.1103799648057, 6.159920082957246}, {11.62528343655102, 
         6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.114294987691705`, 6.162579421733243}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.118206078448292`, 6.165244540120334}, {
         11.62528343655102, 6.799319805067546}}, 0.05577520655383945], 
        ArrowBox[{{12.122113228543197`, 6.167915432304416}, {
         11.66954628186046, 6.828910684504702}}, 0.05577520655383945], 
        ArrowBox[{{12.12601642945285, 6.170592092458853}, {
         11.675398114949713`, 6.832929996334662}}, 0.05577520655383945], 
        ArrowBox[{{12.1299156726622, 6.173274514744362}, {11.675398114949713`,
          6.832929996334662}}, 0.05577520655383945], 
        ArrowBox[{{12.133810949664866`, 6.175962693309111}, {
         11.675398114949713`, 6.832929996334662}}, 0.05577520655383945], 
        ArrowBox[{{12.137702251963109`, 6.178656622288709}, {
         11.685610161157248`, 6.84000532397144}}, 0.05577520655383945], 
        ArrowBox[{{12.141589571067875`, 6.181356295806225}, {
         11.685610161157248`, 6.84000532397144}}, 0.05577520655383945], 
        ArrowBox[{{12.145472898498792`, 6.184061707972193}, {
         11.685610161157248`, 6.84000532397144}}, 0.05577520655383945], 
        ArrowBox[{{12.149352225784193`, 6.186772852884625}, {
         11.685610161157248`, 6.84000532397144}}, 0.05577520655383945], 
        ArrowBox[{{12.16675947006063, 6.199043788852808}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.184084771314383`, 6.211430150679499}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.187923633132103`, 6.214198295702421}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.2032380692523, 6.225327485240996}, {11.754632396641796`,
          6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.218486486944812`, 6.2365469581047215`}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.222288213565733`, 6.23936588726723}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.226085772464877`, 6.242190428527506}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.229879155357686`, 6.245020575723679}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.233668353968717`, 6.247856322681647}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.237453360031651`, 6.250697663215094}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.24123416528932, 6.2535445911255}, {11.754632396641796`, 
         6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.245010761493717`, 6.256397100202157}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.248783140406015`, 6.259255184222178}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.252551293796593`, 6.262118836950522}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.256315213445042`, 6.264988052139991}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.260074891140196`, 6.267862823531255}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.265706436081338`, 6.27218538477441}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.271328390533093`, 6.276520412140793}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.275071018488706`, 6.279417345503728}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.278809363574346`, 6.282319803590272}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.28254341763463, 6.2852277800685705`}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.286273172523542`, 6.288141268594737}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.289998620104445`, 6.291060262812856}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.293719752250096`, 6.2939847563550035`}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.297436560842671`, 6.296914742841256}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.301149037773772`, 6.299850215879712}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.304857174944457`, 6.302791169066495}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.308560964265249`, 6.305737595985776}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.312260397656152`, 6.308689490209785}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.315955467046678`, 6.311646845298824}, {
         11.754632396641796`, 6.889931330880305}}, 0.05577520655383945], 
        ArrowBox[{{12.323332481592228`, 6.317577912253629}, {
         11.823222168443541`, 6.943387818661774}}, 0.05577520655383945], 
        ArrowBox[{{12.327014410653973`, 6.3205516111805125`}, {
         11.823222168443541`, 6.943387818661774}}, 0.05577520655383945], 
        ArrowBox[{{12.330691943528759`, 6.323530745094644}, {
         11.823222168443541`, 6.943387818661774}}, 0.05577520655383945], 
        ArrowBox[{{12.334365072193872`, 6.326515307496901}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.33803378863621, 6.3295052918763215`}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.341698084852293`, 6.33250069171011}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.345357952848286`, 6.335501500463661}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.349013384640008`, 6.338507711590566}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.352664372252963`, 6.341519318532632}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.356310907722351`, 6.344536314719897}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.359952983093077`, 6.347558693570639}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.363590590419783`, 6.350586448491397}, {
         11.839721398933065`, 6.956854893969313}}, 0.05577520655383945], 
        ArrowBox[{{12.367223721766845`, 6.353619572876968}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.370852369208428`, 6.356658060110464}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.374476524828466`, 6.359701903563273}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.378096180720686`, 6.362751096595108}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.381711328988636`, 6.365805632554006}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.385321961745698`, 6.368865504776354}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.388928071115105`, 6.371930706586893}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.39252964922996, 6.375001231298741}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.396126688233245`, 6.378077072213403}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.399719180277852`, 6.381158222620783}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.403307117526587`, 6.384244675799207}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.406890492152195`, 6.387336425015429}, {
         11.868305547212389`, 6.980772190201956}}, 0.05577520655383945], 
        ArrowBox[{{12.410469296337363`, 6.390433463524644}, {
         11.887154097009018`, 6.996962083391309}}, 0.05577520655383945], 
        ArrowBox[{{12.414043522274778`, 6.393535784570529}, {
         11.887154097009018`, 6.996962083391309}}, 0.05577520655383945], 
        ArrowBox[{{12.41761316216709, 6.396643381385221}, {
         11.897849220606151`, 7.00630066807081}}, 0.05577520655383945], 
        ArrowBox[{{12.421178208226959`, 6.3997562471893445`}, {
         11.897849220606151`, 7.00630066807081}}, 0.05577520655383945], 
        ArrowBox[{{12.424738652677064`, 6.402874375192037}, {
         11.897849220606151`, 7.00630066807081}}, 0.05577520655383945], 
        ArrowBox[{{12.42829448775013, 6.405997758590953}, {
         11.897849220606151`, 7.00630066807081}}, 0.05577520655383945], 
        ArrowBox[{{12.43184570568893, 6.409126390572283}, {
         11.897849220606151`, 7.00630066807081}}, 0.05577520655383945], 
        ArrowBox[{{12.435392298746317`, 6.412260264310768}, {
         11.897849220606151`, 7.00630066807081}}, 0.05577520655383945], 
        ArrowBox[{{12.43893425918522, 6.415399372969707}, {
         11.913787991873136`, 7.020426612095337}}, 0.05577520655383945], 
        ArrowBox[{{12.442471579278696`, 6.4185437097009945`}, {
         11.913787991873136`, 7.020426612095337}}, 0.05577520655383945], 
        ArrowBox[{{12.446004251309912`, 6.42169326764511}, {
         11.913787991873136`, 7.020426612095337}}, 0.05577520655383945], 
        ArrowBox[{{12.44953226757217, 6.42484803993114}, {11.913787991873136`,
          7.020426612095337}}, 0.05577520655383945], 
        ArrowBox[{{12.453055620368938`, 6.428008019676798}, {
         11.913787991873136`, 7.020426612095337}}, 0.05577520655383945], 
        ArrowBox[{{12.456574302013854`, 6.4311731999884385`}, {
         11.913787991873136`, 7.020426612095337}}, 0.05577520655383945], 
        ArrowBox[{{11.248394871012838`, 10.111820063980492`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{11.015623292365223`, 10.251209817585913`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.762669375699103`, 10.349324175758158`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.750388561725986`, 10.352872167916518`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.738079830761656`, 10.356322063892607`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.541150987991285`, 10.397565140782692`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.340605859777177`, 10.413801275046302`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.334215130464145`, 10.413903262462401`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.327824045144569`, 10.41397975444472}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[{{10.321432705530553`, 10.414030749775913`}, {
         10.310247556049253`, 8.010816537836144}}, 0.05577520655383945], 
        ArrowBox[BezierCurveBox[{{10.311845441812252`, 8.811896441105564}, {
         10.454806368491553`, 9.027173304050333}, {10.637248945722204`, 
         9.045103707207234}, {10.743240337540403`, 8.980899903380076}, {
         10.742562697002866`, 8.641173354201248}, {10.636316019498041`, 
         8.577392894147868}, {10.453946424023451`, 8.59605097524872}, {
         10.311845441812252`, 8.811896441105564}},
         SplineDegree->7], 0.05577520655383945], 
        ArrowBox[{{7.2730134359148035`, 0.5405592237070991}, {
         7.54927089099639, 1.2924989707433223`}}, 0.05577520655383945], 
        ArrowBox[{{7.282200147401706, 0.5371898774838826}, {7.557622446893575,
          1.2894359287222175`}}, 0.05577520655383945], 
        ArrowBox[{{10.272045468067379`, 0.00008985641036751701}, {
         10.275663647498732`, 0.8011631822917504}}, 0.05577520655383945], 
        ArrowBox[{{10.301400633620878`, 6.165462684393219*^-6}, {
         10.306797932237922`, 0.8010830623809895}}, 0.05577520655383945], 
        ArrowBox[{{10.311185730651697`, 0.}, {10.306797932237922`, 
         0.8010830623809895}}, 0.05577520655383945], 
        ArrowBox[{{10.340540978361757`, 0.00004669827802139537}, {
         10.342380037877293`, 0.8011396663339898}}, 0.05577520655383945], 
        ArrowBox[{{10.350326006251636`, 0.00008399586206842002}, {
         10.342380037877293`, 0.8011396663339898}}, 0.05577520655383945], 
        ArrowBox[{{10.546000553014322`, 0.003111581212250414}, {
         10.524713724723226`, 0.8039102048389157}}, 0.05577520655383945], 
        ArrowBox[{{10.819729290078916`, 0.014648387273187069`}, {
         10.773558031145583`, 0.8143982103488572}}, 0.05577520655383945], 
        ArrowBox[{{12.451128651203469`, 5.425636488511375}, {
         12.025272153523296`, 6.104153111657226}}, 0.05577520655383945], 
        ArrowBox[{{12.456127843597901`, 5.428799916038809}, {
         12.025272153523296`, 6.104153111657226}}, 0.05577520655383945], 
        ArrowBox[{{12.625661449587522`, 5.542409539665323}, {
         12.16675947006063, 6.199043788852808}}, 0.05577520655383945], 
        ArrowBox[{{12.642532143203267`, 5.554414496952157}, {
         12.16675947006063, 6.199043788852808}}, 0.05577520655383945], 
        ArrowBox[{{12.64734092094383, 5.557860488095464}, {12.16675947006063, 
         6.199043788852808}}, 0.05577520655383945], 
        ArrowBox[{{12.676086226112313`, 5.578685246274855}, {12.2032380692523,
          6.225327485240996}}, 0.05577520655383945], 
        ArrowBox[{{12.75417168464861, 5.637257620691621}, {
         12.265706436081338`, 6.27218538477441}}, 0.05577520655383945], 
        ArrowBox[{{11.384704096015495`, 10.962375083187531`}, {
         11.015623292365223`, 10.251209817585913`}}, 0.05577520655383945], 
        ArrowBox[{{11.024793470173625`, 11.106953998293427`}, {
         11.015623292365223`, 10.251209817585913`}}, 0.05577520655383945], 
        ArrowBox[{{11.01563209308238, 11.109779908873996`}, {
         11.015623292365223`, 10.251209817585913`}}, 0.05577520655383945], 
        ArrowBox[{{11.006459515448341`, 11.112569249363222`}, {
         11.015623292365223`, 10.251209817585913`}}, 0.05577520655383945], 
        ArrowBox[{{10.997275883250184`, 11.11532197536963}, {
         11.015623292365223`, 10.251209817585913`}}, 0.05577520655383945], 
        ArrowBox[{{10.978876039953585`, 11.120717409282333`}, {
         10.750388561725986`, 10.352872167916518`}}, 0.05577520655383945], 
        ArrowBox[{{10.965048227531664`, 11.12466755011698}, {
         10.750388561725986`, 10.352872167916518`}}, 0.05577520655383945], 
        ArrowBox[{{10.937322929051268`, 11.132319246308672`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.904863798344232`, 11.140826090271808`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.816195977694846`, 11.161622939850563`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.745677083096643`, 11.175659159520842`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.636815775871263`, 11.193068077911922`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.450784082119943`, 11.211121344314712`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.364571476159705`, 11.214562470176498`}, {
         10.541150987991285`, 10.397565140782692`}}, 0.05577520655383945], 
        ArrowBox[{{10.313443327575252`, 9.612976344374983}, {
         10.311845441812252`, 8.811896441105564}}, 0.05577520655383945], 
        ArrowBox[{{13.073918595785582`, 4.878286366390758}, {
         12.625661449587522`, 5.542409539665323}}, 0.05577520655383945], 
        ArrowBox[{{13.07972554820704, 4.882370255364849}, {
         12.625661449587522`, 5.542409539665323}}, 0.05577520655383945], 
        ArrowBox[{{13.085526462366392`, 4.886462716787225}, {
         12.625661449587522`, 5.542409539665323}}, 0.05577520655383945], 
        ArrowBox[{{13.091321325608664`, 4.890563741729986}, {
         12.625661449587522`, 5.542409539665323}}, 0.05577520655383945], 
        ArrowBox[{{13.097110125292089`, 4.894673321246553}, {
         12.625661449587522`, 5.542409539665323}}, 0.05577520655383945], 
        ArrowBox[{{13.102892848788123`, 4.89879144637168}, {
         12.625661449587522`, 5.542409539665323}}, 0.05577520655383945], 
        ArrowBox[{{13.131714882387886`, 4.91950994103833}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.137460884304433`, 4.923679150502103}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.143200722006483`, 4.927856842296839}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.148934382972321`, 4.93204300730871}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.154661854693678`, 4.936237636405391}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.160383124675818`, 4.940440720436108}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.166098180437503`, 4.944652250231622}, {
         12.676086226112313`, 5.578685246274855}}, 0.05577520655383945], 
        ArrowBox[{{13.239822757114078`, 5.000166496726514}, {
         12.75417168464861, 5.637257620691621}}, 0.05577520655383945], 
        ArrowBox[{{13.245449510902205`, 5.004495294179112}, {
         12.75417168464861, 5.637257620691621}}, 0.05577520655383945], 
        ArrowBox[{{12.17455778980893, 11.419195377399136`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.164141634924349`, 11.426605573601819`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.153696001329495`, 11.433974157532539`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.143221055263346`, 11.441301011922599`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.132716963431358`, 11.448586020167424`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.122183893002852`, 11.455829066328398`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.111622011608317`, 11.463030035134729`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.101031487336774`, 11.470188811985263`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.090412488733072`, 11.477305282950326`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.079765184795239`, 11.484379334773521`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.06908974497175, 11.491410854873546`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.058386339158876`, 11.498399731345971`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{12.04765513769794, 11.505345852965032`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.966302450556613`, 11.556067908196049`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.883468800324396`, 11.604333558312664`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.872316387504341`, 11.610581036094382`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.861139140280883`, 11.616783973692616`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.849937236536382`, 11.62294227238957}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.838710854545614`, 11.629055834177858`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.827460172972902`, 11.635124561762078`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.81618537086931, 11.641148358560333`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.804886627669749`, 11.647127128705804`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.793564123190166`, 11.653060777048239`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.782218037624643`, 11.658949209155502`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.770848551542567`, 11.664792331315045`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.759455845885718`, 11.670590050535427`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.748040101965424`, 11.676342274547768`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.736601501459644`, 11.682048911807238`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.725140226410112`, 11.6877098714945}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.713656459219395`, 11.693325063517168`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.702150382648044`, 11.698894398511227`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.69062217981163, 11.70441778784247}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.679072034177878`, 11.70989514360789}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.667500129563708`, 11.715326378637101`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.655906650132344`, 11.720711406493706`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.644291780390349`, 11.726050141476687`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.632655705184725`, 11.731342498621753`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.620998609699933`, 11.736588393702714`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.609320679454985`, 11.741787743232798`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.59762210030045, 11.746940464465998`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.585903058415541`, 11.752046475398377`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.562404332796696`, 11.762118042063133`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.53882599849176, 11.772001802086374`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.527007446936997`, 11.776873057518937`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.515169556461807`, 11.781697126282896`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.503312515462497`, 11.78647393160471}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.491436512640128`, 11.791203397463036`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.479541736997552`, 11.79588544858991}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.467628377836366`, 11.800520010471963`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.455696624753939`, 11.805107009351605`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.443746667640347`, 11.809646372228194`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.431778696675408`, 11.8141380268592}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.419792902325597`, 11.818581901761354`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.353560978544593`, 11.842166028965254`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.28682757233808, 11.864291382742737`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.274642853958165`, 11.868156603091453`}, {
         11.384704096015495`, 10.962375083187531`}}, 0.05577520655383945], 
        ArrowBox[{{11.188931681639719`, 11.893847894727474`}, {
         10.965048227531664`, 11.12466755011698}}, 0.05577520655383945], 
        ArrowBox[{{11.17662983206093, 11.897322342494075`}, {
         10.965048227531664`, 11.12466755011698}}, 0.05577520655383945], 
        ArrowBox[{{11.151985040589198`, 11.904123872770931`}, {
         10.937322929051268`, 11.132319246308672`}}, 0.05577520655383945], 
        ArrowBox[{{11.13964249091034, 11.907450847036976`}, {
         10.937322929051268`, 11.132319246308672`}}, 0.05577520655383945], 
        ArrowBox[{{11.12728676710228, 11.910728556530039`}, {
         10.904863798344232`, 11.140826090271808`}}, 0.05577520655383945], 
        ArrowBox[{{11.114918065802474`, 11.913956949086405`}, {
         10.904863798344232`, 11.140826090271808`}}, 0.05577520655383945], 
        ArrowBox[{{11.102536583854892`, 11.917135973327223`}, {
         10.904863798344232`, 11.140826090271808`}}, 0.05577520655383945], 
        ArrowBox[{{11.090142518306932`, 11.920265578659325`}, {
         10.904863798344232`, 11.140826090271808`}}, 0.05577520655383945], 
        ArrowBox[{{11.07773606640623, 11.923345715276032`}, {
         10.904863798344232`, 11.140826090271808`}}, 0.05577520655383945], 
        ArrowBox[{{11.065317425597565`, 11.926376334157936`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{11.05288679351969, 11.929357387073692`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{11.040444368002207`, 11.932288826580782`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{11.027990347062385`, 11.935170606026276`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{11.015524928902053`, 11.938002679547552`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{11.003048311904402`, 11.940785002073062`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.990560694630874`, 11.943517529323014`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.97806227581795, 11.946200217810098`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.965553254374038`, 11.948833024840175`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.953033829376263`, 11.95141590851295}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.94050420006734, 11.95394882772264}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.927964565852358`, 11.956431742158635`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.91541512629566, 11.958864612306138`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.902856081117607`, 11.961247399446783`}, {
         10.816195977694846`, 11.161622939850563`}}, 0.05577520655383945], 
        ArrowBox[{{10.877709973540123`, 11.96586257381994}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.865123311333086`, 11.968094887603403`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.852527843883085`, 11.970276971483086`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.839923771643027`, 11.972408790731812`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.827311295202737`, 11.974490311422349`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.814690615285816`, 11.976521500427951`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.802061932746396`, 11.978502325422888`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.789425448565993`, 11.98043275488295}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.776781363850258`, 11.982312758085962`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.764129879825829`, 11.984142305112266`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.73880551934294, 11.987649914971549`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.713453979227781`, 11.990955361171665`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.700768521068538`, 11.992532206640293`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.688076873321029`, 11.99405843329291}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.67537923796884, 11.995534016840098`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.662675817090829`, 11.996958933798412`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.649966812857944`, 11.998333161490745`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.637252427529972`, 11.999656678046698`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.624532863452364`, 12.00092946240292}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.611808323052959`, 12.002151494303451`}, {
         10.636815775871263`, 11.193068077911922`}}, 0.05577520655383945], 
        ArrowBox[{{10.599079008838798`, 12.00332275430004}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.58634512339294, 12.00444322375245}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.57360686937115, 12.005512884828763`}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.541743452344061`, 12.007964641149236`}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.5098571682612, 12.010098497068507`}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.497096962222512`, 12.01086297871776}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.477951188726516`, 12.011914240340271`}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.458799467318977`, 12.012850915784055`}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.426868576769117`, 12.014157316331312`}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.39492624531798, 12.01514520051619}, {
         10.450784082119943`, 11.211121344314712`}}, 0.05577520655383945], 
        ArrowBox[{{10.315041213338251`, 10.414056247644403`}, {
         10.313443327575252`, 9.612976344374983}}, 0.05577520655383945], 
        ArrowBox[{{12.468159028762738`, 12.187337276205346`}, {
         11.966302450556613`, 11.556067908196049`}}, 0.05577520655383945], 
        ArrowBox[{{12.420820326295818`, 12.217115090934664`}, {
         11.966302450556613`, 11.556067908196049`}}, 0.05577520655383945], 
        ArrowBox[{{12.331821844316398`, 12.270651195327494`}, {
         11.966302450556613`, 11.556067908196049`}}, 0.05577520655383945], 
        ArrowBox[{{11.889743314928316`, 12.49340800818534}, {
         11.562404332796696`, 11.762118042063133`}}, 0.05577520655383945], 
        ArrowBox[{{11.87504405554281, 12.499673442302523`}, {
         11.562404332796696`, 11.762118042063133`}}, 0.05577520655383945], 
        ArrowBox[{{11.860319918343913`, 12.50588018661073}, {
         11.562404332796696`, 11.762118042063133`}}, 0.05577520655383945], 
        ArrowBox[{{11.621542721817173`, 12.597128554368117`}, {
         11.353560978544593`, 11.842166028965254`}}, 0.05577520655383945], 
        ArrowBox[{{11.54578460727768, 12.622497870336503`}, {
         11.353560978544593`, 11.842166028965254`}}, 0.05577520655383945], 
        ArrowBox[{{11.207026573374918`, 12.715989147256453`}, {
         11.027990347062385`, 11.935170606026276`}}, 0.05577520655383945], 
        ArrowBox[{{11.09766888963111, 12.739461924376908`}, {
         10.94050420006734, 11.95394882772264}}, 0.05577520655383945], 
        ArrowBox[{{10.89301534435976, 12.774916837331062`}, {
         10.776781363850258`, 11.982312758085962`}}, 0.05577520655383945], 
        ArrowBox[{{10.86137763684328, 12.779427598280106`}, {
         10.73880551934294, 11.987649914971549`}}, 0.05577520655383945], 
        ArrowBox[{{10.845545538725613`, 12.781588283438044`}, {
         10.73880551934294, 11.987649914971549`}}, 0.05577520655383945], 
        ArrowBox[{{10.829704946939064`, 12.783685792201137`}, {
         10.73880551934294, 11.987649914971549`}}, 0.05577520655383945], 
        ArrowBox[{{10.782134731198223`, 12.789598931339746`}, {
         10.688076873321029`, 11.99405843329291}}, 0.05577520655383945], 
        ArrowBox[{{10.734497155619367`, 12.794942341587038`}, {
         10.649966812857944`, 11.998333161490745`}}, 0.05577520655383945], 
        ArrowBox[{{10.70270471886239, 12.79818771772726}, {
         10.624532863452364`, 12.00092946240292}}, 0.05577520655383945], 
        ArrowBox[{{10.623119201420327`, 12.805190540355685`}, {
         10.541743452344061`, 12.007964641149236`}}, 0.05577520655383945], 
        ArrowBox[{{10.607186222755981`, 12.806400532934477`}, {
         10.541743452344061`, 12.007964641149236`}}, 0.05577520655383945], 
        ArrowBox[{{10.591248543836162`, 12.807546954239289`}, {
         10.541743452344061`, 12.007964641149236`}}, 0.05577520655383945], 
        ArrowBox[{{10.575306418304011`, 12.808629786025186`}, {
         10.541743452344061`, 12.007964641149236`}}, 0.05577520655383945], 
        ArrowBox[{{10.527455899502238`, 12.811496577001789`}, {
         10.477951188726516`, 12.011914240340271`}}, 0.05577520655383945], 
        ArrowBox[{{10.511498525306905`, 12.81232488850685}, {
         10.477951188726516`, 12.011914240340271`}}, 0.05577520655383945], 
        ArrowBox[{{10.479574498675644`, 12.813790502673173`}, {
         10.426868576769117`, 12.014157316331312`}}, 0.05577520655383945], 
        ArrowBox[{{10.463608354300543`, 12.814427782009648`}, {
         10.426868576769117`, 12.014157316331312`}}, 0.05577520655383945], 
        ArrowBox[{{10.447639794666507`, 12.815001362321004`}, {
         10.426868576769117`, 12.014157316331312`}}, 0.05577520655383945], 
        ArrowBox[{{10.431669073908132`, 12.815511234478889`}, {
         10.426868576769117`, 12.014157316331312`}}, 0.05577520655383945], 
        ArrowBox[{{12.883242326203321`, 12.872715864663068`}, {
         12.420820326295818`, 12.217115090934664`}}, 0.05577520655383945], 
        ArrowBox[{{12.867021983282626`, 12.88294165943924}, {
         12.420820326295818`, 12.217115090934664`}}, 0.05577520655383945], 
        ArrowBox[{{12.850760975532388`, 12.893102664813522`}, {
         12.420820326295818`, 12.217115090934664`}}, 0.05577520655383945], 
        ArrowBox[{{12.834459561741427`, 12.903198719076716`}, {
         12.420820326295818`, 12.217115090934664`}}, 0.05577520655383945], 
        ArrowBox[{{12.818118001341606`, 12.913229661553299`}, {
         12.420820326295818`, 12.217115090934664`}}, 0.05577520655383945], 
        ArrowBox[{{12.801736554403707`, 12.923195332603976`}, {
         12.420820326295818`, 12.217115090934664`}}, 0.05577520655383945], 
        ArrowBox[{{12.785315481633312`, 12.933095573628233`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{12.768855044366594`, 12.942930227066864`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{12.752355504566246`, 12.952699136404446`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{12.73581712481723, 12.962402146171875`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{12.719240168322663`, 12.972039101948802`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{12.70262489889957, 12.981609850366116`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{12.685971580974742`, 12.991114239108366`}, {
         12.331821844316398`, 12.270651195327494`}}, 0.05577520655383945], 
        ArrowBox[{{11.955761492105465`, 13.328518668764897`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.937730189222702`, 13.33504082482095}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.919673010896496`, 13.341490996459347`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.901590244501135`, 13.347869081027643`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.883482177818165`, 13.354174977020625`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.865349099031747`, 13.360408584081952`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.847191296724128`, 13.366569803005724`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.829009059870998`, 13.372658535738093`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945], 
        ArrowBox[{{11.810802677836943`, 13.378674685378787`}, {
         11.621542721817173`, 12.597128554368117`}}, 0.05577520655383945]}, 
       {GrayLevel[0.85], EdgeForm[GrayLevel[0]], 
        DiskBox[{1.5908215039309024`, 4.768001439242577}, 
         0.05577520655383945], 
        DiskBox[{0.8326952071195937, 4.499316557109851}, 0.05577520655383945],
         DiskBox[{0.8374899200231045, 4.488793172102863}, 
         0.05577520655383945], 
        DiskBox[{0.842296315576224, 4.478275117833211}, 0.05577520655383945], 
        DiskBox[{0.8471143878522742, 4.46776240727051}, 0.05577520655383945], 
        DiskBox[{0.8519441309101854, 4.457255053377786}, 0.05577520655383945],
         DiskBox[{0.8567855387944903, 4.446753069111458}, 
         0.05577520655383945], 
        DiskBox[{0.8616386055353367, 4.436256467421327}, 0.05577520655383945],
         DiskBox[{0.8665033251485017, 4.425765261250555}, 
         0.05577520655383945], 
        DiskBox[{0.8713796916353935, 4.415279463535648}, 0.05577520655383945],
         DiskBox[{0.8762676989830513, 4.404799087206451}, 
         0.05577520655383945], 
        DiskBox[{0.8811673411641685, 4.394324145186115}, 0.05577520655383945],
         DiskBox[{0.8860786121370907, 4.383854650391094}, 
         0.05577520655383945], 
        DiskBox[{0.891001505845816, 4.373390615731129}, 0.05577520655383945], 
        DiskBox[{0.8959360162200216, 4.362932054109221}, 0.05577520655383945],
         DiskBox[{2.6415760632745204`, 4.474098960280289}, 
         0.05577520655383945], 
        DiskBox[{1.6248023913779175`, 4.695511090935768}, 
         0.05577520655383945], 
        DiskBox[{1.6454802941820628`, 4.652153607812534}, 
         0.05577520655383945], 
        DiskBox[{1.6663745947786062`, 4.608899992822111}, 
         0.05577520655383945], 
        DiskBox[{1.6757302753595749`, 4.589709786899239}, 
         0.05577520655383945], 
        DiskBox[{1.6851285520521753`, 4.570540406165772}, 
         0.05577520655383945], 
        DiskBox[{1.689843649462496, 4.560963554795836}, 0.05577520655383945], 
        DiskBox[{1.7569686649311578`, 4.427443380167117}, 
         0.05577520655383945], 
        DiskBox[{1.8336966385847777`, 4.280854818970042}, 
         0.05577520655383945], 
        DiskBox[{1.8463079386406065`, 4.257336078832784}, 
         0.05577520655383945], 
        DiskBox[{2.048700462318285, 3.8996891613732023`}, 
         0.05577520655383945], 
        DiskBox[{2.2661935233248975`, 3.5510190886354707`}, 
         0.05577520655383945], 
        DiskBox[{2.2720403814901466`, 3.5420881046277524`}, 
         0.05577520655383945], 
        DiskBox[{2.2778971533878103`, 3.5331636187215825`}, 
         0.05577520655383945], 
        DiskBox[{2.283763831796012, 3.5242456419215786`}, 
         0.05577520655383945], 
        DiskBox[{2.289640409480663, 3.5153341852243303`}, 
         0.05577520655383945], 
        DiskBox[{2.2955268791954655`, 3.506429259618386}, 
         0.05577520655383945], 
        DiskBox[{2.3014232336819234`, 3.4975308760842427`}, 
         0.05577520655383945], 
        DiskBox[{2.3073294656693513`, 3.48863904559433}, 0.05577520655383945],
         DiskBox[{2.3132455678748904`, 3.4797537791129978`}, 
         0.05577520655383945], 
        DiskBox[{2.3191715330035008`, 3.4708750875964984`}, 
         0.05577520655383945], 
        DiskBox[{2.325107353747991, 3.462002981992981}, 0.05577520655383945], 
        DiskBox[{2.3310530227890096`, 3.4531374732424736`}, 
         0.05577520655383945], 
        DiskBox[{2.337008532795063, 3.4442785722768647`}, 
         0.05577520655383945], 
        DiskBox[{2.342973876422528, 3.435426290019901}, 0.05577520655383945], 
        DiskBox[{2.3489490463156475`, 3.4265806373871657`}, 
         0.05577520655383945], 
        DiskBox[{2.3549340351065533`, 3.417741625286065}, 
         0.05577520655383945], 
        DiskBox[{2.360928835415269, 3.4089092646158186`}, 
         0.05577520655383945], 
        DiskBox[{2.366933439849717, 3.400083566267446}, 0.05577520655383945], 
        DiskBox[{2.3729478410057334`, 3.391264541123748}, 
         0.05577520655383945], 
        DiskBox[{2.3789720314670753`, 3.3824522000592996`}, 
         0.05577520655383945], 
        DiskBox[{2.3850060038054233`, 3.373646553940433}, 
         0.05577520655383945], 
        DiskBox[{2.391049750580402, 3.3648476136252254`}, 
         0.05577520655383945], 
        DiskBox[{3.7111823657857173`, 4.2726890848719385`}, 
         0.05577520655383945], 
        DiskBox[{0.9058398626119466, 4.342031401557828}, 0.05577520655383945],
         DiskBox[{0.910809186417417, 4.331589336400553}, 0.05577520655383945],
         DiskBox[{0.9157901024638875, 4.321152795825706}, 
         0.05577520655383945], 
        DiskBox[{0.9207826046094834, 4.310721792702392}, 0.05577520655383945],
         DiskBox[{0.9257866866980429, 4.300296339892881}, 
         0.05577520655383945], 
        DiskBox[{0.9308023425591312, 4.289876450252606}, 0.05577520655383945],
         DiskBox[{0.9358295660080369, 4.279462136630136}, 
         0.05577520655383945], 
        DiskBox[{0.9408683508457809, 4.269053411867164}, 0.05577520655383945],
         DiskBox[{0.9509805798206212, 4.248252780252016}, 
         0.05577520655383945], 
        DiskBox[{0.9560540114885185, 4.237860899048712}, 0.05577520655383945],
         DiskBox[{0.9611389796068703, 4.227474658002611}, 
         0.05577520655383945], 
        DiskBox[{0.9764630398918062, 4.196349903843438}, 0.05577520655383945],
         DiskBox[{0.9815940909680645, 4.185986351427147}, 
         0.05577520655383945], 
        DiskBox[{0.9867366470017895, 4.175628503133588}, 0.05577520655383945],
         DiskBox[{0.9918907016517906, 4.165276371734828}, 
         0.05577520655383945], 
        DiskBox[{0.9970562485626999, 4.1549299699958855`}, 
         0.05577520655383945], 
        DiskBox[{1.0022332813649797`, 4.144589310674716}, 
         0.05577520655383945], 
        DiskBox[{1.0074217936749275`, 4.13425440652219}, 0.05577520655383945],
         DiskBox[{1.0126217790946868`, 4.123925270282084}, 
         0.05577520655383945], 
        DiskBox[{1.0178332312122542`, 4.11360191469106}, 0.05577520655383945],
         DiskBox[{1.0230561436014831`, 4.103284352478657}, 
         0.05577520655383945], 
        DiskBox[{1.0282905098221011`, 4.0929725963672645`}, 
         0.05577520655383945], 
        DiskBox[{1.0335363234197086`, 4.082666659072116}, 
         0.05577520655383945], 
        DiskBox[{1.0387935779257909`, 4.072366553301268}, 
         0.05577520655383945], 
        DiskBox[{1.044062266857729, 4.062072291755587}, 0.05577520655383945], 
        DiskBox[{1.0493423837188, 4.051783887128735}, 0.05577520655383945], 
        DiskBox[{1.0546339219981906`, 4.041501352107151}, 
         0.05577520655383945], 
        DiskBox[{1.0599368751710045`, 4.031224699370031}, 
         0.05577520655383945], 
        DiskBox[{1.0652512366982698`, 4.020953941589327}, 
         0.05577520655383945], 
        DiskBox[{1.0705770000269492`, 4.010689091429715}, 
         0.05577520655383945], 
        DiskBox[{1.075914158589942, 4.000430161548588}, 0.05577520655383945], 
        DiskBox[{1.0812627058061004`, 3.9901771645960418`}, 
         0.05577520655383945], 
        DiskBox[{1.086622635080225, 3.979930113214853}, 0.05577520655383945], 
        DiskBox[{1.091993939803098, 3.9696890200404678`}, 
         0.05577520655383945], 
        DiskBox[{1.0973766133514573`, 3.9594538977009854`}, 
         0.05577520655383945], 
        DiskBox[{1.102770649088031, 3.9492247588171425`}, 
         0.05577520655383945], 
        DiskBox[{1.1081760403615366`, 3.9390016160022983`}, 
         0.05577520655383945], 
        DiskBox[{1.1135927805066874`, 3.928784481862418}, 
         0.05577520655383945], 
        DiskBox[{1.1190208628442093`, 3.9185733689960403`}, 
         0.05577520655383945], 
        DiskBox[{1.1244602806808217`, 3.908368289994331}, 
         0.05577520655383945], 
        DiskBox[{1.1299110273092872`, 3.898169257440963}, 
         0.05577520655383945], 
        DiskBox[{1.1353730960083954`, 3.887976283912172}, 
         0.05577520655383945], 
        DiskBox[{1.1463311726638832`, 3.867608564195888}, 
         0.05577520655383945], 
        DiskBox[{1.1739240273684644`, 3.8167961767296807`}, 
         0.05577520655383945], 
        DiskBox[{1.2017985763542978`, 3.766137772988543}, 
         0.05577520655383945], 
        DiskBox[{1.2074072140004564`, 3.756024707796107}, 
         0.05577520655383945], 
        DiskBox[{1.2130270781581665`, 3.7459178769040182`}, 
         0.05577520655383945], 
        DiskBox[{1.2412945535947344`, 3.6954776728678853`}, 
         0.05577520655383945], 
        DiskBox[{1.2698416464844584`, 3.645195192436727}, 
         0.05577520655383945], 
        DiskBox[{1.287103752865292, 3.6151020565352905`}, 
         0.05577520655383945], 
        DiskBox[{1.3044660133170183`, 3.5850665932112173`}, 
         0.05577520655383945], 
        DiskBox[{1.321928235158106, 3.555089135789716}, 0.05577520655383945], 
        DiskBox[{1.3424269087964422`, 3.5201891922764226`}, 
         0.05577520655383945], 
        DiskBox[{1.3571517867376652`, 3.495309568732903}, 
         0.05577520655383945], 
        DiskBox[{1.3957591589674703`, 3.430814781756257}, 
         0.05577520655383945], 
        DiskBox[{1.428789825710071, 3.3764610998514826`}, 
         0.05577520655383945], 
        DiskBox[{1.434831036641942, 3.3666003354638177`}, 
         0.05577520655383945], 
        DiskBox[{1.440883193653324, 3.356746285568371}, 0.05577520655383945], 
        DiskBox[{1.446946289281417, 3.3468989623159846`}, 
         0.05577520655383945], 
        DiskBox[{1.4530203160499333`, 3.3370583778492096`}, 
         0.05577520655383945], 
        DiskBox[{1.459105266469102, 3.3272245443022834`}, 
         0.05577520655383945], 
        DiskBox[{1.4652011330356878`, 3.3173974738011225`}, 
         0.05577520655383945], 
        DiskBox[{1.4713079082329887`, 3.307577178463303}, 
         0.05577520655383945], 
        DiskBox[{1.4774255845308595`, 3.297763670398046}, 
         0.05577520655383945], 
        DiskBox[{1.4835541543857058`, 3.287956961706204}, 
         0.05577520655383945], 
        DiskBox[{1.4896936102405025`, 3.2781570644802436`}, 
         0.05577520655383945], 
        DiskBox[{1.4958439445248057`, 3.268363990804236}, 
         0.05577520655383945], 
        DiskBox[{1.5020051496547495`, 3.258577752753834}, 
         0.05577520655383945], 
        DiskBox[{1.5081772180330724`, 3.2487983623962657`}, 
         0.05577520655383945], 
        DiskBox[{1.5143601420491084`, 3.239025831790311}, 
         0.05577520655383945], 
        DiskBox[{1.520553914078814, 3.2292601729862964`}, 
         0.05577520655383945], 
        DiskBox[{1.5267585264847625`, 3.219501398026071}, 
         0.05577520655383945], 
        DiskBox[{1.5329739716161637`, 3.2097495189429956`}, 
         0.05577520655383945], 
        DiskBox[{1.5392002418088708`, 3.2000045477619308`}, 
         0.05577520655383945], 
        DiskBox[{1.5454373293853862`, 3.1902664964992153`}, 
         0.05577520655383945], 
        DiskBox[{1.5516852266548735`, 3.1805353771626574`}, 
         0.05577520655383945], 
        DiskBox[{1.5579439259131682`, 3.170811201751519}, 
         0.05577520655383945], 
        DiskBox[{1.5642134194427886`, 3.161093982256496}, 
         0.05577520655383945], 
        DiskBox[{1.5704936995129373`, 3.1513837306597106`}, 
         0.05577520655383945], 
        DiskBox[{1.5767847583795174`, 3.1416804589346903`}, 
         0.05577520655383945], 
        DiskBox[{1.5830865882851484`, 3.1319841790463565`}, 
         0.05577520655383945], 
        DiskBox[{1.5893991814591573`, 3.122294902951011}, 
         0.05577520655383945], 
        DiskBox[{3.0789507232536852`, 3.778532425436193}, 
         0.05577520655383945], 
        DiskBox[{3.1211205160450515`, 3.718469857170345}, 
         0.05577520655383945], 
        DiskBox[{3.5383513575950154`, 3.175470515480196}, 
         0.05577520655383945], 
        DiskBox[{3.979451834654216, 2.684065623596669}, 0.05577520655383945], 
        DiskBox[{3.98626033782275, 2.677037647606416}, 0.05577520655383945], 
        DiskBox[{3.993076640951309, 2.6700172363951635`}, 
         0.05577520655383945], 
        DiskBox[{3.9999007356348395`, 2.6630043986196466`}, 
         0.05577520655383945], 
        DiskBox[{4.006732613458677, 2.655999142927265}, 0.05577520655383945], 
        DiskBox[{4.013572265998563, 2.649001477956067}, 0.05577520655383945], 
        DiskBox[{4.020419684820649, 2.6420114123347416`}, 
         0.05577520655383945], 
        DiskBox[{4.027274861481512, 2.635028954682608}, 0.05577520655383945], 
        DiskBox[{4.034137787528164, 2.6280541136096023`}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{4.46577750048209, 4.59244785593508}, 0.05577520655383945]}, 
        DiskBox[{0.4118805106158998, 3.542163901910693}, 0.05577520655383945],
         DiskBox[{0.4472103767462041, 3.4763213355863645`}, 
         0.05577520655383945], 
        DiskBox[{0.4531413038897565, 3.4653705228595166`}, 
         0.05577520655383945], 
        DiskBox[{0.45908438761597026`, 3.454426302833226}, 
         0.05577520655383945], 
        DiskBox[{0.4650396205965368, 3.4434886890026037`}, 
         0.05577520655383945], 
        DiskBox[{0.4710069954881728, 3.4325576948546166`}, 
         0.05577520655383945], 
        DiskBox[{0.47698650493261674`, 3.4216333338680682`}, 
         0.05577520655383945], 
        DiskBox[{0.48297814155665186`, 3.4107156195135824`}, 
         0.05577520655383945], 
        DiskBox[{0.488981897972101, 3.3998045652535858`}, 
         0.05577520655383945], 
        DiskBox[{0.4949977667758496, 3.3889001845422966`}, 
         0.05577520655383945], 
        DiskBox[{0.5070658118610876, 3.367111497541533}, 0.05577520655383945],
         DiskBox[{0.5191822172888667, 3.345349665980149}, 
         0.05577520655383945], 
        DiskBox[{0.5252585364648823, 3.334478854537031}, 0.05577520655383945],
         DiskBox[{0.531346923297157, 3.3236147971945256`}, 
         0.05577520655383945], 
        DiskBox[{0.5374473702782083, 3.3127575073488966`}, 
         0.05577520655383945], 
        DiskBox[{0.5435598698856943, 3.3019069983880645`}, 
         0.05577520655383945], 
        DiskBox[{0.5496844145824085, 3.291063283691586}, 0.05577520655383945],
         DiskBox[{0.5558209968162835, 3.280226376630644}, 
         0.05577520655383945], 
        DiskBox[{0.5619696090204229, 3.2693962905680234`}, 
         0.05577520655383945], 
        DiskBox[{0.5681302436130817, 3.2585730388581}, 0.05577520655383945], 
        DiskBox[{0.5804875495629052, 3.2369470918716896`}, 
         0.05577520655383945], 
        DiskBox[{0.5866842056825039, 3.226144423261755}, 0.05577520655383945],
         DiskBox[{0.5928928537155223, 3.215348642337582}, 
         0.05577520655383945], 
        DiskBox[{0.5991134860061926, 3.204559762411244}, 0.05577520655383945],
         DiskBox[{0.6053460948839682, 3.193777796786307}, 
         0.05577520655383945], 
        DiskBox[{0.617847211644829, 3.1722346616122454`}, 
         0.05577520655383945], 
        DiskBox[{0.6241157041130219, 3.1614735186275604`}, 
         0.05577520655383945], 
        DiskBox[{0.6303961423385562, 3.1507193430731126`}, 
         0.05577520655383945], 
        DiskBox[{0.6366885185771398, 3.139972148209673}, 0.05577520655383945],
         DiskBox[{0.6429928250697667, 3.1292319472894077`}, 
         0.05577520655383945], 
        DiskBox[{0.6493090540427122, 3.1184987535558495`}, 
         0.05577520655383945], 
        DiskBox[{0.6556371977075521, 3.1077725802439087`}, 
         0.05577520655383945], 
        DiskBox[{0.6619772482611719, 3.097053440579823}, 0.05577520655383945],
         DiskBox[{0.6683291978857735, 3.086341347781161}, 
         0.05577520655383945], 
        DiskBox[{0.6746930387488916, 3.075636315056803}, 0.05577520655383945],
         DiskBox[{0.68106876300339, 3.064938355606925}, 0.05577520655383945], 
        DiskBox[{0.6874563627874828, 3.0542474826229773`}, 
         0.05577520655383945], 
        DiskBox[{0.6938558302247433, 3.0435637092876773`}, 
         0.05577520655383945], 
        DiskBox[{0.700267157424106, 3.032887048774982}, 0.05577520655383945], 
        DiskBox[{0.7066903364798875, 3.022217514250083}, 0.05577520655383945],
         DiskBox[{0.7131253594717819, 3.0115551188693805`}, 
         0.05577520655383945], 
        DiskBox[{0.7195722184648865, 3.0008998757804752`}, 
         0.05577520655383945], 
        DiskBox[{0.726030905509699, 2.990251798122147}, 0.05577520655383945], 
        DiskBox[{0.7325014126421365, 2.9796108990243386`}, 
         0.05577520655383945], 
        DiskBox[{0.7389837318835344, 2.968977191608144}, 0.05577520655383945],
         DiskBox[{2.397103264339588, 3.3560553899634717`}, 
         0.05577520655383945], 
        DiskBox[{2.4031665376184934`, 3.34726989379672}, 0.05577520655383945],
         DiskBox[{2.4092395629406136`, 3.3384911359581917`}, 
         0.05577520655383945], 
        DiskBox[{2.4153223328174205`, 3.3297191272728046`}, 
         0.05577520655383945], 
        DiskBox[{2.421414839748362, 3.3209538785571597`}, 
         0.05577520655383945], 
        DiskBox[{2.427517076220881, 3.31219540061952}, 0.05577520655383945], 
        DiskBox[{2.4336290347104272`, 3.3034437042598004`}, 
         0.05577520655383945], 
        DiskBox[{2.439750707680459, 3.2946988002695514`}, 
         0.05577520655383945], 
        DiskBox[{2.445882087582455, 3.2859606994319526`}, 
         0.05577520655383945], 
        DiskBox[{2.4520231668559296`, 3.277229412521784}, 
         0.05577520655383945], 
        DiskBox[{2.4581739379284295`, 3.2685049503054424`}, 
         0.05577520655383945], 
        DiskBox[{2.4643343932155553`, 3.259787323540893}, 
         0.05577520655383945], 
        DiskBox[{2.470504525120967, 3.2510765429776773`}, 
         0.05577520655383945], 
        DiskBox[{2.4766843260363895`, 3.2423726193568942`}, 
         0.05577520655383945], 
        DiskBox[{2.482873788341627, 3.2336755634111896`}, 
         0.05577520655383945], 
        DiskBox[{2.5895653986288343`, 3.086886725319652}, 
         0.05577520655383945], 
        DiskBox[{2.69900884278204, 2.9421379939752175`}, 0.05577520655383945],
         DiskBox[{3.0190590691824672`, 2.5489408900596144`}, 
         0.05577520655383945], 
        DiskBox[{3.3593941426790392`, 2.173164164204132}, 
         0.05577520655383945], 
        DiskBox[{3.3667703544334593`, 2.165447965275602}, 
         0.05577520655383945], 
        DiskBox[{3.3741551300293517`, 2.157739961957688}, 
         0.05577520655383945], 
        DiskBox[{3.3815484603606896`, 2.1500401637549826`}, 
         0.05577520655383945], 
        DiskBox[{3.388950336310897, 2.142348580161964}, 0.05577520655383945], 
        DiskBox[{3.3963607487528593`, 2.134665220662976}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{4.708792601742663, 3.0866055893240025`}, 
          0.05577520655383945]}, 
        DiskBox[{4.814627648130082, 2.984911543671071}, 0.05577520655383945], 
        DiskBox[{4.82110156451798, 2.978810796263634}, 0.05577520655383945], 
        DiskBox[{4.827582251438889, 2.9727172415244016`}, 
         0.05577520655383945], 
        DiskBox[{4.834069700901594, 2.966630886967221}, 0.05577520655383945], 
        DiskBox[{4.840563904906545, 2.9605517400970633`}, 
         0.05577520655383945], 
        DiskBox[{4.847064855445859, 2.95447980841001}, 0.05577520655383945], 
        DiskBox[{4.853572544503338, 2.9484150993932454`}, 
         0.05577520655383945], 
        DiskBox[{4.860086964054472, 2.9423576205250486`}, 
         0.05577520655383945], 
        DiskBox[{4.866608106066453, 2.9363073792747825`}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{5.159423727333477, 5.000942411669477}, 
          0.05577520655383945]}, 
        DiskBox[{0., 2.6429868427313643`}, 0.05577520655383945], 
        DiskBox[{1.908319463378863, 2.6610115000980095`}, 
         0.05577520655383945], 
        DiskBox[{1.9910255152547212`, 2.5495813598020467`}, 
         0.05577520655383945], 
        DiskBox[{2.001467959242941, 2.535730372164804}, 0.05577520655383945], 
        DiskBox[{2.0084423995705194`, 2.526506051813178}, 
         0.05577520655383945], 
        DiskBox[{2.0154270786682265`, 2.5172894818582296`}, 
         0.05577520655383945], 
        DiskBox[{2.0224219879233853`, 2.5080806736647405`}, 
         0.05577520655383945], 
        DiskBox[{2.0294271187107054`, 2.498879638587919}, 
         0.05577520655383945], 
        DiskBox[{2.0364424623922925`, 2.489686387973384}, 
         0.05577520655383945], 
        DiskBox[{2.043468010317655, 2.480500933157166}, 0.05577520655383945], 
        DiskBox[{2.050503753823726, 2.4713232854656715`}, 
         0.05577520655383945], 
        DiskBox[{2.057549684234857, 2.462153456215688}, 0.05577520655383945], 
        DiskBox[{2.075209020925124, 2.439263162951703}, 0.05577520655383945], 
        DiskBox[{2.11428281088879, 2.3890776409364713`}, 0.05577520655383945],
         DiskBox[{2.211484562843088, 2.2669145421096433`}, 
         0.05577520655383945], 
        DiskBox[{2.329042086225458, 2.124035421784769}, 0.05577520655383945], 
        DiskBox[{2.41886594351372, 2.018259045191839}, 0.05577520655383945], 
        DiskBox[{2.5331147120059008`, 1.8877370942328549`}, 
         0.05577520655383945], 
        DiskBox[{2.6377847007365354`, 1.7719087869971588`}, 
         0.05577520655383945], 
        DiskBox[{2.669130290131788, 1.7378919501547543`}, 
         0.05577520655383945], 
        DiskBox[{2.676990271887787, 1.729409521809771}, 0.05577520655383945], 
        DiskBox[{2.6848596680401036`, 1.7209358267462074`}, 
         0.05577520655383945], 
        DiskBox[{2.6927384688851372`, 1.7124708754128166`}, 
         0.05577520655383945], 
        DiskBox[{2.7006266647076878`, 1.704014678247571}, 
         0.05577520655383945], 
        DiskBox[{2.708524245780966, 1.6955672456776485`}, 
         0.05577520655383945], 
        DiskBox[{2.716431202366614, 1.6871285881194202`}, 
         0.05577520655383945], 
        DiskBox[{2.7243475247147133`, 1.6786987159784346`}, 
         0.05577520655383945], 
        DiskBox[{2.7322732030637953`, 1.6702776396494086`}, 
         0.05577520655383945], 
        DiskBox[{2.7402082276408546`, 1.6618653695162129`}, 
         0.05577520655383945], 
        DiskBox[{2.7481525886613634`, 1.653461915951861}, 
         0.05577520655383945], 
        DiskBox[{2.7561062763292767`, 1.6450672893184937`}, 
         0.05577520655383945], 
        DiskBox[{2.764069280837055, 1.6366814999673647`}, 
         0.05577520655383945], 
        DiskBox[{2.7720415923656647`, 1.6283045582388347`}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{4.054772977309685, 2.6071753758237843`}, 
          0.05577520655383945]}, 
        DiskBox[{4.148487317735704, 2.514076504145846}, 0.05577520655383945], 
        DiskBox[{4.229411349441348, 2.435885553728423}, 0.05577520655383945], 
        DiskBox[{4.2364952880032645`, 2.4291352962247057`}, 
         0.05577520655383945], 
        DiskBox[{4.2435867179651945`, 2.4223929091837153`}, 
         0.05577520655383945], 
        DiskBox[{4.250685630582832, 2.4156584009193622`}, 
         0.05577520655383945], 
        DiskBox[{4.257792017102639, 2.4089317797358403`}, 
         0.05577520655383945], 
        DiskBox[{5.440567478361202, 3.4967381423959507`}, 
         0.05577520655383945], 
        DiskBox[{5.476088384639159, 3.464400726142708}, 0.05577520655383945], 
        DiskBox[{5.48797646775074, 3.4536742677879797`}, 0.05577520655383945],
         DiskBox[{5.4998883437434225`, 3.44297423791706}, 
         0.05577520655383945], 
        DiskBox[{5.511823953863983, 3.4323006893059578`}, 
         0.05577520655383945], 
        DiskBox[{5.517800640829817, 3.426973861929632}, 0.05577520655383945], 
        DiskBox[{5.5237832392421335`, 3.421653674600064}, 
         0.05577520655383945], 
        DiskBox[{5.529771741723902, 3.4163401338774753`}, 
         0.05577520655383945], 
        DiskBox[{5.535766140890813, 3.4110332463138953`}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{5.8314039428966575`, 5.439880628095979}, 
          0.05577520655383945]}, 
        DiskBox[{1.1852774815032934`, 2.293833543324597}, 
         0.05577520655383945], 
        DiskBox[{1.192521037376034, 2.2837030401545118`}, 
         0.05577520655383945], 
        DiskBox[{1.1997758381161905`, 2.2735805867769328`}, 
         0.05577520655383945], 
        DiskBox[{1.2070418747780032`, 2.2634661956736677`}, 
         0.05577520655383945], 
        DiskBox[{1.2143191384018586`, 2.253359879316579}, 
         0.05577520655383945], 
        DiskBox[{1.2216076200143018`, 2.2432616501675797`}, 
         0.05577520655383945], 
        DiskBox[{1.228907310628042, 2.233171520678602}, 0.05577520655383945], 
        DiskBox[{1.2362182012419662`, 2.2230895032915976`}, 
         0.05577520655383945], 
        DiskBox[{1.243540282841158, 2.2130156104385135`}, 
         0.05577520655383945], 
        DiskBox[{1.2508735463968907`, 2.2029498545412736`}, 
         0.05577520655383945], 
        DiskBox[{1.2582179828666558`, 2.192892248011775}, 
         0.05577520655383945], 
        DiskBox[{1.2655735831941684`, 2.182842803251863}, 
         0.05577520655383945], 
        DiskBox[{1.2729403383093771`, 2.1728015326533185`}, 
         0.05577520655383945], 
        DiskBox[{1.2803182391284729`, 2.162768448597845}, 
         0.05577520655383945], 
        DiskBox[{1.2877072765539026`, 2.1527435634570455`}, 
         0.05577520655383945], 
        DiskBox[{1.2951074414743893`, 2.1427268895924216`}, 
         0.05577520655383945], 
        DiskBox[{1.3025187247649246`, 2.132718439355343}, 
         0.05577520655383945], 
        DiskBox[{1.3099411172867974`, 2.122718225087043}, 
         0.05577520655383945], 
        DiskBox[{1.3173746098875885`, 2.1127262591185962`}, 
         0.05577520655383945], 
        DiskBox[{1.3248191934012041`, 2.1027425537709084`}, 
         0.05577520655383945], 
        DiskBox[{1.3322748586478674`, 2.0927671213547017`}, 
         0.05577520655383945], 
        DiskBox[{1.3397415964341377`, 2.082799974170489}, 
         0.05577520655383945], 
        DiskBox[{1.3472193975529283`, 2.0728411245085647`}, 
         0.05577520655383945], 
        DiskBox[{1.3547082527834853`, 2.06289058464902}, 0.05577520655383945],
         DiskBox[{1.437812580945005, 1.9539865949632924`}, 
         0.05577520655383945], 
        DiskBox[{1.445433361349366, 1.9441367268327463`}, 
         0.05577520655383945], 
        DiskBox[{1.4530650747597118`, 1.9342953272075425`}, 
         0.05577520655383945], 
        DiskBox[{1.4607077117655205`, 1.9244624082229231`}, 
         0.05577520655383945], 
        DiskBox[{1.4683612629427998`, 1.9146379820036774`}, 
         0.05577520655383945], 
        DiskBox[{1.4760257188540997`, 1.9048220606641202`}, 
         0.05577520655383945], 
        DiskBox[{1.4837010700485234`, 1.8950146563080787`}, 
         0.05577520655383945], 
        DiskBox[{1.491387307061741, 1.8852157810288803`}, 
         0.05577520655383945], 
        DiskBox[{1.4990844204159952`, 1.8754254469093325`}, 
         0.05577520655383945], 
        DiskBox[{1.5067924006201245`, 1.8656436660217128`}, 
         0.05577520655383945], 
        DiskBox[{1.5145112381695593`, 1.8558704504277515`}, 
         0.05577520655383945], 
        DiskBox[{1.522240923546354, 1.8461058121786111`}, 
         0.05577520655383945], 
        DiskBox[{1.5299814472191677`, 1.836349763314895}, 
         0.05577520655383945], 
        DiskBox[{1.5377327996433117`, 1.8266023158665963`}, 
         0.05577520655383945], 
        DiskBox[{1.545494971260739, 1.816863481853109}, 0.05577520655383945], 
        DiskBox[{1.5532679525000646`, 1.8071332732832097`}, 
         0.05577520655383945], 
        DiskBox[{1.5610517337765657`, 1.7974117021550313`}, 
         0.05577520655383945], 
        DiskBox[{1.5688463054922117`, 1.787698780456064}, 
         0.05577520655383945], 
        DiskBox[{1.5766516580356633`, 1.7779945201631282`}, 
         0.05577520655383945], 
        DiskBox[{1.5844677817822852`, 1.7682989332423604`}, 
         0.05577520655383945], 
        DiskBox[{1.5922946670941638`, 1.7586120316492133`}, 
         0.05577520655383945], 
        DiskBox[{1.6001323043201126`, 1.7489338273284165`}, 
         0.05577520655383945], 
        DiskBox[{1.607980683795688, 1.7392643322139874`}, 
         0.05577520655383945], 
        DiskBox[{1.615839795843204, 1.7296035582291935`}, 
         0.05577520655383945], 
        DiskBox[{1.6237096307717351`, 1.7199515172865585`}, 
         0.05577520655383945], 
        DiskBox[{1.6315901788771345`, 1.7103082212878284`}, 
         0.05577520655383945], 
        DiskBox[{1.6394814304420482`, 1.7006736821239725`}, 
         0.05577520655383945], 
        DiskBox[{1.6473833757359237`, 1.6910479116751596`}, 
         0.05577520655383945], 
        DiskBox[{1.6552960050150176`, 1.681430921810744}, 
         0.05577520655383945], 
        DiskBox[{1.6632193085224252`, 1.6718227243892523`}, 
         0.05577520655383945], 
        DiskBox[{1.6711532764880541`, 1.6622233312583807`}, 
         0.05577520655383945], 
        DiskBox[{1.6790978991286867`, 1.6526327542549577`}, 
         0.05577520655383945], 
        DiskBox[{1.6910347891721287`, 1.6382634448550988`}, 
         0.05577520655383945], 
        DiskBox[{1.702995597071336, 1.6239140382145303`}, 
         0.05577520655383945], 
        DiskBox[{1.7109827403171316`, 1.6143588438715692`}, 
         0.05577520655383945], 
        DiskBox[{1.7189804891249683`, 1.604812524676853}, 
         0.05577520655383945], 
        DiskBox[{1.726988833632971, 1.5952750924017716`}, 
         0.05577520655383945], 
        DiskBox[{1.7350077639661983`, 1.5857465588067488`}, 
         0.05577520655383945], 
        DiskBox[{1.7430372702366643`, 1.5762269356412437`}, 
         0.05577520655383945], 
        DiskBox[{1.751077342543331, 1.5667162346437244`}, 
         0.05577520655383945], 
        DiskBox[{1.759127970972136, 1.557214467541658}, 0.05577520655383945], 
        DiskBox[{1.767189145596003, 1.5477216460514915`}, 
         0.05577520655383945], 
        DiskBox[{1.7752608564748567`, 1.5382377818786397`}, 
         0.05577520655383945], 
        DiskBox[{1.7833430936556063`, 1.5287628867174927`}, 
         0.05577520655383945], 
        DiskBox[{1.791435847172206, 1.5192969722513556`}, 
         0.05577520655383945], 
        DiskBox[{1.7995391070456321`, 1.5098400501524711`}, 
         0.05577520655383945], 
        DiskBox[{1.8076528632839057`, 1.500392132081993}, 
         0.05577520655383945], 
        DiskBox[{1.8157771058821108`, 1.4909532296899677`}, 
         0.05577520655383945], 
        DiskBox[{1.8239118248223942`, 1.4815233546153337`}, 
         0.05577520655383945], 
        DiskBox[{1.8320570100739868`, 1.4721025184858885`}, 
         0.05577520655383945], 
        DiskBox[{1.8402126515932142`, 1.4626907329182863`}, 
         0.05577520655383945], 
        DiskBox[{1.8483787393235094`, 1.4532880095180278`}, 
         0.05577520655383945], 
        DiskBox[{1.8565552631954247`, 1.4438943598794278`}, 
         0.05577520655383945], 
        DiskBox[{1.864742213126636, 1.4345097955856287`}, 
         0.05577520655383945], 
        DiskBox[{1.8770421647979347`, 1.4204500094769479`}, 
         0.05577520655383945], 
        DiskBox[{1.8934784972379273`, 1.401735534616071}, 
         0.05577520655383945], 
        DiskBox[{1.9058329998918317`, 1.387723658913198}, 
         0.05577520655383945], 
        DiskBox[{1.9140822937310933`, 1.3783938493055947`}, 
         0.05577520655383945], 
        DiskBox[{1.922341942694155, 1.3690732058102322`}, 
         0.05577520655383945], 
        DiskBox[{1.9306119365962005`, 1.3597617399202244`}, 
         0.05577520655383945], 
        DiskBox[{1.9388922652396534`, 1.3504594631173639`}, 
         0.05577520655383945], 
        DiskBox[{1.9471829184141978`, 1.3411663868721124`}, 
         0.05577520655383945], 
        DiskBox[{1.9554838858967845`, 1.3318825226435882`}, 
         0.05577520655383945], 
        DiskBox[{1.9637951574516475`, 1.3226078818795495`}, 
         0.05577520655383945], 
        DiskBox[{1.9721167228303145`, 1.3133424760163805`}, 
         0.05577520655383945], 
        DiskBox[{1.9804485717716158`, 1.304086316479081}, 
         0.05577520655383945], 
        DiskBox[{1.9887906940017075`, 1.2948394146812445`}, 
         0.05577520655383945], 
        DiskBox[{1.99714307923408, 1.2856017820250534`}, 0.05577520655383945],
         DiskBox[{2.0055057171695587`, 1.2763734299012608`}, 
         0.05577520655383945], 
        DiskBox[{2.0138785974963334`, 1.2671543696891705`}, 
         0.05577520655383945], 
        DiskBox[{2.022261709889973, 1.2579446127566216`}, 
         0.05577520655383945], 
        DiskBox[{2.0306550440133986`, 1.2487441704600162`}, 
         0.05577520655383945], 
        DiskBox[{2.0390585895169586`, 1.2395530541442348`}, 
         0.05577520655383945], 
        DiskBox[{2.0474723360383997`, 1.2303712751426703`}, 
         0.05577520655383945], 
        DiskBox[{2.0558962732028885`, 1.2211988447772004`}, 
         0.05577520655383945], 
        DiskBox[{2.0643303906230273`, 1.2120357743581778`}, 
         0.05577520655383945], 
        DiskBox[{2.0727746778988614`, 1.2028820751844123`}, 
         0.05577520655383945], 
        DiskBox[{3.470932364742226, 2.058286030135423}, 0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{3.478436073201552, 2.050693758729042}, 
          0.05577520655383945]}, 
        DiskBox[{3.485948207809451, 2.0431098244345316`}, 
         0.05577520655383945], 
        DiskBox[{3.493468759302856, 2.035534236603497}, 0.05577520655383945], 
        DiskBox[{3.500997718408313, 2.0279670045772518`}, 
         0.05577520655383945], 
        DiskBox[{3.5085350758420075`, 2.0204081376868057`}, 
         0.05577520655383945], 
        DiskBox[{3.516080822309763, 2.012857645252862}, 0.05577520655383945], 
        DiskBox[{3.5236349485070617`, 2.005315536585787}, 
         0.05577520655383945], 
        DiskBox[{3.5311974451190524`, 1.9977818209856126`}, 
         0.05577520655383945], 
        DiskBox[{3.5387683028205634`, 1.9902565077420231`}, 
         0.05577520655383945], 
        DiskBox[{3.546347512276113, 1.9827396061343405`}, 
         0.05577520655383945], 
        DiskBox[{3.5539350641399174`, 1.975231125431515}, 
         0.05577520655383945], 
        DiskBox[{3.561530949055914, 1.9677310748921109`}, 
         0.05577520655383945], 
        DiskBox[{3.569135157657758, 1.9602394637643012`}, 
         0.05577520655383945], 
        DiskBox[{3.576747680568844, 1.9527563012858513`}, 
         0.05577520655383945], 
        DiskBox[{3.584368508402309, 1.9452815966841062`}, 
         0.05577520655383945], 
        DiskBox[{3.5919976317610587`, 1.9378153591759846`}, 
         0.05577520655383945], 
        DiskBox[{3.599635041237759, 1.930357597967963}, 0.05577520655383945], 
        DiskBox[{3.607280727414868, 1.9229083222560694`}, 
         0.05577520655383945], 
        DiskBox[{3.614934680864634, 1.915467541225861}, 0.05577520655383945], 
        DiskBox[{3.622596892149109, 1.9080352640524278`}, 
         0.05577520655383945], 
        DiskBox[{3.630267351820164, 1.9006114999003705`}, 
         0.05577520655383945], 
        DiskBox[{3.6379460504195027`, 1.893196257923794}, 
         0.05577520655383945], 
        DiskBox[{3.6456329784786643`, 1.88578954726629}, 0.05577520655383945],
         DiskBox[{3.6533281265190416`, 1.8783913770609395`}, 
         0.05577520655383945], 
        DiskBox[{3.6610314850518924`, 1.8710017564302825`}, 
         0.05577520655383945], 
        DiskBox[{3.668743044578351, 1.8636206944863236`}, 
         0.05577520655383945], 
        DiskBox[{4.8731359624981865`, 2.930264383102882}, 
         0.05577520655383945], 
        DiskBox[{4.87967052530029, 2.9242286394608588`}, 0.05577520655383945],
         DiskBox[{4.886211786415119, 2.918200155791272}, 0.05577520655383945],
         DiskBox[{4.892759737776768, 2.912178939527731}, 0.05577520655383945],
         DiskBox[{4.899314371311083, 2.9061649980948854`}, 
         0.05577520655383945], 
        DiskBox[{4.905875678935665, 2.900158338908411}, 0.05577520655383945], 
        DiskBox[{4.912443652559891, 2.8941589693750087`}, 
         0.05577520655383945], 
        DiskBox[{4.919018284084918, 2.888166896892387}, 0.05577520655383945], 
        DiskBox[{4.925599565403688, 2.8821821288492577`}, 
         0.05577520655383945], 
        DiskBox[{4.9321874884009524`, 2.876204672625324}, 
         0.05577520655383945], 
        DiskBox[{4.93878204495326, 2.8702345355912797`}, 0.05577520655383945],
         DiskBox[{4.94538322692899, 2.864271725108784}, 0.05577520655383945], 
        DiskBox[{4.95199102618835, 2.8583162485304703`}, 0.05577520655383945],
         DiskBox[{4.958605434583386, 2.852368113199921}, 0.05577520655383945],
         DiskBox[{4.965226443957997, 2.8464273264516704`}, 
         0.05577520655383945], 
        DiskBox[{4.971854046147939, 2.8404938956111945`}, 
         0.05577520655383945], 
        DiskBox[{6.082458066468294, 3.997012998322271}, 0.05577520655383945], 
        DiskBox[{6.098521450729298, 3.98295027403429}, 0.05577520655383945], 
        DiskBox[{6.10388631170051, 3.978274600537482}, 0.05577520655383945], 
        DiskBox[{6.109256361426986, 3.9736048872888583`}, 
         0.05577520655383945], 
        DiskBox[{6.114631593287018, 3.9689411400465575`}, 
         0.05577520655383945], 
        DiskBox[{6.12001200065251, 3.9642833645613544`}, 0.05577520655383945],
         DiskBox[{6.125397576888983, 3.9596315665766655`}, 
         0.05577520655383945], 
        DiskBox[{6.130788315355582, 3.954985751828538}, 0.05577520655383945], 
        DiskBox[{6.13618420940509, 3.950345926045637}, 0.05577520655383945], 
        DiskBox[{6.141585252383932, 3.9457120949492444`}, 
         0.05577520655383945], 
        DiskBox[{6.146991437632182, 3.9410842642532495`}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{6.630904539978427, 5.721101979319924}, 
          0.05577520655383945]}, 
        DiskBox[{1.070996575564795, 1.1309906169263275`}, 
         0.05577520655383945], 
        DiskBox[{1.0795314711952422`, 1.120733928410397}, 
         0.05577520655383945], 
        DiskBox[{1.2613776967919499`, 0.9075536066199188}, 
         0.05577520655383945], 
        DiskBox[{1.2701605888226677`, 0.8975084630016239}, 
         0.05577520655383945], 
        DiskBox[{1.2789546299849306`, 0.8874730784662983}, 
         0.05577520655383945], 
        DiskBox[{1.2877598094349718`, 0.8774474653883875}, 
         0.05577520655383945], 
        DiskBox[{1.296576116315288, 0.8674316361302798}, 0.05577520655383945],
         DiskBox[{1.4391414441706232`, 0.7085190082710486}, 
         0.05577520655383945], 
        DiskBox[{5.541766429351291, 3.405733018453141}, 0.05577520655383945], 
        DiskBox[{5.547772599706484, 3.400439456830834}, 0.05577520655383945], 
        DiskBox[{5.5537846445503, 3.3951525679743595`}, 0.05577520655383945], 
        DiskBox[{5.559802556469399, 3.389872358402883}, 0.05577520655383945], 
        DiskBox[{5.565826328043207, 3.3845988346273295`}, 
         0.05577520655383945], 
        DiskBox[{6.67233309389966, 4.545891689844322}, 0.05577520655383945], 
        DiskBox[{6.677072487458858, 4.5418528536590825`}, 
         0.05577520655383945], 
        DiskBox[{6.681816362988226, 4.537819282784285}, 0.05577520655383945], 
        DiskBox[{6.68656471463818, 4.533790982193646}, 0.05577520655383945], 
        DiskBox[{6.691317536553619, 4.529767956854391}, 0.05577520655383945], 
        DiskBox[{6.696074822873926, 4.525750211727235}, 0.05577520655383945], 
        DiskBox[{6.7008365677329795`, 4.521737751766386}, 
         0.05577520655383945], 
        DiskBox[{6.705602765259165, 4.51773058191953}, 0.05577520655383945], 
        DiskBox[{6.710373409575371, 4.513728707127833}, 0.05577520655383945], 
        DiskBox[{6.715148494799006, 4.509732132325935}, 0.05577520655383945], 
        DiskBox[{6.727105598174198, 4.499763915101112}, 0.05577520655383945], 
        DiskBox[{6.7390903282550045`, 4.489828930417855}, 
         0.05577520655383945], 
        DiskBox[{6.743891935082644, 4.485864258815701}, 0.05577520655383945], 
        DiskBox[{6.748697941486649, 4.48190492156247}, 0.05577520655383945], 
        DiskBox[{6.753508341540824, 4.477950923540346}, 0.05577520655383945], 
        DiskBox[{6.758323129313556, 4.474002269624933}, 0.05577520655383945], 
        DiskBox[{6.76314229886782, 4.470058964685239}, 0.05577520655383945], 
        DiskBox[{6.767965844261187, 4.466121013583679}, 0.05577520655383945], 
        DiskBox[{6.772793759545838, 4.4621884211760685`}, 
         0.05577520655383945], 
        DiskBox[{6.777626038768558, 4.45826119231161}, 0.05577520655383945], 
        DiskBox[{6.782462675970756, 4.4543393318329}, 0.05577520655383945], 
        DiskBox[{6.787303665188464, 4.450422844575907}, 0.05577520655383945], 
        DiskBox[{6.792149000452351, 4.446511735369978}, 0.05577520655383945], 
        DiskBox[{6.796998675787724, 4.442606009037831}, 0.05577520655383945], 
        DiskBox[{6.81887576271634, 4.425096982581352}, 0.05577520655383945], 
        DiskBox[{6.840840068555613, 4.407697493826359}, 0.05577520655383945], 
        DiskBox[{6.8457328148240935`, 4.403845860018165}, 
         0.05577520655383945], 
        DiskBox[{6.85553112331751, 4.396158903597256}, 0.05577520655383945], 
        DiskBox[{6.865346479470402, 4.388493727021275}, 0.05577520655383945], 
        DiskBox[{6.870260535293518, 4.384669317994061}, 0.05577520655383945], 
        DiskBox[{6.875178834870259, 4.380850368097349}, 0.05577520655383945], 
        DiskBox[{6.880101372135959, 4.377036882040215}, 0.05577520655383945], 
        DiskBox[{6.8850281410207295`, 4.373228864524996}, 
         0.05577520655383945], 
        DiskBox[{6.889959135449466, 4.369426320247286}, 0.05577520655383945], 
        DiskBox[{6.894894349341849, 4.365629253895934}, 0.05577520655383945], 
        DiskBox[{6.899833776612363, 4.361837670153028}, 0.05577520655383945], 
        DiskBox[{6.904777411170291, 4.3580515736939}, 0.05577520655383945], 
        DiskBox[{6.909725246919731, 4.354270969187114}, 0.05577520655383945], 
        DiskBox[{6.914677277759599, 4.350495861294463}, 0.05577520655383945], 
        DiskBox[{6.9196334975836375`, 4.34672625467096}, 0.05577520655383945],
         DiskBox[{6.924593900280428, 4.342962153964837}, 0.05577520655383945],
         DiskBox[{6.92955847973339, 4.339203563817536}, 0.05577520655383945], 
        DiskBox[{6.934527229820794, 4.335450488863704}, 0.05577520655383945], 
        DiskBox[{6.939500144415767, 4.3317029337311865`}, 
         0.05577520655383945], 
        DiskBox[{6.944477217386303, 4.327960903041022}, 0.05577520655383945], 
        DiskBox[{6.949458442595265, 4.324224401407442}, 0.05577520655383945], 
        DiskBox[{6.954443813900401, 4.3204934334378535`}, 
         0.05577520655383945], 
        DiskBox[{6.95943332515434, 4.316768003732842}, 0.05577520655383945], 
        DiskBox[{7.0271938053158145`, 4.267019072545112}, 
         0.05577520655383945], 
        DiskBox[{7.095692428362796, 4.218291488296528}, 0.05577520655383945], 
        DiskBox[{7.100795341834946, 4.214722969957511}, 0.05577520655383945], 
        DiskBox[{7.105902214792582, 4.21116012030664}, 0.05577520655383945], 
        DiskBox[{7.111013040938519, 4.207602943737199}, 0.05577520655383945], 
        DiskBox[{7.1161278139706905`, 4.2040514446354775`}, 
         0.05577520655383945], 
        DiskBox[{7.121246527582166, 4.2005056273807595`}, 
         0.05577520655383945], 
        DiskBox[{7.126369175461157, 4.196965496345328}, 0.05577520655383945], 
        DiskBox[{7.131495751291023, 4.19343105589445}, 0.05577520655383945], 
        DiskBox[{7.136626248750279, 4.189902310386381}, 0.05577520655383945], 
        DiskBox[{7.141760661512604, 4.186379264172345}, 0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{8.388443576916167, 5.298519947952482}, 
          0.05577520655383945]}, 
        DiskBox[{0.45493998448163, 0.6189302286477112}, 0.05577520655383945], 
        DiskBox[{0.6673815986233613, 0.36988259779469423`}, 
         0.05577520655383945], 
        DiskBox[{0.6861541006098193, 0.34848420034057526`}, 
         0.05577520655383945], 
        DiskBox[{6.206796954074826, 3.8905757797757}, 0.05577520655383945], 
        DiskBox[{6.212264324782052, 3.88602039686765}, 0.05577520655383945], 
        DiskBox[{6.217736750605653, 3.8814710879647087`}, 
         0.05577520655383945], 
        DiskBox[{6.2232142247976805`, 3.8769278586765434`}, 
         0.05577520655383945], 
        DiskBox[{6.300425148557725, 3.813964131722682}, 0.05577520655383945], 
        DiskBox[{6.305977534309578, 3.809512764702114}, 0.05577520655383945], 
        DiskBox[{6.31153485962181, 3.8050675660267768`}, 0.05577520655383945],
         DiskBox[{6.3170971176417865`, 3.8006285411779617`}, 
         0.05577520655383945], 
        DiskBox[{6.322664301510792, 3.796195695629346}, 0.05577520655383945], 
        DiskBox[{6.328236404364036, 3.7917690348469897`}, 
         0.05577520655383945], 
        DiskBox[{6.333813419330664, 3.7873485642893234`}, 
         0.05577520655383945], 
        DiskBox[{6.339395339533763, 3.782934289407147}, 0.05577520655383945], 
        DiskBox[{6.356170462702098, 3.7697286932069067`}, 
         0.05577520655383945], 
        DiskBox[{6.3617719349611175`, 3.765339255381784}, 
         0.05577520655383945], 
        DiskBox[{6.367378277981489, 3.7609560403714157`}, 
         0.05577520655383945], 
        DiskBox[{6.50051251147558, 3.6597549996815397`}, 0.05577520655383945],
         DiskBox[{6.534923775365421, 3.634475957521868}, 0.05577520655383945],
         DiskBox[{6.583959703253862, 3.5990576695185785`}, 
         0.05577520655383945], 
        DiskBox[{6.6187735171786795`, 3.5743359500190097`}, 
         0.05577520655383945], 
        DiskBox[{6.624591799786012, 3.570238238048847}, 0.05577520655383945], 
        DiskBox[{6.630414629076462, 3.5661469894688347`}, 
         0.05577520655383945], 
        DiskBox[{7.741707417826749, 4.75028015378079}, 0.05577520655383945], 
        DiskBox[{7.917645215347358, 4.644146256246418}, 0.05577520655383945], 
        DiskBox[{8.155002488542817, 4.5165076574528}, 0.05577520655383945], 
        DiskBox[{8.636778580076802, 4.306734142529214}, 0.05577520655383945], 
        DiskBox[{8.912327064208169, 4.213670191936605}, 0.05577520655383945], 
        DiskBox[{8.917433989331593, 4.212118943335833}, 0.05577520655383945], 
        DiskBox[{8.922542633877555, 4.210573366634183}, 0.05577520655383945], 
        DiskBox[{8.927652991546681, 4.209033463737479}, 0.05577520655383945], 
        DiskBox[{9.017354923193691, 4.1830055777340105`}, 
         0.05577520655383945], 
        DiskBox[{9.4016634533873, 4.092372622355965}, 0.05577520655383945], 
        DiskBox[{9.733788264510698, 4.040294380207342}, 0.05577520655383945], 
        DiskBox[{9.768243839184294, 4.036246367511571}, 0.05577520655383945], 
        DiskBox[{10.30881693606766, 4.0054084138708195`}, 
         0.05577520655383945], 
        DiskBox[{10.849428464899256`, 4.035565127106645}, 
         0.05577520655383945], 
        DiskBox[{10.854731971015498`, 4.036165026525421}, 
         0.05577520655383945], 
        DiskBox[{10.860034807708573`, 4.036770814808786}, 
         0.05577520655383945], 
        DiskBox[{10.865336968439648`, 4.037382491209756}, 
         0.05577520655383945], 
        DiskBox[{10.870638446670732`, 4.0380000549740815`}, 
         0.05577520655383945], 
        DiskBox[{10.87593923586467, 4.038623505340258}, 0.05577520655383945], 
        DiskBox[{10.886538720996759`, 4.0398880627958444`}, 
         0.05577520655383945], 
        DiskBox[{10.897135371555823`, 4.041176157339311}, 
         0.05577520655383945], 
        DiskBox[{10.90243261753676, 4.041829029038126}, 0.05577520655383945], 
        DiskBox[{10.907729135275758`, 4.042487782617356}, 
         0.05577520655383945], 
        DiskBox[{10.91302491824178, 4.043152417264705}, 0.05577520655383945], 
        DiskBox[{10.918319959904697`, 4.043822932160622}, 
         0.05577520655383945], 
        DiskBox[{10.923614253735291`, 4.044499326478309}, 
         0.05577520655383945], 
        DiskBox[{10.92890779320527, 4.045181599383719}, 0.05577520655383945], 
        DiskBox[{10.934200571787267`, 4.045869750035551}, 
         0.05577520655383945], 
        DiskBox[{10.939492582954857`, 4.046563777585261}, 
         0.05577520655383945], 
        DiskBox[{10.944783820182563`, 4.047263681177055}, 
         0.05577520655383945], 
        DiskBox[{10.950074276945859`, 4.047969459947897}, 
         0.05577520655383945], 
        DiskBox[{10.95536394672118, 4.048681113027505}, 0.05577520655383945], 
        DiskBox[{10.960652822985937`, 4.04939863953835}, 0.05577520655383945],
         DiskBox[{10.965940899218513`, 4.050122038595666}, 
         0.05577520655383945], 
        DiskBox[{10.971228168898284`, 4.050851309307443}, 
         0.05577520655383945], 
        DiskBox[{10.976514625505613`, 4.051586450774431}, 
         0.05577520655383945], 
        DiskBox[{10.981800262521874`, 4.0523274620901395`}, 
         0.05577520655383945], 
        DiskBox[{10.987085073429444`, 4.0530743423408415`}, 
         0.05577520655383945], 
        DiskBox[{10.992369051711725`, 4.053827090605575}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{8.804283593291188, 5.984360003239441}, 
          0.05577520655383945]}, 
        DiskBox[{6.008021692602426, 3.027662881394911}, 0.05577520655383945], 
        DiskBox[{6.014447400345469, 3.022887302164518}, 0.05577520655383945], 
        DiskBox[{6.0208784071292145`, 3.018118861252421}, 
         0.05577520655383945], 
        DiskBox[{6.02731470502371, 3.0133575645384925`}, 0.05577520655383945],
         DiskBox[{6.033756286092477, 3.0086034178937986`}, 
         0.05577520655383945], 
        DiskBox[{6.040203142392524, 3.0038564271805894`}, 
         0.05577520655383945], 
        DiskBox[{6.046655265974353, 2.9991165982522885`}, 
         0.05577520655383945], 
        DiskBox[{6.053112648881973, 2.994383936953489}, 0.05577520655383945], 
        DiskBox[{6.0595752831529035`, 2.9896584491199487`}, 
         0.05577520655383945], 
        DiskBox[{6.066043160818195, 2.984940140578577}, 0.05577520655383945], 
        DiskBox[{6.072516273902427, 2.9802290171474315`}, 
         0.05577520655383945], 
        DiskBox[{6.078994614423728, 2.97552508463571}, 0.05577520655383945], 
        DiskBox[{6.085478174393775, 2.9708283488437415`}, 
         0.05577520655383945], 
        DiskBox[{6.0919669458178145`, 2.966138815562985}, 
         0.05577520655383945], 
        DiskBox[{6.098460920694664, 2.9614564905760155`}, 
         0.05577520655383945], 
        DiskBox[{6.104960091016724, 2.956781379656517}, 0.05577520655383945], 
        DiskBox[{6.111464448769992, 2.9521134885692852`}, 
         0.05577520655383945], 
        DiskBox[{6.117973985934063, 2.947452823070205}, 0.05577520655383945], 
        DiskBox[{6.124488694482154, 2.9427993889062583`}, 
         0.05577520655383945], 
        DiskBox[{6.131008566381097, 2.9381531918155046`}, 
         0.05577520655383945], 
        DiskBox[{6.137533593591362, 2.933514237527084}, 0.05577520655383945], 
        DiskBox[{6.144063768067061, 2.9288825317612037`}, 
         0.05577520655383945], 
        DiskBox[{6.150599081755956, 2.924258080229132}, 0.05577520655383945], 
        DiskBox[{7.1468989832468655`, 4.182861921596541}, 
         0.05577520655383945], 
        DiskBox[{7.152041207617069, 4.179350286996152}, 0.05577520655383945], 
        DiskBox[{7.157187328282447, 4.175844364701302}, 0.05577520655383945], 
        DiskBox[{7.162337338897414, 4.172344159035075}, 0.05577520655383945], 
        DiskBox[{7.167491233111589, 4.168849674313511}, 0.05577520655383945], 
        DiskBox[{7.172649004569804, 4.165360914845592}, 0.05577520655383945], 
        DiskBox[{7.177810646912105, 4.161877884933243}, 0.05577520655383945], 
        DiskBox[{7.182976153773771, 4.158400588871324}, 0.05577520655383945], 
        DiskBox[{7.18814551878531, 4.15492903094762}, 0.05577520655383945], 
        DiskBox[{7.193318735572477, 4.1514632154428455`}, 
         0.05577520655383945], 
        DiskBox[{7.198495797756275, 4.148003146630632}, 0.05577520655383945], 
        DiskBox[{7.203676698952966, 4.144548828777526}, 0.05577520655383945], 
        DiskBox[{7.208861432774078, 4.141100266142982}, 0.05577520655383945], 
        DiskBox[{7.214049992826412, 4.137657462979356}, 0.05577520655383945], 
        DiskBox[{7.219242372712056, 4.1342204235319056`}, 
         0.05577520655383945], 
        DiskBox[{7.224438566028381, 4.130789152038779}, 0.05577520655383945], 
        DiskBox[{7.229638566368059, 4.127363652731012}, 0.05577520655383945], 
        DiskBox[{7.234842367319066, 4.123943929832524}, 0.05577520655383945], 
        DiskBox[{7.240049962464697, 4.120529987560111}, 0.05577520655383945], 
        DiskBox[{7.245261345383561, 4.117121830123441}, 0.05577520655383945], 
        DiskBox[{7.2504765096496016`, 4.113719461725049}, 
         0.05577520655383945], 
        DiskBox[{7.255695448832096, 4.11032288656033}, 0.05577520655383945], 
        DiskBox[{7.260918156495669, 4.1069321088175395`}, 
         0.05577520655383945], 
        DiskBox[{7.266144626200299, 4.103547132677779}, 0.05577520655383945], 
        DiskBox[{7.271374851501324, 4.100167962315001}, 0.05577520655383945], 
        DiskBox[{7.276608825949452, 4.096794601895996}, 0.05577520655383945], 
        DiskBox[{7.281846543090767, 4.093427055580392}, 0.05577520655383945], 
        DiskBox[{7.287087996466736, 4.090065327520646}, 0.05577520655383945], 
        DiskBox[{7.292333179614227, 4.086709421862042}, 0.05577520655383945], 
        DiskBox[{7.2975820860655, 4.083359342742685}, 0.05577520655383945], 
        DiskBox[{7.302834709348225, 4.080015094293493}, 0.05577520655383945], 
        DiskBox[{7.308091042985495, 4.076676680638197}, 0.05577520655383945], 
        DiskBox[{7.313351080495822, 4.073344105893333}, 0.05577520655383945], 
        DiskBox[{7.318614815393153, 4.070017374168234}, 0.05577520655383945], 
        DiskBox[{7.323882241186876, 4.0666964895650315`}, 
         0.05577520655383945], 
        DiskBox[{7.3291533513818266`, 4.063381456178646}, 
         0.05577520655383945], 
        DiskBox[{7.334428139478297, 4.060072278096782}, 0.05577520655383945], 
        DiskBox[{7.339706598972047, 4.056768959399926}, 0.05577520655383945], 
        DiskBox[{7.344988723354307, 4.053471504161337}, 0.05577520655383945], 
        DiskBox[{7.350274506111788, 4.050179916447046}, 0.05577520655383945], 
        DiskBox[{7.355563940726692, 4.046894200315847}, 0.05577520655383945], 
        DiskBox[{7.360857020676716, 4.043614359819296}, 0.05577520655383945], 
        DiskBox[{7.366153739435061, 4.0403403990017015`}, 
         0.05577520655383945], 
        DiskBox[{7.371454090470445, 4.037072321900123}, 0.05577520655383945], 
        DiskBox[{7.3767580672471045`, 4.033810132544365}, 
         0.05577520655383945], 
        DiskBox[{7.382065663224806, 4.030553834956972}, 0.05577520655383945], 
        DiskBox[{7.38737687185885, 4.027303433153224}, 0.05577520655383945], 
        DiskBox[{7.392691686600087, 4.024058931141131}, 0.05577520655383945], 
        DiskBox[{7.398010100894919, 4.020820332921423}, 0.05577520655383945], 
        DiskBox[{7.403332108185309, 4.01758764248756}, 0.05577520655383945], 
        DiskBox[{7.4086577019087905`, 4.01436086382571}, 0.05577520655383945],
         DiskBox[{7.413986875498474, 4.01114000091475}, 0.05577520655383945], 
        DiskBox[{7.419319622383054, 4.007925057726271}, 0.05577520655383945], 
        DiskBox[{7.424655935986823, 4.004716038224555}, 0.05577520655383945], 
        DiskBox[{7.429995809729672, 4.001512946366583}, 0.05577520655383945], 
        DiskBox[{7.435339237027101, 3.9983157861020313`}, 
         0.05577520655383945], 
        DiskBox[{7.4406862112902346`, 3.9951245613732542`}, 
         0.05577520655383945], 
        DiskBox[{7.446036725925817, 3.9919392761152928`}, 
         0.05577520655383945], 
        DiskBox[{7.451390774336227, 3.988759934255863}, 0.05577520655383945], 
        DiskBox[{7.4567483499194935`, 3.9855865397153494`}, 
         0.05577520655383945], 
        DiskBox[{7.462109446069286, 3.982419096406807}, 0.05577520655383945], 
        DiskBox[{7.46747405617494, 3.979257608235949}, 0.05577520655383945], 
        DiskBox[{7.472842173621455, 3.9761020791011488`}, 
         0.05577520655383945], 
        DiskBox[{7.478213791789508, 3.9729525128934284`}, 
         0.05577520655383945], 
        DiskBox[{7.4835889040554555`, 3.9698089134964603`}, 
         0.05577520655383945], 
        DiskBox[{7.488967503791365, 3.9666712847865453`}, 
         0.05577520655383945], 
        DiskBox[{7.494349584364953, 3.9635396306326562`}, 
         0.05577520655383945], 
        DiskBox[{7.499735139139693, 3.9604139548963673`}, 
         0.05577520655383945], 
        DiskBox[{7.505124161474761, 3.9572942614318896`}, 
         0.05577520655383945], 
        DiskBox[{7.510516644725053, 3.954180554086059}, 0.05577520655383945], 
        DiskBox[{7.515912582241199, 3.951072836698329}, 0.05577520655383945], 
        DiskBox[{7.521311967369572, 3.947971113100767}, 0.05577520655383945], 
        DiskBox[{7.526714793452289, 3.944875387118051}, 0.05577520655383945], 
        DiskBox[{7.532121053827229, 3.9417856625674617`}, 
         0.05577520655383945], 
        DiskBox[{7.537530741828033, 3.93870194325888}, 0.05577520655383945], 
        DiskBox[{7.542943850784118, 3.935624232994784}, 0.05577520655383945], 
        DiskBox[{7.548360374020678, 3.93255253557024}, 0.05577520655383945], 
        DiskBox[{7.553780304858707, 3.929486854772896}, 0.05577520655383945], 
        DiskBox[{7.559203636614981, 3.926427194382992}, 0.05577520655383945], 
        DiskBox[{7.57277680112659, 3.918804407431548}, 0.05577520655383945], 
        DiskBox[{7.58637107496448, 3.9112193303332736`}, 0.05577520655383945],
         DiskBox[{7.591814671648473, 3.90819587135684}, 0.05577520655383945], 
        DiskBox[{7.597261622351255, 3.9051784590413554`}, 
         0.05577520655383945], 
        DiskBox[{7.602711920356288, 3.902167097107534}, 0.05577520655383945], 
        DiskBox[{7.608165558942918, 3.8991617892686277`}, 
         0.05577520655383945], 
        DiskBox[{7.613622531386363, 3.896162539230427}, 0.05577520655383945], 
        DiskBox[{7.619082830957732, 3.8931693506912497`}, 
         0.05577520655383945], 
        DiskBox[{7.624546450924034, 3.890182227341941}, 0.05577520655383945], 
        DiskBox[{7.630013384548182, 3.8872011728658658`}, 
         0.05577520655383945], 
        DiskBox[{7.635483625089, 3.8842261909389055`}, 0.05577520655383945], 
        DiskBox[{7.640957165801241, 3.8812572852294576`}, 
         0.05577520655383945], 
        DiskBox[{7.646433999935584, 3.87829445939842}, 0.05577520655383945], 
        DiskBox[{7.651914120738647, 3.8753377170991996`}, 
         0.05577520655383945], 
        DiskBox[{7.657397521452996, 3.8723870619777}, 0.05577520655383945], 
        DiskBox[{7.662884195317154, 3.869442497672318}, 0.05577520655383945], 
        DiskBox[{7.668374135565605, 3.8665040278139395`}, 
         0.05577520655383945], 
        DiskBox[{7.673867335428807, 3.863571656025938}, 0.05577520655383945], 
        DiskBox[{7.6793637881332, 3.8606453859241645`}, 0.05577520655383945], 
        DiskBox[{7.684863486901211, 3.857725221116949}, 0.05577520655383945], 
        DiskBox[{7.690366424951264, 3.854811165205091}, 0.05577520655383945], 
        DiskBox[{7.695872595497791, 3.8519032217818587`}, 
         0.05577520655383945], 
        DiskBox[{7.723451697904048, 3.837455317231588}, 0.05577520655383945], 
        DiskBox[{7.751110592604663, 3.8231607595480117`}, 
         0.05577520655383945], 
        DiskBox[{7.7566518716308295`, 3.8203202884965277`}, 
         0.05577520655383945], 
        DiskBox[{7.767743875129839, 3.814657814944532}, 0.05577520655383945], 
        DiskBox[{7.77884842696016, 3.809019989388802}, 0.05577520655383945], 
        DiskBox[{7.784405391385958, 3.806210328304158}, 0.05577520655383945], 
        DiskBox[{7.789965472350549, 3.803406839636918}, 0.05577520655383945], 
        DiskBox[{7.795528662997903, 3.80060952684401}, 0.05577520655383945], 
        DiskBox[{7.80109495646815, 3.7978183933747482`}, 0.05577520655383945],
         DiskBox[{7.806664345897602, 3.795033442670827}, 0.05577520655383945],
         DiskBox[{7.812236824418747, 3.792254678166315}, 0.05577520655383945],
         DiskBox[{7.817812385160269, 3.789482103287657}, 0.05577520655383945],
         DiskBox[{7.823391021247047, 3.786715721453663}, 0.05577520655383945],
         DiskBox[{7.8289727258001705`, 3.7839555360755037`}, 
         0.05577520655383945], 
        DiskBox[{7.834557491936945, 3.7812015505567143`}, 
         0.05577520655383945], 
        DiskBox[{7.840145312770899, 3.778453768293181}, 0.05577520655383945], 
        DiskBox[{7.845736181411796, 3.7757121926731427`}, 
         0.05577520655383945], 
        DiskBox[{7.851330090965642, 3.772976827077186}, 0.05577520655383945], 
        DiskBox[{7.856927034534692, 3.770247674878237}, 0.05577520655383945], 
        DiskBox[{7.86252700521746, 3.767524739441564}, 0.05577520655383945], 
        DiskBox[{7.8681299961087285`, 3.7648080241247657`}, 
         0.05577520655383945], 
        DiskBox[{7.873736000299554, 3.7620975322777728`}, 
         0.05577520655383945], 
        DiskBox[{7.879345010877277, 3.7593932672428423`}, 
         0.05577520655383945], 
        DiskBox[{7.884957020925533, 3.756695232354553}, 0.05577520655383945], 
        DiskBox[{7.890572023524259, 3.7540034309398003`}, 
         0.05577520655383945], 
        DiskBox[{7.896190011749701, 3.7513178663177937`}, 
         0.05577520655383945], 
        DiskBox[{7.901810978674419, 3.7486385418000534`}, 
         0.05577520655383945], 
        DiskBox[{7.9074349173673095`, 3.745965460690403}, 
         0.05577520655383945], 
        DiskBox[{7.913061820893598, 3.743298626284969}, 0.05577520655383945], 
        DiskBox[{7.918691682314855, 3.7406380418721747`}, 
         0.05577520655383945], 
        DiskBox[{7.924324494689005, 3.7379837107327383`}, 
         0.05577520655383945], 
        DiskBox[{7.929960251070332, 3.735335636139662}, 0.05577520655383945], 
        DiskBox[{7.935598944509491, 3.7326938213582403`}, 
         0.05577520655383945], 
        DiskBox[{7.941240568053516, 3.730058269646044}, 0.05577520655383945], 
        DiskBox[{7.946885114745826, 3.7274289842529216`}, 
         0.05577520655383945], 
        DiskBox[{7.952532577626238, 3.7248059684209958`}, 
         0.05577520655383945], 
        DiskBox[{7.958182949730971, 3.7221892253846587`}, 
         0.05577520655383945], 
        DiskBox[{7.963836224092657, 3.7195787583705675`}, 
         0.05577520655383945], 
        DiskBox[{7.9694923937403495`, 3.716974570597638}, 
         0.05577520655383945], 
        DiskBox[{7.975151451699533, 3.7143766652770465`}, 
         0.05577520655383945], 
        DiskBox[{7.980813390992131, 3.7117850456122206`}, 
         0.05577520655383945], 
        DiskBox[{7.986478204636509, 3.7091997147988396`}, 
         0.05577520655383945], 
        DiskBox[{7.992145885647495, 3.7066206760248237`}, 
         0.05577520655383945], 
        DiskBox[{7.997816427036375, 3.7040479324703384`}, 
         0.05577520655383945], 
        DiskBox[{8.003489821810915, 3.7014814873077855`}, 
         0.05577520655383945], 
        DiskBox[{8.009166062975355, 3.698921343701799}, 0.05577520655383945], 
        DiskBox[{8.014845143530431, 3.6963675048092455`}, 
         0.05577520655383945], 
        DiskBox[{8.020527056473375, 3.693819973779215}, 0.05577520655383945], 
        DiskBox[{8.026211794797927, 3.6912787537530205`}, 
         0.05577520655383945], 
        DiskBox[{8.031899351494342, 3.6887438478641927`}, 
         0.05577520655383945], 
        DiskBox[{8.037589719549402, 3.686215259238475}, 0.05577520655383945], 
        DiskBox[{8.043282891946422, 3.6836929909938236`}, 
         0.05577520655383945], 
        DiskBox[{8.057528045856884, 3.6774149924405943`}, 
         0.05577520655383945], 
        DiskBox[{8.071790573235347, 3.6711765640692144`}, 
         0.05577520655383945], 
        DiskBox[{8.077500424140677, 3.6686922831513096`}, 
         0.05577520655383945], 
        DiskBox[{8.083213030174827, 3.666214344221724}, 0.05577520655383945], 
        DiskBox[{8.08892838429369, 3.663742750335956}, 0.05577520655383945], 
        DiskBox[{8.094646479449768, 3.661277504541683}, 0.05577520655383945], 
        DiskBox[{8.10036730859219, 3.658818609878753}, 0.05577520655383945], 
        DiskBox[{8.106090864666704, 3.656366069379181}, 0.05577520655383945], 
        DiskBox[{8.235576532689993, 3.60287022832798}, 0.05577520655383945], 
        DiskBox[{8.501300757691034, 3.504658495131018}, 0.05577520655383945], 
        DiskBox[{8.643368062508598, 3.458296726600965}, 0.05577520655383945], 
        DiskBox[{8.649313951666002, 3.456447280422231}, 0.05577520655383945], 
        DiskBox[{8.65526189085972, 3.454604437947139}, 0.05577520655383945], 
        DiskBox[{8.661211872755457, 3.45276820144806}, 0.05577520655383945], 
        DiskBox[{8.667163890016406, 3.450938573189223}, 0.05577520655383945], 
        DiskBox[{8.673117935303242, 3.449115555426709}, 0.05577520655383945], 
        DiskBox[{8.702918325075023, 3.440099702451044}, 0.05577520655383945], 
        DiskBox[{8.708884384252062, 3.4383163945874857`}, 
         0.05577520655383945], 
        DiskBox[{8.714852420010235, 3.4365397127844215`}, 
         0.05577520655383945], 
        DiskBox[{8.720822424990468, 3.4347696592326447`}, 
         0.05577520655383945], 
        DiskBox[{8.726794391831259, 3.4330062361147737`}, 
         0.05577520655383945], 
        DiskBox[{8.732768313168691, 3.4312494456052534`}, 
         0.05577520655383945], 
        DiskBox[{8.73874418163643, 3.429499289870349}, 0.05577520655383945], 
        DiskBox[{8.74472198986575, 3.4277557710681448`}, 0.05577520655383945],
         DiskBox[{8.750701730485526, 3.426018891348539}, 0.05577520655383945],
         DiskBox[{8.75668339612225, 3.4242886528532486`}, 
         0.05577520655383945], 
        DiskBox[{8.762666979400045, 3.422565057715796}, 0.05577520655383945], 
        DiskBox[{8.768652472940667, 3.4208481080615147`}, 
         0.05577520655383945], 
        DiskBox[{8.774639869363515, 3.4191378060075435`}, 
         0.05577520655383945], 
        DiskBox[{8.780629161285646, 3.417434153662822}, 0.05577520655383945], 
        DiskBox[{8.786620341321772, 3.4157371531280933`}, 
         0.05577520655383945], 
        DiskBox[{8.792613402084285, 3.4140468064958966`}, 
         0.05577520655383945], 
        DiskBox[{8.798608336183255, 3.4123631158505665`}, 
         0.05577520655383945], 
        DiskBox[{8.80460513622644, 3.4106860832682298`}, 0.05577520655383945],
         DiskBox[{8.810603794819299, 3.4090157108168047`}, 
         0.05577520655383945], 
        DiskBox[{8.816604304564999, 3.4073520005559947`}, 
         0.05577520655383945], 
        DiskBox[{8.822606658064423, 3.4056949545372905`}, 
         0.05577520655383945], 
        DiskBox[{8.828610847916185, 3.404044574803966}, 0.05577520655383945], 
        DiskBox[{8.834616866716628, 3.40240086339107}, 0.05577520655383945], 
        DiskBox[{8.840624707059844, 3.400763822325435}, 0.05577520655383945], 
        DiskBox[{8.84663436153768, 3.399133453625663}, 0.05577520655383945], 
        DiskBox[{8.852645822739742, 3.3975097593021335`}, 
         0.05577520655383945], 
        DiskBox[{8.85865908325341, 3.3958927413569935`}, 0.05577520655383945],
         DiskBox[{8.864674135663847, 3.394282401784154}, 0.05577520655383945],
         DiskBox[{8.870690972554005, 3.3926787425692986`}, 
         0.05577520655383945], 
        DiskBox[{8.876709586504637, 3.391081765689867}, 0.05577520655383945], 
        DiskBox[{8.8827299700943, 3.3894914731150605`}, 0.05577520655383945], 
        DiskBox[{8.888752115899372, 3.3879078668058424`}, 
         0.05577520655383945], 
        DiskBox[{8.894776016494061, 3.3863309487149245`}, 
         0.05577520655383945], 
        DiskBox[{8.900801664450407, 3.384760720786775}, 0.05577520655383945], 
        DiskBox[{8.906829052338308, 3.3831971849576137`}, 
         0.05577520655383945], 
        DiskBox[{8.912858172725484, 3.381640343155407}, 0.05577520655383945], 
        DiskBox[{8.918889018177552, 3.380090197299869}, 0.05577520655383945], 
        DiskBox[{8.924921581257987, 3.378546749302452}, 0.05577520655383945], 
        DiskBox[{8.93095585452815, 3.3770100010663553`}, 0.05577520655383945],
         DiskBox[{8.936991830547294, 3.375479954486514}, 0.05577520655383945],
         DiskBox[{9.03379294103235, 3.3519121486701033`}, 
         0.05577520655383945], 
        DiskBox[{9.188891012753613, 3.3179160972520023`}, 
         0.05577520655383945], 
        DiskBox[{9.298921446023243, 3.2965694655630857`}, 
         0.05577520655383945], 
        DiskBox[{9.381712244694437, 3.2820050403625887`}, 
         0.05577520655383945], 
        DiskBox[{9.41857635703982, 3.2759306707470133`}, 0.05577520655383945],
         DiskBox[{9.42472427512651, 3.2749421606360345`}, 
         0.05577520655383945], 
        DiskBox[{9.430873287105626, 3.2739604780392444`}, 
         0.05577520655383945], 
        DiskBox[{9.437023385394939, 3.272985624167138}, 0.05577520655383945], 
        DiskBox[{9.443174562410876, 3.2720176002217896`}, 
         0.05577520655383945], 
        DiskBox[{9.449326810568536, 3.27105640739685}, 0.05577520655383945], 
        DiskBox[{9.461634489962833, 3.26915451984069}, 0.05577520655383945], 
        DiskBox[{9.50782514034199, 3.2622660008676396`}, 0.05577520655383945],
         DiskBox[{9.547902262076024, 3.2566072959281316`}, 
         0.05577520655383945], 
        DiskBox[{9.575671401768453, 3.252859253682071}, 0.05577520655383945], 
        DiskBox[{9.603458923612386, 3.2492500197316163`}, 
         0.05577520655383945], 
        DiskBox[{9.609636355019465, 3.248466827385503}, 0.05577520655383945], 
        DiskBox[{9.61581465230736, 3.247690495199813}, 0.05577520655383945], 
        DiskBox[{9.621993807857733, 3.2469210241318285`}, 
         0.05577520655383945], 
        DiskBox[{9.62817381405118, 3.2461584151303713`}, 0.05577520655383945],
         DiskBox[{9.634354663267255, 3.245402669135796}, 0.05577520655383945],
         DiskBox[{9.640536347884465, 3.2446537870800025`}, 
         0.05577520655383945], 
        DiskBox[{9.646718860280295, 3.243911769886422}, 0.05577520655383945], 
        DiskBox[{9.652902192831204, 3.243176618470022}, 0.05577520655383945], 
        DiskBox[{9.65908633791264, 3.242448333737305}, 0.05577520655383945], 
        DiskBox[{9.665271287899051, 3.241726916586302}, 0.05577520655383945], 
        DiskBox[{9.67145703516389, 3.241012367906581}, 0.05577520655383945], 
        DiskBox[{9.683830891017772, 3.239603879476901}, 0.05577520655383945], 
        DiskBox[{9.755038798215068, 3.2320386445270746`}, 
         0.05577520655383945], 
        DiskBox[{9.826337505424343, 3.225383332547054}, 0.05577520655383945], 
        DiskBox[{9.832541301982888, 3.2248476485913846`}, 
         0.05577520655383945], 
        DiskBox[{9.972268473745793, 3.214617267154125}, 0.05577520655383945], 
        DiskBox[{10.51686701007871, 3.2080751712097015`}, 
         0.05577520655383945], 
        DiskBox[{10.926648475347433`, 3.2381307572659885`}, 
         0.05577520655383945], 
        DiskBox[{10.932837438247368`, 3.23881689665662}, 0.05577520655383945],
         DiskBox[{10.97613831076398, 3.2438122416118453`}, 
         0.05577520655383945], 
        DiskBox[{10.982320934194176`, 3.244553333077558}, 
         0.05577520655383945], 
        DiskBox[{10.988502730873652`, 3.245301289529352}, 
         0.05577520655383945], 
        DiskBox[{11.15233990340667, 4.895666343606759}, 0.05577520655383945], 
        DiskBox[{11.157148773239273`, 4.8967015041446}, 0.05577520655383945], 
        DiskBox[{11.161956368169696`, 4.897742569652108}, 
         0.05577520655383945], 
        DiskBox[{11.17877280590413, 4.901432777815097}, 0.05577520655383945], 
        DiskBox[{11.209960603621447`, 4.9084776482196615`}, 
         0.05577520655383945], 
        DiskBox[{11.229124775528485`, 4.9129366130920085`}, 
         0.05577520655383945], 
        DiskBox[{11.233912377920642`, 4.914066059744405}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{9.22720541426489, 6.667335858470613}, 0.05577520655383945]},
         DiskBox[{7.172171065572073, 3.225013146325872}, 0.05577520655383945],
         DiskBox[{7.178376909602201, 3.2215301654526947`}, 
         0.05577520655383945], 
        DiskBox[{7.184586617453444, 3.218054077955033}, 0.05577520655383945], 
        DiskBox[{7.190800181468729, 3.2145848881191865`}, 
         0.05577520655383945], 
        DiskBox[{7.344215851467155, 3.1317560596699314`}, 
         0.05577520655383945], 
        DiskBox[{7.366314340771927, 3.1202651572721045`}, 
         0.05577520655383945], 
        DiskBox[{7.37263638164194, 3.116997825772689}, 0.05577520655383945], 
        DiskBox[{7.378962046795367, 3.113737516545651}, 0.05577520655383945], 
        DiskBox[{7.397960709933258, 3.103998762657742}, 0.05577520655383945], 
        DiskBox[{7.404300794175208, 3.1007665826358126`}, 
         0.05577520655383945], 
        DiskBox[{7.410644463655782, 3.097541444900701}, 0.05577520655383945], 
        DiskBox[{7.725712207358569, 2.9482171326882227`}, 
         0.05577520655383945], 
        DiskBox[{7.73222507594949, 2.9453489976484146`}, 0.05577520655383945],
         DiskBox[{7.73874112542177, 2.942488096537926}, 0.05577520655383945], 
        DiskBox[{7.74526034774059, 2.939634432884481}, 0.05577520655383945], 
        DiskBox[{7.7975273833019125`, 2.9170660924902334`}, 
         0.05577520655383945], 
        DiskBox[{7.804074799030509, 2.914277723223779}, 0.05577520655383945], 
        DiskBox[{7.810625307043923, 2.911496626200048}, 0.05577520655383945], 
        DiskBox[{7.817178899264842, 2.9087228048483595`}, 
         0.05577520655383945], 
        DiskBox[{7.823735567612159, 2.9059562625890614`}, 
         0.05577520655383945], 
        DiskBox[{7.830295304000967, 2.9031970028335223`}, 
         0.05577520655383945], 
        DiskBox[{7.83685810034258, 2.9004450289841355`}, 0.05577520655383945],
         DiskBox[{7.843423948544535, 2.897700344434308}, 0.05577520655383945],
         DiskBox[{7.849992840510611, 2.8949629525684584`}, 
         0.05577520655383945], 
        DiskBox[{7.856564768140828, 2.8922328567620124`}, 
         0.05577520655383945], 
        DiskBox[{7.863139723331468, 2.889510060381401}, 0.05577520655383945], 
        DiskBox[{7.869717697975075, 2.8867945667840527`}, 
         0.05577520655383945], 
        DiskBox[{7.876298683960474, 2.8840863793183917`}, 
         0.05577520655383945], 
        DiskBox[{7.882882673172775, 2.881385501323832}, 0.05577520655383945], 
        DiskBox[{7.889469657493384, 2.878691936130778}, 0.05577520655383945], 
        DiskBox[{7.896059628800016, 2.876005687060611}, 0.05577520655383945], 
        DiskBox[{7.902652578966698, 2.873326757425697}, 0.05577520655383945], 
        DiskBox[{7.909248499863791, 2.870655150529373}, 0.05577520655383945], 
        DiskBox[{7.9158473833579865`, 2.8679908696659453`}, 
         0.05577520655383945], 
        DiskBox[{7.922449221312325, 2.865333918120691}, 0.05577520655383945], 
        DiskBox[{7.929054005586208, 2.862684299169846}, 0.05577520655383945], 
        DiskBox[{7.935661728035395, 2.860042016080606}, 0.05577520655383945], 
        DiskBox[{7.942272380512032, 2.85740707211112}, 0.05577520655383945], 
        DiskBox[{7.948885954864645, 2.854779470510489}, 0.05577520655383945], 
        DiskBox[{7.955502442938162, 2.852159214518757}, 0.05577520655383945], 
        DiskBox[{7.962121836573914, 2.849546307366915}, 0.05577520655383945], 
        DiskBox[{7.968744127609652, 2.846940752276887}, 0.05577520655383945], 
        DiskBox[{7.975369307879554, 2.8443425524615362`}, 
         0.05577520655383945], 
        DiskBox[{7.981997369214234, 2.841751711124653}, 0.05577520655383945], 
        DiskBox[{7.9886283034407555`, 2.8391682314609543`}, 
         0.05577520655383945], 
        DiskBox[{7.995262102382636, 2.8365921166560817`}, 
         0.05577520655383945], 
        DiskBox[{8.001898757859866, 2.8340233698865944`}, 
         0.05577520655383945], 
        DiskBox[{8.008538261688907, 2.831461994319964}, 0.05577520655383945], 
        DiskBox[{8.015180605682714, 2.8289079931145746`}, 
         0.05577520655383945], 
        DiskBox[{8.021825781650735, 2.8263613694197183`}, 
         0.05577520655383945], 
        DiskBox[{8.028473781398933, 2.823822126375588}, 0.05577520655383945], 
        DiskBox[{8.03512459672978, 2.8212902671132776`}, 0.05577520655383945],
         DiskBox[{8.041778219442284, 2.818765794754774}, 0.05577520655383945],
         DiskBox[{8.048434641331985, 2.816248712412957}, 0.05577520655383945],
         DiskBox[{8.055093854190977, 2.8137390231915926`}, 
         0.05577520655383945], 
        DiskBox[{8.061755849807907, 2.8112367301853327`}, 
         0.05577520655383945], 
        DiskBox[{8.068420619967998, 2.808741836479708}, 0.05577520655383945], 
        DiskBox[{8.075088156453042, 2.8062543451511237`}, 
         0.05577520655383945], 
        DiskBox[{8.081758451041429, 2.8037742592668593`}, 
         0.05577520655383945], 
        DiskBox[{8.118494004649342, 2.7902662954221755`}, 
         0.05577520655383945], 
        DiskBox[{8.168719521114845, 2.772208417180617}, 0.05577520655383945], 
        DiskBox[{8.225821284563686, 2.7522493099862153`}, 
         0.05577520655383945], 
        DiskBox[{8.269613004435712, 2.7373506300975814`}, 
         0.05577520655383945], 
        DiskBox[{8.276359692651468, 2.735086595201966}, 0.05577520655383945], 
        DiskBox[{8.286484428472994, 2.7317045934783097`}, 
         0.05577520655383945], 
        DiskBox[{8.29661478352159, 2.7283394608354747`}, 0.05577520655383945],
         DiskBox[{8.303371461467943, 2.7261054153976128`}, 
         0.05577520655383945], 
        DiskBox[{8.310130616025791, 2.7238788742342086`}, 
         0.05577520655383945], 
        DiskBox[{8.316892238860541, 2.7216598400907674`}, 
         0.05577520655383945], 
        DiskBox[{8.32365632163457, 2.7194483157035396`}, 0.05577520655383945],
         DiskBox[{8.330422856007207, 2.7172443037995144`}, 
         0.05577520655383945], 
        DiskBox[{8.337191833634773, 2.7150478070964166`}, 
         0.05577520655383945], 
        DiskBox[{8.343963246170564, 2.7128588283027053`}, 
         0.05577520655383945], 
        DiskBox[{8.35073708526488, 2.710677370117569}, 0.05577520655383945], 
        DiskBox[{8.357513342565028, 2.7085034352309227`}, 
         0.05577520655383945], 
        DiskBox[{8.364292009715331, 2.7063370263234052`}, 
         0.05577520655383945], 
        DiskBox[{8.371073078357146, 2.704178146066374}, 0.05577520655383945], 
        DiskBox[{8.37785654012886, 2.7020267971219036`}, 0.05577520655383945],
         DiskBox[{8.384642386665917, 2.6998829821427828`}, 
         0.05577520655383945], 
        DiskBox[{8.391430609600816, 2.6977467037725082`}, 
         0.05577520655383945], 
        DiskBox[{8.398221200563126, 2.695617964645286}, 0.05577520655383945], 
        DiskBox[{8.74748436759547, 2.597108064355889}, 0.05577520655383945], 
        DiskBox[{8.754386492380004, 2.595374764223793}, 0.05577520655383945], 
        DiskBox[{8.761290537637876, 2.5936491295676625`}, 
         0.05577520655383945], 
        DiskBox[{8.76819649485584, 2.591931162515345}, 0.05577520655383945], 
        DiskBox[{8.775104355518287, 2.5902208651852323`}, 
         0.05577520655383945], 
        DiskBox[{8.782014111107266, 2.5885182396862607`}, 
         0.05577520655383945], 
        DiskBox[{8.78892575310249, 2.5868232881179063`}, 0.05577520655383945],
         DiskBox[{8.795839272981338, 2.58513601257018}, 0.05577520655383945], 
        DiskBox[{8.80275466221888, 2.5834564151236314`}, 0.05577520655383945],
         DiskBox[{8.809671912287884, 2.5817844978493394`}, 
         0.05577520655383945], 
        DiskBox[{8.816591014658814, 2.580120262808915}, 0.05577520655383945], 
        DiskBox[{8.823511960799856, 2.5784637120544938`}, 
         0.05577520655383945], 
        DiskBox[{8.830434742176923, 2.5768148476287385`}, 
         0.05577520655383945], 
        DiskBox[{8.837359350253664, 2.5751736715648317`}, 
         0.05577520655383945], 
        DiskBox[{8.844285776491471, 2.5735401858864773`}, 
         0.05577520655383945], 
        DiskBox[{8.851214012349502, 2.571914392607896}, 0.05577520655383945], 
        DiskBox[{8.858144049284679, 2.570296293733822}, 0.05577520655383945], 
        DiskBox[{8.865075878751703, 2.5686858912595047`}, 
         0.05577520655383945], 
        DiskBox[{8.872009492203064, 2.5670831871706987`}, 
         0.05577520655383945], 
        DiskBox[{8.878944881089058, 2.5654881834436694`}, 
         0.05577520655383945], 
        DiskBox[{8.885882036857783, 2.5639008820451856`}, 
         0.05577520655383945], 
        DiskBox[{8.892820950955166, 2.562321284932519}, 0.05577520655383945], 
        DiskBox[{8.899761614824959, 2.560749394053442}, 0.05577520655383945], 
        DiskBox[{8.906704019908762, 2.5591852113462217`}, 
         0.05577520655383945], 
        DiskBox[{8.913648157646026, 2.5576287387396235`}, 
         0.05577520655383945], 
        DiskBox[{8.920594019474066, 2.556079978152905}, 0.05577520655383945], 
        DiskBox[{8.927541596828068, 2.554538931495813}, 0.05577520655383945], 
        DiskBox[{8.934490881141107, 2.553005600668583}, 0.05577520655383945], 
        DiskBox[{8.941441863844151, 2.551479987561936}, 0.05577520655383945], 
        DiskBox[{8.948394536366074, 2.5499620940570784`}, 
         0.05577520655383945], 
        DiskBox[{8.955348890133665, 2.548451922025695}, 0.05577520655383945], 
        DiskBox[{8.962304916571654, 2.5469494733299483`}, 
         0.05577520655383945], 
        DiskBox[{8.969262607102673, 2.5454547498224853`}, 
         0.05577520655383945], 
        DiskBox[{8.976221953147334, 2.5439677533464176`}, 
         0.05577520655383945], 
        DiskBox[{8.9831829461242, 2.5424884857353325`}, 0.05577520655383945], 
        DiskBox[{8.990145577449804, 2.5410169488132883`}, 
         0.05577520655383945], 
        DiskBox[{8.99710983853865, 2.5395531443948087`}, 0.05577520655383945],
         DiskBox[{9.004075720803243, 2.5380970742848836`}, 
         0.05577520655383945], 
        DiskBox[{9.011043215654084, 2.5366487402789666`}, 
         0.05577520655383945], 
        DiskBox[{9.018012314499686, 2.5352081441629695`}, 
         0.05577520655383945], 
        DiskBox[{9.024983008746583, 2.533775287713265}, 0.05577520655383945], 
        DiskBox[{9.031955289799344, 2.532350172696681}, 0.05577520655383945], 
        DiskBox[{9.03892914906058, 2.5309328008705014`}, 0.05577520655383945],
         DiskBox[{9.045904577930958, 2.5295231739824597`}, 
         0.05577520655383945], 
        DiskBox[{9.052881567809207, 2.52812129377074}, 0.05577520655383945], 
        DiskBox[{9.05986011009213, 2.526727161963975}, 0.05577520655383945], 
        DiskBox[{9.06684019617462, 2.525340780281242}, 0.05577520655383945], 
        DiskBox[{9.073821817449664, 2.5239621504320624`}, 
         0.05577520655383945], 
        DiskBox[{9.080804965308355, 2.522591274116399}, 0.05577520655383945], 
        DiskBox[{9.087789631139906, 2.521228153024654}, 0.05577520655383945], 
        DiskBox[{9.094775806331654, 2.519872788837665}, 0.05577520655383945], 
        DiskBox[{9.101763482269087, 2.518525183226706}, 0.05577520655383945], 
        DiskBox[{9.10875265033582, 2.517185337853486}, 0.05577520655383945], 
        DiskBox[{9.11574330191365, 2.5158532543701417`}, 0.05577520655383945],
         DiskBox[{9.12273542838253, 2.514528934419241}, 0.05577520655383945], 
        DiskBox[{9.129729021120607, 2.513212379633778}, 0.05577520655383945], 
        DiskBox[{9.136724071504208, 2.5119035916371706`}, 
         0.05577520655383945], 
        DiskBox[{9.14372057090787, 2.510602572043261}, 0.05577520655383945], 
        DiskBox[{9.150718510704342, 2.5093093224563123`}, 
         0.05577520655383945], 
        DiskBox[{9.157717882264595, 2.5080238444710066`}, 
         0.05577520655383945], 
        DiskBox[{9.164718676957836, 2.506746139672442}, 0.05577520655383945], 
        DiskBox[{9.171720886151517, 2.5054762096361323`}, 
         0.05577520655383945], 
        DiskBox[{9.178724501211345, 2.5042140559280046`}, 
         0.05577520655383945], 
        DiskBox[{9.185729513501293, 2.5029596801043965`}, 
         0.05577520655383945], 
        DiskBox[{9.192735914383615, 2.5017130837120565`}, 
         0.05577520655383945], 
        DiskBox[{9.199743695218848, 2.500474268288137}, 0.05577520655383945], 
        DiskBox[{9.206752847365827, 2.4992432353601997`}, 
         0.05577520655383945], 
        DiskBox[{9.213763362181709, 2.4980199864462076`}, 
         0.05577520655383945], 
        DiskBox[{9.220775231021944, 2.496804523054526}, 0.05577520655383945], 
        DiskBox[{9.227788445240337, 2.4955968466839193`}, 
         0.05577520655383945], 
        DiskBox[{9.234802996189025, 2.494396958823552}, 0.05577520655383945], 
        DiskBox[{9.25234516498934, 2.491431323590895}, 0.05577520655383945], 
        DiskBox[{9.269895499096906, 2.488514398623627}, 0.05577520655383945], 
        DiskBox[{9.276917888730688, 2.4873612725591707`}, 
         0.05577520655383945], 
        DiskBox[{9.283941554514174, 2.486215945160085}, 0.05577520655383945], 
        DiskBox[{9.333142219491622, 2.4784171334164036`}, 
         0.05577520655383945], 
        DiskBox[{9.340175782555773, 2.47733424537428}, 0.05577520655383945], 
        DiskBox[{9.34721054376751, 2.476259168361665}, 0.05577520655383945], 
        DiskBox[{9.354246494452395, 2.475191903704215}, 0.05577520655383945], 
        DiskBox[{9.361283625934533, 2.4741324527179556`}, 
         0.05577520655383945], 
        DiskBox[{9.36832192953657, 2.4730808167092757`}, 0.05577520655383945],
         DiskBox[{9.375361396579704, 2.4720369969749267`}, 
         0.05577520655383945], 
        DiskBox[{9.3824020183837, 2.471000994802024}, 0.05577520655383945], 
        DiskBox[{9.389443786266904, 2.4699728114680424`}, 
         0.05577520655383945], 
        DiskBox[{9.396486691546242, 2.468952448240816}, 0.05577520655383945], 
        DiskBox[{9.403530725537237, 2.4679399063785334`}, 
         0.05577520655383945], 
        DiskBox[{9.410575879554028, 2.466935187129743}, 0.05577520655383945], 
        DiskBox[{9.417622144909366, 2.4659382917333446`}, 
         0.05577520655383945], 
        DiskBox[{9.424669512914633, 2.4649492214185917`}, 
         0.05577520655383945], 
        DiskBox[{9.431717974879852, 2.463967977405086}, 0.05577520655383945], 
        DiskBox[{9.459922588493738, 2.460121288417837}, 0.05577520655383945], 
        DiskBox[{9.481087109276432, 2.4573185061652856`}, 
         0.05577520655383945], 
        DiskBox[{9.48814400992248, 2.4563999153091496`}, 0.05577520655383945],
         DiskBox[{9.495201926259275, 2.455489161296252}, 0.05577520655383945],
         DiskBox[{9.60118663328264, 2.44276901294346}, 0.05577520655383945], 
        DiskBox[{9.60825961624673, 2.441983794579645}, 0.05577520655383945], 
        DiskBox[{9.61533346678927, 2.441206430835316}, 0.05577520655383945], 
        DiskBox[{9.622408176187628, 2.440436922669024}, 0.05577520655383945], 
        DiskBox[{9.629483735718111, 2.4396752710296354`}, 
         0.05577520655383945], 
        DiskBox[{9.63656013665598, 2.4389214768563283`}, 0.05577520655383945],
         DiskBox[{9.643637370275458, 2.438175541078592}, 0.05577520655383945],
         DiskBox[{9.650715427849743, 2.4374374646162273`}, 
         0.05577520655383945], 
        DiskBox[{9.657794300651014, 2.4367072483793413`}, 
         0.05577520655383945], 
        DiskBox[{9.664873979950446, 2.4359848932683494`}, 
         0.05577520655383945], 
        DiskBox[{9.671954457018222, 2.435270400173975}, 0.05577520655383945], 
        DiskBox[{9.679035723123535, 2.434563769977246}, 0.05577520655383945], 
        DiskBox[{9.68611776953461, 2.433865003549494}, 0.05577520655383945], 
        DiskBox[{9.69320058751871, 2.433174101752355}, 0.05577520655383945], 
        DiskBox[{9.700284168342147, 2.432491065437768}, 0.05577520655383945], 
        DiskBox[{9.707368503270287, 2.431815895447972}, 0.05577520655383945], 
        DiskBox[{9.714453583567572, 2.4311485926155045`}, 
         0.05577520655383945], 
        DiskBox[{9.721539400497521, 2.4304891577632075`}, 
         0.05577520655383945], 
        DiskBox[{9.728625945322747, 2.4298375917042145`}, 
         0.05577520655383945], 
        DiskBox[{9.735713209304969, 2.429193895241961}, 0.05577520655383945], 
        DiskBox[{9.742801183705009, 2.428558069170177}, 0.05577520655383945], 
        DiskBox[{9.74988985978282, 2.427930114272886}, 0.05577520655383945], 
        DiskBox[{9.771160010669508, 2.4260934843226405`}, 
         0.05577520655383945], 
        DiskBox[{9.77825140604079, 2.4254970217694485`}, 0.05577520655383945],
         DiskBox[{9.785343459376842, 2.424908434165271}, 0.05577520655383945],
         DiskBox[{9.792436161932585, 2.424327722235885}, 0.05577520655383945],
         DiskBox[{9.799529504962143, 2.4237548866973535`}, 
         0.05577520655383945], 
        DiskBox[{9.806623479718848, 2.423189928256031}, 0.05577520655383945], 
        DiskBox[{9.813718077455253, 2.422632847608556}, 0.05577520655383945], 
        DiskBox[{9.820813289423143, 2.4220836454418553`}, 
         0.05577520655383945], 
        DiskBox[{9.827909106873543, 2.4215423224331376`}, 
         0.05577520655383945], 
        DiskBox[{9.835005521056738, 2.421008879249901}, 0.05577520655383945], 
        DiskBox[{9.842102523222271, 2.420483316549922}, 0.05577520655383945], 
        DiskBox[{9.849200104618962, 2.4199656349812626`}, 
         0.05577520655383945], 
        DiskBox[{9.856298256494917, 2.4194558351822675`}, 
         0.05577520655383945], 
        DiskBox[{9.86339697009754, 2.41895391778156}, 0.05577520655383945], 
        DiskBox[{9.870496236673539, 2.418459883398045}, 0.05577520655383945], 
        DiskBox[{9.877596047468941, 2.417973732640907}, 0.05577520655383945], 
        DiskBox[{9.884696393729106, 2.41749546610961}, 0.05577520655383945], 
        DiskBox[{9.891797266698727, 2.4170250843938943`}, 
         0.05577520655383945], 
        DiskBox[{9.898898657621855, 2.4165625880737807`}, 
         0.05577520655383945], 
        DiskBox[{9.906000557741894, 2.4161079777195633`}, 
         0.05577520655383945], 
        DiskBox[{9.913102958301629, 2.4156612538918134`}, 
         0.05577520655383945], 
        DiskBox[{9.92020585054322, 2.4152224171413783`}, 0.05577520655383945],
         DiskBox[{9.927309225708225, 2.414791468009379}, 0.05577520655383945],
         DiskBox[{9.934413075037607, 2.4143684070272107`}, 
         0.05577520655383945], 
        DiskBox[{9.941517389771741, 2.4139532347165424`}, 
         0.05577520655383945], 
        DiskBox[{9.948622161150432, 2.413545951589316}, 0.05577520655383945], 
        DiskBox[{9.95572738041292, 2.4131465581477425`}, 0.05577520655383945],
         DiskBox[{9.962833038797891, 2.4127550548843084`}, 
         0.05577520655383945], 
        DiskBox[{9.969939127543492, 2.412371442281769}, 0.05577520655383945], 
        DiskBox[{9.977045637887338, 2.411995720813148}, 0.05577520655383945], 
        DiskBox[{9.984152561066526, 2.411627890941742}, 0.05577520655383945], 
        DiskBox[{9.991259888317645, 2.411267953121114}, 0.05577520655383945], 
        DiskBox[{9.998367610876778, 2.410915907795098}, 0.05577520655383945], 
        DiskBox[{10.005475719979529`, 2.4105717553977932`}, 
         0.05577520655383945], 
        DiskBox[{10.012584206861023`, 2.410235496353568}, 
         0.05577520655383945], 
        DiskBox[{10.019693062755916`, 2.409907131077058}, 
         0.05577520655383945], 
        DiskBox[{10.026802278898415`, 2.4095866599731623`}, 
         0.05577520655383945], 
        DiskBox[{10.033911846522276`, 2.409274083437049}, 
         0.05577520655383945], 
        DiskBox[{10.041021756860827`, 2.40896940185415}, 0.05577520655383945],
         DiskBox[{10.048132001146971`, 2.408672615600163}, 
         0.05577520655383945], 
        DiskBox[{10.055242570613197`, 2.408383725041049}, 
         0.05577520655383945], 
        DiskBox[{10.0623534564916, 2.4081027305330327`}, 0.05577520655383945],
         DiskBox[{10.069464650013876`, 2.4078296324226054`}, 
         0.05577520655383945], 
        DiskBox[{10.076576142411348`, 2.4075644310465165`}, 
         0.05577520655383945], 
        DiskBox[{10.129920976856818`, 2.405827160543713}, 
         0.05577520655383945], 
        DiskBox[{10.197508742605528`, 2.4042644871367616`}, 
         0.05577520655383945], 
        DiskBox[{10.218855247486797`, 2.4039191500981385`}, 
         0.05577520655383945], 
        DiskBox[{10.225970990141619`, 2.4038198406849816`}, 
         0.05577520655383945], 
        DiskBox[{10.233086838686612`, 2.4037284329505617`}, 
         0.05577520655383945], 
        DiskBox[{10.243760790854097`, 2.4036061372404642`}, 
         0.05577520655383945], 
        DiskBox[{10.354063962397339`, 2.4033835297643407`}, 
         0.05577520655383945], 
        DiskBox[{10.507037450025306`, 2.4062176934444466`}, 
         0.05577520655383945], 
        DiskBox[{10.599484647651675`, 2.4097027681859755`}, 
         0.05577520655383945], 
        DiskBox[{10.68476775916889, 2.4141039246570273`}, 
         0.05577520655383945], 
        DiskBox[{10.730936095748582`, 2.4169622614528317`}, 
         0.05577520655383945], 
        DiskBox[{10.741587314204274`, 2.4176691960492427`}, 
         0.05577520655383945], 
        DiskBox[{10.762886144698651`, 2.4191362842838418`}, 
         0.05577520655383945], 
        DiskBox[{10.787728437255263`, 2.4209375527261576`}, 
         0.05577520655383945], 
        DiskBox[{10.80192082965659, 2.422010193875745}, 0.05577520655383945], 
        DiskBox[{10.809016123778045`, 2.4225583336564664`}, 
         0.05577520655383945], 
        DiskBox[{10.816110804847686`, 2.4231143520098426`}, 
         0.05577520655383945], 
        DiskBox[{10.823204864117189`, 2.4236782482502583`}, 
         0.05577520655383945], 
        DiskBox[{10.830298292839005`, 2.4242500216823837`}, 
         0.05577520655383945], 
        DiskBox[{10.837391082266363`, 2.4248296716011755`}, 
         0.05577520655383945], 
        DiskBox[{10.844483223653276`, 2.425417197291879}, 
         0.05577520655383945], 
        DiskBox[{10.851574708254557`, 2.4260125980300256`}, 
         0.05577520655383945], 
        DiskBox[{10.85866552732583, 2.42661587308144}, 0.05577520655383945], 
        DiskBox[{10.865755672123539`, 2.427227021702234}, 
         0.05577520655383945], 
        DiskBox[{10.872845133904962`, 2.4278460431388122`}, 
         0.05577520655383945], 
        DiskBox[{10.879933903928213`, 2.4284729366278714`}, 
         0.05577520655383945], 
        DiskBox[{10.887021973452267`, 2.429107701396399}, 
         0.05577520655383945], 
        DiskBox[{10.894109333736958`, 2.42975033666168}, 0.05577520655383945],
         DiskBox[{10.901195976042994`, 2.430400841631293}, 
         0.05577520655383945], 
        DiskBox[{10.90828189163197, 2.4310592155031117`}, 
         0.05577520655383945], 
        DiskBox[{10.915367071766378`, 2.4317254574653084`}, 
         0.05577520655383945], 
        DiskBox[{10.922451507709612`, 2.4323995666963523`}, 
         0.05577520655383945], 
        DiskBox[{10.929535190725993`, 2.433081542365013}, 
         0.05577520655383945], 
        DiskBox[{10.93661811208076, 2.433771383630357}, 0.05577520655383945], 
        DiskBox[{10.943700263040096`, 2.4344690896417562`}, 
         0.05577520655383945], 
        DiskBox[{10.950781634871138`, 2.4351746595388812`}, 
         0.05577520655383945], 
        DiskBox[{10.957862218841974`, 2.435888092451707}, 
         0.05577520655383945], 
        DiskBox[{10.964942006221674`, 2.436609387500514}, 
         0.05577520655383945], 
        DiskBox[{10.972020988280283`, 2.437338543795886}, 
         0.05577520655383945], 
        DiskBox[{10.979099156288843`, 2.4380755604387145`}, 
         0.05577520655383945], 
        DiskBox[{10.986176501519395`, 2.4388204365201966`}, 
         0.05577520655383945], 
        DiskBox[{10.993253015245, 2.4395731711218414`}, 0.05577520655383945], 
        DiskBox[{11.00032868873974, 2.440333763315466}, 0.05577520655383945], 
        DiskBox[{11.007403513278739`, 2.441102212163197}, 
         0.05577520655383945], 
        DiskBox[{11.337746128774008`, 4.116168158049847}, 
         0.05577520655383945], 
        DiskBox[{11.343512156824366`, 4.117431602922823}, 
         0.05577520655383945], 
        DiskBox[{11.349276628895845`, 4.118702128074797}, 
         0.05577520655383945], 
        DiskBox[{11.355039536294344`, 4.119979731589539}, 
         0.05577520655383945], 
        DiskBox[{11.360800870328159`, 4.121264411540144}, 
         0.05577520655383945], 
        DiskBox[{11.366560622307919`, 4.122556165989033}, 
         0.05577520655383945], 
        DiskBox[{11.383830299065298`, 4.126473856789592}, 
         0.05577520655383945], 
        DiskBox[{11.403959847894459`, 4.131124875238917}, 
         0.05577520655383945], 
        DiskBox[{11.355465250905299`, 5.78228215399813}, 0.05577520655383945],
         DiskBox[{11.36389865519153, 5.7852003759554425`}, 
         0.05577520655383945], 
        DiskBox[{11.368112301446487`, 5.78666829172322}, 0.05577520655383945],
         DiskBox[{11.372323899547393`, 5.788142073559056}, 
         0.05577520655383945], 
        DiskBox[{11.376533441327751`, 5.789621718605213}, 
         0.05577520655383945], 
        DiskBox[{11.399648799829508`, 5.797864442459353}, 
         0.05577520655383945], 
        DiskBox[{11.422700352159886`, 5.806283957312379}, 
         0.05577520655383945], 
        DiskBox[{11.426884582573988`, 5.80783373384624}, 0.05577520655383945],
         DiskBox[{11.43106665087166, 5.809389335407313}, 0.05577520655383945],
         DiskBox[{11.435246548943661`, 5.810950758979209}, 
         0.05577520655383945], 
        DiskBox[{11.441512309149935`, 5.813303803981215}, 
         0.05577520655383945], 
        DiskBox[{11.447773140776485`, 5.815669931426646}, 
         0.05577520655383945], 
        DiskBox[{11.451944276937823`, 5.81725461265225}, 0.05577520655383945],
         DiskBox[{11.456113202390734`, 5.818845100637514}, 
         0.05577520655383945], 
        DiskBox[{11.460279909051465`, 5.8204413922984}, 0.05577520655383945], 
        DiskBox[{11.464444388840565`, 5.822043484539621}, 
         0.05577520655383945], 
        DiskBox[{11.4686066336829, 5.823651374254639}, 0.05577520655383945], 
        DiskBox[{11.472766635507668`, 5.825265058325677}, 
         0.05577520655383945], 
        DiskBox[{11.47692438624842, 5.826884533623721}, 0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{9.818269775626112, 7.287655869413179}, 
          0.05577520655383945]}, 
        DiskBox[{6.959078598990364, 2.4291688709190034`}, 
         0.05577520655383945], 
        DiskBox[{6.969714717740356, 2.4235931483086297`}, 
         0.05577520655383945], 
        DiskBox[{6.976810616793813, 2.4198858455683734`}, 
         0.05577520655383945], 
        DiskBox[{6.983910628215989, 2.416186424696167}, 0.05577520655383945], 
        DiskBox[{6.991014743251995, 2.412494890253697}, 0.05577520655383945], 
        DiskBox[{7.810504752220147, 2.0499772244824914`}, 
         0.05577520655383945], 
        DiskBox[{7.818015011601361, 2.047203800423384}, 0.05577520655383945], 
        DiskBox[{7.825528346077976, 2.0444387177795456`}, 
         0.05577520655383945], 
        DiskBox[{7.8330447463854425`, 2.0416819799605523`}, 
         0.05577520655383945], 
        DiskBox[{7.840564203255427, 2.038933590365681}, 0.05577520655383945], 
        DiskBox[{7.848086707415829, 2.03619355238392}, 0.05577520655383945], 
        DiskBox[{7.8556122495907905`, 2.0334618693939612`}, 
         0.05577520655383945], 
        DiskBox[{7.863140820500707, 2.0307385447641897`}, 
         0.05577520655383945], 
        DiskBox[{7.8706724108622375`, 2.028023581852687}, 
         0.05577520655383945], 
        DiskBox[{7.878207011388323, 2.0253169840072216`}, 
         0.05577520655383945], 
        DiskBox[{7.8857446127881925`, 2.0226187545652445`}, 
         0.05577520655383945], 
        DiskBox[{7.89328520576736, 2.0199288968539015`}, 0.05577520655383945],
         DiskBox[{7.900828781027668, 2.017247414189998}, 0.05577520655383945],
         DiskBox[{7.908375329267278, 2.0145743098800217`}, 
         0.05577520655383945], 
        DiskBox[{7.915924841180679, 2.0119095872201287`}, 
         0.05577520655383945], 
        DiskBox[{7.923477307458715, 2.009253249496137}, 0.05577520655383945], 
        DiskBox[{7.931032718788577, 2.0066052999835264`}, 
         0.05577520655383945], 
        DiskBox[{7.938591065853832, 2.003965741947434}, 0.05577520655383945], 
        DiskBox[{7.946152339334425, 2.0013345786426493`}, 
         0.05577520655383945], 
        DiskBox[{7.953716529906689, 1.9987118133136113`}, 
         0.05577520655383945], 
        DiskBox[{7.9612836282433666`, 1.9960974491943997`}, 
         0.05577520655383945], 
        DiskBox[{7.968853625013608, 1.9934914895087399`}, 
         0.05577520655383945], 
        DiskBox[{7.976426510882995, 1.990893937469992}, 0.05577520655383945], 
        DiskBox[{7.984002276513542, 1.9883047962811489`}, 
         0.05577520655383945], 
        DiskBox[{7.991580912563717, 1.9857240691348297`}, 
         0.05577520655383945], 
        DiskBox[{7.999162409688445, 1.983151759213281}, 0.05577520655383945], 
        DiskBox[{8.006746758539125, 1.9805878696883736`}, 
         0.05577520655383945], 
        DiskBox[{8.021923974006372, 1.9754853644640162`}, 
         0.05577520655383945], 
        DiskBox[{8.029516821908192, 1.972946755056375}, 0.05577520655383945], 
        DiskBox[{8.03711248410651, 1.970416578628969}, 0.05577520655383945], 
        DiskBox[{9.108065554394276, 1.7033684134339095`}, 
         0.05577520655383945], 
        DiskBox[{9.115959902660771, 1.70203606872174}, 0.05577520655383945], 
        DiskBox[{9.123855725551232, 1.700712491044678}, 0.05577520655383945], 
        DiskBox[{9.13175301332947, 1.699397682034804}, 0.05577520655383945], 
        DiskBox[{9.337564733937421, 1.6682955396127888`}, 
         0.05577520655383945], 
        DiskBox[{9.345497887090675, 1.667218061988061}, 0.05577520655383945], 
        DiskBox[{9.353432231828922, 1.666149394331871}, 0.05577520655383945], 
        DiskBox[{9.361367758368475, 1.6650895379619763`}, 
         0.05577520655383945], 
        DiskBox[{9.369304456924183, 1.6640384941852622`}, 
         0.05577520655383945], 
        DiskBox[{9.377242317709454, 1.6629962642977514`}, 
         0.05577520655383945], 
        DiskBox[{10.055168235302828`, 1.6067334624350593`}, 
         0.05577520655383945], 
        DiskBox[{10.063169307123237`, 1.606452879631946}, 
         0.05577520655383945], 
        DiskBox[{10.071170685581512`, 1.6061811817257734`}, 
         0.05577520655383945], 
        DiskBox[{10.0791723608113, 1.605918369051568}, 0.05577520655383945], 
        DiskBox[{10.087174322945891`, 1.605664441933401}, 
         0.05577520655383945], 
        DiskBox[{10.095176562118212`, 1.605419400684383}, 
         0.05577520655383945], 
        DiskBox[{10.103179068460854`, 1.6051832456066712`}, 
         0.05577520655383945], 
        DiskBox[{10.111181832106077`, 1.6049559769914632`}, 
         0.05577520655383945], 
        DiskBox[{10.119184843185822`, 1.6047375951189995`}, 
         0.05577520655383945], 
        DiskBox[{10.12718809183173, 1.6045281002585625`}, 
         0.05577520655383945], 
        DiskBox[{10.135191568175141`, 1.6043274926684772`}, 
         0.05577520655383945], 
        DiskBox[{10.143195262347122`, 1.6041357725961092`}, 
         0.05577520655383945], 
        DiskBox[{10.151199164478468`, 1.603952940277864}, 
         0.05577520655383945], 
        DiskBox[{10.159203264699716`, 1.603778995939189}, 
         0.05577520655383945], 
        DiskBox[{10.16720755314117, 1.6036139397945712`}, 
         0.05577520655383945], 
        DiskBox[{10.175212019932877`, 1.6034577720475394`}, 
         0.05577520655383945], 
        DiskBox[{10.183216655204687`, 1.6033104928906612`}, 
         0.05577520655383945], 
        DiskBox[{10.191221449086234`, 1.6031721025055417`}, 
         0.05577520655383945], 
        DiskBox[{10.199226391706958`, 1.6030426010628291`}, 
         0.05577520655383945], 
        DiskBox[{10.223242013295906`, 1.6027074319311865`}, 
         0.05577520655383945], 
        DiskBox[{10.231247452164245`, 1.602613487745348}, 
         0.05577520655383945], 
        DiskBox[{10.239252990416448`, 1.6025284331907343`}, 
         0.05577520655383945], 
        DiskBox[{10.247258618181037`, 1.6024522683722235`}, 
         0.05577520655383945], 
        DiskBox[{10.255264325586426`, 1.6023849933837324`}, 
         0.05577520655383945], 
        DiskBox[{10.263270102760924`, 1.6023266083082186`}, 
         0.05577520655383945], 
        DiskBox[{10.271275939832758`, 1.6022771132176743`}, 
         0.05577520655383945], 
        DiskBox[{10.283284786153335`, 1.6022195394341843`}, 
         0.05577520655383945], 
        DiskBox[{10.295293711713517`, 1.6021819684113616`}, 
         0.05577520655383945], 
        DiskBox[{10.311305678135435`, 1.6021629892919211`}, 
         0.05577520655383945], 
        DiskBox[{10.327317647219642`, 1.6021795709084188`}, 
         0.05577520655383945], 
        DiskBox[{10.34332953998993, 1.6022317131790684`}, 
         0.05577520655383945], 
        DiskBox[{10.359341277470469`, 1.6023194158466882`}, 
         0.05577520655383945], 
        DiskBox[{10.367347063297334`, 1.6023766022010326`}, 
         0.05577520655383945], 
        DiskBox[{10.375352780686192`, 1.6024426784787007`}, 
         0.05577520655383945], 
        DiskBox[{10.383358419765347`, 1.6025176445982137`}, 
         0.05577520655383945], 
        DiskBox[{10.391363970663193`, 1.6026015004671335`}, 
         0.05577520655383945], 
        DiskBox[{10.399369423508237`, 1.6026942459820583`}, 
         0.05577520655383945], 
        DiskBox[{10.407374768429104`, 1.6027958810286256`}, 
         0.05577520655383945], 
        DiskBox[{10.415379995554556`, 1.6029064054815123`}, 
         0.05577520655383945], 
        DiskBox[{10.423385095013495`, 1.603025819204431}, 
         0.05577520655383945], 
        DiskBox[{10.431390056934989`, 1.6031541220501353`}, 
         0.05577520655383945], 
        DiskBox[{10.439394871448263`, 1.6032913138604172`}, 
         0.05577520655383945], 
        DiskBox[{10.447399528682736`, 1.6034373944661091`}, 
         0.05577520655383945], 
        DiskBox[{10.455404018768014`, 1.6035923636870812`}, 
         0.05577520655383945], 
        DiskBox[{10.463408331833909`, 1.603756221332243}, 
         0.05577520655383945], 
        DiskBox[{10.471412458010457`, 1.603928967199547}, 
         0.05577520655383945], 
        DiskBox[{10.47941638742793, 1.6041106010759822`}, 
         0.05577520655383945], 
        DiskBox[{10.487420110216808`, 1.604301122737577}, 
         0.05577520655383945], 
        DiskBox[{10.507428448422733`, 1.6048163093829615`}, 
         0.05577520655383945], 
        DiskBox[{10.527435279318677`, 1.605387039216919}, 
         0.05577520655383945], 
        DiskBox[{10.539438590204846`, 1.6057561360358497`}, 
         0.05577520655383945], 
        DiskBox[{10.551441269649226`, 1.6061452258033997`}, 
         0.05577520655383945], 
        DiskBox[{10.55944268869966, 1.6064157256446405`}, 
         0.05577520655383945], 
        DiskBox[{10.567443802442584`, 1.6066951104286362`}, 
         0.05577520655383945], 
        DiskBox[{10.575444601011979`, 1.6069833798108828`}, 
         0.05577520655383945], 
        DiskBox[{10.583445074542206`, 1.6072805334359233`}, 
         0.05577520655383945], 
        DiskBox[{10.591445213168042`, 1.6075865709373414`}, 
         0.05577520655383945], 
        DiskBox[{10.59944500702465, 1.607901491937767}, 0.05577520655383945], 
        DiskBox[{10.607444446247646`, 1.6082252960488788`}, 
         0.05577520655383945], 
        DiskBox[{10.615443520973066`, 1.6085579828713996`}, 
         0.05577520655383945], 
        DiskBox[{10.623442221337406`, 1.6088995519950986`}, 
         0.05577520655383945], 
        DiskBox[{10.631440537477618`, 1.6092500029987944`}, 
         0.05577520655383945], 
        DiskBox[{10.639438459531126`, 1.6096093354503518`}, 
         0.05577520655383945], 
        DiskBox[{10.647435977635848`, 1.6099775489066852`}, 
         0.05577520655383945], 
        DiskBox[{10.65543308193019, 1.610354642913757}, 0.05577520655383945], 
        DiskBox[{10.663429762553074`, 1.6107406170065808`}, 
         0.05577520655383945], 
        DiskBox[{10.671426009643945`, 1.6111354707092191`}, 
         0.05577520655383945], 
        DiskBox[{10.679421813342781`, 1.6115392035347815`}, 
         0.05577520655383945], 
        DiskBox[{10.687417163790112`, 1.6119518149854386`}, 
         0.05577520655383945], 
        DiskBox[{10.695412051127011`, 1.6123733045524027`}, 
         0.05577520655383945], 
        DiskBox[{10.707403492235336`, 1.6130221842310224`}, 
         0.05577520655383945], 
        DiskBox[{10.71939383589462, 1.6136910366991044`}, 
         0.05577520655383945], 
        DiskBox[{10.731383048838463`, 1.6143798601009607`}, 
         0.05577520655383945], 
        DiskBox[{10.743371097803607`, 1.6150886525254968`}, 
         0.05577520655383945], 
        DiskBox[{10.751362467367361`, 1.615572273741182}, 
         0.05577520655383945], 
        DiskBox[{10.759353294970936`, 1.6160647686088545`}, 
         0.05577520655383945], 
        DiskBox[{10.767343570760994`, 1.6165661365212296`}, 
         0.05577520655383945], 
        DiskBox[{10.775333284884876`, 1.6170763768600809`}, 
         0.05577520655383945], 
        DiskBox[{10.79131098872696, 1.6181234722895974`}, 
         0.05577520655383945], 
        DiskBox[{10.799298958743346`, 1.6186603260891097`}, 
         0.05577520655383945], 
        DiskBox[{10.807286327689969`, 1.6192060497327923`}, 
         0.05577520655383945], 
        DiskBox[{10.815273085717754`, 1.619760642547722}, 
         0.05577520655383945], 
        DiskBox[{10.823259222978379`, 1.6203241038500424`}, 
         0.05577520655383945], 
        DiskBox[{10.831244729624288`, 1.6208964329449573`}, 
         0.05577520655383945], 
        DiskBox[{10.84322178565095, 1.6217715521516798`}, 
         0.05577520655383945], 
        DiskBox[{10.855197367409906`, 1.6226666198733328`}, 
         0.05577520655383945], 
        DiskBox[{11.549064340502412`, 3.342514751635023}, 
         0.05577520655383945], 
        DiskBox[{11.555780329284447`, 3.34403829882341}, 0.05577520655383945],
         DiskBox[{11.562494441940807`, 3.3455700927369305`}, 
         0.05577520655383945], 
        DiskBox[{11.569206668345124`, 3.3471101310653006`}, 
         0.05577520655383945], 
        DiskBox[{11.575916998373913`, 3.348658411485813}, 
         0.05577520655383945], 
        DiskBox[{11.585978915574827`, 3.3509962809278084`}, 
         0.05577520655383945], 
        DiskBox[{11.61109552608046, 5.023065706557577}, 0.05577520655383945], 
        DiskBox[{11.61637020317856, 5.024878582221272}, 0.05577520655383945], 
        DiskBox[{11.621642350738174`, 5.026698801101215}, 
         0.05577520655383945], 
        DiskBox[{11.647964787828249`, 5.035909919714343}, 
         0.05577520655383945], 
        DiskBox[{11.653221543647913`, 5.037774123274495}, 
         0.05577520655383945], 
        DiskBox[{11.671599639333822`, 5.044356442797801}, 
         0.05577520655383945], 
        DiskBox[{11.692563602446562`, 5.051988665983814}, 
         0.05577520655383945], 
        DiskBox[{11.716096825726513`, 5.060714338447621}, 
         0.05577520655383945], 
        DiskBox[{11.721318975403141`, 5.062673391641422}, 
         0.05577520655383945], 
        DiskBox[{11.726538392040387`, 5.064639714765454}, 
         0.05577520655383945], 
        DiskBox[{11.443573267683107`, 6.691807714165314}, 
         0.05577520655383945], 
        DiskBox[{11.62528343655102, 6.799319805067546}, 0.05577520655383945], 
        DiskBox[{11.66954628186046, 6.828910684504702}, 0.05577520655383945], 
        DiskBox[{11.675398114949713`, 6.832929996334662}, 
         0.05577520655383945], 
        DiskBox[{11.685610161157248`, 6.84000532397144}, 0.05577520655383945],
         DiskBox[{11.754632396641796`, 6.889931330880305}, 
         0.05577520655383945], 
        DiskBox[{11.817695983734934`, 6.938931351377337}, 
         0.05577520655383945], 
        DiskBox[{11.823222168443541`, 6.943387818661774}, 
         0.05577520655383945], 
        DiskBox[{11.839721398933065`, 6.956854893969313}, 
         0.05577520655383945], 
        DiskBox[{11.868305547212389`, 6.980772190201956}, 
         0.05577520655383945], 
        DiskBox[{11.887154097009018`, 6.996962083391309}, 
         0.05577520655383945], 
        DiskBox[{11.897849220606151`, 7.00630066807081}, 0.05577520655383945],
         DiskBox[{11.913787991873136`, 7.020426612095337}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{10.310247556049253`, 8.010816537836144}, 
          0.05577520655383945]}, 
        DiskBox[{6.5826119417250855`, 1.7220463744304473`}, 
         0.05577520655383945], 
        DiskBox[{6.590487106249128, 1.7179096491499726`}, 
         0.05577520655383945], 
        DiskBox[{7.532578008932136, 1.2986528670799284`}, 
         0.05577520655383945], 
        DiskBox[{7.54927089099639, 1.2924989707433223`}, 0.05577520655383945],
         DiskBox[{7.557622446893575, 1.2894359287222175`}, 
         0.05577520655383945], 
        DiskBox[{10.240082304444236`, 0.8014029158462961}, 
         0.05577520655383945], 
        DiskBox[{10.257872842866332`, 0.8012632935529584}, 
         0.05577520655383945], 
        DiskBox[{10.266768217390592`, 0.801208299007909}, 
         0.05577520655383945], 
        DiskBox[{10.275663647498732`, 0.8011631822917504}, 
         0.05577520655383945], 
        DiskBox[{10.28455912222196, 0.8011279434601128}, 0.05577520655383945],
         DiskBox[{10.306797932237922`, 0.8010830623809895}, 
         0.05577520655383945], 
        DiskBox[{10.320141247888383`, 0.8010857676651355}, 
         0.05577520655383945], 
        DiskBox[{10.342380037877293`, 0.8011396663339898}, 
         0.05577520655383945], 
        DiskBox[{10.35572320988462, 0.8012016393062513}, 0.05577520655383945],
         DiskBox[{10.515821191474044`, 0.8036787642653884}, 
         0.05577520655383945], 
        DiskBox[{10.524713724723226`, 0.8039102048389157}, 
         0.05577520655383945], 
        DiskBox[{10.53360599548853, 0.8041515199096647}, 0.05577520655383945],
         DiskBox[{10.542497992805066`, 0.8044027091800707}, 
         0.05577520655383945], 
        DiskBox[{10.560281123233967`, 0.8049347090687444}, 
         0.05577520655383945], 
        DiskBox[{10.569172234418286`, 0.8052155190310106}, 
         0.05577520655383945], 
        DiskBox[{10.746913245904347`, 0.8129044751170973}, 
         0.05577520655383945], 
        DiskBox[{10.75579539206167, 0.8133925242609212}, 0.05577520655383945],
         DiskBox[{10.773558031145583`, 0.8143982103488572}, 
         0.05577520655383945], 
        DiskBox[{10.782438502169397`, 0.8149158460528767}, 
         0.05577520655383945], 
        DiskBox[{10.897827835141644`, 0.8225422055735381}, 
         0.05577520655383945], 
        DiskBox[{10.906699186116015`, 0.8231978306313064}, 
         0.05577520655383945], 
        DiskBox[{11.76416541906283, 2.5699747160287085`}, 
         0.05577520655383945], 
        DiskBox[{11.771829998398434`, 2.5717630104137656`}, 
         0.05577520655383945], 
        DiskBox[{11.927801749804555`, 4.285195485833846}, 
         0.05577520655383945], 
        DiskBox[{11.9341036021743, 4.287450089458022}, 0.05577520655383945], 
        DiskBox[{11.94040230890467, 4.289713466209024}, 0.05577520655383945], 
        DiskBox[{11.946697857782164`, 4.291985611698047}, 
         0.05577520655383945], 
        DiskBox[{11.952990236599396`, 4.294266521519292}, 
         0.05577520655383945], 
        DiskBox[{11.95927943315513, 4.29655619124996}, 0.05577520655383945], 
        DiskBox[{11.965565435254314`, 4.29885461645027}, 0.05577520655383945],
         DiskBox[{11.971848230708053`, 4.301161792663454}, 
         0.05577520655383945], 
        DiskBox[{11.631895919988395`, 5.89210676209719}, 0.05577520655383945],
         DiskBox[{11.63620702664248, 5.894059669248225}, 0.05577520655383945],
         DiskBox[{11.640515244138774`, 5.8960189417989675`}, 
         0.05577520655383945], 
        DiskBox[{11.644820563078696`, 5.897984575475171}, 
         0.05577520655383945], 
        DiskBox[{11.649122974069986`, 5.89995656598871}, 0.05577520655383945],
         DiskBox[{11.65342246772673, 5.901934909037596}, 0.05577520655383945],
         DiskBox[{11.65771903466938, 5.903919600305979}, 0.05577520655383945],
         DiskBox[{11.662012665524768`, 5.90591063546416}, 
         0.05577520655383945], 
        DiskBox[{11.666303350926139`, 5.907908010168601}, 
         0.05577520655383945], 
        DiskBox[{11.670591081513153`, 5.909911720061934}, 
         0.05577520655383945], 
        DiskBox[{11.674875847931926`, 5.91192176077297}, 0.05577520655383945],
         DiskBox[{11.679157640835033`, 5.913938127916712}, 
         0.05577520655383945], 
        DiskBox[{11.683436450881542`, 5.915960817094357}, 
         0.05577520655383945], 
        DiskBox[{11.687712268737023`, 5.917989823893313}, 
         0.05577520655383945], 
        DiskBox[{11.691985085073577`, 5.920025143887206}, 
         0.05577520655383945], 
        DiskBox[{11.696254890569852`, 5.922066772635887}, 
         0.05577520655383945], 
        DiskBox[{11.700521675911066`, 5.924114705685446}, 
         0.05577520655383945], 
        DiskBox[{11.70478543178902, 5.926168938568221}, 0.05577520655383945], 
        DiskBox[{11.70904614890213, 5.928229466802804}, 0.05577520655383945], 
        DiskBox[{11.713303817955438`, 5.930296285894055}, 
         0.05577520655383945], 
        DiskBox[{11.71755842966064, 5.93236939133311}, 0.05577520655383945], 
        DiskBox[{11.721809974736093`, 5.934448778597392}, 
         0.05577520655383945], 
        DiskBox[{11.726058443906851`, 5.936534443150617}, 
         0.05577520655383945], 
        DiskBox[{11.730303827904677`, 5.938626380442807}, 
         0.05577520655383945], 
        DiskBox[{11.734546117468065`, 5.9407245859103055`}, 
         0.05577520655383945], 
        DiskBox[{11.738785303342256`, 5.942829054975775}, 
         0.05577520655383945], 
        DiskBox[{11.743021376279268`, 5.944939783048216}, 
         0.05577520655383945], 
        DiskBox[{11.747254327037902`, 5.9470567655229765`}, 
         0.05577520655383945], 
        DiskBox[{11.751484146383778`, 5.949179997781757}, 
         0.05577520655383945], 
        DiskBox[{11.755710825089341`, 5.951309475192625}, 
         0.05577520655383945], 
        DiskBox[{11.759934353933891`, 5.953445193110025}, 
         0.05577520655383945], 
        DiskBox[{11.764154723703603`, 5.955587146874787}, 
         0.05577520655383945], 
        DiskBox[{11.768371925191534`, 5.957735331814137}, 
         0.05577520655383945], 
        DiskBox[{11.772585949197662`, 5.959889743241707}, 
         0.05577520655383945], 
        DiskBox[{11.776796786528891`, 5.962050376457546}, 
         0.05577520655383945], 
        DiskBox[{11.781004427999083`, 5.964217226748129}, 
         0.05577520655383945], 
        DiskBox[{11.785208864429062`, 5.966390289386371}, 
         0.05577520655383945], 
        DiskBox[{11.789410086646654`, 5.968569559631631}, 
         0.05577520655383945], 
        DiskBox[{11.793608085486692`, 5.970755032729729}, 
         0.05577520655383945], 
        DiskBox[{11.79780285179104, 5.972946703912949}, 0.05577520655383945], 
        DiskBox[{11.80199437640862, 5.975144568400058}, 0.05577520655383945], 
        DiskBox[{11.806182650195417`, 5.977348621396308}, 
         0.05577520655383945], 
        DiskBox[{11.810367664014517`, 5.979558858093455}, 
         0.05577520655383945], 
        DiskBox[{11.81454940873611, 5.981775273669761}, 0.05577520655383945], 
        DiskBox[{11.818727875237522`, 5.983997863290011}, 
         0.05577520655383945], 
        DiskBox[{11.82290305440323, 5.986226622105519}, 0.05577520655383945], 
        DiskBox[{11.82707493712488, 5.988461545254143}, 0.05577520655383945], 
        DiskBox[{11.831243514301315`, 5.990702627860291}, 
         0.05577520655383945], 
        DiskBox[{11.835408776838584`, 5.992949865034934}, 
         0.05577520655383945], 
        DiskBox[{11.839570715649966`, 5.995203251875617}, 
         0.05577520655383945], 
        DiskBox[{11.843729321655998`, 5.997462783466471}, 
         0.05577520655383945], 
        DiskBox[{11.84788458578448, 5.99972845487822}, 0.05577520655383945], 
        DiskBox[{11.852036498970506`, 6.0020002611681935`}, 
         0.05577520655383945], 
        DiskBox[{11.85618505215648, 6.004278197380337}, 0.05577520655383945], 
        DiskBox[{11.860330236292139`, 6.006562258545227}, 
         0.05577520655383945], 
        DiskBox[{11.864472042334562`, 6.008852439680074}, 
         0.05577520655383945], 
        DiskBox[{11.868610461248206`, 6.011148735788738}, 
         0.05577520655383945], 
        DiskBox[{11.87274548400491, 6.013451141861741}, 0.05577520655383945], 
        DiskBox[{11.876877101583927`, 6.015759652876275}, 
         0.05577520655383945], 
        DiskBox[{11.881005304971936`, 6.018074263796212}, 
         0.05577520655383945], 
        DiskBox[{11.885130085163066`, 6.020394969572118}, 
         0.05577520655383945], 
        DiskBox[{11.889251433158911`, 6.022721765141265}, 
         0.05577520655383945], 
        DiskBox[{11.893369339968558`, 6.025054645427637}, 
         0.05577520655383945], 
        DiskBox[{11.897483796608592`, 6.027393605341944}, 
         0.05577520655383945], 
        DiskBox[{11.901594794103135`, 6.029738639781633}, 
         0.05577520655383945], 
        DiskBox[{11.905702323483847`, 6.032089743630902}, 
         0.05577520655383945], 
        DiskBox[{11.90980637578996, 6.034446911760705}, 0.05577520655383945], 
        DiskBox[{11.913906942068287`, 6.036810139028766}, 
         0.05577520655383945], 
        DiskBox[{11.918004013373247`, 6.039179420279596}, 
         0.05577520655383945], 
        DiskBox[{11.922097580766886`, 6.041554750344492}, 
         0.05577520655383945], 
        DiskBox[{11.926187635318891`, 6.04393612404156}, 0.05577520655383945],
         DiskBox[{11.930274168106614`, 6.04632353617572}, 
         0.05577520655383945], 
        DiskBox[{11.934357170215089`, 6.048716981538718}, 
         0.05577520655383945], 
        DiskBox[{11.938436632737051`, 6.05111645490914}, 0.05577520655383945],
         DiskBox[{11.942512546772962`, 6.053521951052419}, 
         0.05577520655383945], 
        DiskBox[{11.946584903431019`, 6.055933464720853}, 
         0.05577520655383945], 
        DiskBox[{11.950653693827183`, 6.05835099065361}, 0.05577520655383945],
         DiskBox[{11.954718909085194`, 6.0607745235767405`}, 
         0.05577520655383945], 
        DiskBox[{11.95878054033659, 6.063204058203193}, 0.05577520655383945], 
        DiskBox[{11.962838578720735`, 6.065639589232823}, 
         0.05577520655383945], 
        DiskBox[{11.966893015384818`, 6.068081111352402}, 
         0.05577520655383945], 
        DiskBox[{11.970943841483898`, 6.070528619235635}, 
         0.05577520655383945], 
        DiskBox[{11.9749910481809, 6.072982107543167}, 0.05577520655383945], 
        DiskBox[{11.979034626646655`, 6.075441570922595}, 
         0.05577520655383945], 
        DiskBox[{11.983074568059902`, 6.077907004008484}, 
         0.05577520655383945], 
        DiskBox[{11.987110863607317`, 6.080378401422374}, 
         0.05577520655383945], 
        DiskBox[{11.991143504483528`, 6.082855757772795}, 
         0.05577520655383945], 
        DiskBox[{11.99517248189114, 6.0853390676552745`}, 
         0.05577520655383945], 
        DiskBox[{11.999197787040744`, 6.087828325652356}, 
         0.05577520655383945], 
        DiskBox[{12.003219411150948`, 6.090323526333602}, 
         0.05577520655383945], 
        DiskBox[{12.00723734544828, 6.09282466425555}, 0.05577520655383945], 
        DiskBox[{12.011251581167638`, 6.095331733961979}, 
         0.05577520655383945], 
        DiskBox[{12.01526210955167, 6.097844729983532}, 0.05577520655383945], 
        DiskBox[{12.019268921851216`, 6.100363646837989}, 
         0.05577520655383945], 
        DiskBox[{12.025272153523296`, 6.104153111657226}, 
         0.05577520655383945], 
        DiskBox[{12.031266974873077`, 6.107955867382899}, 
         0.05577520655383945], 
        DiskBox[{12.035258835505521`, 6.1104984124886155`}, 
         0.05577520655383945], 
        DiskBox[{12.039246936429674`, 6.113046850822625}, 
         0.05577520655383945], 
        DiskBox[{12.043231268945298`, 6.115601176825388}, 
         0.05577520655383945], 
        DiskBox[{12.047211824360389`, 6.118161384924521}, 
         0.05577520655383945], 
        DiskBox[{12.05118859399117, 6.120727469534809}, 0.05577520655383945], 
        DiskBox[{12.055161569162133`, 6.123299425058216}, 
         0.05577520655383945], 
        DiskBox[{12.05913074120604, 6.125877245883897}, 0.05577520655383945], 
        DiskBox[{12.063096101463957`, 6.128460926388216}, 
         0.05577520655383945], 
        DiskBox[{12.067057641285261`, 6.13105046093475}, 0.05577520655383945],
         DiskBox[{12.071015352027663`, 6.133645843874305}, 
         0.05577520655383945], 
        DiskBox[{12.074969225057231`, 6.1362470695449325`}, 
         0.05577520655383945], 
        DiskBox[{12.0789192517484, 6.138854132271932}, 0.05577520655383945], 
        DiskBox[{12.082865423484002`, 6.141467026367874}, 
         0.05577520655383945], 
        DiskBox[{12.086807731655274`, 6.144085746132603}, 
         0.05577520655383945], 
        DiskBox[{12.090746167661882`, 6.146710285853262}, 
         0.05577520655383945], 
        DiskBox[{12.094680722911942`, 6.149340639804288}, 
         0.05577520655383945], 
        DiskBox[{12.098611388822036`, 6.151976802247442}, 
         0.05577520655383945], 
        DiskBox[{12.102538156817227`, 6.15461876743181}, 0.05577520655383945],
         DiskBox[{12.106461018331085`, 6.157266529593817}, 
         0.05577520655383945], 
        DiskBox[{12.1103799648057, 6.159920082957246}, 0.05577520655383945], 
        DiskBox[{12.114294987691705`, 6.162579421733243}, 
         0.05577520655383945], 
        DiskBox[{12.118206078448292`, 6.165244540120334}, 
         0.05577520655383945], 
        DiskBox[{12.122113228543197`, 6.167915432304416}, 
         0.05577520655383945], 
        DiskBox[{12.12601642945285, 6.170592092458853}, 0.05577520655383945], 
        DiskBox[{12.1299156726622, 6.173274514744362}, 0.05577520655383945], 
        DiskBox[{12.133810949664866`, 6.175962693309111}, 
         0.05577520655383945], 
        DiskBox[{12.137702251963109`, 6.178656622288709}, 
         0.05577520655383945], 
        DiskBox[{12.141589571067875`, 6.181356295806225}, 
         0.05577520655383945], 
        DiskBox[{12.145472898498792`, 6.184061707972193}, 
         0.05577520655383945], 
        DiskBox[{12.149352225784193`, 6.186772852884625}, 
         0.05577520655383945], 
        DiskBox[{12.16675947006063, 6.199043788852808}, 0.05577520655383945], 
        DiskBox[{12.184084771314383`, 6.211430150679499}, 
         0.05577520655383945], 
        DiskBox[{12.187923633132103`, 6.214198295702421}, 
         0.05577520655383945], 
        DiskBox[{12.2032380692523, 6.225327485240996}, 0.05577520655383945], 
        DiskBox[{12.218486486944812`, 6.2365469581047215`}, 
         0.05577520655383945], 
        DiskBox[{12.222288213565733`, 6.23936588726723}, 0.05577520655383945],
         DiskBox[{12.226085772464877`, 6.242190428527506}, 
         0.05577520655383945], 
        DiskBox[{12.229879155357686`, 6.245020575723679}, 
         0.05577520655383945], 
        DiskBox[{12.233668353968717`, 6.247856322681647}, 
         0.05577520655383945], 
        DiskBox[{12.237453360031651`, 6.250697663215094}, 
         0.05577520655383945], 
        DiskBox[{12.24123416528932, 6.2535445911255}, 0.05577520655383945], 
        DiskBox[{12.245010761493717`, 6.256397100202157}, 
         0.05577520655383945], 
        DiskBox[{12.248783140406015`, 6.259255184222178}, 
         0.05577520655383945], 
        DiskBox[{12.252551293796593`, 6.262118836950522}, 
         0.05577520655383945], 
        DiskBox[{12.256315213445042`, 6.264988052139991}, 
         0.05577520655383945], 
        DiskBox[{12.260074891140196`, 6.267862823531255}, 
         0.05577520655383945], 
        DiskBox[{12.265706436081338`, 6.27218538477441}, 0.05577520655383945],
         DiskBox[{12.271328390533093`, 6.276520412140793}, 
         0.05577520655383945], 
        DiskBox[{12.275071018488706`, 6.279417345503728}, 
         0.05577520655383945], 
        DiskBox[{12.278809363574346`, 6.282319803590272}, 
         0.05577520655383945], 
        DiskBox[{12.28254341763463, 6.2852277800685705`}, 
         0.05577520655383945], 
        DiskBox[{12.286273172523542`, 6.288141268594737}, 
         0.05577520655383945], 
        DiskBox[{12.289998620104445`, 6.291060262812856}, 
         0.05577520655383945], 
        DiskBox[{12.293719752250096`, 6.2939847563550035`}, 
         0.05577520655383945], 
        DiskBox[{12.297436560842671`, 6.296914742841256}, 
         0.05577520655383945], 
        DiskBox[{12.301149037773772`, 6.299850215879712}, 
         0.05577520655383945], 
        DiskBox[{12.304857174944457`, 6.302791169066495}, 
         0.05577520655383945], 
        DiskBox[{12.308560964265249`, 6.305737595985776}, 
         0.05577520655383945], 
        DiskBox[{12.312260397656152`, 6.308689490209785}, 
         0.05577520655383945], 
        DiskBox[{12.315955467046678`, 6.311646845298824}, 
         0.05577520655383945], 
        DiskBox[{12.323332481592228`, 6.317577912253629}, 
         0.05577520655383945], 
        DiskBox[{12.327014410653973`, 6.3205516111805125`}, 
         0.05577520655383945], 
        DiskBox[{12.330691943528759`, 6.323530745094644}, 
         0.05577520655383945], 
        DiskBox[{12.334365072193872`, 6.326515307496901}, 
         0.05577520655383945], 
        DiskBox[{12.33803378863621, 6.3295052918763215`}, 
         0.05577520655383945], 
        DiskBox[{12.341698084852293`, 6.33250069171011}, 0.05577520655383945],
         DiskBox[{12.345357952848286`, 6.335501500463661}, 
         0.05577520655383945], 
        DiskBox[{12.349013384640008`, 6.338507711590566}, 
         0.05577520655383945], 
        DiskBox[{12.352664372252963`, 6.341519318532632}, 
         0.05577520655383945], 
        DiskBox[{12.356310907722351`, 6.344536314719897}, 
         0.05577520655383945], 
        DiskBox[{12.359952983093077`, 6.347558693570639}, 
         0.05577520655383945], 
        DiskBox[{12.363590590419783`, 6.350586448491397}, 
         0.05577520655383945], 
        DiskBox[{12.367223721766845`, 6.353619572876968}, 
         0.05577520655383945], 
        DiskBox[{12.370852369208428`, 6.356658060110464}, 
         0.05577520655383945], 
        DiskBox[{12.374476524828466`, 6.359701903563273}, 
         0.05577520655383945], 
        DiskBox[{12.378096180720686`, 6.362751096595108}, 
         0.05577520655383945], 
        DiskBox[{12.381711328988636`, 6.365805632554006}, 
         0.05577520655383945], 
        DiskBox[{12.385321961745698`, 6.368865504776354}, 
         0.05577520655383945], 
        DiskBox[{12.388928071115105`, 6.371930706586893}, 
         0.05577520655383945], 
        DiskBox[{12.39252964922996, 6.375001231298741}, 0.05577520655383945], 
        DiskBox[{12.396126688233245`, 6.378077072213403}, 
         0.05577520655383945], 
        DiskBox[{12.399719180277852`, 6.381158222620783}, 
         0.05577520655383945], 
        DiskBox[{12.403307117526587`, 6.384244675799207}, 
         0.05577520655383945], 
        DiskBox[{12.406890492152195`, 6.387336425015429}, 
         0.05577520655383945], 
        DiskBox[{12.410469296337363`, 6.390433463524644}, 
         0.05577520655383945], 
        DiskBox[{12.414043522274778`, 6.393535784570529}, 
         0.05577520655383945], 
        DiskBox[{12.41761316216709, 6.396643381385221}, 0.05577520655383945], 
        DiskBox[{12.421178208226959`, 6.3997562471893445`}, 
         0.05577520655383945], 
        DiskBox[{12.424738652677064`, 6.402874375192037}, 
         0.05577520655383945], 
        DiskBox[{12.42829448775013, 6.405997758590953}, 0.05577520655383945], 
        DiskBox[{12.43184570568893, 6.409126390572283}, 0.05577520655383945], 
        DiskBox[{12.435392298746317`, 6.412260264310768}, 
         0.05577520655383945], 
        DiskBox[{12.43893425918522, 6.415399372969707}, 0.05577520655383945], 
        DiskBox[{12.442471579278696`, 6.4185437097009945`}, 
         0.05577520655383945], 
        DiskBox[{12.446004251309912`, 6.42169326764511}, 0.05577520655383945],
         DiskBox[{12.44953226757217, 6.42484803993114}, 0.05577520655383945], 
        DiskBox[{12.453055620368938`, 6.428008019676798}, 
         0.05577520655383945], 
        DiskBox[{12.456574302013854`, 6.4311731999884385`}, 
         0.05577520655383945], 
        DiskBox[{11.248394871012838`, 10.111820063980492`}, 
         0.05577520655383945], 
        DiskBox[{11.015623292365223`, 10.251209817585913`}, 
         0.05577520655383945], 
        DiskBox[{10.762669375699103`, 10.349324175758158`}, 
         0.05577520655383945], 
        DiskBox[{10.750388561725986`, 10.352872167916518`}, 
         0.05577520655383945], 
        DiskBox[{10.738079830761656`, 10.356322063892607`}, 
         0.05577520655383945], 
        DiskBox[{10.541150987991285`, 10.397565140782692`}, 
         0.05577520655383945], 
        DiskBox[{10.340605859777177`, 10.413801275046302`}, 
         0.05577520655383945], 
        DiskBox[{10.334215130464145`, 10.413903262462401`}, 
         0.05577520655383945], 
        DiskBox[{10.327824045144569`, 10.41397975444472}, 
         0.05577520655383945], 
        DiskBox[{10.321432705530553`, 10.414030749775913`}, 
         0.05577520655383945], 
        {RGBColor[0.85, 0.5, 0.5], Opacity[1], EdgeForm[{Hue[1, 1, 0.7], 
         Opacity[1]}], 
         DiskBox[{10.311845441812252`, 8.811896441105564}, 
          0.05577520655383945]}, 
        DiskBox[{7.2730134359148035`, 0.5405592237070991}, 
         0.05577520655383945], 
        DiskBox[{7.282200147401706, 0.5371898774838826}, 0.05577520655383945],
         DiskBox[{10.272045468067379`, 0.00008985641036751701}, 
         0.05577520655383945], 
        DiskBox[{10.301400633620878`, 6.165462684393219*^-6}, 
         0.05577520655383945], 
        DiskBox[{10.311185730651697`, 0.}, 0.05577520655383945], 
        DiskBox[{10.340540978361757`, 0.00004669827802139537}, 
         0.05577520655383945], 
        DiskBox[{10.350326006251636`, 0.00008399586206842002}, 
         0.05577520655383945], 
        DiskBox[{10.546000553014322`, 0.003111581212250414}, 
         0.05577520655383945], 
        DiskBox[{10.819729290078916`, 0.014648387273187069`}, 
         0.05577520655383945], 
        DiskBox[{12.451128651203469`, 5.425636488511375}, 
         0.05577520655383945], 
        DiskBox[{12.456127843597901`, 5.428799916038809}, 
         0.05577520655383945], 
        DiskBox[{12.625661449587522`, 5.542409539665323}, 
         0.05577520655383945], 
        DiskBox[{12.642532143203267`, 5.554414496952157}, 
         0.05577520655383945], 
        DiskBox[{12.64734092094383, 5.557860488095464}, 0.05577520655383945], 
        DiskBox[{12.676086226112313`, 5.578685246274855}, 
         0.05577520655383945], 
        DiskBox[{12.75417168464861, 5.637257620691621}, 0.05577520655383945], 
        DiskBox[{11.384704096015495`, 10.962375083187531`}, 
         0.05577520655383945], 
        DiskBox[{11.024793470173625`, 11.106953998293427`}, 
         0.05577520655383945], 
        DiskBox[{11.01563209308238, 11.109779908873996`}, 
         0.05577520655383945], 
        DiskBox[{11.006459515448341`, 11.112569249363222`}, 
         0.05577520655383945], 
        DiskBox[{10.997275883250184`, 11.11532197536963}, 
         0.05577520655383945], 
        DiskBox[{10.978876039953585`, 11.120717409282333`}, 
         0.05577520655383945], 
        DiskBox[{10.965048227531664`, 11.12466755011698}, 
         0.05577520655383945], 
        DiskBox[{10.937322929051268`, 11.132319246308672`}, 
         0.05577520655383945], 
        DiskBox[{10.904863798344232`, 11.140826090271808`}, 
         0.05577520655383945], 
        DiskBox[{10.816195977694846`, 11.161622939850563`}, 
         0.05577520655383945], 
        DiskBox[{10.745677083096643`, 11.175659159520842`}, 
         0.05577520655383945], 
        DiskBox[{10.636815775871263`, 11.193068077911922`}, 
         0.05577520655383945], 
        DiskBox[{10.450784082119943`, 11.211121344314712`}, 
         0.05577520655383945], 
        DiskBox[{10.364571476159705`, 11.214562470176498`}, 
         0.05577520655383945], 
        DiskBox[{10.313443327575252`, 9.612976344374983}, 
         0.05577520655383945], 
        DiskBox[{13.073918595785582`, 4.878286366390758}, 
         0.05577520655383945], 
        DiskBox[{13.07972554820704, 4.882370255364849}, 0.05577520655383945], 
        DiskBox[{13.085526462366392`, 4.886462716787225}, 
         0.05577520655383945], 
        DiskBox[{13.091321325608664`, 4.890563741729986}, 
         0.05577520655383945], 
        DiskBox[{13.097110125292089`, 4.894673321246553}, 
         0.05577520655383945], 
        DiskBox[{13.102892848788123`, 4.89879144637168}, 0.05577520655383945],
         DiskBox[{13.131714882387886`, 4.91950994103833}, 
         0.05577520655383945], 
        DiskBox[{13.137460884304433`, 4.923679150502103}, 
         0.05577520655383945], 
        DiskBox[{13.143200722006483`, 4.927856842296839}, 
         0.05577520655383945], 
        DiskBox[{13.148934382972321`, 4.93204300730871}, 0.05577520655383945],
         DiskBox[{13.154661854693678`, 4.936237636405391}, 
         0.05577520655383945], 
        DiskBox[{13.160383124675818`, 4.940440720436108}, 
         0.05577520655383945], 
        DiskBox[{13.166098180437503`, 4.944652250231622}, 
         0.05577520655383945], 
        DiskBox[{13.239822757114078`, 5.000166496726514}, 
         0.05577520655383945], 
        DiskBox[{13.245449510902205`, 5.004495294179112}, 
         0.05577520655383945], 
        DiskBox[{12.17455778980893, 11.419195377399136`}, 
         0.05577520655383945], 
        DiskBox[{12.164141634924349`, 11.426605573601819`}, 
         0.05577520655383945], 
        DiskBox[{12.153696001329495`, 11.433974157532539`}, 
         0.05577520655383945], 
        DiskBox[{12.143221055263346`, 11.441301011922599`}, 
         0.05577520655383945], 
        DiskBox[{12.132716963431358`, 11.448586020167424`}, 
         0.05577520655383945], 
        DiskBox[{12.122183893002852`, 11.455829066328398`}, 
         0.05577520655383945], 
        DiskBox[{12.111622011608317`, 11.463030035134729`}, 
         0.05577520655383945], 
        DiskBox[{12.101031487336774`, 11.470188811985263`}, 
         0.05577520655383945], 
        DiskBox[{12.090412488733072`, 11.477305282950326`}, 
         0.05577520655383945], 
        DiskBox[{12.079765184795239`, 11.484379334773521`}, 
         0.05577520655383945], 
        DiskBox[{12.06908974497175, 11.491410854873546`}, 
         0.05577520655383945], 
        DiskBox[{12.058386339158876`, 11.498399731345971`}, 
         0.05577520655383945], 
        DiskBox[{12.04765513769794, 11.505345852965032`}, 
         0.05577520655383945], 
        DiskBox[{11.966302450556613`, 11.556067908196049`}, 
         0.05577520655383945], 
        DiskBox[{11.883468800324396`, 11.604333558312664`}, 
         0.05577520655383945], 
        DiskBox[{11.872316387504341`, 11.610581036094382`}, 
         0.05577520655383945], 
        DiskBox[{11.861139140280883`, 11.616783973692616`}, 
         0.05577520655383945], 
        DiskBox[{11.849937236536382`, 11.62294227238957}, 
         0.05577520655383945], 
        DiskBox[{11.838710854545614`, 11.629055834177858`}, 
         0.05577520655383945], 
        DiskBox[{11.827460172972902`, 11.635124561762078`}, 
         0.05577520655383945], 
        DiskBox[{11.81618537086931, 11.641148358560333`}, 
         0.05577520655383945], 
        DiskBox[{11.804886627669749`, 11.647127128705804`}, 
         0.05577520655383945], 
        DiskBox[{11.793564123190166`, 11.653060777048239`}, 
         0.05577520655383945], 
        DiskBox[{11.782218037624643`, 11.658949209155502`}, 
         0.05577520655383945], 
        DiskBox[{11.770848551542567`, 11.664792331315045`}, 
         0.05577520655383945], 
        DiskBox[{11.759455845885718`, 11.670590050535427`}, 
         0.05577520655383945], 
        DiskBox[{11.748040101965424`, 11.676342274547768`}, 
         0.05577520655383945], 
        DiskBox[{11.736601501459644`, 11.682048911807238`}, 
         0.05577520655383945], 
        DiskBox[{11.725140226410112`, 11.6877098714945}, 0.05577520655383945],
         DiskBox[{11.713656459219395`, 11.693325063517168`}, 
         0.05577520655383945], 
        DiskBox[{11.702150382648044`, 11.698894398511227`}, 
         0.05577520655383945], 
        DiskBox[{11.69062217981163, 11.70441778784247}, 0.05577520655383945], 
        DiskBox[{11.679072034177878`, 11.70989514360789}, 
         0.05577520655383945], 
        DiskBox[{11.667500129563708`, 11.715326378637101`}, 
         0.05577520655383945], 
        DiskBox[{11.655906650132344`, 11.720711406493706`}, 
         0.05577520655383945], 
        DiskBox[{11.644291780390349`, 11.726050141476687`}, 
         0.05577520655383945], 
        DiskBox[{11.632655705184725`, 11.731342498621753`}, 
         0.05577520655383945], 
        DiskBox[{11.620998609699933`, 11.736588393702714`}, 
         0.05577520655383945], 
        DiskBox[{11.609320679454985`, 11.741787743232798`}, 
         0.05577520655383945], 
        DiskBox[{11.59762210030045, 11.746940464465998`}, 
         0.05577520655383945], 
        DiskBox[{11.585903058415541`, 11.752046475398377`}, 
         0.05577520655383945], 
        DiskBox[{11.562404332796696`, 11.762118042063133`}, 
         0.05577520655383945], 
        DiskBox[{11.53882599849176, 11.772001802086374`}, 
         0.05577520655383945], 
        DiskBox[{11.527007446936997`, 11.776873057518937`}, 
         0.05577520655383945], 
        DiskBox[{11.515169556461807`, 11.781697126282896`}, 
         0.05577520655383945], 
        DiskBox[{11.503312515462497`, 11.78647393160471}, 
         0.05577520655383945], 
        DiskBox[{11.491436512640128`, 11.791203397463036`}, 
         0.05577520655383945], 
        DiskBox[{11.479541736997552`, 11.79588544858991}, 
         0.05577520655383945], 
        DiskBox[{11.467628377836366`, 11.800520010471963`}, 
         0.05577520655383945], 
        DiskBox[{11.455696624753939`, 11.805107009351605`}, 
         0.05577520655383945], 
        DiskBox[{11.443746667640347`, 11.809646372228194`}, 
         0.05577520655383945], 
        DiskBox[{11.431778696675408`, 11.8141380268592}, 0.05577520655383945],
         DiskBox[{11.419792902325597`, 11.818581901761354`}, 
         0.05577520655383945], 
        DiskBox[{11.353560978544593`, 11.842166028965254`}, 
         0.05577520655383945], 
        DiskBox[{11.28682757233808, 11.864291382742737`}, 
         0.05577520655383945], 
        DiskBox[{11.274642853958165`, 11.868156603091453`}, 
         0.05577520655383945], 
        DiskBox[{11.188931681639719`, 11.893847894727474`}, 
         0.05577520655383945], 
        DiskBox[{11.17662983206093, 11.897322342494075`}, 
         0.05577520655383945], 
        DiskBox[{11.151985040589198`, 11.904123872770931`}, 
         0.05577520655383945], 
        DiskBox[{11.13964249091034, 11.907450847036976`}, 
         0.05577520655383945], 
        DiskBox[{11.12728676710228, 11.910728556530039`}, 
         0.05577520655383945], 
        DiskBox[{11.114918065802474`, 11.913956949086405`}, 
         0.05577520655383945], 
        DiskBox[{11.102536583854892`, 11.917135973327223`}, 
         0.05577520655383945], 
        DiskBox[{11.090142518306932`, 11.920265578659325`}, 
         0.05577520655383945], 
        DiskBox[{11.07773606640623, 11.923345715276032`}, 
         0.05577520655383945], 
        DiskBox[{11.065317425597565`, 11.926376334157936`}, 
         0.05577520655383945], 
        DiskBox[{11.05288679351969, 11.929357387073692`}, 
         0.05577520655383945], 
        DiskBox[{11.040444368002207`, 11.932288826580782`}, 
         0.05577520655383945], 
        DiskBox[{11.027990347062385`, 11.935170606026276`}, 
         0.05577520655383945], 
        DiskBox[{11.015524928902053`, 11.938002679547552`}, 
         0.05577520655383945], 
        DiskBox[{11.003048311904402`, 11.940785002073062`}, 
         0.05577520655383945], 
        DiskBox[{10.990560694630874`, 11.943517529323014`}, 
         0.05577520655383945], 
        DiskBox[{10.97806227581795, 11.946200217810098`}, 
         0.05577520655383945], 
        DiskBox[{10.965553254374038`, 11.948833024840175`}, 
         0.05577520655383945], 
        DiskBox[{10.953033829376263`, 11.95141590851295}, 
         0.05577520655383945], 
        DiskBox[{10.94050420006734, 11.95394882772264}, 0.05577520655383945], 
        DiskBox[{10.927964565852358`, 11.956431742158635`}, 
         0.05577520655383945], 
        DiskBox[{10.91541512629566, 11.958864612306138`}, 
         0.05577520655383945], 
        DiskBox[{10.902856081117607`, 11.961247399446783`}, 
         0.05577520655383945], 
        DiskBox[{10.877709973540123`, 11.96586257381994}, 
         0.05577520655383945], 
        DiskBox[{10.865123311333086`, 11.968094887603403`}, 
         0.05577520655383945], 
        DiskBox[{10.852527843883085`, 11.970276971483086`}, 
         0.05577520655383945], 
        DiskBox[{10.839923771643027`, 11.972408790731812`}, 
         0.05577520655383945], 
        DiskBox[{10.827311295202737`, 11.974490311422349`}, 
         0.05577520655383945], 
        DiskBox[{10.814690615285816`, 11.976521500427951`}, 
         0.05577520655383945], 
        DiskBox[{10.802061932746396`, 11.978502325422888`}, 
         0.05577520655383945], 
        DiskBox[{10.789425448565993`, 11.98043275488295}, 
         0.05577520655383945], 
        DiskBox[{10.776781363850258`, 11.982312758085962`}, 
         0.05577520655383945], 
        DiskBox[{10.764129879825829`, 11.984142305112266`}, 
         0.05577520655383945], 
        DiskBox[{10.73880551934294, 11.987649914971549`}, 
         0.05577520655383945], 
        DiskBox[{10.713453979227781`, 11.990955361171665`}, 
         0.05577520655383945], 
        DiskBox[{10.700768521068538`, 11.992532206640293`}, 
         0.05577520655383945], 
        DiskBox[{10.688076873321029`, 11.99405843329291}, 
         0.05577520655383945], 
        DiskBox[{10.67537923796884, 11.995534016840098`}, 
         0.05577520655383945], 
        DiskBox[{10.662675817090829`, 11.996958933798412`}, 
         0.05577520655383945], 
        DiskBox[{10.649966812857944`, 11.998333161490745`}, 
         0.05577520655383945], 
        DiskBox[{10.637252427529972`, 11.999656678046698`}, 
         0.05577520655383945], 
        DiskBox[{10.624532863452364`, 12.00092946240292}, 
         0.05577520655383945], 
        DiskBox[{10.611808323052959`, 12.002151494303451`}, 
         0.05577520655383945], 
        DiskBox[{10.599079008838798`, 12.00332275430004}, 
         0.05577520655383945], 
        DiskBox[{10.58634512339294, 12.00444322375245}, 0.05577520655383945], 
        DiskBox[{10.57360686937115, 12.005512884828763`}, 
         0.05577520655383945], 
        DiskBox[{10.541743452344061`, 12.007964641149236`}, 
         0.05577520655383945], 
        DiskBox[{10.5098571682612, 12.010098497068507`}, 0.05577520655383945],
         DiskBox[{10.497096962222512`, 12.01086297871776}, 
         0.05577520655383945], 
        DiskBox[{10.477951188726516`, 12.011914240340271`}, 
         0.05577520655383945], 
        DiskBox[{10.458799467318977`, 12.012850915784055`}, 
         0.05577520655383945], 
        DiskBox[{10.426868576769117`, 12.014157316331312`}, 
         0.05577520655383945], 
        DiskBox[{10.39492624531798, 12.01514520051619}, 0.05577520655383945], 
        DiskBox[{10.315041213338251`, 10.414056247644403`}, 
         0.05577520655383945], 
        DiskBox[{12.468159028762738`, 12.187337276205346`}, 
         0.05577520655383945], 
        DiskBox[{12.420820326295818`, 12.217115090934664`}, 
         0.05577520655383945], 
        DiskBox[{12.331821844316398`, 12.270651195327494`}, 
         0.05577520655383945], 
        DiskBox[{11.889743314928316`, 12.49340800818534}, 
         0.05577520655383945], 
        DiskBox[{11.87504405554281, 12.499673442302523`}, 
         0.05577520655383945], 
        DiskBox[{11.860319918343913`, 12.50588018661073}, 
         0.05577520655383945], 
        DiskBox[{11.621542721817173`, 12.597128554368117`}, 
         0.05577520655383945], 
        DiskBox[{11.54578460727768, 12.622497870336503`}, 
         0.05577520655383945], 
        DiskBox[{11.207026573374918`, 12.715989147256453`}, 
         0.05577520655383945], 
        DiskBox[{11.09766888963111, 12.739461924376908`}, 
         0.05577520655383945], 
        DiskBox[{10.89301534435976, 12.774916837331062`}, 
         0.05577520655383945], 
        DiskBox[{10.86137763684328, 12.779427598280106`}, 
         0.05577520655383945], 
        DiskBox[{10.845545538725613`, 12.781588283438044`}, 
         0.05577520655383945], 
        DiskBox[{10.829704946939064`, 12.783685792201137`}, 
         0.05577520655383945], 
        DiskBox[{10.782134731198223`, 12.789598931339746`}, 
         0.05577520655383945], 
        DiskBox[{10.734497155619367`, 12.794942341587038`}, 
         0.05577520655383945], 
        DiskBox[{10.70270471886239, 12.79818771772726}, 0.05577520655383945], 
        DiskBox[{10.623119201420327`, 12.805190540355685`}, 
         0.05577520655383945], 
        DiskBox[{10.607186222755981`, 12.806400532934477`}, 
         0.05577520655383945], 
        DiskBox[{10.591248543836162`, 12.807546954239289`}, 
         0.05577520655383945], 
        DiskBox[{10.575306418304011`, 12.808629786025186`}, 
         0.05577520655383945], 
        DiskBox[{10.527455899502238`, 12.811496577001789`}, 
         0.05577520655383945], 
        DiskBox[{10.511498525306905`, 12.81232488850685}, 
         0.05577520655383945], 
        DiskBox[{10.479574498675644`, 12.813790502673173`}, 
         0.05577520655383945], 
        DiskBox[{10.463608354300543`, 12.814427782009648`}, 
         0.05577520655383945], 
        DiskBox[{10.447639794666507`, 12.815001362321004`}, 
         0.05577520655383945], 
        DiskBox[{10.431669073908132`, 12.815511234478889`}, 
         0.05577520655383945], 
        DiskBox[{12.883242326203321`, 12.872715864663068`}, 
         0.05577520655383945], 
        DiskBox[{12.867021983282626`, 12.88294165943924}, 
         0.05577520655383945], 
        DiskBox[{12.850760975532388`, 12.893102664813522`}, 
         0.05577520655383945], 
        DiskBox[{12.834459561741427`, 12.903198719076716`}, 
         0.05577520655383945], 
        DiskBox[{12.818118001341606`, 12.913229661553299`}, 
         0.05577520655383945], 
        DiskBox[{12.801736554403707`, 12.923195332603976`}, 
         0.05577520655383945], 
        DiskBox[{12.785315481633312`, 12.933095573628233`}, 
         0.05577520655383945], 
        DiskBox[{12.768855044366594`, 12.942930227066864`}, 
         0.05577520655383945], 
        DiskBox[{12.752355504566246`, 12.952699136404446`}, 
         0.05577520655383945], 
        DiskBox[{12.73581712481723, 12.962402146171875`}, 
         0.05577520655383945], 
        DiskBox[{12.719240168322663`, 12.972039101948802`}, 
         0.05577520655383945], 
        DiskBox[{12.70262489889957, 12.981609850366116`}, 
         0.05577520655383945], 
        DiskBox[{12.685971580974742`, 12.991114239108366`}, 
         0.05577520655383945], 
        DiskBox[{11.955761492105465`, 13.328518668764897`}, 
         0.05577520655383945], 
        DiskBox[{11.937730189222702`, 13.33504082482095}, 
         0.05577520655383945], 
        DiskBox[{11.919673010896496`, 13.341490996459347`}, 
         0.05577520655383945], 
        DiskBox[{11.901590244501135`, 13.347869081027643`}, 
         0.05577520655383945], 
        DiskBox[{11.883482177818165`, 13.354174977020625`}, 
         0.05577520655383945], 
        DiskBox[{11.865349099031747`, 13.360408584081952`}, 
         0.05577520655383945], 
        DiskBox[{11.847191296724128`, 13.366569803005724`}, 
         0.05577520655383945], 
        DiskBox[{11.829009059870998`, 13.372658535738093`}, 
         0.05577520655383945], 
        DiskBox[{11.810802677836943`, 13.378674685378787`}, 
         0.05577520655383945]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaseStyle->{
    EdgeForm[
     GrayLevel[0]]},
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.6775727978698854`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: N-K-Modell \[Dash] Teil 4"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704872223864946`*^9, 3.670489147179757*^9, 
   3.6704896993111305`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Im vierten und letzten Teil dieses ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses wenden wir uns den zwei Modellbeschreibungen des regulatorischen \
Drei-Knoten-Systems aus Karlebach und Shamir (2008) zu, das wir im \
vorliegenden Kapitel sowohl \[UDoubleDot]ber Differenzialgleichungen als auch \
\[UDoubleDot]ber Boole\[CloseCurlyQuote]sche Netzwerke diskutiert haben. \n\n\
Wir beginnen mit der Beschreibung als System gekoppelter \
Differenzialgleichungen. Das im Kapitel beschriebene System hat die Form:"
}], "Text",
 CellChangeTimes->{{3.677398488612175*^9, 3.6773984948833866`*^9}, {
  3.677398531949052*^9, 3.6773985519638863`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"system1", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", "t"}], "]"}], "\[Equal]", " ", 
      RowBox[{
       RowBox[{"k1", "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"kzx", " ", 
           RowBox[{"z", "[", "t", "]"}]}]}], ")"}]}], " ", "-", " ", 
       RowBox[{"k2", " ", 
        RowBox[{"x", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], ",", "t"}], "]"}], "\[Equal]", " ", 
      RowBox[{
       RowBox[{"k3", " ", "kxy", " ", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"kxy", " ", 
            RowBox[{"x", "[", "t", "]"}]}]}], ")"}]}]}], " ", "-", " ", 
       RowBox[{"k4", " ", 
        RowBox[{"y", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"z", "[", "t", "]"}], ",", "t"}], "]"}], "\[Equal]", " ", 
      RowBox[{
       RowBox[{"k5", " ", "kxz", " ", 
        RowBox[{"x", "[", "t", "]"}], "kyz", " ", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"kxz", " ", 
              RowBox[{"x", "[", "t", "]"}]}]}], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"kyz", " ", 
              RowBox[{"y", "[", "t", "]"}]}]}], ")"}]}], ")"}]}]}], " ", "-", 
       " ", 
       RowBox[{"k6", " ", 
        RowBox[{"z", "[", "t", "]"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4933834436344147`*^9, 3.49338355597687*^9}, {
   3.49343244304958*^9, 3.49343254574219*^9}, {3.493432835266024*^9, 
   3.493432836369748*^9}, {3.493432886917738*^9, 3.49343288957787*^9}, {
   3.6063755492792377`*^9, 3.606375685596491*^9}, {3.606375738254534*^9, 
   3.60637573991092*^9}, 3.606375939612439*^9, {3.606375978763006*^9, 
   3.606375978948448*^9}}],

Cell["\<\
Die Parameterwerte und die Anfangsbedingungen entnehmen wir der Publikation \
Karlebach und Shamir (2008):\
\>", "Text",
 CellChangeTimes->{{3.6773985885927505`*^9, 3.6773986069851832`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"parList", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k1", "\[Rule]", " ", "2"}], ",", " ", 
     RowBox[{"k3", "\[Rule]", " ", "2"}], ",", " ", 
     RowBox[{"k5", "\[Rule]", " ", "15"}], ",", " ", 
     RowBox[{"k2", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"k4", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"k6", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"kxy", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"kxz", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"kyz", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"kzx", "\[Rule]", " ", "100"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.493432622106151*^9, 3.4934327438958883`*^9}, {
   3.493433361980501*^9, 3.493433436098955*^9}, {3.606375696074139*^9, 
   3.60637572814062*^9}, 3.606375943052082*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"init1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"z", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.493432798424872*^9, 3.4934328322460947`*^9}, {
   3.60637575920424*^9, 3.606375761899069*^9}, 3.606375944585752*^9, {
   3.6239172386711826`*^9, 3.6239172394823837`*^9}, 3.623917279340454*^9}],

Cell[TextData[{
 "Daraus l\[ADoubleDot]sst sich nun ein System von Differenzialgleichungen \
gem\[ADoubleDot]\[SZ] den Vorgaben des Befehls ",
 StyleBox["NDSolve",
  FontWeight->"Bold"],
 " konstruieren:"
}], "Text",
 CellChangeTimes->{{3.6774805054073224`*^9, 3.6774805276695614`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"system2", " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{"system1", ",", " ", "init1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.493432839644518*^9, 3.493432849124134*^9}, {
   3.4934329090238523`*^9, 3.4934329095900393`*^9}, 3.606375953442707*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol1", " ", "=", " ", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"system2", " ", "/.", " ", "parList"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.493432753486724*^9, 3.493432769059124*^9}, {
  3.4934328533553143`*^9, 3.493432879745103*^9}, {3.4934329402616873`*^9, 
  3.493432964289103*^9}, {3.4934330015253963`*^9, 3.4934330024537*^9}, {
  3.493433506548072*^9, 3.493433506587099*^9}, {3.6063758059538593`*^9, 
  3.606375808504033*^9}, {3.606376034102932*^9, 3.6063760364119062`*^9}}],

Cell[TextData[{
 "Das Ausf\[UDoubleDot]hren des folgenden ",
 StyleBox["Plot",
  FontWeight->"Bold"],
 "-Befehls ergibt Abb. 5.56a."
}], "Text",
 CellChangeTimes->{{3.6774805608276205`*^9, 3.6774805732764425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}], ",", 
       RowBox[{"z", "[", "t", "]"}]}], "}"}], " ", "/.", " ", "sol1"}], "]"}],
    ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", " ", "0.2"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dashed", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dotted", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "14", ",", "Plain"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<Zeit\>\"", ",", "\"\<Aktivit\[ADoubleDot]t\>\""}], "}"}]}], 
   ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "14", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.493432981655219*^9, 3.493433131865939*^9}, {
  3.493433489951692*^9, 3.493433492726921*^9}, {3.606375861561881*^9, 
  3.606375924460436*^9}, {3.606375994123104*^9, 3.606376025975079*^9}, {
  3.670489731619787*^9, 3.6704897346461926`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[2], Opacity[1.], LineBox[CompressedData["
1:eJwd13k8VF8bAHD7NtbKMkM1M4RoUaFInqddKUkS2iwlUdKqEiqFCC2U7BVR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      "]]}, 
    {GrayLevel[0], AbsoluteThickness[2], Opacity[1.], Dashing[{Small, Small}],
      LineBox[CompressedData["
1:eJwV13k8VF8UAHClhIQZknUso0giS9LmnFLaUBRFsu+J0oKSRFmjBVFRqFDW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      "]]}, 
    {GrayLevel[0], AbsoluteThickness[2], Opacity[1.], Dashing[{0, Small}], 
     LineBox[CompressedData["
1:eJwVhwk4FAgARqm21LqTI9qUq5KzRKX5lSNtJKwIYZSzdostJVbkqtxyTKVE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      "]], LineBox[CompressedData["
1:eJwV13c8lV8YAHCzkHWve5V178ulZIWiNJwnGtqiYZRsGnbZosiMMiIz+Slk
VDSkMkruvUYUyU6SFbKSSH6Hf3y+n3vf87zn3Oc85zmy1i5GdlwcHBwvODk4
lv8/1t23/63AEkpJXv5rRzYDT/cPii+h0uoRnp1J7cg+83EiSXMJHW7P5h+I
bUcXKHlq9o5L6METJ653oe3I62+ShcinJcQZ4if9zbkd7R3Y+kX9JAdYTCbS
uHXw880to2GnOaCK/0j8Xa12FFLpPN9jwwGmW9tu62i2o6qULGq0Kwdsafa+
ckK5HW07InBwOIIDdjg9nN0l0442lLaX3n3FAfdjWnsWl9rQ6kjvOLIcJ6iY
nf67vqoNDao+2z0zygnPFq8+St3UhuQCnOyUpznB6Pn5qRXqbehUvfw16z+c
YP4xzdFZuQ01nYuvbuLlgiURRNGUa0NlOa76hTQueNlrbBot0oauyyrvtDfk
guKxutmU4c9Ig5q5va2EC8z73Il9qZ+R39+Ija98ueHAUcWylNlWtJI0dPaY
Ei94mVm4evl+QrwNvHtXvV4Bdue+DI2KtKCF94UX4tz44Lbi7f6OuI/o+8ki
CRpNANLWOAd+1/6AdoY7O7EKV0G54rjFW1ITuvWvlF//jBCoK1m7c882IMF1
75xv2QlBNw8pMXi8AYUc+dA8eF4ITJKvOfMNNiD3zOH0695CENWap0u0NaDD
epKarbFCcHRS3zq8rAGtCPUzO1stBFvlh4e3BjUgbyHd/BvrhcHd4kCCkkgD
Mpd+e7BrWhii+o2dt22rRyNOk1NP54XBctpj0HpTPfKuoCff4BQBJHV46IZq
PUq09v+uJyIC2YU1gfP0evQxV+tynpIIcGT1LZB469F+rdyHnlYikDAR376v
qQ5tPRxNJjWKQEZBam/7uTrEvvOydOSTCOTE0lwe29Yhk8lhi+ouEfAJDnSP
sahDlxL25HuNiEC8jUmLiRH+fGxJ9ieXKJhMNP5Q21qHEja+KDtOE4VhksK9
LwJ1SLBSeVTuuCicXrlT8tCjWtSXfJQVaCIKX4KPi/54UIuee3hld5mLQuxL
dZWYe7XIet3bU4nWovCaa3fTtxT8eYxZA7+rKAz6KebUX8Ofn44omogUhT7P
3z7xp2pR6fyAa3mlKDzxvc0zJlSLYloED0lVi8LTPvWDqvy1yKZIc703UxSa
NnfHuvPUImHry1813ovC9SN+ZMEFNrJhU43udYrCh0rRGt8hNhK+vWvj9VlR
qDD2qtpdzUZ2Wlm/TFVIYBvoLBsWyEaRMVSRgA0kOHirWi/fj42KBsMVMzVJ
kNlWH9fsxUazyS7mA1tIoGzd+0LdlY3C/22vct9NAqPOSA4ZKzZ6wPx8PcqC
BKpT94xf6bPRuKmQ/OubJDjlMxwpKMhG5JKgHb3xJKjfMT1WwsdG2oIzJ7iT
SCAfYGF8hpeNAss7Ivalk8Dmpiv9zT8WEmXk/vyUR4J+boX455MspDmq93L8
DQlov3rSLdtYyOuytxHxiwSbudXaMnNZSHHUXzBsjgRRUdk7wu+xUJvplZqx
BRLY7ZmkX8xioS1akVtfcpFhQ3G6kWkaC839SJU7IUqGgd+btExvspCvacVU
lDIZhEcmxVV9WOjyphXxv63IkAF94eKHWUgtS+CQhR0ZbjrpuUccYKEeEZGV
7xzJ0OR/MoFjHwuhH6v94lzw+OtcfRb0WYgja72NagAZdMYFwhhbWeiqyKGN
NrfJkGNuWbh1HQtdG4lvfv+eDNZ25uRLPCwU8vl77cIHMrAEVytGc2FXb36j
+IkMio9m83M58PMZnY+udpLBhvPe7PBfJrpsxIjRHiLDpcuTlrd+MZFnWbFB
BqcYHC46UBc9yESXcnigjkcMRoWbPnd+Z6KLCSc2z60Ug4SfHZqq/Uzk7jyv
YCQsBhkt0fXtvUzkIqfHvUJKDL7ezz9h1sFEjpEfXjttEgMj7W8rfzcwkYMX
42nKZjHofTsh5FPPRPa2lwqYW8Vg5Ey+3r9aJrLVlUiV3SkGAg4a6mQWE1lN
WXp/OiQGTKXqb2feMJGZ2YTmDgcxWMExPXrzORMdVBLJFUwRg4pP4Wu2ZTOR
Kcsld326GPBysG7K/4fHt2/K3ZMpBgdOzbSJZjFRUFZsXtB9MZD8gD5M3mGi
J5KU/JliMQh93qj0KZWJpFdJFHXViUHnJ/06egITrc/zKfrzHsdPtT2pFc9E
2ns7isQ/ikGpCj3hUBwTGQanPjRsE4MNKddXh95kopAFmcfV/WJAE5YWXh3N
RKM/5J4ULIqByj/m72ehTPQnIvgJm4MC6tpR6bPXmGiFYv+TAW4KvDza0bwF
m7C995QQoEDwa+pIdTATHeta9zxBnAJhai0hC0F4PXzDnz+WoID/PrbnEWzn
NcPP30tTQPnUjuF7gUwUfuxBKR+DAp+mUveaXWaiV/UqZf4bKMBXwFvc68dE
7HPRZcmaFIg48M7FALuVb7zsmRYF5mZn04t9mWhi18OXE9vw+yzk6cf4MJH8
a43XtgYUiAyW9bf2YqLoQu3Kg1YUMCHt+eLvwURrLRWtCm0pUNUqSePELidL
cgk7UsA3rIga7o7H81rUb3SmgIXNG/kMNzwfvWrmUX8KxIme8x1xYaKxmaeO
xYEUWL2dZ3MIdmhODr9YMAV+vX2VRGCXCkYdaImgANzdss3KGf8+n482nkii
QEn6+jecTkz0NELf9XkKBe48Dzn56AITHd6uRVqTQYHxjNP+VthBd9cYt2dT
QCtmy7m680wkcUxgRieXAm7uZLUQ7OIVfxNS8imQ0CXhhbD7z39pNS+mAHnB
Mub1OSYKoH3wevWUAo+ivE8GYYt/eLNG5gUFXpg5pe7GNtC+b9ZTQYH4CxkR
n88y0dehpAXdtxS4H1Wslo3tmxqRdqeGAnl3jXd5YBdwOPVYNlCA5/zoszXY
u0ssAquaKJAx/1L4pyMT9dgZEnItFCjSYdUzsb3W6FVd/UyB61Pe41nYonUb
rb91UGAiY61bEHZegAL3rh4K7PsBRpbYeuqrs7O/UiBNZtsNPezOPr7dvN8p
MOIXrrAO++Kt+e92QxTYfDCNLIwtZDAaWvMD51fLsPFvBya6P9+9bt1PCnSa
9Q/0YaPCRlbYFAW2KCyxmrDbzlSdHfqF19un8Hclthu5RGDfHwpQM6xdS7AF
3mXn5/3F8dti1XOxs7wSDwpwUGGzS5HWHextSuFj57ipMJyjHHAbu6XLJ6Zu
BRWesvx5ErAv3Di/QUWACndWU9mx2Lx6p5uuC1Ehr8OBteyMmcNuY6JUaD05
tBSPvTkHyIcpVFj/id9pebwmU82SotVUuH8bCS3HOysof0xEigpHhv5252Bz
VVB/udCosE7gaVcxdqrbysQmWSpo7upcsTyfTfJ/tDUUqODe1WfaiN3QOvI5
VpEKI2tQcy+2fUSX95QyFTKQjesM9tK29xLGG6hwM/GNmgBez9vjFWUlmlSo
tmlaJYdda/zf34s6VFj0rl5tgl18ra8jdTsVfF3XqF7ETnku++INokKM1z5y
HPY5qcxLonuoUNQ7p9+MbXToi/HmfVRoNjG6Pou9NZCmaXGQCm8EUZoUzh/+
b2nj+UZUUD0WLnAee4LSVf/xOBXuHiy3vYXdtkcq/48JFVaXql2uws59kOyw
9wwV4uQzB2jL+eue2Nt3ngrc047Hx7HVsz+V87tQIV1hzHUt3g9rWinp6u5U
OBsVtc0Se1An3vSyNxV0yvlb27BDOW9+lLhGhakzDwe78X5z3tj4CMKpcK4u
V5+B9+cJO+EbDlFUOMibpXsOey37+oGnsVT4+TiUfxH73c2IasMMKoxFvyrT
wvu94A0ry+suFTgFTVrDsBNmVl7JyKbCi+m2oE5sW5PQHaMPqFDYEOAb5spE
PETws7DnVBjd/5s5ieuL3kP/3PImKgzZ1vAJX2Iipa8vQ783UyHtlIqsNzZZ
bMFW8DMVpDap5X7D7vP0kTXrpsLfSZn5ck8muqLrmfJrmArdjcLeod5MVNng
cl2FWxzCDdCGk/44PyiwKmmFOHAXmIr3YeeaiUZyCoiDTHdTmHMAE90YfBTW
KioO+nQqx3Vcfy04p64G0cThpe1jznZcr/9uuujToiMOH5ck173A9V4nzdve
31UcftnvGg3C50dBn8H3AQ9xeNT7zWFLLD4P1kvYHvUSB2uxj8QkNt+zF1Zr
L4vDtsnInfb4PGprnD/VFCUOBYUcSxaJ+PzmDjCWzxEHAdlo5/A0nG/nrkB9
tzjEFT7elZ+H39/akrX2qzjkBfzjvfqAiZ6ZIsMr/eJwUvdAiWk+E70wWDyj
/UMcPBcPs1cV4vmv9QnMnBOH6Y79eb6P8H7ocy2/KLYari09Cr6Cz98hM8vt
MvtWw9zh41xra5iIdgBtcX6yGq5ESjAscL+gv3Qq+I7/GqgIYZt2MVjItrVi
qvS4BPiv0njAd5aFdK9cfWpFSMKagA/59++zUJzL5EvBQUmQ8xnPcOpmoc8o
je/8iCS4q9kqHuxhIWnRvcfZY5Kw/VHOWqUvLJTzKG382owkjica1N/LQq8m
98oucUpBQvGTVKN+FhrwyAidlJYCuaQ7BOUHC231PnC01UgKUqJfPFk/x0J9
QfcG7pRLwbdDSsk3RNnIsyndtbpKCv598/bYTmIjASJxfqhaCgSKCt8NYWtW
hApr1knBzvANH5AYGwUvOmhXf5YC4UXzoEEqG8n7KoUOTUhB1LpbMjJSbGTv
8VBBgyENZh/OJxAKbDT/Jufh8bXSwC1OaL7CjiFn6viulwbT//bsPrmWjZ49
vnno7QZp2Nc1Uhe1jo1WTrhdOr4df/9erNn4ejbKvbDpnc9xaVgIdAhIVmOj
H3YvbN+EScNIfX572GY2EqzVu6EUJQ1+i24VMlvYSEWt/kVcjDTQ7R24SrAv
zPYI29yShjjt3judOmw0Gsrzgvs/aWjcJKijsB0754jQ7nJpWEoWGUwG3H8P
f3/KnJGGj3vJS/z7cP9/2KV3w5w0SLSmFURhqxXPCdxekAYmxJUJ7mcjZ99V
lo5cMlDgeGxO8AB+XkBDgF9UBqY3HF/iPcRGP5X9LfYry4DcSr1THYZsNOFE
XtlgJQMOqgmmQiZsdObosPOCrQyMx1ElLmK/31TZut5RBh6LRR3twC5YcLof
6iwDPror1O6ZspFjBHs3+MnAkuWF1E3mbNSbHRRSkiADxYp8nlst2Kixc5wz
hSkDukRByjcbNtKteHeWVSsDr5rce3Rs8XhZaR9mG2Tg/WzF3RvYkWf33zVu
kQHDlZU5OnZstOf3PRD6KgNoevXzMHs27m9OBwbNy0DwGxWS4Fl8v9lX99de
lQbnt26Wf+7ERso9j5yuqdOgtMTN4i92rntiz38babCJp42x05mNslKtKnt1
aFD0mnGUjX1r7Hew2R4aGCXd3t7iwkb+sfKrDp+hwX0BjpgWNzb6oyDgf8Ga
Bpc2eNwmu+P8LPs5GmlHAz0vDk1DbNdvZe+Z52nA5rITq8W20Toat9ObBtrC
mxNLPdhof3uAhFYsDT5KrWwOusRGTCebSOMEGqzKSxp9jr2La9+CWxINSPfU
k8exdZUp3UXpNPD09yow82QjjYAHmYoPaLC/UOeNKr6/rZH9vE76LQ2ct9/+
WuHNRgOO6trcv2hgtmOo8Ba+7/0k5ey1m6NB552rqm+x58pkTJkLNODTv609
gc0vtMo/iosOz/lSBwz8cX4+/l4lJkqHvPIa5gy2x5+UQ/LKdKjSnevSvozX
I4t0JlSNDkmdmrTT2CEHwl2HNOhgVRQ4fhU7Mf1SfMEWOtBLnu5owC7badi+
aQ8drtmbZ57C91GOSF673VZ06Ox5X20fhONv9PfMsaWDj4CEbCg2uWsqjN+R
DkZWguR72Ay13gcNznTgOXys5Cv2no9lE8f96ZBjqLF4/AobHfHT4CoNpMMx
7mg+d2wT+VwxyWA6fDE/nR+Nfc7zlnZPBB2+vqwqfYsdLenqb59EB4EH7n+V
ruL3fTsQzUqhA5+oTYM+dsaF03eUMuhwR7ZwyynsR+X734xn0yEruPxLFHaL
tQKfVzEdlAcHfQawJfM74sMa6NByqE8tIpiN3Jsz+h420WFbteetFGz2grVG
WzMdploCcvOxvQ/+eK/YQYedciKf6rE/jy3w1w7QgfTbyXBVCN6/4pUmU8N0
yKitkZPEDtUNyZEco4PN1NB/itjaNwR3n5+mQ1jqk5Jd2PtvC+O7FwHfe26T
fLA9C1wdUjgJvL7nra9hZ1V+jFHjJmBy1MI2Fnt+KLH7xAoCXG82+edir12c
4/mxkgDjlv74EmwjkrlKID8B+4N3nS7HztOh++UIEuAYSOJrxm45dCVrmzAB
/H6UkS5sDutv7EYRAop1YwIHsE0ic9bMkQkg+ZFq5rD5Ojc8M5AgoMgolC1x
jY02/Yzt7pIkQFfC5YgstiX3DI+bNAGvrRSiFLFLlUuNk+kEXP2koKCN3Y8k
/VRlCdj5kDdkO7boMf+sKjk8X4eeZD1sB3+YHFYg4GHbvR+HsONuZq25vI4A
oR0aisbY5dk8QF5PwOeVo9Im2COl9g73lQgwlKTXnsIWb2DFbFUh4NVxMXUr
bL2vSs/eqxJwOpV0xA7b+df1busNBPjUW687i10jc1QlSpMAFU9ZXlfsKY0S
Y/omvF6PiVUe2LQ9VL8SLQImTiXWXcLeb+aVtXczAdZmdXu8sS85t7M7txDQ
H8kX4IudeXXbpMtWAkobE539sesT09fwbCeAIVAhdRl77sESur2DAAep2pBA
bPkKKwcVRAC7n+NBELZh89uYSiDg+t6CqCvY/oMKz47pETAjT1W6ip27ENY9
pE/AbouQa8tuERnhCdhNQFWLXsayOeQPqpD2ElBwNvnislW2FBnfMyDgwL8m
vmWbHBT109lPQK+Hpvny+MGW7lkNBwh4lL/iwnL8mX/SKcGHCOBpV6Ivv599
OjNW5wgBP7JWhAZgt21zj/hpiOOzZjP9ltejQ/rKPSMCpleauPpgv/Jmepsf
I+ATETbjia222t2VdIKAug+9qheX1+eptCPzJAFP26uk3bDJx5hnAkwJuPg7
tMoJO2TK7eRGcwIGh69Ln8OevSl9ZPgUAT9d1NXssR03MPfcsSDggsH72eXf
t73BTfe4JQFI863n6eX3uSCtvcqagL2j54uW8+OVAFO1yoYAOy2FjOX8ydwr
LaPqQICt6/Ycg+X4AzWUb44E8PYaVy3nX0iIm2DyOQK2d4wnLOenQ1XNAo8z
3m9n5c5tWJ7/GbfpMhcC1AIuXljO7/3/pH64uhEQLP56/XL+q21z6+i6SMCv
1uxW0nK8dqmPcZ4EfPRbrOFfjuddwzbwJsAgq8KDc3l+T6RePPEj4LLLNPcE
3l+v1WqSrl/F+dWzg792uX40uN7QCyFAvZRnEPd4KPO8VNjcNQISW8ghT7FD
cl09bSMIaPe2WryDfVBO6vj2mwSMDxnOumGXV747OBVLwJajHZ/tsNXPuO7K
jSfAQ9/WzxRbLO3dRkoSAefPtvIDdgfVlTyaToCk1qtDAsvjPZEUyLpDQJ79
R4O/uL6VG73jNLlLQMjZLL5x7Ls3JCffZhNQE1r/uQnbkf9dY2o+jpf84XU8
9u+/EtEHXhCQ9qNvRhh7YvpAxJ8yAs5e6n22iOvt0EjAtZxXBERHz+8axe5o
+xrAXYnz89j7GhZ2+ZM855c1eH+V/DkbiB1yQcdQuQXXr3Rjz2+4/ot2mYit
+knAk95aVvjy+dMcKfJigoCj67pz3bC5al+tcpgiwM35o4UZ9vRzguftLwJK
4m8dUsZujR+a8f1L4POnTrcOn2dpB7xbR/hlwWHv6WJubMWXScm18rKQeXTD
T5MANmK5uT4xXysLujarFnWxHRX3NY6uk4XI9N3j8th5t+Z5RJRlobjjsd8E
Pm+VXE+7GmvIwvc0T4NQbGUFxt6uHbIw5iTZUYDPa7UbRTNjJ/B4+RSrQR82
0rJ5d4QUIQudvKGfZHB/UJlGXVP/SxYoIQ991XC/o1hJjTxsLgdH7C9KRuN+
6hDvqMzHcjkId1o8YX4Kr29n/1u2EgNQjChb8xiuZ5cZVadUGMAyfL1RHHtG
1rr8pyoDRrODC/8Y43rk8KWUqsEAfYOk95XYHDPthVabGfDlrznrCLaoYGPS
H30GZNG/ZLka4fzZ/uL8+tMMuGN0TqMc95cuadFiETcY0BnElRmJ+896Tvmf
+2MZ8FknVs8FW8mhrFYwngHHhpPnjbH7NQav3ExkgNcuzXwZbBMmTCSl4+eT
1ESKD+J6PTVdfz+fAYvizYM9uL8VNzALrWYygGKRvXIf7n89CiesQtkMeB4Z
aKeO3UQO22FQxwCVmaj21dhR3SUzde9xvEHEM4j7Zw4PIZvmT3h+Gw1sQ7FH
0itR3zcGJIX6GLIN2Ggv90mp7O8MsBzYQy7GznYcm7UbZIC6ks1ICvaZjZJF
wyMMeMq80X0Bu4XlIT05yYBx3bFGEraGmsBc8TQD4v6z27WwF9834jObL/5i
QHvFtsZ+7H0WDZFzcwygRfAplmLff2tjXzbPAO4fXLN3sXnWz+/0/8sAE2fr
jihsq5ibMrr/GBA7pvjpEnb59No/S0sMkNU3GTiD/T911qEc
      "]]}}, {}},
  AspectRatio->0.2,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Aktivit\[ADoubleDot]t\"", TraditionalForm], None}, {
     FormBox["\"Zeit\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[
    GrayLevel[0], 14, Plain],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    GrayLevel[0], 14, Bold],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 10}, {0, 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775727984158864`*^9}]
}, Open  ]],

Cell[TextData[{
 "F\[UDoubleDot]r die Beschreibung desselben Systems als Boole\
\[CloseCurlyQuote]sches Netzwerk kehren wir zur\[UDoubleDot]ck zu den zu \
Beginn dieses ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses eingef\[UDoubleDot]hrten Update-Routinen. Zuerst definieren wir \
die Boole\[CloseCurlyQuote]schen Funktionen der drei Knoten:"
}], "Text",
 CellChangeTimes->{{3.6774806186569223`*^9, 3.6774806283289385`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"updateSchemeX", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"updateSchemeY", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"updateSchemeZ", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.401338889245556*^9, 3.401338928869643*^9}, {
  3.4013394561041594`*^9, 3.4013394726537952`*^9}, {3.401339525639936*^9, 
  3.4013395286079273`*^9}, {3.606108718216188*^9, 3.60610873855087*^9}}],

Cell[TextData[{
 "Die Update-Regeln sind so abgefasst, dass sie die Netzwerkarchitektur \
bereits einbeziehen (z.B. die Unabh\[ADoubleDot]ngigkeit des Gens ",
 StyleBox["Y",
  FontSlant->"Italic"],
 " von ",
 StyleBox["Z",
  FontSlant->"Italic"],
 "; vgl. auch die Diskussion im Kapitel). Daher k\[ODoubleDot]nnen wir den \
oben eingef\[UDoubleDot]hrten Graphen ",
 StyleBox["g0",
  FontWeight->"Bold"],
 ", die Adjazenzmatrix ",
 StyleBox["ad0",
  FontWeight->"Bold"],
 ", den Anfangszustand ",
 StyleBox["init",
  FontWeight->"Bold"],
 " und die Update-Routine wiederverwenden. Einzig der Vektor aus Boole\
\[CloseCurlyQuote]schen Funktionen muss gem\[ADoubleDot]\[SZ] der obigen \
Zuweisung neu definiert werden:"
}], "Text",
 CellChangeTimes->{{3.6774806481273737`*^9, 3.6774806835394363`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"schemeX", "=", " ", 
   RowBox[{"{", 
    RowBox[{"updateSchemeX", ",", "updateSchemeY", ",", "updateSchemeZ"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.401338889245556*^9, 3.401338928869643*^9}, {
  3.4013394561041594`*^9, 3.4013394726537952`*^9}, {3.401339525639936*^9, 
  3.4013395286079273`*^9}, {3.6061315643221607`*^9, 3.60613158737481*^9}, {
  3.606272825050408*^9, 3.6062728340619307`*^9}}],

Cell[TextData[{
 "Ab da f\[UDoubleDot]hrt die \[UDoubleDot]bliche Verarbeitungssequenz auf \
den Attraktorgraphen, der bereits im Kapitel diskutiert worden ist. Die \
Darstellung der so erzeugten Liste ",
 StyleBox["asp2",
  FontWeight->"Bold"],
 " ergibt Abb. 5.54b."
}], "Text",
 CellChangeTimes->{{3.67748074822015*^9, 3.67748078225941*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"allStates", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"IntegerDigits", "[", 
      RowBox[{"j", ",", "2", ",", "3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "3"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"j", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "3"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"allStatesUpdated", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"updateGeneralFull", "[", 
       RowBox[{"#", ",", "2", ",", "schemeX", ",", "ad0"}], "]"}], "&"}], ",",
      " ", "allStates"}], "]"}]}], ";", 
  RowBox[{"allStatesPairs", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"allStates", ",", "allStatesUpdated"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labels2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"allStates", "\[Rule]", "labels"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelPairs", " ", "=", " ", 
   RowBox[{"allStatesPairs", " ", "/.", " ", "labels2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"asp2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "3"}], "]"}], "&"}],
        ",", "allStates"}], "]"}], "\[Rule]", " ", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerString", "[", 
         RowBox[{
          RowBox[{"FromDigits", "[", 
           RowBox[{"#", ",", "2"}], "]"}], ",", "2", ",", "3"}], "]"}], "&"}],
        ",", "allStatesUpdated"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"GraphPlot", "[", 
  RowBox[{"asp2", ",", 
   RowBox[{"Method", "\[Rule]", "\"\<SpringEmbedding\>\""}], ",", " ", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
   RowBox[{"EdgeRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"#1", ",", "0.1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", 
   RowBox[{"VertexRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"White", ",", 
        RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
        RowBox[{"Disk", "[", 
         RowBox[{"#", ",", ".15"}], "]"}], ",", "Black", ",", 
        RowBox[{"Text", "[", 
         RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.60637664803614*^9, {3.606379499486083*^9, 3.606379506094776*^9}, {
   3.642044462328117*^9, 3.642044463170589*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[
  TagBox[{{
     {GrayLevel[0], 
      ArrowBox[{{2.688617098940011, 1.5924479506466431`}, {
       1.8774070527486781`, 0.9776735102163483}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{1.8774070527486781`, 0.9776735102163483}, {
       2.2899413639048114`, 0.}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{2.9762481803847036`, 2.534826135088539}, {2.688617098940011, 
       1.5924479506466431`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{0.9177955377412137, 1.062056209420791}, {1.8774070527486781`,
        0.9776735102163483}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{3.5386580697378784`, 0.9694055740419785}, {2.688617098940011,
        1.5924479506466431`}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{2.2899413639048114`, 0.}, {3.286802150180141, 
       0.006028540475083721}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{0., 1.090038864674556}, {0.9177955377412137, 
       1.062056209420791}}, 0.1]}, 
     {GrayLevel[0], 
      ArrowBox[{{3.286802150180141, 0.006028540475083721}, {
       3.5386580697378784`, 0.9694055740419785}}, 0.1]}}, {
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.688617098940011, 1.5924479506466431`}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"000\"\>", {2.688617098940011, 1.5924479506466431`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.8774070527486781`, 0.9776735102163483}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"100\"\>", {1.8774070527486781`, 0.9776735102163483}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.9762481803847036`, 2.534826135088539}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"001\"\>", {2.9762481803847036`, 2.534826135088539}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.9177955377412137, 1.062056209420791}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"010\"\>", {0.9177955377412137, 1.062056209420791}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.5386580697378784`, 0.9694055740419785}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"011\"\>", {3.5386580697378784`, 0.9694055740419785}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.2899413639048114`, 0.}, 0.15], 
      {GrayLevel[0], InsetBox["\<\"110\"\>", {2.2899413639048114`, 0.}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0., 1.090038864674556}, 0.15], 
      {GrayLevel[0], InsetBox["\<\"101\"\>", {0., 1.090038864674556}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.286802150180141, 0.006028540475083721}, 0.15], 
      {GrayLevel[0], 
       InsetBox["\<\"111\"\>", {3.286802150180141, 0.006028540475083721}]}}}},
   Annotation[#, 
    VertexCoordinateRules -> {{2.688617098940011, 1.5924479506466431`}, {
     1.8774070527486781`, 0.9776735102163483}, {2.9762481803847036`, 
     2.534826135088539}, {0.9177955377412137, 1.062056209420791}, {
     3.5386580697378784`, 0.9694055740419785}, {2.2899413639048114`, 0.}, {0.,
      1.090038864674556}, {3.286802150180141, 0.006028540475083721}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.6775727984782867`*^9}]
}, Open  ]],

Cell["\<\
Die Verbindung zu der Beschreibung \[UDoubleDot]ber Differenzialgleichungen l\
\[ADoubleDot]sst sich nun durch die Simulation einer kurzen Zeitreihe \
herstellen:\
\>", "Text",
 CellChangeTimes->{{3.6774808049584494`*^9, 3.6774808257426863`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "=", " ", 
  RowBox[{"NestList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"updateGeneralFull", "[", 
      RowBox[{"#", ",", "2", ",", "schemeX", ",", "ad0"}], "]"}], "&"}], ",", 
    "init", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.401339932323998*^9, 3.4013399421242723`*^9}, {
   3.606134032617045*^9, 3.60613403539783*^9}, {3.606134075473246*^9, 
   3.606134104329802*^9}, {3.606272282153646*^9, 3.6062722918402977`*^9}, {
   3.606376759045586*^9, 3.606376763488377*^9}, {3.606379526704609*^9, 
   3.606379534206812*^9}, 3.60637963893777*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775727984938865`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", "res2", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Dashing", "[", "Large", "]"}], ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dotted", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "14", ",", "Plain"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<Zeit\>\"", ",", "\"\<Aktivit\[ADoubleDot]t\>\""}], "}"}]}], 
   ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "14", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.606109136149981*^9, 3.606109152811654*^9}, {
   3.6061092219066257`*^9, 3.606109257541757*^9}, {3.6061092999495373`*^9, 
   3.606109328522264*^9}, 3.6061349924432077`*^9, 3.606376767854393*^9, {
   3.606376798526587*^9, 3.606376798801681*^9}, {3.606379647409101*^9, 
   3.6063796922050858`*^9}, {3.606443715953456*^9, 3.6064437161748257`*^9}, 
   3.6420456272362843`*^9, {3.67048981292813*^9, 3.670489820322543*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[2], 
     LineBox[{{1., 0.}, {2., 1.}, {3., 1.}, {4., 1.}, {5., 0.}, {6., 0.}}]}, 
    {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[2], 
     Dashing[Large], 
     LineBox[{{1., 0.}, {2., 0.}, {3., 1.}, {4., 1.}, {5., 1.}, {6., 0.}}]}, 
    {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[2], 
     Dashing[{0, Small}], 
     LineBox[{{1., 0.}, {2., 0.}, {3., 0.}, {4., 1.}, {5., 1.}, {6., 
      0.}}]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Aktivit\[ADoubleDot]t\"", TraditionalForm], None}, {
     FormBox["\"Zeit\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[
    GrayLevel[0], 14, Plain],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    GrayLevel[0], 14, Bold],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 6.}, {0, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775727985874863`*^9}]
}, Open  ]],

Cell["\<\
Eine Erh\[ODoubleDot]hung der Interpolationsordnung auf 2 f\[UDoubleDot]hrt \
auf die im Kapitel diskutierte Abbildung (Abb. 5.56b).\
\>", "Text",
 CellChangeTimes->{{3.6774808806859827`*^9, 3.6774809065528283`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", "res2", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Dashing", "[", "Large", "]"}], ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dotted", ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "14", ",", "Plain"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<Zeit\>\"", ",", "\"\<Aktivit\[ADoubleDot]t\>\""}], "}"}]}], 
   ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "14", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.15"}], ",", "1.2"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.606109136149981*^9, 3.606109152811654*^9}, {
   3.6061092219066257`*^9, 3.606109257541757*^9}, {3.6061092999495373`*^9, 
   3.606109328522264*^9}, 3.6061349924432077`*^9, 3.606376767854393*^9, {
   3.606376798526587*^9, 3.606376798801681*^9}, {3.606379647409101*^9, 
   3.606379667280583*^9}, {3.6064437203434553`*^9, 3.606443720622237*^9}, {
   3.642045862374359*^9, 3.6420459008681097`*^9}, {3.670489867297226*^9, 
   3.670489867874427*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[2], 
     LineBox[CompressedData["
1:eJw9lXk81GsXwGcG2ZmxDC12detmSVEqnEO3MYqUrbxJlogusuemJISyVJQK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      "]]}, 
    {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[2], 
     Dashing[Large], LineBox[CompressedData["
1:eJw9lXk41esWx/c2hIi9bTYNZjkNJFOpg7VyThtFMkRubokUHSRTTnUkhDJU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      "]]}, 
    {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[2], 
     Dashing[{0, Small}], LineBox[CompressedData["
1:eJw1VXk41AsXHrITY5mhIrJUbqFQqXBOiyxZSkq6biFESbKXLsJFlrLEJWUK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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.921875, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Aktivit\[ADoubleDot]t\"", TraditionalForm], None}, {
     FormBox["\"Zeit\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[
    GrayLevel[0], 14, Plain],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    GrayLevel[0], 14, Bold],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1., 6.}, {-0.15, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677572798634287*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "34"], TraditionalForm]]],
 " Die Befehle ",
 StyleBox["Graph",
  FontWeight->"Bold"],
 " und ",
 StyleBox["GraphPlot",
  FontWeight->"Bold"],
 " wechseln das Default-Layout ab einer bestimmten \
Graphengr\[ODoubleDot]\[SZ]e. Dies wurde hier mit einer Reihe von \
Formatierungsoptionen umgangen."
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.674621151407549*^9, 3.6746211807235928`*^9}, {
   3.674622662511799*^9, 3.6746227213398905`*^9}, 3.674622755272942*^9, {
   3.6771332497970695`*^9, 3.6771332889727383`*^9}, {3.677397498260234*^9, 
   3.67739750751105*^9}, {3.6773975387493057`*^9, 3.6773975615877457`*^9}, {
   3.6773975998546133`*^9, 3.6773976298846655`*^9}, {3.6774853377815075`*^9, 
   3.677485341697114*^9}}]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{606, Automatic}, {194, Automatic}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.938, 842}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 373, 10, 94, "Subtitle"],
Cell[1829, 72, 753, 20, 163, "Text"],
Cell[2585, 94, 280, 7, 31, "Input"],
Cell[2868, 103, 654, 17, 72, "Input"],
Cell[3525, 122, 423, 10, 87, "Text"],
Cell[CellGroupData[{
Cell[3973, 136, 320, 8, 31, "Input"],
Cell[4296, 146, 331, 11, 31, "Output"]
}, Open  ]],
Cell[4642, 160, 128, 1, 30, "Text"],
Cell[4773, 163, 132, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[4930, 170, 452, 11, 52, "Input"],
Cell[5385, 183, 331, 11, 31, "Output"]
}, Open  ]],
Cell[5731, 197, 135, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[5891, 202, 1302, 30, 192, "Input"],
Cell[7196, 234, 1370, 44, 102, "Output"]
}, Open  ]],
Cell[8581, 281, 766, 14, 163, "Text"],
Cell[CellGroupData[{
Cell[9372, 299, 627, 13, 72, "Input"],
Cell[10002, 314, 3190, 62, 367, "Output"]
}, Open  ]],
Cell[13207, 379, 221, 4, 49, "Text"],
Cell[13431, 385, 261, 7, 31, "Input"],
Cell[13695, 394, 1432, 44, 277, "Text"],
Cell[15130, 440, 2278, 54, 192, "Input"],
Cell[17411, 496, 269, 5, 49, "Text"],
Cell[17683, 503, 701, 15, 92, "Input"],
Cell[18387, 520, 292, 5, 68, "Text"],
Cell[18682, 527, 205, 5, 31, "Input"],
Cell[18890, 534, 446, 9, 52, "Input"],
Cell[19339, 545, 180, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[19544, 553, 434, 9, 52, "Input"],
Cell[19981, 564, 856, 25, 72, "Output"]
}, Open  ]],
Cell[20852, 592, 253, 5, 68, "Text"],
Cell[21108, 599, 658, 21, 72, "Input"],
Cell[21769, 622, 219, 4, 49, "Text"],
Cell[21991, 628, 292, 8, 72, "Input"],
Cell[22286, 638, 355, 8, 87, "Text"],
Cell[22644, 648, 1194, 35, 212, "Input"],
Cell[23841, 685, 269, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[24135, 696, 1230, 28, 152, "Input"],
Cell[25368, 726, 3232, 67, 279, "Output"]
}, Open  ]],
Cell[28615, 796, 314, 9, 106, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28966, 810, 394, 10, 94, "Subtitle"],
Cell[29363, 822, 676, 17, 108, "Text"],
Cell[30042, 841, 790, 20, 92, "Input"],
Cell[30835, 863, 396, 11, 68, "Text"],
Cell[31234, 876, 199, 4, 47, "Input"],
Cell[31436, 882, 214, 5, 52, "Input"],
Cell[CellGroupData[{
Cell[31675, 891, 482, 11, 72, "Input"],
Cell[32160, 904, 6249, 110, 278, "Output"]
}, Open  ]],
Cell[38424, 1017, 265, 5, 31, "Input"],
Cell[38692, 1024, 280, 6, 31, "Input"],
Cell[38975, 1032, 400, 11, 87, "Text"],
Cell[39378, 1045, 2678, 72, 332, "Input"],
Cell[42059, 1119, 422, 10, 51, "Text"],
Cell[CellGroupData[{
Cell[42506, 1133, 836, 15, 92, "Input"],
Cell[43345, 1150, 145268, 2681, 446, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[188662, 3837, 396, 10, 94, "Subtitle"],
Cell[189061, 3849, 641, 12, 163, "Text"],
Cell[189705, 3863, 522, 11, 72, "Input"],
Cell[190230, 3876, 1519, 45, 132, "Input"],
Cell[191752, 3923, 1304, 40, 112, "Input"],
Cell[193059, 3965, 721, 22, 72, "Input"],
Cell[193783, 3989, 474, 8, 144, "Text"],
Cell[194260, 3999, 690, 15, 52, "Input"],
Cell[194953, 4016, 647, 15, 52, "Input"],
Cell[195603, 4033, 650, 15, 52, "Input"],
Cell[CellGroupData[{
Cell[196278, 4052, 1780, 44, 292, "Input"],
Cell[198061, 4098, 14234, 265, 366, "Output"]
}, Open  ]],
Cell[212310, 4366, 582, 13, 125, "Text"],
Cell[CellGroupData[{
Cell[212917, 4383, 666, 20, 112, "Input"],
Cell[213586, 4405, 1815, 47, 206, "Output"]
}, Open  ]],
Cell[215416, 4455, 348, 8, 87, "Text"],
Cell[215767, 4465, 1575, 42, 172, "Input"],
Cell[217345, 4509, 192, 4, 49, "Text"],
Cell[217540, 4515, 408, 9, 31, "Input"],
Cell[217951, 4526, 305, 5, 87, "Text"],
Cell[218259, 4533, 460, 12, 92, "Input"],
Cell[218722, 4547, 283, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[219030, 4558, 1223, 31, 148, "Input"],
Cell[220256, 4591, 2536, 61, 260, "Output"]
}, Open  ]],
Cell[222807, 4655, 932, 17, 220, "Text"],
Cell[223742, 4674, 2295, 69, 348, "Input"],
Cell[226040, 4745, 241, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[226306, 4756, 533, 11, 92, "Input"],
Cell[226842, 4769, 332599, 6060, 294, 296790, 5471, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[559456, 10832, 259, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[559740, 10841, 174, 4, 52, "Input"],
Cell[559917, 10847, 178, 5, 31, "Output"]
}, Open  ]],
Cell[560110, 10855, 355, 8, 87, "Text"],
Cell[560468, 10865, 1638, 33, 172, "Input"],
Cell[562109, 10900, 451, 13, 87, "Text"],
Cell[CellGroupData[{
Cell[562585, 10917, 948, 23, 192, "Input"],
Cell[563536, 10942, 504081, 8228, 418, 434889, 7092, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1067666, 19176, 396, 10, 94, "Subtitle"],
Cell[1068065, 19188, 676, 12, 201, "Text"],
Cell[1068744, 19202, 2160, 58, 172, "Input"],
Cell[1070907, 19262, 200, 4, 49, "Text"],
Cell[1071110, 19268, 818, 17, 72, "Input"],
Cell[1071931, 19287, 563, 14, 31, "Input"],
Cell[1072497, 19303, 286, 7, 49, "Text"],
Cell[1072786, 19312, 297, 6, 31, "Input"],
Cell[1073086, 19320, 698, 14, 52, "Input"],
Cell[1073787, 19336, 214, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[1074026, 19346, 1887, 48, 212, "Input"],
Cell[1075916, 19396, 40594, 681, 124, "Output"]
}, Open  ]],
Cell[1116525, 20080, 442, 9, 87, "Text"],
Cell[1116970, 20091, 699, 17, 72, "Input"],
Cell[1117672, 20110, 798, 22, 163, "Text"],
Cell[1118473, 20134, 446, 9, 52, "Input"],
Cell[1118922, 20145, 344, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[1119291, 20157, 3164, 91, 488, "Input"],
Cell[1122458, 20250, 3228, 67, 271, "Output"]
}, Open  ]],
Cell[1125701, 20320, 256, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[1125982, 20329, 592, 12, 92, "Input"],
Cell[1126577, 20343, 511, 15, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1127125, 20363, 1668, 36, 212, "Input"],
Cell[1128796, 20401, 1925, 46, 243, "Output"]
}, Open  ]],
Cell[1130736, 20450, 226, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[1130987, 20458, 1947, 46, 228, "Input"],
Cell[1132937, 20506, 10040, 182, 250, "Output"]
}, Open  ]],
Cell[1142992, 20691, 805, 20, 78, "Text"]
}, Open  ]]
}
]
*)

